@@ -39,8 +39,8 @@
 #include <QCryptographicHash>
 #include <QMutex>
 #include <QMutexLocker>
+#include <QString>
 #include <QTime>
-#include <QDebug>
 
 #include "FileTypeResolver.h"
 #include "MetaReplayGain.h"
@@ -113,13 +113,13 @@ Meta::Tag::addRandomness( QCryptographicHash *md5 )
 {
     //md5 has size of file already added for some little extra randomness for the hash
     qsrand( QTime::currentTime().msec() );
-    md5->addData( QString::number( qrand() ).toAscii() );
-    md5->addData( QString::number( qrand() ).toAscii() );
-    md5->addData( QString::number( qrand() ).toAscii() );
-    md5->addData( QString::number( qrand() ).toAscii() );
-    md5->addData( QString::number( qrand() ).toAscii() );
-    md5->addData( QString::number( qrand() ).toAscii() );
-    md5->addData( QString::number( qrand() ).toAscii() );
+    md5->addData( QString::number( qrand() ).toLatin1() );
+    md5->addData( QString::number( qrand() ).toLatin1() );
+    md5->addData( QString::number( qrand() ).toLatin1() );
+    md5->addData( QString::number( qrand() ).toLatin1() );
+    md5->addData( QString::number( qrand() ).toLatin1() );
+    md5->addData( QString::number( qrand() ).toLatin1() );
+    md5->addData( QString::number( qrand() ).toLatin1() );
 }
 
 TagLib::ByteVector
@@ -152,7 +152,6 @@ Meta::Tag::generateUniqueId( const QString &path )
 
     char databuf[16384];
     int readlen = 0;
-    QString returnval;
 
     if( qfile.open( QIODevice::ReadOnly ) )
     {
@@ -170,7 +169,7 @@ Meta::Tag::generateUniqueId( const QString &path )
     else
         addRandomness( &md5 );
 
-    return QString( md5.result().toHex() );
+    return QString::fromLatin1( md5.result().toHex() );
 }
 
 
@@ -257,7 +256,7 @@ Meta::Tag::readTags( const QString &path, bool /*useCharsetDetector*/ )
     //we didn't set a FileType till now, let's look it up via FileExtension
     if( !result.contains( Meta::valFormat ) )
     {
-        QString ext = path.mid( path.lastIndexOf( '.' ) + 1 );
+        QString ext = path.mid( path.lastIndexOf( QLatin1Char('.') ) + 1 );
         result.insert( Meta::valFormat, Amarok::FileTypeSupport::fileType( ext ) );
     }
 
