@@ -30,7 +30,7 @@
 #include "core/capabilities/MultiPlayableCapability.h"
 #include "core/capabilities/MultiSourceCapability.h"
 #include "core/capabilities/SourceInfoCapability.h"
-#include "core/interfaces/Logger.h"
+#include "core/logger/Logger.h"
 #include "core/meta/Meta.h"
 #include "core/meta/support/MetaConstants.h"
 #include "core/meta/support/MetaUtility.h"
@@ -42,16 +42,20 @@
 #include "playback/PowerManager.h"
 #include "playlist/PlaylistActions.h"
 
-#include <KLocale>
-
-#include <Phonon/AudioOutput>
-#include <Phonon/BackendCapabilities>
-#include <Phonon/MediaObject>
-#include <Phonon/VolumeFaderEffect>
+#include <phonon/AudioOutput>
+#include <phonon/BackendCapabilities>
+#include <phonon/MediaObject>
+#include <phonon/VolumeFaderEffect>
 
 #include <QCoreApplication>
-#include <QTextDocument> // for Qt::escape
-#include <qmath.h>
+#include <QUrlQuery>
+#include <QTimer>
+#include <QtMath>
+
+#include <KLocalizedString>
+
+#include <thread>
+
 
 // for slotMetaDataChanged()
 typedef QPair<Phonon::MetaData, QString> FieldPair;
@@ -85,13 +89,14 @@ EngineController::EngineController()
     DEBUG_BLOCK
     // ensure this object is created in a main thread
     Q_ASSERT( thread() == QCoreApplication::instance()->thread() );
-    connect( this, SIGNAL(fillInSupportedMimeTypes()), SLOT(slotFillInSupportedMimeTypes()) );
-    connect( this, SIGNAL(trackFinishedPlaying(Meta::TrackPtr,double)),
-             SLOT(slotTrackFinishedPlaying(Meta::TrackPtr,double)) );
+
+    connect( this, &EngineController::fillInSupportedMimeTypes, this, &EngineController::slotFillInSupportedMimeTypes );
+    connect( this, &EngineController::trackFinishedPlaying, this, &EngineController::slotTrackFinishedPlaying );
+
     new PowerManager( this ); // deals with inhibiting suspend etc.
 
     m_pauseTimer->setSingleShot( true );
-    connect( m_pauseTimer, SIGNAL(timeout()), SLOT(slotPause() ) );
+    connect( m_pauseTimer, &QTimer::timeout, this, &EngineController::slotPause );
     m_equalizerController = new EqualizerController( this );
 }
 
@@ -103,8 +108,8 @@ EngineController::~EngineController()
     // the media is stopped - that's what endSession() is for
     if( m_media )
     {
-        m_media.data()->blockSignals(true);
-        m_media.data()->stop();
+        m_media->blockSignals(true);
+        m_media->stop();
     }
 
     delete m_boundedPlayback;
@@ -139,11 +144,11 @@ EngineController::initializePhonon()
 
     // Enable zeitgeist support on linux
     //TODO: make this configurable by the user.
-    m_media.data()->setProperty( "PlaybackTracking", true );
+    m_media->setProperty( "PlaybackTracking", true );
 
     m_audio = new AudioOutput( MusicCategory, this );
     m_audioDataOutput = new AudioDataOutput( this );
-    m_audioDataOutput.data()->setDataSize( DATAOUTPUT_DATA_SIZE ); // The number of samples that Phonon sends per signal
+    m_audioDataOutput->setDataSize( DATAOUTPUT_DATA_SIZE ); // The number of samples that Phonon sends per signal
 
     m_path = createPath( m_media.data(), m_audio.data() );
 
@@ -186,29 +191,19 @@ EngineController::initializePhonon()
     // Get the next track when there is 2 seconds left on the current one.
     m_media.data()->setPrefinishMark( 2000 );
 
-    connect( m_media.data(), SIGNAL(finished()), SLOT(slotFinished()));
-    connect( m_media.data(), SIGNAL(aboutToFinish()), SLOT(slotAboutToFinish()) );
-    connect( m_media.data(), SIGNAL(metaDataChanged()), SLOT(slotMetaDataChanged()) );
-    connect( m_media.data(), SIGNAL(stateChanged(Phonon::State,Phonon::State)),
-             SLOT(slotStateChanged(Phonon::State,Phonon::State)) );
-    connect( m_media.data(), SIGNAL(tick(qint64)), SLOT(slotTick(qint64)) );
-    connect( m_media.data(), SIGNAL(totalTimeChanged(qint64)),
-             SLOT(slotTrackLengthChanged(qint64)) );
-    connect( m_media.data(), SIGNAL(currentSourceChanged(Phonon::MediaSource)),
-             SLOT(slotNewTrackPlaying(Phonon::MediaSource)) );
-    connect( m_media.data(), SIGNAL(seekableChanged(bool)),
-             SLOT(slotSeekableChanged(bool)) );
-    connect( m_audio.data(), SIGNAL(volumeChanged(qreal)),
-             SLOT(slotVolumeChanged(qreal)) );
-    connect( m_audio.data(), SIGNAL(mutedChanged(bool)),
-             SLOT(slotMutedChanged(bool)) );
-    connect( m_audioDataOutput.data(),
-             SIGNAL(dataReady(QMap<Phonon::AudioDataOutput::Channel,QVector<qint16> >)),
-             SIGNAL(audioDataReady(QMap<Phonon::AudioDataOutput::Channel,QVector<qint16> >))
-           );
+    connect( m_media.data(), &MediaObject::finished, this, &EngineController::slotFinished );
+    connect( m_media.data(), &MediaObject::aboutToFinish, this, &EngineController::slotAboutToFinish );
+    connect( m_media.data(), &MediaObject::metaDataChanged, this, &EngineController::slotMetaDataChanged );
+    connect( m_media.data(), &MediaObject::stateChanged, this, &EngineController::slotStateChanged );
+    connect( m_media.data(), &MediaObject::tick, this, &EngineController::slotTick );
+    connect( m_media.data(), &MediaObject::totalTimeChanged, this, &EngineController::slotTrackLengthChanged );
+    connect( m_media.data(), &MediaObject::currentSourceChanged, this, &EngineController::slotNewTrackPlaying );
+    connect( m_media.data(), &MediaObject::seekableChanged, this, &EngineController::slotSeekableChanged );
+    connect( m_audio.data(), &AudioOutput::volumeChanged, this, &EngineController::slotVolumeChanged );
+    connect( m_audio.data(), &AudioOutput::mutedChanged, this, &EngineController::slotMutedChanged );
+    connect( m_audioDataOutput.data(), &AudioDataOutput::dataReady, this, &EngineController::audioDataReady );
 
-    connect( m_controller.data(), SIGNAL(titleChanged(int)),
-             SLOT(slotTitleChanged(int)) );
+    connect( m_controller.data(), &MediaController::titleChanged, this, &EngineController::slotTitleChanged );
 
     // Read the volume from phonon
     m_volume = qBound<qreal>( 0, qRound(m_audio.data()->volume()*100), 100 );
@@ -237,7 +232,7 @@ EngineController::supportedMimeTypes()
     // this ensures that slotFillInSupportedMimeTypes() is called in the main thread. It
     // will be called directly if we are called in the main thread (so that no deadlock
     // can occur) and indirectly if we are called in non-main thread.
-    emit fillInSupportedMimeTypes();
+    Q_EMIT fillInSupportedMimeTypes();
 
     // ensure slotFillInSupportedMimeTypes() called above has already finished:
     m_supportedMimeTypesSemaphore.acquire();
@@ -287,11 +282,11 @@ EngineController::restoreSession()
 
     if( AmarokConfig::resumePlayback() )
     {
-        const KUrl url = AmarokConfig::resumeTrack();
+        const QUrl url = QUrl::fromUserInput(AmarokConfig::resumeTrack());
         Meta::TrackPtr track = CollectionManager::instance()->trackForUrl( url );
 
         // Only give a resume time for local files, because resuming remote protocols can have weird side effects.
-        // See: http://bugs.kde.org/show_bug.cgi?id=172897
+        // See: https://bugs.kde.org/show_bug.cgi?id=172897
         if( url.isLocalFile() )
             play( track, AmarokConfig::resumeTime(), AmarokConfig::resumePaused() );
         else
@@ -305,13 +300,13 @@ EngineController::endSession()
     //only update song stats, when we're not going to resume it
     if ( !AmarokConfig::resumePlayback() && m_currentTrack )
     {
-        emit stopped( trackPositionMs(), m_currentTrack->length() );
+        Q_EMIT stopped( trackPositionMs(), m_currentTrack->length() );
         unsubscribeFrom( m_currentTrack );
         if( m_currentAlbum )
             unsubscribeFrom( m_currentAlbum );
-        emit trackChanged( Meta::TrackPtr( 0 ) );
+        Q_EMIT trackChanged( Meta::TrackPtr( 0 ) );
     }
-    emit sessionEnded( AmarokConfig::resumePlayback() && m_currentTrack );
+    Q_EMIT sessionEnded( AmarokConfig::resumePlayback() && m_currentTrack );
 }
 
 EqualizerController*
@@ -344,9 +339,9 @@ EngineController::play() //SLOT
         {
             m_pauseTimer->stop();
             if( supportsFadeout() )
-                m_fader.data()->setVolume( 1.0 );
-            m_media.data()->play();
-            emit trackPlaying( m_currentTrack );
+                m_fader->setVolume( 1.0 );
+            m_media->play();
+            Q_EMIT trackPlaying( m_currentTrack );
             return;
         }
     }
@@ -376,8 +371,8 @@ EngineController::play( Meta::TrackPtr track, uint offset, bool startPaused )
 
     if( m_multiPlayback )
     {
-        connect( m_multiPlayback, SIGNAL(playableUrlFetched(KUrl)),
-                 SLOT(slotPlayableUrlFetched(KUrl)) );
+        connect( m_multiPlayback, &Capabilities::MultiPlayableCapability::playableUrlFetched,
+                 this, &EngineController::slotPlayableUrlFetched );
         m_multiPlayback->fetchFirst();
     }
     else if( m_boundedPlayback )
@@ -398,23 +393,23 @@ EngineController::replay() // slot
     DEBUG_BLOCK
 
     seekTo( 0 );
-    emit trackPositionChanged( 0, true );
+    Q_EMIT trackPositionChanged( 0, true );
 }
 
 void
-EngineController::playUrl( const KUrl &url, uint offset, bool startPaused )
+EngineController::playUrl( const QUrl &url, uint offset, bool startPaused )
 {
     DEBUG_BLOCK
 
-    m_media.data()->stop();
+    m_media->stop();
 
     debug() << "URL: " << url << url.url();
     debug() << "Offset: " << offset;
 
     m_currentAudioCdTrack = 0;
-    if( url.protocol() == "audiocd" )
+    if( url.scheme() == "audiocd" )
     {
-        QStringList pathItems = url.path().split( '/', QString::KeepEmptyParts );
+        QStringList pathItems = url.path().split( QLatin1Char('/'), QString::KeepEmptyParts );
         if( pathItems.count() != 3 )
         {
             error() << __PRETTY_FUNCTION__ << url.url() << "is not in expected format";
@@ -427,54 +422,51 @@ EngineController::playUrl( const KUrl &url, uint offset, bool startPaused )
             error() << __PRETTY_FUNCTION__ << "failed to get positive track number from" << url.url();
             return;
         }
-        QString device = url.queryItem( "device" );
+        QString device = QUrlQuery(url).queryItemValue( "device" );
 
-        m_media.data()->setCurrentSource( Phonon::MediaSource( Phonon::Cd, device ) );
+        m_media->setCurrentSource( Phonon::MediaSource( Phonon::Cd, device ) );
         m_currentAudioCdTrack = trackNumber;
     }
     else
     {
         // keep in sync with setNextTrack(), slotPlayableUrlFetched()
-        if( url.isLocalFile() )
-            m_media.data()->setCurrentSource( url.toLocalFile() );
-        else
-            m_media.data()->setCurrentSource( url );
+        m_media->setCurrentSource( url );
     }
 
-    m_media.data()->clearQueue();
+    m_media->clearQueue();
 
     if( m_currentAudioCdTrack )
     {
         // call to play() is asynchronous and ->setCurrentTitle() can be only called on
         // playing, buffering or paused media.
-        m_media.data()->pause();
+        m_media->pause();
         DelayedTrackChanger *trackChanger = new DelayedTrackChanger( m_media.data(),
                 m_controller.data(), m_currentAudioCdTrack, offset, startPaused );
-        connect( trackChanger, SIGNAL(trackPositionChanged(qint64,bool)),
-                 SIGNAL(trackPositionChanged(qint64,bool)) );
+        connect( trackChanger, &DelayedTrackChanger::trackPositionChanged,
+                 this, &EngineController::trackPositionChanged );
     }
     else if( offset )
     {
         // call to play() is asynchronous and ->seek() can be only called on playing,
         // buffering or paused media. Calling play() would lead to audible glitches,
         // so call pause() that doesn't suffer from such problem.
-        m_media.data()->pause();
+        m_media->pause();
         DelayedSeeker *seeker = new DelayedSeeker( m_media.data(), offset, startPaused );
-        connect( seeker, SIGNAL(trackPositionChanged(qint64,bool)),
-                 SIGNAL(trackPositionChanged(qint64,bool)) );
+        connect( seeker, &DelayedSeeker::trackPositionChanged,
+                 this, &EngineController::trackPositionChanged );
     }
     else
     {
         if( startPaused )
         {
-            m_media.data()->pause();
+            m_media->pause();
         }
         else
         {
             m_pauseTimer->stop();
             if( supportsFadeout() )
-                m_fader.data()->setVolume( 1.0 );
-            m_media.data()->play();
+                m_fader->setVolume( 1.0 );
+            m_media->play();
         }
     }
 }
@@ -484,7 +476,7 @@ EngineController::pause() //SLOT
 {
     if( supportsFadeout() && AmarokConfig::fadeoutOnPause() )
     {
-        m_fader.data()->fadeOut( AmarokConfig::fadeoutLength() );
+        m_fader->fadeOut( AmarokConfig::fadeoutLength() );
         m_pauseTimer->start( AmarokConfig::fadeoutLength() + 500 );
         return;
     }
@@ -498,17 +490,17 @@ EngineController::slotPause()
     if( supportsFadeout() && AmarokConfig::fadeoutOnPause() )
     {
         // Reset VolumeFaderEffect to full volume
-        m_fader.data()->setVolume( 1.0 );
+        m_fader->setVolume( 1.0 );
 
         // Wait a bit before pausing the pipeline. Necessary for the new fader setting to take effect.
-        QTimer::singleShot( 1000, m_media.data(), SLOT(pause()) );
+        QTimer::singleShot( 1000, m_media.data(), &Phonon::MediaObject::pause );
     }
     else
     {
-        m_media.data()->pause();
+        m_media->pause();
     }
 
-    emit paused();
+    Q_EMIT paused();
 }
 
 void
@@ -526,7 +518,7 @@ EngineController::stop( bool forceInstant, bool playingWillContinue ) //SLOT
      */
     bool doFadeOut = !forceInstant
                   && !m_fadeouter
-                  && m_media.data()->state() == Phonon::PlayingState
+                  && m_media->state() == Phonon::PlayingState
                   && AmarokConfig::fadeoutOnStop()
                   && AmarokConfig::fadeoutLength() > 0
                   && m_fader;
@@ -541,14 +533,14 @@ EngineController::stop( bool forceInstant, bool playingWillContinue ) //SLOT
         const qint64 pos = trackPositionMs();
         // updateStreamLength() intentionally not here, we're probably in the middle of a track
         const qint64 length = trackLength();
-        emit trackFinishedPlaying( m_currentTrack, pos / qMax<double>( length, pos ) );
+        Q_EMIT trackFinishedPlaying( m_currentTrack, pos / qMax<double>( length, pos ) );
 
         m_currentTrack = 0;
         m_currentAlbum = 0;
         if( !playingWillContinue )
         {
-            emit stopped( pos, length );
-            emit trackChanged( m_currentTrack );
+            Q_EMIT stopped( pos, length );
+            Q_EMIT trackChanged( m_currentTrack );
         }
     }
 
@@ -562,7 +554,7 @@ EngineController::stop( bool forceInstant, bool playingWillContinue ) //SLOT
 
         m_nextTrack.clear();
         m_nextUrl.clear();
-        m_media.data()->clearQueue();
+        m_media->clearQueue();
     }
 
     if( doFadeOut )
@@ -570,19 +562,26 @@ EngineController::stop( bool forceInstant, bool playingWillContinue ) //SLOT
         m_fadeouter = new Fadeouter( m_media, m_fader, AmarokConfig::fadeoutLength() );
         // even though we don't pass forceInstant, doFadeOut will be false because
         // m_fadeouter will be still valid
-        connect( m_fadeouter.data(), SIGNAL(fadeoutFinished()), SLOT(stop()) );
+        connect( m_fadeouter.data(), &Fadeouter::fadeoutFinished,
+                 this, &EngineController::regularStop );
     }
     else
     {
-        m_media.data()->stop();
-        m_media.data()->setCurrentSource( Phonon::MediaSource() );
+        m_media->stop();
+        m_media->setCurrentSource( Phonon::MediaSource() );
     }
 }
 
+void
+EngineController::regularStop()
+{
+    stop( false, false );
+}
+
 bool
 EngineController::isPaused() const
 {
-    return m_media.data()->state() == Phonon::PausedState;
+    return m_media->state() == Phonon::PausedState;
 }
 
 bool
@@ -595,16 +594,16 @@ bool
 EngineController::isStopped() const
 {
     return
-        m_media.data()->state() == Phonon::StoppedState ||
-        m_media.data()->state() == Phonon::LoadingState ||
-        m_media.data()->state() == Phonon::ErrorState;
+        m_media->state() == Phonon::StoppedState ||
+        m_media->state() == Phonon::LoadingState ||
+        m_media->state() == Phonon::ErrorState;
 }
 
 void
 EngineController::playPause() //SLOT
 {
     DEBUG_BLOCK
-    debug() << "PlayPause: EngineController state" << m_media.data()->state();
+    debug() << "PlayPause: EngineController state" << m_media->state();
 
     if( isPlaying() )
         pause();
@@ -617,7 +616,7 @@ EngineController::seekTo( int ms ) //SLOT
 {
     DEBUG_BLOCK
 
-    if( m_media.data()->isSeekable() )
+    if( m_media->isSeekable() )
     {
 
         debug() << "seek to: " << ms;
@@ -634,8 +633,8 @@ EngineController::seekTo( int ms ) //SLOT
         else
             seekTo = ms;
 
-        m_media.data()->seek( static_cast<qint64>( seekTo ) );
-        emit trackPositionChanged( seekTo, true ); /* User seek */
+        m_media->seek( static_cast<qint64>( seekTo ) );
+        Q_EMIT trackPositionChanged( seekTo, true ); /* User seek */
     }
     else
         debug() << "Stream is not seekable.";
@@ -645,7 +644,7 @@ EngineController::seekTo( int ms ) //SLOT
 void
 EngineController::seekBy( int ms ) //SLOT
 {
-    qint64 newPos = m_media.data()->currentTime() + ms;
+    qint64 newPos = m_media->currentTime() + ms;
     seekTo( newPos <= 0 ? 0 : newPos );
 }
 
@@ -661,6 +660,18 @@ EngineController::decreaseVolume( int ticks ) //SLOT
     return setVolume( volume() - ticks );
 }
 
+int
+EngineController::regularIncreaseVolume() //SLOT
+{
+    return increaseVolume();
+}
+
+int
+EngineController::regularDecreaseVolume() //SLOT
+{
+    return decreaseVolume();
+}
+
 int
 EngineController::setVolume( int percent ) //SLOT
 {
@@ -668,13 +679,13 @@ EngineController::setVolume( int percent ) //SLOT
     m_volume = percent;
 
     const qreal volume =  percent / 100.0;
-    if ( !m_ignoreVolumeChangeAction && m_audio.data()->volume() != volume )
+    if ( !m_ignoreVolumeChangeAction && m_audio->volume() != volume )
     {
         m_ignoreVolumeChangeObserve = true;
-        m_audio.data()->setVolume( volume );
+        m_audio->setVolume( volume );
 
         AmarokConfig::setMasterVolume( percent );
-        emit volumeChanged( percent );
+        Q_EMIT volumeChanged( percent );
     }
     m_ignoreVolumeChangeAction = false;
 
@@ -690,18 +701,18 @@ EngineController::volume() const
 bool
 EngineController::isMuted() const
 {
-    return m_audio.data()->isMuted();
+    return m_audio->isMuted();
 }
 
 void
 EngineController::setMuted( bool mute ) //SLOT
 {
-    m_audio.data()->setMuted( mute ); // toggle mute
+    m_audio->setMuted( mute ); // toggle mute
     if( !isMuted() )
         setVolume( m_volume );
 
     AmarokConfig::setMuteState( mute );
-    emit muteStateChanged( mute );
+    Q_EMIT muteStateChanged( mute );
 }
 
 void
@@ -724,7 +735,7 @@ EngineController::trackLength() const
     if( m_currentTrack && m_currentTrack->length() > 0 )
         return m_currentTrack->length();
     else
-        return m_media.data()->totalTime(); //may return -1
+        return m_media->totalTime(); //may return -1
 }
 
 void
@@ -735,19 +746,17 @@ EngineController::setNextTrack( Meta::TrackPtr track )
         return;
 
     track->prepareToPlay();
-    KUrl url = track->playableUrl();
+    QUrl url = track->playableUrl();
     if( url.isEmpty() )
         return;
 
     QMutexLocker locker( &m_mutex );
     if( isPlaying() )
     {
-        m_media.data()->clearQueue();
+        m_media->clearQueue();
         // keep in sync with playUrl(), slotPlayableUrlFetched()
-        if( url.isLocalFile() )
-            m_media.data()->enqueue( url.toLocalFile() );
-        else if( url.protocol() != "audiocd" ) // we don't support gapless for CD, bug 305708
-            m_media.data()->enqueue( url );
+        if( url.scheme() != "audiocd" ) // we don't support gapless for CD, bug 305708
+            m_media->enqueue( url );
         m_nextTrack = track;
         m_nextUrl = url;
     }
@@ -761,8 +770,8 @@ EngineController::isStream()
     Phonon::MediaSource::Type type = Phonon::MediaSource::Invalid;
     if( m_media )
         // type is determined purely from the MediaSource constructor used in
-        // setCurrentSource(). For streams we use the KUrl one, see playUrl()
-        type = m_media.data()->currentSource().type();
+        // setCurrentSource(). For streams we use the QUrl one, see playUrl()
+        type = m_media->currentSource().type();
     return type == Phonon::MediaSource::Url || type == Phonon::MediaSource::Stream;
 }
 
@@ -770,7 +779,7 @@ bool
 EngineController::isSeekable() const
 {
     if( m_media )
-        return m_media.data()->isSeekable();
+        return m_media->isSeekable();
     return false;
 }
 
@@ -783,7 +792,7 @@ EngineController::trackPosition() const
 qint64
 EngineController::trackPositionMs() const
 {
-    return m_media.data()->currentTime();
+    return m_media->currentTime();
 }
 
 bool
@@ -814,7 +823,7 @@ EngineController::slotTick( qint64 position )
     if( m_boundedPlayback )
     {
         qint64 newPosition = position;
-        emit trackPositionChanged(
+        Q_EMIT trackPositionChanged(
                     static_cast<long>( position - m_boundedPlayback->startPosition() ),
                     false
                 );
@@ -840,7 +849,7 @@ EngineController::slotTick( qint64 position )
     else
     {
         m_lastTickPosition = position;
-        emit trackPositionChanged( static_cast<long>( position ), false );
+        Q_EMIT trackPositionChanged( static_cast<long>( position ), false );
     }
 }
 
@@ -862,12 +871,12 @@ EngineController::slotAboutToFinish()
         m_playWhenFetched = false;
         m_mutex.unlock();
         m_multiPlayback->fetchNext();
-        debug() << "The queue has: " << m_media.data()->queue().size() << " tracks in it";
+        debug() << "The queue has: " << m_media->queue().size() << " tracks in it";
     }
     else if( m_multiSource )
     {
         debug() << "source finished, lets get the next one";
-        KUrl nextSource = m_multiSource->nextUrl();
+        QUrl nextSource = m_multiSource->nextUrl();
 
         if( !nextSource.isEmpty() )
         { //more sources
@@ -877,10 +886,10 @@ EngineController::slotAboutToFinish()
             debug() << "playing next source: " << nextSource;
             slotPlayableUrlFetched( nextSource );
         }
-        else if( m_media.data()->queue().isEmpty() )
+        else if( m_media->queue().isEmpty() )
         {
             debug() << "no more sources, skip to next track";
-            m_multiSource.reset(); // don't cofuse slotFinished
+            m_multiSource.reset(); // don't confuse slotFinished
             The::playlistActions()->requestNextTrack();
         }
     }
@@ -893,7 +902,7 @@ EngineController::slotAboutToFinish()
         stop( true );
         The::playlistActions()->requestNextTrack();
     }
-    else if( m_media.data()->queue().isEmpty() )
+    else if( m_media->queue().isEmpty() )
         The::playlistActions()->requestNextTrack();
 }
 
@@ -908,7 +917,7 @@ EngineController::slotFinished()
         debug() << "Track finished completely, updating statistics";
         unsubscribeFrom( m_currentTrack ); // don't bother with trackMetadataChanged()
         stampStreamTrackLength(); // update track length in stream for accurate scrobbling
-        emit trackFinishedPlaying( m_currentTrack, 1.0 );
+        Q_EMIT trackFinishedPlaying( m_currentTrack, 1.0 );
         subscribeTo( m_currentTrack );
     }
 
@@ -916,7 +925,7 @@ EngineController::slotFinished()
     {
         // again. at this point the track is finished so it's trackPositionMs is 0
         if( !m_nextTrack && m_nextUrl.isEmpty() )
-            emit stopped( m_currentTrack ? m_currentTrack->length() : 0,
+            Q_EMIT stopped( m_currentTrack ? m_currentTrack->length() : 0,
                           m_currentTrack ? m_currentTrack->length() : 0 );
         unsubscribeFrom( m_currentTrack );
         if( m_currentAlbum )
@@ -924,8 +933,8 @@ EngineController::slotFinished()
         m_currentTrack = 0;
         m_currentAlbum = 0;
         if( !m_nextTrack && m_nextUrl.isEmpty() ) // we will the trackChanged signal later
-            emit trackChanged( Meta::TrackPtr() );
-        m_media.data()->setCurrentSource( Phonon::MediaSource() );
+            Q_EMIT trackChanged( Meta::TrackPtr() );
+        m_media->setCurrentSource( Phonon::MediaSource() );
     }
 
     m_mutex.lock(); // in case setNextTrack is being handled right now.
@@ -976,7 +985,7 @@ EngineController::slotNewTrackPlaying( const Phonon::MediaSource &source )
     {
         debug() << "Previous track finished completely, updating statistics";
         stampStreamTrackLength(); // update track length in stream for accurate scrobbling
-        emit trackFinishedPlaying( m_currentTrack, 1.0 );
+        Q_EMIT trackFinishedPlaying( m_currentTrack, 1.0 );
 
         if( m_multiSource )
             // advance source of a multi-source track
@@ -994,8 +1003,8 @@ EngineController::slotNewTrackPlaying( const Phonon::MediaSource &source )
         if( m_multiSource )
         {
             debug() << "Got a MultiSource Track with" <<  m_multiSource->sources().count() << "sources";
-            connect( m_multiSource.data(), SIGNAL(urlChanged(KUrl)),
-                     SLOT(slotPlayableUrlFetched(KUrl)) );
+            connect( m_multiSource.data(), &Capabilities::MultiSourceCapability::urlChanged,
+                     this, &EngineController::slotPlayableUrlFetched );
         }
     }
 
@@ -1023,9 +1032,9 @@ EngineController::slotNewTrackPlaying( const Phonon::MediaSource &source )
         if( m_preamp )
         {
             debug() << "Using gain of" << gain << "with relative peak of" << peak;
-            // we calculate the volume change ourselves, because m_preamp.data()->setVolumeDecibel is
+            // we calculate the volume change ourselves, because m_preamp->setVolumeDecibel is
             // a little confused about minus signs
-            m_preamp.data()->setVolume( qExp( gain * log10over20 ) );
+            m_preamp->setVolume( qExp( gain * log10over20 ) );
         }
         else
             warning() << "Would use gain of" << gain << ", but current Phonon backend"
@@ -1033,7 +1042,7 @@ EngineController::slotNewTrackPlaying( const Phonon::MediaSource &source )
     }
     else if( m_preamp )
     {
-        m_preamp.data()->setVolume( 1.0 );
+        m_preamp->setVolume( 1.0 );
     }
 
     bool useTrackWithinStreamDetection = false;
@@ -1051,8 +1060,8 @@ EngineController::slotNewTrackPlaying( const Phonon::MediaSource &source )
     }
 
     m_lastStreamStampPosition = useTrackWithinStreamDetection ? 0 : -1;
-    emit trackChanged( m_currentTrack );
-    emit trackPlaying( m_currentTrack );
+    Q_EMIT trackChanged( m_currentTrack );
+    Q_EMIT trackPlaying( m_currentTrack );
 }
 
 void
@@ -1069,9 +1078,9 @@ EngineController::slotStateChanged( Phonon::State newState, Phonon::State oldSta
 
     if( newState == Phonon::ErrorState )  // If media is borked, skip to next track
     {
-        emit trackError( m_currentTrack );
+        Q_EMIT trackError( m_currentTrack );
 
-        warning() << "Phonon failed to play this URL. Error: " << m_media.data()->errorString();
+        warning() << "Phonon failed to play this URL. Error: " << m_media->errorString();
         warning() << "Forcing phonon engine reinitialization.";
 
         /* In case of error Phonon MediaObject automatically switches to KioMediaSource,
@@ -1086,7 +1095,7 @@ EngineController::slotStateChanged( Phonon::State newState, Phonon::State oldSta
             // reset error count
             errorCount = 0;
 
-            Amarok::Components::logger()->longMessage(
+            Amarok::Logger::longMessage(
                             i18n( "Too many errors encountered in playlist. Playback stopped." ),
                             Amarok::Logger::Warning
                         );
@@ -1100,17 +1109,17 @@ EngineController::slotStateChanged( Phonon::State newState, Phonon::State oldSta
     else if( newState == Phonon::PlayingState )
     {
         errorCount = 0;
-        emit playbackStateChanged();
+        Q_EMIT playbackStateChanged();
     }
     else if( newState == Phonon::StoppedState ||
              newState == Phonon::PausedState )
     {
-        emit playbackStateChanged();
+        Q_EMIT playbackStateChanged();
     }
 }
 
 void
-EngineController::slotPlayableUrlFetched( const KUrl &url )
+EngineController::slotPlayableUrlFetched( const QUrl &url )
 {
     DEBUG_BLOCK
     debug() << "Fetched url: " << url;
@@ -1125,12 +1134,9 @@ EngineController::slotPlayableUrlFetched( const KUrl &url )
     {
         DEBUG_LINE_INFO
         m_mutex.lock();
-        m_media.data()->clearQueue();
+        m_media->clearQueue();
         // keep synced with setNextTrack(), playUrl()
-        if( url.isLocalFile() )
-            m_media.data()->enqueue( url.toLocalFile() );
-        else
-            m_media.data()->enqueue( url );
+        m_media->enqueue( url );
         m_nextTrack.clear();
         m_nextUrl = url;
         debug() << "The next url we're playing is: " << m_nextUrl;
@@ -1151,7 +1157,7 @@ void
 EngineController::slotTrackLengthChanged( qint64 milliseconds )
 {
     debug() << "slotTrackLengthChanged(" << milliseconds << ")";
-    emit trackLengthChanged( ( !m_multiPlayback || !m_boundedPlayback )
+    Q_EMIT trackLengthChanged( ( !m_multiPlayback || !m_boundedPlayback )
                              ? trackLength() : milliseconds );
 }
 
@@ -1159,7 +1165,7 @@ void
 EngineController::slotMetaDataChanged()
 {
     QVariantMap meta;
-    meta.insert( Meta::Field::URL, m_media.data()->currentSource().url() );
+    meta.insert( Meta::Field::URL, m_media->currentSource().url() );
     static const QList<FieldPair> fieldPairs = QList<FieldPair>()
             << FieldPair( Phonon::ArtistMetaData, Meta::Field::ARTIST )
             << FieldPair( Phonon::AlbumMetaData, Meta::Field::ALBUM )
@@ -1169,12 +1175,12 @@ EngineController::slotMetaDataChanged()
             << FieldPair( Phonon::DescriptionMetaData, Meta::Field::COMMENT );
     foreach( const FieldPair &pair, fieldPairs )
     {
-        QStringList values = m_media.data()->metaData( pair.first );
+        QStringList values = m_media->metaData( pair.first );
         if( !values.isEmpty() )
             meta.insert( pair.second, values.first() );
     }
 
-    // note: don't rely on m_currentTrack here. At least some Phonon backends first emit
+    // note: don't rely on m_currentTrack here. At least some Phonon backends first Q_EMIT
     // totalTimeChanged(), then metaDataChanged() and only then currentSourceChanged()
     // which currently sets correct m_currentTrack.
     if( isInRecentMetaDataHistory( meta ) )
@@ -1190,7 +1196,7 @@ EngineController::slotMetaDataChanged()
     if( m_currentTrack && m_lastStreamStampPosition >= 0 )
     {
         stampStreamTrackLength();
-        emit trackFinishedPlaying( m_currentTrack, 1.0 );
+        Q_EMIT trackFinishedPlaying( m_currentTrack, 1.0 );
 
         // update track length to 0 because length emitted by stampStreamTrackLength()
         // is for the previous song
@@ -1198,13 +1204,13 @@ EngineController::slotMetaDataChanged()
     }
 
     debug() << "slotMetaDataChanged(): new meta-data:" << meta;
-    emit currentMetadataChanged( meta );
+    Q_EMIT currentMetadataChanged( meta );
 }
 
 void
 EngineController::slotSeekableChanged( bool seekable )
 {
-    emit seekableChanged( seekable );
+    Q_EMIT seekableChanged( seekable );
 }
 
 void
@@ -1228,7 +1234,7 @@ void EngineController::slotVolumeChanged( qreal newVolume )
 
         m_volume = percent;
         AmarokConfig::setMasterVolume( percent );
-        emit volumeChanged( percent );
+        Q_EMIT volumeChanged( percent );
     }
     else
         m_volume = percent;
@@ -1239,7 +1245,7 @@ void EngineController::slotVolumeChanged( qreal newVolume )
 void EngineController::slotMutedChanged( bool mute )
 {
     AmarokConfig::setMuteState( mute );
-    emit muteStateChanged( mute );
+    Q_EMIT muteStateChanged( mute );
 }
 
 void
@@ -1247,15 +1253,18 @@ EngineController::slotTrackFinishedPlaying( Meta::TrackPtr track, double playedF
 {
     Q_ASSERT( track );
     debug() << "slotTrackFinishedPlaying("
-            << ( track->artist() ? track->artist()->name() : QString( "[no artist]" ) )
-            << "-" << ( track->album() ? track->album()->name() : QString( "[no album]" ) )
+            << ( track->artist() ? track->artist()->name() : QStringLiteral( "[no artist]" ) )
+            << "-" << ( track->album() ? track->album()->name() : QStringLiteral( "[no album]" ) )
             << "-" << track->name()
             << "," << playedFraction << ")";
-    track->finishedPlaying( playedFraction );
+
+    // Track::finishedPlaying is thread-safe and can take a long time to finish.
+    std::thread thread( &Meta::Track::finishedPlaying, track, playedFraction );
+    thread.detach();
 }
 
 void
-EngineController::metadataChanged( Meta::TrackPtr track )
+EngineController::metadataChanged( const Meta::TrackPtr &track )
 {
     Meta::AlbumPtr album = m_currentTrack->album();
     if( m_currentAlbum != album ) {
@@ -1265,13 +1274,13 @@ EngineController::metadataChanged( Meta::TrackPtr track )
         if( m_currentAlbum )
             subscribeTo( m_currentAlbum );
     }
-    emit trackMetadataChanged( track );
+    Q_EMIT trackMetadataChanged( track );
 }
 
 void
-EngineController::metadataChanged( Meta::AlbumPtr album )
+EngineController::metadataChanged( const Meta::AlbumPtr &album )
 {
-    emit albumMetadataChanged( album );
+    Q_EMIT albumMetadataChanged( album );
 }
 
 QString EngineController::prettyNowPlaying( bool progress ) const
@@ -1280,10 +1289,10 @@ QString EngineController::prettyNowPlaying( bool progress ) const
 
     if( track )
     {
-        QString title       = Qt::escape( track->name() );
-        QString prettyTitle = Qt::escape( track->prettyName() );
-        QString artist      = track->artist() ? Qt::escape( track->artist()->name() ) : QString();
-        QString album       = track->album() ? Qt::escape( track->album()->name() ) : QString();
+        QString title       = track->name().toHtmlEscaped();
+        QString prettyTitle = track->prettyName().toHtmlEscaped();
+        QString artist      = track->artist() ? track->artist()->name().toHtmlEscaped() : QString();
+        QString album       = track->album() ? track->album()->name().toHtmlEscaped() : QString();
 
         // ugly because of translation requirements
         if( !title.isEmpty() && !artist.isEmpty() && !album.isEmpty() )
@@ -1309,10 +1318,10 @@ QString EngineController::prettyNowPlaying( bool progress ) const
 
         if( track->length() > 0 )
         {
-            QString length = Qt::escape( Meta::msToPrettyTime( track->length() ) );
+            QString length = Meta::msToPrettyTime( track->length() ).toHtmlEscaped();
             title += " (";
             if( progress )
-                    title+= Qt::escape( Meta::msToPrettyTime( m_lastTickPosition ) ) + '/';
+                    title += Meta::msToPrettyTime( m_lastTickPosition ).toHtmlEscaped() + '/';
             title += length + ')';
         }
 
@@ -1374,7 +1383,6 @@ EngineController::updateStreamLength( qint64 length )
     lengthMetaData.insert( Meta::Field::URL, QUrl( m_currentTrack->playableUrl() ) );
     lengthMetaData.insert( Meta::Field::LENGTH, length );
     debug() << "updateStreamLength(): emitting currentMetadataChanged(" << lengthMetaData << ")";
-    emit currentMetadataChanged( lengthMetaData );
+    Q_EMIT currentMetadataChanged( lengthMetaData );
 }
 
-#include "EngineController.moc" // mention explicitly so that it knows full Meta::Track
