@@ -25,20 +25,20 @@
 #include "core/capabilities/BoundedPlaybackCapability.h"
 #include "core/meta/Observer.h"
 #include "playback/EqualizerController.h"
-
-#include <KUrl>
+#include "core/meta/Meta.h"
 
 #include <QMutex>
 #include <QObject>
+#include <QPointer>
 #include <QSemaphore>
 #include <QStringList>
-#include <QWeakPointer>
+#include <QUrl>
 
-#include <Phonon/Path>
-#include <Phonon/MediaController>
-#include <Phonon/MediaObject>
-#include <Phonon/Effect>
-#include <Phonon/EffectParameter>
+#include <phonon/Path>
+#include <phonon/MediaController>
+#include <phonon/MediaObject>
+#include <phonon/Effect>
+#include <phonon/EffectParameter>
 #include <phonon/audiodataoutput.h>
 
 class Fadeouter;
@@ -62,7 +62,7 @@ public:
      * Construct EngineController. Must be called from the main thread.
      */
     EngineController();
-    ~EngineController();
+    ~EngineController() override;
 
     /**
      * Returns the global EngineController instance
@@ -117,7 +117,7 @@ public:
     int volume() const;
 
     /**
-     * @return @c true if sound output is disabled, @false otherwise
+     * @return @c true if sound output is disabled, @c false otherwise
      */
     bool isMuted() const;
 
@@ -145,7 +145,7 @@ public:
      * However for rewinding we have isSeekable().
      * Also for streams usually the meta data received by currentTrack() is only
      * for the whole stream while the meta data received by currentMetaDataChanged
-     * will be more current (or contain advertisment)
+     * will be more current (or contain advertisement)
      *
      * @return @c true if the current track is a stream, @c false otherwise
      */
@@ -163,11 +163,11 @@ public:
 
     /**
      * @return QString with a pretty name for the current track
-     * @param whether to include the playing progress (default false)
+     * @param progress whether to include the playing progress (default false)
      */
     QString prettyNowPlaying( bool progress = false ) const;
 
-public slots:
+public Q_SLOTS:
     /**
      * Plays the current track, if there is one
      * This happens asynchronously.
@@ -198,10 +198,18 @@ public slots:
      * This happens asynchronously.
      *
      * @param forceInstant skip any fade-out effects
-     * @param playingWillContinue don't emit stopped() or trackChanged( 0 ) signals
+     * @param playingWillContinue don't Q_EMIT stopped() or trackChanged( 0 ) signals
      */
     void stop( bool forceInstant = false, bool playingWillContinue = false );
 
+    /**
+     * Stops playing
+     * This happens asynchronously.
+     * Doesn't skip any fade-out effects
+     * Emits stopped() and trackChanged( 0 ) signals
+     */
+    void regularStop();
+
     /**
      * Pauses if Amarok is currently playing, plays if Amarok is stopped or paused
      * This happens asynchronously.
@@ -253,6 +261,16 @@ public slots:
      */
     int decreaseVolume( int ticks = 100/25 );
 
+    /**
+     * Increases the volume by default amount
+     */
+    int regularIncreaseVolume();
+
+    /**
+     * Decreases the volume by default amount
+     */
+    int regularDecreaseVolume();
+
     /**
      * Sets the volume
      *
@@ -295,11 +313,11 @@ public slots:
 Q_SIGNALS:
     /**
      * Emitted when the playback stops while playing a track.
-     * This signal is not emitted when the track pauses or the playback stopps because
+     * This signal is not emitted when the track pauses or the playback stops because
      * Amarok was closed and "resume at start" is configured.
      * It is also not emitted if the playback continues with another track. In such
      * a case you would just get another trackPlaying signal.
-     * Both parameters are in milli seconds.
+     * Both parameters are in milliseconds.
      */
     void stopped( qint64 /*ms*/ finalPosition, qint64 /*ms*/ trackLength );
 
@@ -359,7 +377,7 @@ Q_SIGNALS:
     /**
      * Emitted then the information for the current changed.
      * This signal contains data from Phonon about the meta data of the track or stream.
-     * This signal is expecially emitted when a stream changes it's metadata.
+     * This signal is especially emitted when a stream changes it's metadata.
      * This can happen e.g. in a ogg stream where the currentTrack data will probably
      * not be updated.
      *
@@ -389,7 +407,7 @@ Q_SIGNALS:
 
     /** Called when the track position changes.
         If the track just progresses you will get a notification every couple of milliseconds.
-        @parem position The current position in milliseconds
+        @param position The current position in milliseconds
         @param userSeek True if the position change was caused by the user
     */
     void trackPositionChanged( qint64 position, bool userSeek );
@@ -435,7 +453,7 @@ Q_SIGNALS:
      */
     void fillInSupportedMimeTypes();
 
-private slots:
+private Q_SLOTS:
     /**
      * Sets up the Phonon system
      */
@@ -447,7 +465,7 @@ private slots:
     void slotAboutToFinish();
     void slotNewTrackPlaying( const Phonon::MediaSource &source);
     void slotStateChanged( Phonon::State newState, Phonon::State oldState);
-    void slotPlayableUrlFetched( const KUrl &url );
+    void slotPlayableUrlFetched( const QUrl &url );
     void slotTick( qint64 );
     void slotTrackLengthChanged( qint64 );
     void slotMetaDataChanged();
@@ -484,8 +502,8 @@ private slots:
 protected:
     // reimplemented from Meta::Observer
     using Observer::metadataChanged;
-    virtual void metadataChanged( Meta::TrackPtr track );
-    virtual void metadataChanged( Meta::AlbumPtr album );
+    void metadataChanged( const Meta::TrackPtr &track ) override;
+    void metadataChanged( const Meta::AlbumPtr &album ) override;
 
 private:
     /**
@@ -495,13 +513,13 @@ private:
      * @param offset the position in the media to start at in milliseconds
      * @param startPaused if true, go to paused state. if false, go to playing state (default)
      */
-    void playUrl( const KUrl &url, uint offset, bool startPaused = false );
+    void playUrl( const QUrl &url, uint offset, bool startPaused = false );
 
     /**
      * Try to detect MetaData spam in Streams etc.
      *
-     * Some streams are doing advertisment in the metadata. We try to filter that
-     * out. Additionally, some Phonon back-ends emit more than one
+     * Some streams are doing advertisement in the metadata. We try to filter that
+     * out. Additionally, some Phonon back-ends Q_EMIT more than one
      * metadataChanged() signals per on track, so filter it all altogether.
      */
     bool isInRecentMetaDataHistory( const QVariantMap &meta );
@@ -513,7 +531,7 @@ private:
     void stampStreamTrackLength();
 
     /**
-     * emit metadataChanged() with info so that MetaStream::Track that is
+     * Q_EMIT metadataChanged() with info so that MetaStream::Track that is
      * currently listening updates its length.
      *
      * @param length new track length in milliseconds
@@ -523,21 +541,21 @@ private:
     Q_DISABLE_COPY( EngineController )
 
     EqualizerController                     *m_equalizerController;
-    QWeakPointer<Phonon::MediaObject>       m_media;
-    QWeakPointer<Phonon::VolumeFaderEffect> m_preamp;
-    QWeakPointer<Phonon::AudioOutput>       m_audio;
-    QWeakPointer<Phonon::AudioDataOutput>   m_audioDataOutput;
-    QWeakPointer<Phonon::MediaController>   m_controller;
+    QPointer<Phonon::MediaObject>       m_media;
+    QPointer<Phonon::VolumeFaderEffect> m_preamp;
+    QPointer<Phonon::AudioOutput>       m_audio;
+    QPointer<Phonon::AudioDataOutput>   m_audioDataOutput;
+    QPointer<Phonon::MediaController>   m_controller;
     Phonon::Path                            m_path;
     Phonon::Path                            m_dataPath;
 
-    QWeakPointer<Fadeouter> m_fadeouter;
-    QWeakPointer<Phonon::VolumeFaderEffect> m_fader;
+    QPointer<Fadeouter> m_fadeouter;
+    QPointer<Phonon::VolumeFaderEffect> m_fader;
 
     Meta::TrackPtr  m_currentTrack;
     Meta::AlbumPtr  m_currentAlbum;
     Meta::TrackPtr  m_nextTrack;
-    KUrl            m_nextUrl;
+    QUrl            m_nextUrl;
     Capabilities::BoundedPlaybackCapability* m_boundedPlayback;
     Capabilities::MultiPlayableCapability* m_multiPlayback;
     QScopedPointer<Capabilities::MultiSourceCapability> m_multiSource;
