@@ -18,8 +18,7 @@
  
 #include "PaletteHandler.h"
 
-#include <kglobal.h>
-
+#include <QAbstractItemView>
 #include <QPainter>
 
 
@@ -50,7 +49,7 @@ void
 PaletteHandler::setPalette( const QPalette & palette )
 {
     m_palette = palette;
-    emit( newPalette( m_palette ) );
+    Q_EMIT( newPalette( m_palette ) );
 }
 
 void
@@ -151,4 +150,3 @@ PaletteHandler::alternateBackgroundColor()
     return result;
 }
 
-#include "PaletteHandler.moc"
