@@ -32,13 +32,14 @@
 
 #include <KColorScheme>
 #include <KColorUtils>
-#include <KStandardDirs>
 
 #include <QHash>
 #include <QPainter>
 #include <QPalette>
 #include <QReadLocker>
+#include <QStandardPaths>
 #include <QStyleOptionSlider>
+#include <QSvgRenderer>
 #include <QWriteLocker>
 
 
@@ -61,7 +62,7 @@ SvgHandler::SvgHandler( QObject* parent )
     , m_customTheme( false )
 {
     DEBUG_BLOCK
-    connect( The::paletteHandler(), SIGNAL(newPalette(QPalette)), this, SLOT(discardCache()) );
+    connect( The::paletteHandler(), &PaletteHandler::newPalette, this, &SvgHandler::discardCache );
 }
 
 SvgHandler::~SvgHandler()
@@ -75,9 +76,9 @@ SvgHandler::~SvgHandler()
 }
 
 
-bool SvgHandler::loadSvg( const QString& name )
+bool SvgHandler::loadSvg( const QString& name, bool forceCustomTheme )
 {
-    const QString &svgFilename = !m_customTheme ? KStandardDirs::locate( "data", name ) : name;
+    const QString &svgFilename = m_customTheme || forceCustomTheme ? name : QStandardPaths::locate( QStandardPaths::GenericDataLocation, name );
     QSvgRenderer *renderer = new QSvgRenderer( The::svgTinter()->tint( svgFilename ) );
 
     if ( !renderer->isValid() )
@@ -127,7 +128,7 @@ QPixmap SvgHandler::renderSvg( const QString &name,
     QString key;
     if( !skipCache )
     {
-        key = QString("%1:%2x%3")
+        key = QStringLiteral("%1:%2x%3")
             .arg( keyname )
             .arg( width )
             .arg( height );
@@ -165,6 +166,50 @@ QPixmap SvgHandler::renderSvg( const QString &name,
     return pixmap;
 }
 
+QPixmap SvgHandler::renderSvg( const QUrl& url, const QString& keyname, int width, int height, const QString& element, bool skipCache, const qreal opacity )
+{
+    QString key;
+    if( !skipCache )
+    {
+        key = QStringLiteral("%1:%2x%3")
+        .arg( keyname )
+        .arg( width )
+        .arg( height );
+    }
+
+    QPixmap pixmap;
+    if( skipCache || !m_cache->findPixmap( key, &pixmap ) )
+    {
+        pixmap = QPixmap( width, height );
+        pixmap.fill( Qt::transparent );
+
+        QString name = url.isLocalFile() ? url.toLocalFile() : ":" + url.path();
+        QReadLocker readLocker( &m_lock );
+        if( ! m_renderers[name] )
+        {
+            readLocker.unlock();
+            if( !loadSvg( name, true ) )
+            {
+                return pixmap;
+            }
+            readLocker.relock();
+        }
+
+        QPainter pt( &pixmap );
+        pt.setOpacity( opacity );
+
+        if ( element.isEmpty() )
+            m_renderers[name]->render( &pt, QRectF( 0, 0, width, height ) );
+        else
+            m_renderers[name]->render( &pt, element, QRectF( 0, 0, width, height ) );
+
+        if( !skipCache )
+            m_cache->insertPixmap( key, pixmap );
+    }
+
+    return pixmap;
+}
+
 QPixmap SvgHandler::renderSvg(const QString & keyname, int width, int height, const QString & element, bool skipCache, const qreal opacity )
 {
     return renderSvg( m_themeFile, keyname, width, height, element, skipCache, opacity );
@@ -172,14 +217,14 @@ QPixmap SvgHandler::renderSvg(const QString & keyname, int width, int height, co
 
 QPixmap SvgHandler::renderSvgWithDividers(const QString & keyname, int width, int height, const QString & element)
 {
-    const QString key = QString("%1:%2x%3-div")
+    const QString key = QStringLiteral("%1:%2x%3-div")
             .arg( keyname )
             .arg( width )
             .arg( height );
 
     QPixmap pixmap;
     if ( !m_cache->findPixmap( key, &pixmap ) ) {
-//         debug() << QString("svg %1 not in cache...").arg( key );
+//         debug() << QStringLiteral("svg %1 not in cache...").arg( key );
 
         pixmap = QPixmap( width, height );
         pixmap.fill( Qt::transparent );
@@ -222,7 +267,7 @@ void SvgHandler::reTint()
     The::svgTinter()->init();
     if ( !loadSvg( m_themeFile ))
         warning() << "Unable to load theme file: " << m_themeFile;
-    emit retinted();
+    Q_EMIT retinted();
 }
 
 QString SvgHandler::themeFile()
@@ -244,7 +289,9 @@ void SvgHandler::discardCache()
     //redraw entire app....
     reTint();
     m_cache->clear();
-    App::instance()->mainWindow()->update();
+
+    if( auto window = pApp->mainWindow() )
+        window->update();
 }
 
 QPixmap
@@ -264,7 +311,7 @@ QPixmap SvgHandler::addBordersToPixmap( const QPixmap &orgPixmap, int borderWidt
     QString key;
     if( !skipCache )
     {
-        key = QString("%1:%2x%3b%4")
+        key = QStringLiteral("%1:%2x%3b%4")
             .arg( name )
             .arg( newWidth )
             .arg( newHeight )
@@ -393,6 +440,7 @@ void SvgHandler::paintCustomSlider( QPainter *p, QStyleOptionSlider *slider, qre
     QRect knob = sliderKnobRect( slider->rect, percentage, inverse );
     QPoint pt = slider->rect.topLeft() + QPoint( 0, 2 );
 
+    p->setRenderHint( QPainter::SmoothPixmapTransform );
     //debug() << "rel: " << knobRelPos << ", width: " << width << ", height:" << height << ", %: " << percentage;
 
     //if we should paint moodbar, paint this as the bottom layer
@@ -471,4 +519,3 @@ void SvgHandler::paintCustomSlider( QPainter *p, QStyleOptionSlider *slider, qre
     }
 }
 
-#include "SvgHandler.moc"
