@@ -31,8 +31,8 @@
 #include "core-impl/meta/timecode/TimecodeObserver.h"
 #include "playlist/PlaylistViewUrlGenerator.h"
 
-#include <KIcon>
-#include <KLocale>
+#include <QIcon>
+#include <KLocalizedString>
 
 namespace The {
     static AmarokUrlHandler* s_AmarokUrlHandler_instance = 0;
@@ -104,7 +104,7 @@ void AmarokUrlHandler::unRegisterGenerator( AmarokUrlGenerator * generator )
     m_registeredGenerators.removeAll( generator );
 }
 
-bool AmarokUrlHandler::run( AmarokUrl url )
+bool AmarokUrlHandler::run( const AmarokUrl &url )
 {
 
     DEBUG_BLOCK
@@ -121,13 +121,13 @@ bool AmarokUrlHandler::run( AmarokUrl url )
 
 }
 
-void AmarokUrlHandler::bookmarkAlbum( Meta::AlbumPtr album ) //slot
+void AmarokUrlHandler::bookmarkAlbum( const Meta::AlbumPtr &album ) //slot
 {
     NavigationUrlGenerator::instance()->urlFromAlbum( album ).saveToDb();
     BookmarkModel::instance()->reloadFromDb();
 }
 
-void AmarokUrlHandler::bookmarkArtist( Meta::ArtistPtr artist ) //slot
+void AmarokUrlHandler::bookmarkArtist( const Meta::ArtistPtr &artist ) //slot
 {
     NavigationUrlGenerator::instance()->urlFromArtist( artist ).saveToDb();
     BookmarkModel::instance()->reloadFromDb();
@@ -137,7 +137,7 @@ BookmarkList AmarokUrlHandler::urlsByCommand( const QString &command )
 {
     DEBUG_BLOCK
 
-    QString query = "SELECT id, parent_id, name, url, description, custom FROM bookmarks where url like 'amarok://%1%' ORDER BY name;";
+    QString query = QStringLiteral("SELECT id, parent_id, name, url, description, custom FROM bookmarks where url like 'amarok://%1%' ORDER BY name;");
     query = query.arg( command );
     QStringList result = StorageManager::instance()->sqlStorage()->query( query );
 
@@ -157,7 +157,7 @@ BookmarkList AmarokUrlHandler::urlsByCommand( const QString &command )
 AmarokUrl
 AmarokUrlHandler::createBrowserViewBookmark()
 {
-    return NavigationUrlGenerator::instance()->CreateAmarokUrl();;
+    return NavigationUrlGenerator::instance()->CreateAmarokUrl();
 }
 
 AmarokUrl
@@ -195,24 +195,24 @@ AmarokUrlHandler::bookmarkCurrentContextView()
     BookmarkModel::instance()->reloadFromDb(); 
 }
 
-KIcon
+QIcon
 AmarokUrlHandler::iconForCommand( const QString &command )
 {
     if( m_registeredRunners.keys().contains( command ) )
         return m_registeredRunners.value( command )->icon();
 
-    return KIcon( "unknown" );
+    return QIcon::fromTheme( QStringLiteral("unknown") );
 }
 
 void AmarokUrlHandler::updateTimecodes(const QString* BookmarkName)
 {
-    emit timecodesUpdated( BookmarkName );
+    Q_EMIT timecodesUpdated( BookmarkName );
 }
 
 void
 AmarokUrlHandler::paintNewTimecode( const QString &name, int pos )
 {
-    emit timecodeAdded( name, pos );
+    Q_EMIT timecodeAdded( name, pos );
 }
 
 QString
@@ -226,4 +226,3 @@ AmarokUrlHandler::prettyCommand( const QString &command )
 
 
 
-#include "AmarokUrlHandler.moc"
