@@ -23,7 +23,7 @@
 
 #include <typeinfo>
 
-BookmarkGroup::BookmarkGroup( const QStringList & dbResultRow, BookmarkGroupPtr parent )
+BookmarkGroup::BookmarkGroup( const QStringList & dbResultRow, const BookmarkGroupPtr &parent )
     : BookmarkViewItem()
     , m_parent( parent )
     , m_customType()
@@ -35,7 +35,7 @@ BookmarkGroup::BookmarkGroup( const QStringList & dbResultRow, BookmarkGroupPtr
     m_description = dbResultRow[3];
 }
 
-BookmarkGroup::BookmarkGroup( const QString & name, BookmarkGroupPtr parent )
+BookmarkGroup::BookmarkGroup( const QString & name, const BookmarkGroupPtr &parent )
     : BookmarkViewItem()
     , m_dbId( -1 )
     , m_parent( parent )
@@ -59,7 +59,7 @@ BookmarkGroup::BookmarkGroup( const QString &name, const QString &customType )
     
     debug() << "custom type: " << customType << " named '" << name << "'";
     //check if this custom group already exists and if so, just load that data.
-    QString query = "SELECT id, parent_id, name, description FROM bookmark_groups where custom='%1';";
+    QString query = QStringLiteral("SELECT id, parent_id, name, description FROM bookmark_groups where custom='%1';");
     query = query.arg( customType );
     QStringList result = StorageManager::instance()->sqlStorage()->query( query );
 
@@ -99,16 +99,16 @@ void BookmarkGroup::save()
 
     if ( m_dbId != -1 ) {
         //update existing
-        QString query = "UPDATE bookmark_groups SET parent_id=%1, name='%2', description='%3', custom='%4%' WHERE id=%5;";
+        QString query = QStringLiteral("UPDATE bookmark_groups SET parent_id=%1, name='%2', description='%3', custom='%4%' WHERE id=%5;");
         query = query.arg( QString::number( parentId ), m_name, m_description, m_customType, QString::number( m_dbId ) );
         StorageManager::instance()->sqlStorage()->query( query );
     }
     else
     {
         //insert new
-        QString query = "INSERT INTO bookmark_groups ( parent_id, name, description, custom) VALUES ( %1, '%2', '%3', '%4' );";
+        QString query = QStringLiteral("INSERT INTO bookmark_groups ( parent_id, name, description, custom) VALUES ( %1, '%2', '%3', '%4' );");
         query = query.arg( QString::number( parentId ), m_name, m_description, m_customType );
-        m_dbId = StorageManager::instance()->sqlStorage()->insert( query, NULL );
+        m_dbId = StorageManager::instance()->sqlStorage()->insert( query, nullptr );
 
     }
 }
@@ -119,7 +119,7 @@ BookmarkGroupList BookmarkGroup::childGroups() const
     if ( !m_hasFetchedChildGroups )
     {
 
-        QString query = "SELECT id, parent_id, name, description FROM bookmark_groups where parent_id=%1 ORDER BY name;";
+        QString query = QStringLiteral("SELECT id, parent_id, name, description FROM bookmark_groups where parent_id=%1 ORDER BY name;");
         query = query.arg( QString::number( m_dbId ) );
         QStringList result = StorageManager::instance()->sqlStorage()->query( query );
 
@@ -145,7 +145,7 @@ BookmarkList BookmarkGroup::childBookmarks() const
     //DEBUG_BLOCK
     //debug() << "my name: " << m_name << " my pointer: " << this;
     if ( !m_hasFetchedChildPlaylists ) {
-        QString query = "SELECT id, parent_id, name, url, description, custom FROM bookmarks where parent_id=%1 ORDER BY name;";
+        QString query = QStringLiteral("SELECT id, parent_id, name, url, description, custom FROM bookmarks where parent_id=%1 ORDER BY name;");
         query = query.arg( QString::number( m_dbId ) );
         QStringList result = StorageManager::instance()->sqlStorage()->query( query );
 
@@ -188,7 +188,7 @@ int BookmarkGroup::childCount() const
 void BookmarkGroup::clear()
 {
     //DEBUG_BLOCK
-//m_childBookmarks, m_childGroups are KSharedPtrs, so we should be able to just clear the list
+//m_childBookmarks, m_childGroups are AmarokSharedPointers, so we should be able to just clear the list
 //and the playlistptrs will delete themselves
     m_childGroups.clear();
     m_childBookmarks.clear();
@@ -209,16 +209,14 @@ void BookmarkGroup::setDescription( const QString &description )
     save();
 }
 
-void BookmarkGroup::deleteChild( BookmarkViewItemPtr item )
+void BookmarkGroup::deleteChild( const BookmarkViewItemPtr &item )
 {
-    if ( typeid( * item ) == typeid( BookmarkGroup ) )
+    if ( auto group = BookmarkGroupPtr::dynamicCast( item ) )
     {
-        BookmarkGroupPtr group = BookmarkGroupPtr::staticCast( item );
         m_childGroups.removeAll( group );
     }
-    else if ( typeid( * item ) == typeid( AmarokUrl ) )
+    else if ( auto bookmark = AmarokUrlPtr::dynamicCast( item ) )
     {
-        AmarokUrlPtr bookmark = AmarokUrlPtr::staticCast( item );
         m_childBookmarks.removeAll( bookmark );
     }
 }
@@ -232,12 +230,12 @@ void BookmarkGroup::removeFromDb()
     foreach( AmarokUrlPtr bookmark, m_childBookmarks )
         bookmark->removeFromDb();
 
-    QString query = QString( "DELETE FROM bookmark_groups where id=%1;").arg( QString::number( m_dbId ) );
+    QString query = QStringLiteral( "DELETE FROM bookmark_groups where id=%1;").arg( QString::number( m_dbId ) );
     debug() << "query: " << query;
     QStringList result = StorageManager::instance()->sqlStorage()->query( query );
 }
 
-void BookmarkGroup::reparent( BookmarkGroupPtr parent )
+void BookmarkGroup::reparent( const BookmarkGroupPtr &parent )
 {
     m_parent = parent;
     save();
