@@ -23,38 +23,38 @@
 #include "amarokurls/PlayUrlGenerator.h"
 #include "widgets/ProgressWidget.h"
 
-#include <KAction>
-#include <KIcon>
-#include <KLocale>
-#include <KVBox>
-
+#include <QAction>
+#include <QHBoxLayout>
+#include <QIcon>
 #include <QLabel>
+#include <QVBoxLayout>
+
+#include <KLocalizedString>
 
 BookmarkManagerWidget::BookmarkManagerWidget( QWidget * parent )
- : KVBox( parent )
+    : BoxWidget( true, parent )
 {
+    layout()->setContentsMargins( 0,0,0,0 );
 
-    setContentsMargins( 0,0,0,0 );
-
-    KHBox * topLayout = new KHBox( this );
+    BoxWidget * topLayout = new BoxWidget( false, this );
     
     m_toolBar = new QToolBar( topLayout );
     m_toolBar->setToolButtonStyle( Qt::ToolButtonTextBesideIcon );
 
-    KAction * addGroupAction = new KAction( KIcon("media-track-add-amarok" ), i18n( "Add Group" ), this  );
+    QAction * addGroupAction = new QAction( QIcon::fromTheme(QStringLiteral("media-track-add-amarok") ), i18n( "Add Group" ), this  );
     m_toolBar->addAction( addGroupAction );
-    connect( addGroupAction, SIGNAL(triggered(bool)), BookmarkModel::instance(), SLOT(createNewGroup()) );
+    connect( addGroupAction, &QAction::triggered, BookmarkModel::instance(), &BookmarkModel::createNewGroup );
 
-    /*KAction * addBookmarkAction = new KAction( KIcon("bookmark-new" ), i18n( "New Bookmark" ), this  );
+    /*QAction * addBookmarkAction = new QAction( QIcon::fromTheme("bookmark-new" ), i18n( "New Bookmark" ), this  );
     m_toolBar->addAction( addBookmarkAction );
-    connect( addBookmarkAction, SIGNAL(triggered(bool)), BookmarkModel::instance(), SLOT(createNewBookmark()) );*/
+    connect( addBookmarkaction, &QAction::triggered, BookmarkModel::instance(), &BookmarkModel::createNewBookmark );*/
 
     m_toolBar->addWidget( new BookmarkCurrentButton( 0 ) );
 
     m_searchEdit = new Amarok::LineEdit( topLayout );
-    m_searchEdit->setClickMessage( i18n( "Filter bookmarks" ) );
+    m_searchEdit->setPlaceholderText( i18n( "Filter bookmarks" ) );
     m_searchEdit->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed );
-    m_searchEdit->setClearButtonShown( true );
+    m_searchEdit->setClearButtonEnabled( true );
     m_searchEdit->setFrame( true );
     m_searchEdit->setToolTip( i18n( "Start typing to progressively filter the bookmarks" ) );
     m_searchEdit->setFocusPolicy( Qt::ClickFocus ); // Without this, the widget goes into text input mode directly on startup
@@ -73,8 +73,8 @@ BookmarkManagerWidget::BookmarkManagerWidget( QWidget * parent )
     m_bookmarkView->setSortingEnabled( true );
     m_bookmarkView->resizeColumnToContents( 0 );
 
-    connect( BookmarkModel::instance(), SIGNAL(editIndex(QModelIndex)), m_bookmarkView, SLOT(slotEdit(QModelIndex)) );
-    connect( m_searchEdit, SIGNAL(textChanged(QString)), m_proxyModel, SLOT(setFilterFixedString(QString)) );
+    connect( BookmarkModel::instance(), &BookmarkModel::editIndex, m_bookmarkView, &BookmarkTreeView::slotEdit );
+    connect( m_searchEdit, &Amarok::LineEdit::textChanged, m_proxyModel, &QSortFilterProxyModel::setFilterFixedString );
 
     m_currentBookmarkId = -1;
 
@@ -90,7 +90,6 @@ BookmarkTreeView * BookmarkManagerWidget::treeView()
     return m_bookmarkView;
 }
 
-#include "BookmarkManagerWidget.moc"
 
 
 
