@@ -26,10 +26,10 @@
 #include "SvgHandler.h"
 #include "core-impl/meta/timecode/TimecodeMeta.h"
 
-#include <KAction>
-#include <KMenu>
+#include <QAction>
+#include <QMenu>
+#include <KLocalizedString>
 
-#include <QFrame>
 #include <QHeaderView>
 #include <QHelpEvent>
 #include <QKeyEvent>
@@ -56,8 +56,8 @@ BookmarkTreeView::BookmarkTreeView( QWidget *parent )
     setAlternatingRowColors( true );
     setDropIndicatorShown( true );
 
-    connect( header(), SIGNAL(sectionCountChanged(int,int)),
-             this, SLOT(slotSectionCountChanged(int,int)) );
+    connect( header(), &QHeaderView::sectionCountChanged,
+             this, &BookmarkTreeView::slotSectionCountChanged );
 }
 
 
@@ -73,10 +73,8 @@ void BookmarkTreeView::mouseDoubleClickEvent( QMouseEvent * event )
     {
         BookmarkViewItemPtr item = BookmarkModel::instance()->data( index, 0xf00d ).value<BookmarkViewItemPtr>();
 
-        if ( typeid( *item ) == typeid( AmarokUrl ) ) {
-            AmarokUrl * bookmark = static_cast< AmarokUrl* >( item.data() );
+        if ( auto bookmark = AmarokUrlPtr::dynamicCast( item ) )
             bookmark->run();
-        }
     }
 }
 
@@ -97,32 +95,32 @@ BookmarkTreeView::keyPressEvent( QKeyEvent *event )
     QTreeView::keyPressEvent( event );
 }
 
-QList<KAction *>
-BookmarkTreeView::createCommonActions( QModelIndexList indices )
+QList<QAction *>
+BookmarkTreeView::createCommonActions( const QModelIndexList &indices )
 {
     DEBUG_BLOCK
 
     //there are 4 columns, so for each selected row we get 4 indices...
     int selectedRowCount = indices.count() / 4;
 
-    QList< KAction * > actions;
+    QList< QAction * > actions;
     if ( m_loadAction == 0 )
     {
-        m_loadAction = new KAction( KIcon( "folder-open" ), i18nc( "Load the view represented by this bookmark", "&Load" ), this );
-        connect( m_loadAction, SIGNAL(triggered()), this, SLOT(slotLoad()) );
+        m_loadAction = new QAction( QIcon::fromTheme( QStringLiteral("folder-open") ), i18nc( "Load the view represented by this bookmark", "&Load" ), this );
+        connect( m_loadAction, &QAction::triggered, this, &BookmarkTreeView::slotLoad );
     }
 
     if ( m_deleteAction == 0 )
     {
-        m_deleteAction = new KAction( KIcon( "media-track-remove-amarok" ), i18n( "&Delete" ), this );
-        connect( m_deleteAction, SIGNAL(triggered()), this, SLOT(slotDelete()) );
+        m_deleteAction = new QAction( QIcon::fromTheme( QStringLiteral("media-track-remove-amarok") ), i18n( "&Delete" ), this );
+        connect( m_deleteAction, &QAction::triggered, this, &BookmarkTreeView::slotDelete );
     }
 
     if ( m_createTimecodeTrackAction == 0 )
     {
         debug() << "creating m_createTimecodeTrackAction";
-        m_createTimecodeTrackAction = new KAction( KIcon( "media-track-edit-amarok" ), i18n( "&Create timecode track" ), this );
-        connect( m_createTimecodeTrackAction, SIGNAL(triggered()), this, SLOT(slotCreateTimecodeTrack()) );
+        m_createTimecodeTrackAction = new QAction( QIcon::fromTheme( QStringLiteral("media-track-edit-amarok") ), i18n( "&Create timecode track" ), this );
+        connect( m_createTimecodeTrackAction, &QAction::triggered, this, &BookmarkTreeView::slotCreateTimecodeTrack );
     }
 
     if ( selectedRowCount == 1 )
@@ -144,11 +142,8 @@ void BookmarkTreeView::slotLoad()
     DEBUG_BLOCK
     foreach( BookmarkViewItemPtr item, selectedItems() )
     {
-        if( typeid( * item ) == typeid( AmarokUrl ) )
-        {
-            AmarokUrlPtr bookmark = AmarokUrlPtr::staticCast( item );
+        if( auto bookmark = AmarokUrlPtr::dynamicCast( item ) )
             bookmark->run();
-        }
     }
 }
 
@@ -179,19 +174,21 @@ void BookmarkTreeView::contextMenuEvent( QContextMenuEvent * event )
 {
     DEBUG_BLOCK
 
-    QModelIndexList indices = selectionModel()->selectedIndexes();
+    const QModelIndexList indices = selectionModel()->selectedIndexes();
 
-    KMenu* menu = new KMenu( this );
+    QMenu* menu = new QMenu( this );
+    const QList<QAction *> actions = createCommonActions( indices );
 
-    QList<KAction *> actions = createCommonActions( indices );
-
-    foreach( KAction * action, actions )
+    for ( QAction * action : actions )
         menu->addAction( action );
 
-    if( indices.count() == 0 )
+    if( indices.isEmpty() && m_addGroupAction)
         menu->addAction( m_addGroupAction );
 
-    menu->exec( event->globalPos() );
+    if (!menu->isEmpty()) {
+        menu->exec( event->globalPos() );
+    }
+    delete menu;
 }
 
 void BookmarkTreeView::resizeEvent( QResizeEvent *event )
@@ -204,8 +201,8 @@ void BookmarkTreeView::resizeEvent( QResizeEvent *event )
     if( oldWidth == newWidth || oldWidth < 0 || newWidth < 0 )
         return;
 
-    disconnect( headerView, SIGNAL(sectionResized(int,int,int)),
-                this, SLOT(slotSectionResized(int,int,int)) );
+    disconnect( headerView, &QHeaderView::sectionResized,
+                this, &BookmarkTreeView::slotSectionResized );
 
     QMap<BookmarkModel::Column, qreal>::const_iterator i = m_columnsSize.constBegin();
     while( i != m_columnsSize.constEnd() )
@@ -216,8 +213,8 @@ void BookmarkTreeView::resizeEvent( QResizeEvent *event )
         ++i;
     }
 
-    connect( headerView, SIGNAL(sectionResized(int,int,int)),
-             this, SLOT(slotSectionResized(int,int,int)) );
+    connect( headerView, &QHeaderView::sectionResized,
+             this, &BookmarkTreeView::slotSectionResized );
 
     QWidget::resizeEvent( event );
 }
@@ -264,7 +261,7 @@ BookmarkTreeView::selectedItems() const
     return selected;
 }
 
-void BookmarkTreeView::setNewGroupAction( KAction * action )
+void BookmarkTreeView::setNewGroupAction( QAction * action )
 {
     m_addGroupAction = action;
 }
@@ -282,20 +279,20 @@ void BookmarkTreeView::selectionChanged( const QItemSelection & selected, const
         {
             BookmarkViewItemPtr item = BookmarkModel::instance()->data( sourceIndex, 0xf00d ).value<BookmarkViewItemPtr>();
 
-            if ( typeid( * item ) == typeid( AmarokUrl ) ) {
+            if ( auto bookmark = AmarokUrlPtr::dynamicCast( item ) )
+            {
                 debug() << "a url was selected...";
-                AmarokUrl bookmark = *static_cast< AmarokUrl* >( item.data() );
-                emit( bookmarkSelected( bookmark ) );
+                Q_EMIT( bookmarkSelected( *bookmark ) );
             }
         }
     }
     
 }
 
-KMenu* BookmarkTreeView::contextMenu( const QPoint& point )
+QMenu* BookmarkTreeView::contextMenu( const QPoint& point )
 {
     DEBUG_BLOCK
-    KMenu* menu = new KMenu( 0 );
+    QMenu* menu = new QMenu( nullptr );
 
     debug() << "getting menu for point:" << point;
     QModelIndex index = m_proxyModel->mapToSource( indexAt( point ) );
@@ -306,12 +303,12 @@ KMenu* BookmarkTreeView::contextMenu( const QPoint& point )
         
         QModelIndexList indices = selectionModel()->selectedIndexes();
 
-        QList<KAction *> actions = createCommonActions( indices );
+        QList<QAction *> actions = createCommonActions( indices );
 
-        foreach( KAction * action, actions )
+        foreach( QAction * action, actions )
             menu->addAction( action );
 
-        if( indices.count() == 0 )
+        if( indices.isEmpty() )
             menu->addAction( m_addGroupAction );
 
     }
@@ -331,14 +328,14 @@ void BookmarkTreeView::slotCreateTimecodeTrack() const
 
     if ( url1 == 0 )
         return;
-    if ( url1->command() != "play" )
+    if ( url1->command() != QLatin1String("play") )
         return;
 
     const AmarokUrl * url2 = dynamic_cast<const AmarokUrl *>( list.at( 1 ).data() );
 
     if ( url2 == 0 )
         return;
-    if ( url2->command() != "play" )
+    if ( url2->command() != QLatin1String("play") )
         return;
 
     if ( url1->path() != url2->path() )
@@ -349,14 +346,14 @@ void BookmarkTreeView::slotCreateTimecodeTrack() const
     qreal pos1 = 0;
     qreal pos2 = 0;
 
-    if ( url1->args().keys().contains( "pos" ) )
+    if ( url1->args().keys().contains( QStringLiteral("pos") ) )
     {
-        pos1 = url1->args().value( "pos" ).toDouble();
+        pos1 = url1->args().value( QStringLiteral("pos") ).toDouble();
     }
 
-    if ( url2->args().keys().contains( "pos" ) )
+    if ( url2->args().keys().contains( QStringLiteral("pos") ) )
     {
-        pos2 = url2->args().value( "pos" ).toDouble();
+        pos2 = url2->args().value( QStringLiteral("pos") ).toDouble();
     }
 
     if ( pos1 == pos2 )
@@ -368,7 +365,7 @@ void BookmarkTreeView::slotCreateTimecodeTrack() const
     //Now we really should pop up a menu to get the user to enter some info about this
     //new track, but for now, just fake it as this is just for testing anyway
 
-    QString url = QUrl::fromEncoded ( QByteArray::fromBase64 ( url1->path().toUtf8() ) ).toString();
+    QUrl url = QUrl::fromEncoded ( QByteArray::fromBase64 ( url1->path().toUtf8() ) );
     Meta::TimecodeTrackPtr track = Meta::TimecodeTrackPtr( new Meta::TimecodeTrack( i18n( "New Timecode Track" ), url, start, end ) );
     Meta::TimecodeAlbumPtr album = Meta::TimecodeAlbumPtr( new Meta::TimecodeAlbum( i18n( "Unknown" ) ) );
     Meta::TimecodeArtistPtr artist = Meta::TimecodeArtistPtr( new Meta::TimecodeArtist( i18n(  "Unknown" ) ) );
@@ -428,14 +425,13 @@ void BookmarkTreeView::slotSectionCountChanged( int oldCount, int newCount )
         const BookmarkModel::Column col = BookmarkModel::Column( index );
 
         if( col == BookmarkModel::Command )
-            header()->setResizeMode( index, QHeaderView::ResizeToContents );
+            header()->setSectionResizeMode( index, QHeaderView::ResizeToContents );
 
         m_columnsSize[ col ] = ratio;
     }
 }
 
 
-#include "BookmarkTreeView.moc"
 
 
 
