@@ -19,21 +19,22 @@
 #include "BrowserCategoryList.h"
 
 #include "App.h"
-#include "BrowserCategoryListDelegate.h"
-#include "context/ContextView.h"
 #include "core/support/Debug.h"
 #include "InfoProxy.h"
 #include "PaletteHandler.h"
 #include "widgets/PrettyTreeView.h"
+#include "widgets/PrettyTreeDelegate.h"
 #include "widgets/SearchWidget.h"
 
-#include <QStackedWidget>
-#include <QTreeView>
-
-#include <KComboBox>
-#include <KStandardDirs>
-
+#include <QComboBox>
 #include <QFile>
+#include <QStackedWidget>
+#include <QStandardPaths>
+#include <QTreeView>
+#include <QVBoxLayout>
+
+#include <KLocalizedString>
+
 
 BrowserCategoryList::BrowserCategoryList( const QString &name, QWidget* parent, bool sort )
     : BrowserCategory( name, parent )
@@ -52,31 +53,18 @@ BrowserCategoryList::BrowserCategoryList( const QString &name, QWidget* parent,
     m_searchWidget->setClickMessage( i18n( "Filter Music Sources" ) );
     vLayout->addWidget( m_searchWidget );
 
-    connect( m_searchWidget, SIGNAL( filterChanged( const QString & ) ), SLOT( setFilter( const QString & ) ) );
+    connect( m_searchWidget, &SearchWidget::filterChanged, this, &BrowserCategoryList::setFilter );
 
     // -- the main list view
     m_categoryListView = new Amarok::PrettyTreeView();
-#ifdef Q_WS_MAC
-    // for some bizarre reason w/ some styles on mac
-    // per-pixel scrolling is slower than per-item
-    m_categoryListView->setVerticalScrollMode( QAbstractItemView::ScrollPerItem );
-    m_categoryListView->setHorizontalScrollMode( QAbstractItemView::ScrollPerItem );
-#else
-    // Scrolling per item is really not smooth and looks terrible
-    m_categoryListView->setVerticalScrollMode( QAbstractItemView::ScrollPerPixel );
-    m_categoryListView->setHorizontalScrollMode( QAbstractItemView::ScrollPerPixel );
-#endif
-
     m_categoryListView->setFrameShape( QFrame::NoFrame );
 
     m_proxyModel = new BrowserCategoryListSortFilterProxyModel( this );
     m_proxyModel->setSourceModel( m_categoryListModel );
 
-    m_delegate = new BrowserCategoryListDelegate( m_categoryListView );
-    m_categoryListView->setItemDelegate( m_delegate );
+    m_categoryListView->setItemDelegate( new PrettyTreeDelegate( m_categoryListView ) );
     m_categoryListView->setHeaderHidden( true );
     m_categoryListView->setRootIsDecorated( false );
-    m_categoryListView->setAlternatingRowColors( true );
     m_categoryListView->setModel( m_proxyModel );
     m_categoryListView->setMouseTracking ( true );
 
@@ -87,16 +75,14 @@ BrowserCategoryList::BrowserCategoryList( const QString &name, QWidget* parent,
         m_categoryListView->sortByColumn( 0 );
     }
 
-    connect( m_categoryListView, SIGNAL(activated(const QModelIndex &)),
-            SLOT(categoryActivated(const QModelIndex &)) );
+    connect( m_categoryListView, &Amarok::PrettyTreeView::activated,
+             this, &BrowserCategoryList::categoryActivated );
 
-    connect( m_categoryListView, SIGNAL(entered( const QModelIndex &) ),
-            SLOT(categoryEntered( const QModelIndex &) ) );
+    connect( m_categoryListView, &Amarok::PrettyTreeView::entered,
+             this, &BrowserCategoryList::categoryEntered );
 
     vLayout->addWidget( m_categoryListView );
     m_widgetStack->addWidget( mainWidget );
-
-    The::paletteHandler()->updateItemView( m_categoryListView );
 }
 
 BrowserCategoryList::~BrowserCategoryList()
@@ -134,7 +120,7 @@ BrowserCategoryList::home()
         activeCategory()->clearAdditionalItems();
         m_widgetStack->setCurrentIndex( 0 );
 
-        emit( viewChanged() );
+        Q_EMIT( viewChanged() );
     }
 }
 
@@ -163,7 +149,7 @@ BrowserCategoryList::addCategory( BrowserCategory *category )
 
     BrowserCategoryList *childList = qobject_cast<BrowserCategoryList*>( category );
     if ( childList )
-        connect( childList, SIGNAL( viewChanged() ), this, SLOT( childViewChanged() ) );
+        connect( childList, &BrowserCategoryList::viewChanged, this, &BrowserCategoryList::childViewChanged );
 
     category->polish(); // service categories do an additional construction in polish
 
@@ -171,7 +157,7 @@ BrowserCategoryList::addCategory( BrowserCategory *category )
     {
         m_proxyModel->sort( 0 );
     }
-    emit( viewChanged() );
+    Q_EMIT( viewChanged() );
 }
 
 
@@ -193,7 +179,7 @@ BrowserCategoryList::removeCategory( BrowserCategory *category )
 
     m_categoryListView->reset();
 
-    emit( viewChanged() );
+    Q_EMIT( viewChanged() );
 }
 
 BrowserCategory*
@@ -209,15 +195,16 @@ void BrowserCategoryList::setActiveCategory( BrowserCategory* category )
     if( m_widgetStack->indexOf( category ) == -1 )
         return; // no such category
 
-    if( !category )
+    if( !category || activeCategory() == category )
         return; // nothing to do
 
-    if( activeCategory() && (activeCategory() != category) )
+    if( activeCategory() )
         activeCategory()->clearAdditionalItems();
+    category->setupAddItems();
 
     m_widgetStack->setCurrentWidget( category );
 
-    emit( viewChanged() );
+    Q_EMIT( viewChanged() );
 }
 
 void BrowserCategoryList::back()
@@ -240,15 +227,15 @@ void BrowserCategoryList::back()
 void BrowserCategoryList::childViewChanged()
 {
     DEBUG_BLOCK
-    emit( viewChanged() );
+    Q_EMIT( viewChanged() );
 }
 
 QString BrowserCategoryList::navigate( const QString & target )
 {
     DEBUG_BLOCK
     debug() << "target: " << target;
-    QStringList categories = target.split( '/' );
-    if ( categories.size() == 0 )
+    QStringList categories = target.split( QLatin1Char('/') );
+    if ( categories.isEmpty() )
         return QString();
 
     //remove our own name if present, before passing on...
@@ -257,7 +244,7 @@ QString BrowserCategoryList::navigate( const QString & target )
         debug() << "removing own name (" << categories.at( 0 ) << ") from path";
         categories.removeFirst();
 
-        if ( categories.size() == 0 )
+        if ( categories.isEmpty() )
         {
             //nothing else left, make sure this category is visible
             home();
@@ -277,13 +264,13 @@ QString BrowserCategoryList::navigate( const QString & target )
     //check if this category is also BrowserCategoryList.target
     BrowserCategoryList *childList = qobject_cast<BrowserCategoryList*>( activeCategory() );
 
-    if ( childList == 0 )
+    if ( childList == nullptr )
     {
         debug() << "child is not a list...";
         if ( categories.size() > 1 )
         {
             categories.removeFirst();
-            QString leftover = categories.join( "/" );
+            QString leftover = categories.join( QLatin1Char('/') );
             return leftover;
         }
         return QString();
@@ -301,8 +288,8 @@ QString BrowserCategoryList::navigate( const QString & target )
     }
 
     categories.removeFirst();
-    debug() << "passing remaining path to child: " << categories.join( "/" );
-    return childList->navigate( categories.join( "/" ) );
+    debug() << "passing remaining path to child: " << categories.join( QLatin1Char('/') );
+    return childList->navigate( categories.join( QLatin1Char('/') ) );
 
 }
 
@@ -324,9 +311,9 @@ QString BrowserCategoryList::path()
 
 void BrowserCategoryList::categoryEntered( const QModelIndex & index )
 {
-    //get the long description for this item and pass it it to info proxy.
+    //get the long description for this item and pass it to info proxy.
 
-    BrowserCategory *category = 0;
+    BrowserCategory *category = nullptr;
 
     if ( index.data( CustomCategoryRoles::CategoryRole ).canConvert<BrowserCategory *>() )
         category = index.data( CustomCategoryRoles::CategoryRole ).value<BrowserCategory *>();
@@ -342,37 +329,36 @@ void BrowserCategoryList::categoryEntered( const QModelIndex & index )
         if ( m_infoHtmlTemplate.isEmpty() )
         {
 
-            KUrl dataUrl( KStandardDirs::locate( "data", "amarok/data/" ) );
-            QString dataPath = dataUrl.path();
+            QString dataPath = QStandardPaths::locate( QStandardPaths::GenericDataLocation, QStringLiteral("amarok/data/"), QStandardPaths::LocateDirectory );
 
             //load html
-            QString htmlPath = dataPath + "hover_info_template.html";
+            QString htmlPath = dataPath + "/hover_info_template.html";
             QFile file( htmlPath );
             if ( !file.open( QIODevice::ReadOnly | QIODevice::Text) )
             {
-                debug() << "error opening file. Error: " << file.error();
+                debug() << "error opening file:" << file.fileName() << "Error: " << file.error();
                 return;
             }
             m_infoHtmlTemplate = file.readAll();
             file.close();
 
-            m_infoHtmlTemplate.replace( "{background_color}",PaletteHandler::highlightColor().lighter( 150 ).name() );
-            m_infoHtmlTemplate.replace( "{border_color}", PaletteHandler::highlightColor().lighter( 150 ).name() );
-            m_infoHtmlTemplate.replace( "{text_color}", App::instance()->palette().brush( QPalette::Text ).color().name() );
-            QColor highlight( App::instance()->palette().highlight().color() );
+            m_infoHtmlTemplate.replace( QLatin1String("{background_color}"), The::paletteHandler()->highlightColor().lighter( 150 ).name() );
+            m_infoHtmlTemplate.replace( QLatin1String("{border_color}"), The::paletteHandler()->highlightColor().lighter( 150 ).name() );
+            m_infoHtmlTemplate.replace( QLatin1String("{text_color}"), pApp->palette().brush( QPalette::Text ).color().name() );
+            QColor highlight( pApp->palette().highlight().color() );
             highlight.setHsvF( highlight.hueF(), 0.3, .95, highlight.alphaF() );
-            m_infoHtmlTemplate.replace( "{header_background_color}", highlight.name() );
+            m_infoHtmlTemplate.replace( QLatin1String("{header_background_color}"), highlight.name() );
 
         }
 
         QString currentHtml = m_infoHtmlTemplate;
 
-        currentHtml.replace( "%%NAME%%", category->prettyName() );
-        currentHtml.replace( "%%DESCRIPTION%%", category->longDescription() );
-        currentHtml.replace( "%%IMAGE_PATH%%", "file://" + category->imagePath() );
+        currentHtml.replace( QLatin1String("%%NAME%%"), category->prettyName() );
+        currentHtml.replace( QLatin1String("%%DESCRIPTION%%"), category->longDescription() );
+        currentHtml.replace( QLatin1String("%%IMAGE_PATH%%"), "file://" + category->imagePath() );
 
         QVariantMap variantMap;
-        variantMap["main_info"] = QVariant( currentHtml );
+        variantMap[QStringLiteral("main_info")] = QVariant( currentHtml );
         The::infoProxy()->setInfo( variantMap );
     }
 }
@@ -432,4 +418,3 @@ void BrowserCategoryList::setFilter( const QString &filter )
     m_proxyModel->setFilterFixedString( filter );
 }
 
-#include "BrowserCategoryList.moc"
