@@ -24,13 +24,13 @@
 #include "core/support/Debug.h"
 #include "widgets/PrettyTreeRoles.h"
 
-#include <KStringHandler>
-
+#include <QCollator>
 #include <QVariant>
 #include <QString>
 
 CollectionSortFilterProxyModel::CollectionSortFilterProxyModel(  QObject * parent )
     : QSortFilterProxyModel( parent )
+    , m_col( new QCollator )
 {
     setSortLocaleAware( true );
 
@@ -40,11 +40,14 @@ CollectionSortFilterProxyModel::CollectionSortFilterProxyModel(  QObject * paren
     setFilterCaseSensitivity( Qt::CaseInsensitive );
 
     setDynamicSortFilter( true );
+
+    m_col->setCaseSensitivity( Qt::CaseInsensitive );
 }
 
 
 CollectionSortFilterProxyModel::~CollectionSortFilterProxyModel()
 {
+    delete m_col;
 }
 
 bool
@@ -54,6 +57,24 @@ CollectionSortFilterProxyModel::hasChildren(const QModelIndex & parent) const
     return sourceModel()->hasChildren(sourceParent);
 }
 
+bool
+CollectionSortFilterProxyModel::filterAcceptsRow( int source_row, const QModelIndex& source_parent ) const
+{
+    bool stringAccepted = QSortFilterProxyModel::filterAcceptsRow( source_row, source_parent );
+
+    if( AmarokConfig::showYears())
+    {
+        QModelIndex index = sourceModel()->index( source_row, 0, source_parent );
+        if( treeItem( index )->isAlbumItem() )
+        {
+            bool yearLoaded = index.data( PrettyTreeRoles::YearRole ) >= 0;
+            return yearLoaded && stringAccepted;
+        }
+    }
+
+    return stringAccepted;
+}
+
 bool
 CollectionSortFilterProxyModel::lessThan( const QModelIndex &left, const QModelIndex &right ) const
 {
@@ -108,7 +129,7 @@ CollectionSortFilterProxyModel::lessThanTrack( const QModelIndex &left, const QM
 
     // compare by name
     {
-        int comp = KStringHandler::naturalCompare( leftTrack->sortableName(), rightTrack->sortableName(), Qt::CaseInsensitive );
+        int comp = m_col->compare( leftTrack->sortableName(), rightTrack->sortableName() );
         if( comp < 0 )
             return true;
         if( comp > 0 )
@@ -135,8 +156,8 @@ CollectionSortFilterProxyModel::lessThanAlbum( const QModelIndex &left, const QM
     // compare by year
     if( AmarokConfig::showYears() )
     {
-        int leftYear = albumYear( leftAlbum );
-        int rightYear = albumYear( rightAlbum );
+        int leftYear = left.data( PrettyTreeRoles::YearRole ).toInt();
+        int rightYear = right.data( PrettyTreeRoles::YearRole ).toInt();
 
         if( leftYear < rightYear )
             return false; // left album is newer
@@ -146,7 +167,7 @@ CollectionSortFilterProxyModel::lessThanAlbum( const QModelIndex &left, const QM
 
     // compare by name
     {
-        int comp = KStringHandler::naturalCompare( leftAlbum->sortableName(), rightAlbum->sortableName(), Qt::CaseInsensitive );
+        int comp = m_col->compare( leftAlbum->sortableName(), rightAlbum->sortableName() );
         if( comp < 0 )
             return true;
         if( comp > 0 )
@@ -159,8 +180,8 @@ CollectionSortFilterProxyModel::lessThanAlbum( const QModelIndex &left, const QM
 bool
 CollectionSortFilterProxyModel::lessThanItem( const QModelIndex &left, const QModelIndex &right ) const
 {
-    Meta::DataPtr leftData = Meta::DataPtr::dynamicCast( treeItem(left)->data() );
-    Meta::DataPtr rightData = Meta::DataPtr::dynamicCast( treeItem(right)->data() );
+    Meta::DataPtr leftData = treeItem(left)->data();
+    Meta::DataPtr rightData = treeItem(right)->data();
 
     if( !leftData || !rightData )
     {
@@ -172,7 +193,7 @@ CollectionSortFilterProxyModel::lessThanItem( const QModelIndex &left, const QMo
 
     // compare by name
     {
-        int comp = KStringHandler::naturalCompare( leftData->sortableName(), rightData->sortableName(), Qt::CaseInsensitive );
+        int comp = m_col->compare( leftData->sortableName(), rightData->sortableName() );
         if( comp < 0 )
             return true;
         if( comp > 0 )
@@ -187,20 +208,3 @@ CollectionSortFilterProxyModel::treeItem( const QModelIndex &index ) const
 {
     return static_cast<CollectionTreeItem*>( index.internalPointer() );
 }
-
-int
-CollectionSortFilterProxyModel::albumYear( Meta::AlbumPtr album ) const
-{
-    if( album->name().isEmpty() ) // an unnamed album has no year
-        return 0;
-
-    Meta::TrackList tracks = album->tracks();
-    if( !tracks.isEmpty() )
-    {
-        Meta::YearPtr year = tracks.first()->year();
-        if( year && (year->year() != 0) )
-            return year->year();
-    }
-    return 0;
-}
-
