@@ -31,7 +31,6 @@ class QAction;
 class AMAROK_EXPORT CollectionTreeItem : public QObject
 {
     Q_OBJECT
-    Q_ENUMS( Type )
 
     public:
         enum Type
@@ -42,14 +41,15 @@ class AMAROK_EXPORT CollectionTreeItem : public QObject
             NoLabel,
             Data
         };
+        Q_ENUM( Type )
 
-        CollectionTreeItem( CollectionTreeItemModelBase *model ); //root node
-        CollectionTreeItem( Meta::DataPtr data, CollectionTreeItem *parent, CollectionTreeItemModelBase *model  ); //data node
+        explicit CollectionTreeItem( CollectionTreeItemModelBase *model ); //root node
+        CollectionTreeItem( const Meta::DataPtr &data, CollectionTreeItem *parent, CollectionTreeItemModelBase *model  ); //data node
         CollectionTreeItem( Collections::Collection *parentCollection, CollectionTreeItem *parent, CollectionTreeItemModelBase *model  ); //collection node
         //this ctor creates a "Various Artists" and "No Labels" nodes. do not use it for anything else
         CollectionTreeItem( Type type, const Meta::DataList &data, CollectionTreeItem *parent, CollectionTreeItemModelBase *model  ); //various artist node
 
-        ~CollectionTreeItem();
+        ~CollectionTreeItem() override;
 
         CollectionTreeItem* parent() const { return m_parent; }
 
@@ -92,21 +92,21 @@ class AMAROK_EXPORT CollectionTreeItem : public QObject
         const Meta::DataPtr data() const;
         Collections::Collection* parentCollection() const { return m_parentCollection ? m_parentCollection : (m_parent ? m_parent->parentCollection() : 0); }
 
-        KUrl::List urls() const;
+        QList<QUrl> urls() const;
         Meta::TrackList descendentTracks();
 
         bool allDescendentTracksLoaded() const;
 
-        //required to mark a tree item as dirty if the model has to requiry its childre
+        //required to mark a tree item as dirty if the model has to require its children
 
         Type type() const;
         bool requiresUpdate() const;
         void setRequiresUpdate( bool updateRequired );
 
-    signals:
+    Q_SIGNALS:
         void dataUpdated();
 
-    private slots:
+    private Q_SLOTS:
         void tracksCounted( QStringList res );
         void collectionUpdated();
 
