@@ -34,21 +34,68 @@
 #include "core-impl/collections/support/TextualQueryFilter.h"
 #include "widgets/PrettyTreeRoles.h"
 
-#include <KGlobalSettings>
-#include <KIcon>
-#include <KIconLoader>
-#include <KLocale>
-#include <KStandardDirs>
+#include <KLocalizedString>
+#include <ThreadWeaver/Lambda>
+#include <ThreadWeaver/Queue>
 
 #include <QApplication>
-#include <QStyle>
+#include <QIcon>
 #include <QPixmap>
+#include <QPointer>
+#include <QStandardPaths>
+#include <QStyle>
 #include <QTimeLine>
 #include <QTimer>
 
+#include <functional>
+
+
 using namespace Meta;
 
 
+class TrackLoaderJob : public ThreadWeaver::Job
+{
+public:
+    TrackLoaderJob( const QModelIndex &index, const Meta::AlbumPtr &album, CollectionTreeItemModelBase *model )
+        : m_index( index )
+        , m_album( album )
+        , m_model( model )
+        , m_abortRequested( false )
+    {
+        if( !m_model || !m_album || !m_index.isValid() )
+            requestAbort();
+    }
+
+    void requestAbort() override
+    {
+        m_abortRequested = true;
+    }
+
+protected:
+    void run( ThreadWeaver::JobPointer self, ThreadWeaver::Thread *thread ) override
+    {
+        Q_UNUSED( self )
+        Q_UNUSED( thread )
+
+        if( m_abortRequested || !m_model )
+            return;
+
+        const auto tracks = m_album->tracks();
+
+        if( m_model && !m_abortRequested )
+        {
+            auto slot = std::bind( &CollectionTreeItemModelBase::tracksLoaded, m_model, m_album, m_index, tracks );
+            QTimer::singleShot( 0, m_model, slot );
+        }
+    }
+
+private:
+    QModelIndex m_index;
+    Meta::AlbumPtr m_album;
+    QPointer<CollectionTreeItemModelBase> m_model;
+    bool m_abortRequested;
+};
+
 inline uint qHash( const Meta::DataPtr &data )
 {
     return qHash( data.data() );
@@ -65,20 +112,20 @@ CollectionTreeItemModelBase::CollectionTreeItemModelBase( )
     : QAbstractItemModel()
     , m_rootItem( 0 )
     , m_animFrame( 0 )
-    , m_loading1( QPixmap( KStandardDirs::locate("data", "amarok/images/loading1.png" ) ) )
-    , m_loading2( QPixmap( KStandardDirs::locate("data", "amarok/images/loading2.png" ) ) )
+    , m_loading1( QPixmap( QStandardPaths::locate( QStandardPaths::GenericDataLocation, QStringLiteral("amarok/images/loading1.png") ) ) )
+    , m_loading2( QPixmap( QStandardPaths::locate( QStandardPaths::GenericDataLocation, QStringLiteral("amarok/images/loading2.png") ) ) )
     , m_currentAnimPixmap( m_loading1 )
     , m_autoExpand( false )
 {
     m_timeLine = new QTimeLine( 10000, this );
     m_timeLine->setFrameRange( 0, 20 );
     m_timeLine->setLoopCount ( 0 );
-    connect( m_timeLine, SIGNAL(frameChanged(int)), this, SLOT(loadingAnimationTick()) );
+    connect( m_timeLine, &QTimeLine::frameChanged, this, &CollectionTreeItemModelBase::loadingAnimationTick );
 }
 
 CollectionTreeItemModelBase::~CollectionTreeItemModelBase()
 {
-    KConfigGroup config = Amarok::config( "Collection Browser" );
+    KConfigGroup config = Amarok::config( QStringLiteral("Collection Browser") );
     QList<int> levelNumbers;
     foreach( CategoryId::CatMenuId category, levels() )
         levelNumbers.append( category );
@@ -96,7 +143,6 @@ Qt::ItemFlags CollectionTreeItemModelBase::flags(const QModelIndex & index) cons
         flags = Qt::ItemIsEnabled | Qt::ItemIsSelectable | Qt::ItemIsDragEnabled | Qt::ItemIsEditable;
     }
     return flags;
-
 }
 
 bool
@@ -116,7 +162,7 @@ CollectionTreeItemModelBase::setData( const QModelIndex &index, const QVariant &
         if( ec )
         {
             ec->setTitle( value.toString() );
-            emit dataChanged( index, index );
+            Q_EMIT dataChanged( index, index );
             return true;
         }
     }
@@ -131,7 +177,7 @@ CollectionTreeItemModelBase::setData( const QModelIndex &index, const QVariant &
                 if( ec )
                     ec->setAlbum( value.toString() );
             }
-            emit dataChanged( index, index );
+            Q_EMIT dataChanged( index, index );
             return true;
         }
     }
@@ -146,7 +192,7 @@ CollectionTreeItemModelBase::setData( const QModelIndex &index, const QVariant &
                 if( ec )
                     ec->setArtist( value.toString() );
             }
-            emit dataChanged( index, index );
+            Q_EMIT dataChanged( index, index );
             return true;
         }
     }
@@ -161,7 +207,7 @@ CollectionTreeItemModelBase::setData( const QModelIndex &index, const QVariant &
                 if( ec )
                     ec->setGenre( value.toString() );
             }
-            emit dataChanged( index, index );
+            Q_EMIT dataChanged( index, index );
             return true;
         }
     }
@@ -176,7 +222,7 @@ CollectionTreeItemModelBase::setData( const QModelIndex &index, const QVariant &
                 if( ec )
                     ec->setYear( value.toInt() );
             }
-            emit dataChanged( index, index );
+            Q_EMIT dataChanged( index, index );
             return true;
         }
     }
@@ -191,7 +237,7 @@ CollectionTreeItemModelBase::setData( const QModelIndex &index, const QVariant &
                 if( ec )
                     ec->setComposer( value.toString() );
             }
-            emit dataChanged( index, index );
+            Q_EMIT dataChanged( index, index );
             return true;
         }
     }
@@ -218,13 +264,13 @@ CollectionTreeItemModelBase::dataForItem( CollectionTreeItem *item, int role, in
                 Meta::ArtistPtr artist = track->artist();
 
                 if( album && artist && album->isCompilation() )
-                    name.prepend( QString("%1 - ").arg(artist->prettyName()) );
+                    name.prepend( QStringLiteral("%1 - ").arg(artist->prettyName()) );
 
                 if( AmarokConfig::showTrackNumbers() )
                 {
                     int trackNum = track->trackNumber();
                     if( trackNum > 0 )
-                        name.prepend( QString("%1 - ").arg(trackNum) );
+                        name.prepend( QStringLiteral("%1 - ").arg(trackNum) );
                 }
 
                 // Check empty after track logic and before album logic
@@ -234,7 +280,7 @@ CollectionTreeItemModelBase::dataForItem( CollectionTreeItem *item, int role, in
             }
 
         case Qt::DecorationRole:
-            return KIcon( "media-album-track" );
+            return QIcon::fromTheme( QStringLiteral("media-album-track") );
         case PrettyTreeRoles::SortRole:
             return track->sortableName();
         }
@@ -249,14 +295,25 @@ CollectionTreeItemModelBase::dataForItem( CollectionTreeItem *item, int role, in
             {
                 QString name = album->prettyName();
                 // add years for named albums (if enabled)
-                if( AmarokConfig::showYears() && !album->name().isEmpty() )
+                if( AmarokConfig::showYears() )
                 {
-                    Meta::TrackList tracks = album->tracks();
-                    if( !tracks.isEmpty() )
+                    if( m_years.contains( album.data() ) )
                     {
-                        Meta::YearPtr year = tracks.first()->year();
-                        if( year && (year->year() != 0) )
-                            name.prepend( QString("%1 - ").arg( year->name() ) );
+                        int year = m_years.value( album.data() );
+
+                        if( year > 0 )
+                            name.prepend( QStringLiteral("%1 - ").arg( year ) );
+                    }
+                    else if( !album->name().isEmpty() )
+                    {
+                        if( !m_loadingAlbums.contains( album ) )
+                        {
+                            m_loadingAlbums.insert( album );
+
+                            auto nonConstThis = const_cast<CollectionTreeItemModelBase*>( this );
+                            auto job = QSharedPointer<TrackLoaderJob>::create( itemIndex( item ), album, nonConstThis );
+                            ThreadWeaver::Queue::instance()->enqueue( job );
+                        }
                     }
                 }
                 return name;
@@ -278,6 +335,25 @@ CollectionTreeItemModelBase::dataForItem( CollectionTreeItem *item, int role, in
 
         case PrettyTreeRoles::HasCoverRole:
             return AmarokConfig::showAlbumArt();
+
+        case PrettyTreeRoles::YearRole:
+            {
+                if( m_years.contains( album.data() ) )
+                    return m_years.value( album.data() );
+
+                else if( !album->name().isEmpty() )
+                {
+                    if( !m_loadingAlbums.contains( album ) )
+                    {
+                        m_loadingAlbums.insert( album );
+
+                        auto nonConstThis = const_cast<CollectionTreeItemModelBase*>( this );
+                        auto job = QSharedPointer<TrackLoaderJob>::create( itemIndex( item ), album, nonConstThis );
+                        ThreadWeaver::Queue::instance()->enqueue( job );
+                    }
+                }
+                return -1;
+            }
         }
     }
     else if( item->isDataItem() )
@@ -313,7 +389,7 @@ CollectionTreeItemModelBase::dataForItem( CollectionTreeItem *item, int role, in
         switch( role )
         {
         case Qt::DecorationRole:
-            return KIcon( "similarartists-amarok" );
+            return QIcon::fromTheme( QStringLiteral("similarartists-amarok") );
         case Qt::DisplayRole:
             return i18n( "Various Artists" );
         case PrettyTreeRoles::SortRole:
@@ -505,7 +581,8 @@ CollectionTreeItemModelBase::itemIndex( CollectionTreeItem *item ) const
     return createIndex( item->row(), 0, item );
 }
 
-void CollectionTreeItemModelBase::listForLevel(int level, Collections::QueryMaker * qm, CollectionTreeItem * parent)
+void
+CollectionTreeItemModelBase::listForLevel(int level, Collections::QueryMaker * qm, CollectionTreeItem * parent)
 {
     if( qm && parent )
     {
@@ -562,7 +639,7 @@ void CollectionTreeItemModelBase::listForLevel(int level, Collections::QueryMake
 
         //some very quick queries may be done so fast that the loading
         //animation creates an unnecessary flicker, therefore delay it for a bit
-        QTimer::singleShot( 150, this, SLOT(startAnimationTick()) );
+        QTimer::singleShot( 150, this, &CollectionTreeItemModelBase::startAnimationTick );
     }
 }
 
@@ -617,19 +694,50 @@ CollectionTreeItemModelBase::mapCategoryToQueryType( int levelType ) const
     return type;
 }
 
+void
+CollectionTreeItemModelBase::tracksLoaded( const Meta::AlbumPtr &album, const QModelIndex &index, const Meta::TrackList& tracks )
+{
+    DEBUG_BLOCK
+
+    if( !album )
+        return;
+
+    m_loadingAlbums.remove( album );
+
+    if( !index.isValid() )
+        return;
+
+    int year = 0;
+
+    if( !tracks.isEmpty() )
+    {
+        Meta::YearPtr yearPtr = tracks.first()->year();
+        if( yearPtr )
+            year = yearPtr->year();
+
+        debug() << "Valid album year found:" << year;
+    }
+
+    if( !m_years.contains( album.data() ) || m_years.value( album.data() ) != year )
+    {
+        m_years[ album.data() ] = year;
+        Q_EMIT dataChanged( index, index );
+    }
+}
+
 void
 CollectionTreeItemModelBase::addQueryMaker( CollectionTreeItem* item,
                                             Collections::QueryMaker *qm ) const
 {
-    connect( qm, SIGNAL(newResultReady(Meta::TrackList)), SLOT(newResultReady(Meta::TrackList)), Qt::QueuedConnection );
-    connect( qm, SIGNAL(newResultReady(Meta::ArtistList)), SLOT(newResultReady(Meta::ArtistList)), Qt::QueuedConnection );
-    connect( qm, SIGNAL(newResultReady(Meta::AlbumList)), SLOT(newResultReady(Meta::AlbumList)), Qt::QueuedConnection );
-    connect( qm, SIGNAL(newResultReady(Meta::GenreList)), SLOT(newResultReady(Meta::GenreList)), Qt::QueuedConnection );
-    connect( qm, SIGNAL(newResultReady(Meta::ComposerList)), SLOT(newResultReady(Meta::ComposerList)), Qt::QueuedConnection );
-    connect( qm, SIGNAL(newResultReady(Meta::YearList)), SLOT(newResultReady(Meta::YearList)), Qt::QueuedConnection );
-    connect( qm, SIGNAL(newResultReady(Meta::LabelList)), SLOT(newResultReady(Meta::LabelList)), Qt::QueuedConnection );
-    connect( qm, SIGNAL(newResultReady(Meta::DataList)), SLOT(newResultReady(Meta::DataList)), Qt::QueuedConnection );
-    connect( qm, SIGNAL(queryDone()), SLOT(queryDone()), Qt::QueuedConnection );
+    connect( qm, &Collections::QueryMaker::newTracksReady, this, &CollectionTreeItemModelBase::newTracksReady, Qt::QueuedConnection );
+    connect( qm, &Collections::QueryMaker::newArtistsReady, this, &CollectionTreeItemModelBase::newArtistsReady, Qt::QueuedConnection );
+    connect( qm, &Collections::QueryMaker::newAlbumsReady, this, &CollectionTreeItemModelBase::newAlbumsReady, Qt::QueuedConnection );
+    connect( qm, &Collections::QueryMaker::newGenresReady, this, &CollectionTreeItemModelBase::newGenresReady, Qt::QueuedConnection );
+    connect( qm, &Collections::QueryMaker::newComposersReady, this, &CollectionTreeItemModelBase::newComposersReady, Qt::QueuedConnection );
+    connect( qm, &Collections::QueryMaker::newYearsReady, this, &CollectionTreeItemModelBase::newYearsReady, Qt::QueuedConnection );
+    connect( qm, &Collections::QueryMaker::newLabelsReady, this, &CollectionTreeItemModelBase::newLabelsReady, Qt::QueuedConnection );
+    connect( qm, &Collections::QueryMaker::newDataReady, this, &CollectionTreeItemModelBase::newDataReady, Qt::QueuedConnection );
+    connect( qm, &Collections::QueryMaker::queryDone, this, &CollectionTreeItemModelBase::queryDone, Qt::QueuedConnection );
     m_runningQueries.insert( item, qm );
 }
 
@@ -654,13 +762,13 @@ CollectionTreeItemModelBase::queryDone()
     //reset icon for this item
     if( item && item != m_rootItem )
     {
-        emit dataChanged( itemIndex( item ), itemIndex( item ) );
+        Q_EMIT dataChanged( itemIndex( item ), itemIndex( item ) );
     }
 
     //stop timer if there are no more animations active
     if( m_runningQueries.isEmpty() )
     {
-        emit allQueriesFinished( m_autoExpand );
+        Q_EMIT allQueriesFinished( m_autoExpand );
         m_autoExpand = false; // reset to default value
         m_timeLine->stop();
     }
@@ -670,61 +778,61 @@ CollectionTreeItemModelBase::queryDone()
 // TODO
 
 /** Small helper function to convert a list of e.g. tracks to a list of DataPtr */
-template<class PointerType, class ListType>
+template<class PointerType>
 static Meta::DataList
-convertToDataList( const ListType& list )
+convertToDataList( const QList<PointerType>& list )
 {
     Meta::DataList data;
-    foreach( PointerType p, list )
+    for( const auto &p : list )
         data << Meta::DataPtr::staticCast( p );
 
     return data;
 }
 
 void
-CollectionTreeItemModelBase::newResultReady( Meta::TrackList res )
+CollectionTreeItemModelBase::newTracksReady( const Meta::TrackList &res )
 {
-    newResultReady( convertToDataList<Meta::TrackPtr, Meta::TrackList>( res ) );
+    newDataReady( convertToDataList( res ) );
 }
 
 void
-CollectionTreeItemModelBase::newResultReady( Meta::ArtistList res )
+CollectionTreeItemModelBase::newArtistsReady( const Meta::ArtistList &res )
 {
-    newResultReady( convertToDataList<Meta::ArtistPtr, Meta::ArtistList>( res ) );
+    newDataReady( convertToDataList( res ) );
 }
 
 void
-CollectionTreeItemModelBase::newResultReady( Meta::AlbumList res )
+CollectionTreeItemModelBase::newAlbumsReady( const Meta::AlbumList &res )
 {
-    newResultReady( convertToDataList<Meta::AlbumPtr, Meta::AlbumList>( res ) );
+    newDataReady( convertToDataList( res ) );
 }
 
 void
-CollectionTreeItemModelBase::newResultReady( Meta::GenreList res )
+CollectionTreeItemModelBase::newGenresReady( const Meta::GenreList &res )
 {
-    newResultReady( convertToDataList<Meta::GenrePtr, Meta::GenreList>( res ) );
+    newDataReady( convertToDataList( res ) );
 }
 
 void
-CollectionTreeItemModelBase::newResultReady( Meta::ComposerList res )
+CollectionTreeItemModelBase::newComposersReady( const Meta::ComposerList &res )
 {
-    newResultReady( convertToDataList<Meta::ComposerPtr, Meta::ComposerList>( res ) );
+    newDataReady( convertToDataList( res ) );
 }
 
 void
-CollectionTreeItemModelBase::newResultReady( Meta::YearList res )
+CollectionTreeItemModelBase::newYearsReady( const Meta::YearList &res )
 {
-    newResultReady( convertToDataList<Meta::YearPtr, Meta::YearList>( res ) );
+    newDataReady( convertToDataList( res ) );
 }
 
 void
-CollectionTreeItemModelBase::newResultReady( Meta::LabelList res )
+CollectionTreeItemModelBase::newLabelsReady( const Meta::LabelList &res )
 {
-    newResultReady( convertToDataList<Meta::LabelPtr, Meta::LabelList>( res ) );
+    newDataReady( convertToDataList( res ) );
 }
 
 void
-CollectionTreeItemModelBase::newResultReady( Meta::DataList data )
+CollectionTreeItemModelBase::newDataReady( const Meta::DataList &data )
 {
     //if we are expanding an item, we'll find the sender in childQueries
     //otherwise we are filtering all collections
@@ -745,7 +853,7 @@ CollectionTreeItemModelBase::newResultReady( Meta::DataList data )
 void
 CollectionTreeItemModelBase::handleSpecialQueryResult( CollectionTreeItem::Type type, Collections::QueryMaker *qm, const Meta::DataList &dataList )
 {
-    CollectionTreeItem *parent = 0;
+    CollectionTreeItem *parent = nullptr;
 
     if( type == CollectionTreeItem::VariousArtist )
         parent = m_compilationQueries.value( qm );
@@ -837,7 +945,7 @@ CollectionTreeItemModelBase::handleSpecialQueryResult( CollectionTreeItem::Type
         {
             if( m_expandedSpecialNodes.contains( parent->parentCollection() ) )
             {
-                emit expandIndex( createIndex( 0, 0, specialNode ) ); //we have just inserted the vaItem at row 0
+                Q_EMIT expandIndex( createIndex( 0, 0, specialNode ) ); //we have just inserted the vaItem at row 0
             }
         }
     }
@@ -854,7 +962,7 @@ CollectionTreeItemModelBase::handleNormalQueryResult( Collections::QueryMaker *q
         if ( parent->isDataItem() )
         {
             if ( m_expandedItems.contains( parent->data() ) )
-                emit expandIndex( parentIndex );
+                Q_EMIT expandIndex( parentIndex );
             else
                 //simply insert the item, nothing will change if it is already in the set
                 m_expandedItems.insert( parent->data() );
@@ -870,7 +978,7 @@ CollectionTreeItemModelBase::populateChildren( const DataList &dataList, Collect
     // add new rows after existing ones here (which means all artists nodes
     // will be inserted after the "Various Artists" node)
     // figure out which children of parent have to be removed,
-    // which new children have to be added, and preemptively emit dataChanged for the rest
+    // which new children have to be added, and preemptively Q_EMIT dataChanged for the rest
     // have to check how that influences performance...
     const QSet<Meta::DataPtr> dataSet = dataList.toSet();
     QSet<Meta::DataPtr> childrenSet;
@@ -886,7 +994,7 @@ CollectionTreeItemModelBase::populateChildren( const DataList &dataList, Collect
     const QSet<Meta::DataPtr> dataToBeRemoved = childrenSet - dataSet;
 
     // first remove all rows that have to be removed
-    // walking through the cildren in reverse order does not screw up the order
+    // walking through the children in reverse order does not screw up the order
     for( int i = parent->childCount() - 1; i >= 0; i-- )
     {
         CollectionTreeItem *child = parent->child( i );
@@ -914,13 +1022,13 @@ CollectionTreeItemModelBase::populateChildren( const DataList &dataList, Collect
         }
         else
         {
-            // the remainging child items may be dirty, so refresh them
+            // the remaining child items may be dirty, so refresh them
             if( child->isDataItem() && child->data() && m_expandedItems.contains( child->data() ) )
                 ensureChildrenLoaded( child );
 
             // tell the view that the existing children may have changed
             QModelIndex idx = index( i, 0, parentIndex );
-            emit dataChanged( idx, idx );
+            Q_EMIT dataChanged( idx, idx );
         }
     }
 
@@ -956,22 +1064,22 @@ CollectionTreeItemModelBase::iconForCategory( CategoryId::CatMenuId category )
     switch( category )
     {
         case CategoryId::Album :
-            return KIcon( "media-optical-amarok" );
+            return QIcon::fromTheme( QStringLiteral("media-optical-amarok") );
         case CategoryId::Artist :
-            return KIcon( "view-media-artist-amarok" );
+            return QIcon::fromTheme( QStringLiteral("view-media-artist-amarok") );
         case CategoryId::AlbumArtist :
-            return KIcon( "view-media-artist-amarok" );
+            return QIcon::fromTheme( QStringLiteral("view-media-artist-amarok") );
         case CategoryId::Composer :
-            return KIcon( "filename-composer-amarok" );
+            return QIcon::fromTheme( QStringLiteral("filename-composer-amarok") );
         case CategoryId::Genre :
-            return KIcon( "favorite-genres-amarok" );
+            return QIcon::fromTheme( QStringLiteral("favorite-genres-amarok") );
         case CategoryId::Year :
-            return KIcon( "clock" );
+            return QIcon::fromTheme( QStringLiteral("clock") );
         case CategoryId::Label :
-            return KIcon( "label-amarok" );
+            return QIcon::fromTheme( QStringLiteral("label-amarok") );
         case CategoryId::None:
         default:
-            return KIcon( "image-missing" );
+            return QIcon::fromTheme( QStringLiteral("image-missing") );
     }
 
 }
@@ -1071,7 +1179,7 @@ void CollectionTreeItemModelBase::loadingAnimationTick()
     {
         if( item == m_rootItem )
             continue;
-        emit dataChanged( itemIndex( item ), itemIndex( item ) );
+        Q_EMIT dataChanged( itemIndex( item ), itemIndex( item ) );
     }
 }
 
@@ -1099,7 +1207,7 @@ CollectionTreeItemModelBase::slotFilter( bool autoExpand )
     {
         CollectionTreeItem *expandedItem = m_collections.value( expanded->collectionId() ).second;
         if( expandedItem )
-            emit expandIndex( itemIndex( expandedItem ) );
+            Q_EMIT expandIndex( itemIndex( expandedItem ) );
     }
 }
 
@@ -1214,4 +1322,3 @@ CollectionTreeItemModelBase::levelCategory( const int level ) const
     return CategoryId::None;
 }
 
-#include "CollectionTreeItemModelBase.moc"
