@@ -28,7 +28,6 @@ class SearchWidget;
 class CollectionWidget : public BrowserCategory
 {
     Q_OBJECT
-    Q_ENUMS( ViewMode )
 
     public:
         enum ViewMode
@@ -36,32 +35,33 @@ class CollectionWidget : public BrowserCategory
             UnifiedCollection,
             NormalCollections
         };
+        Q_ENUM( ViewMode )
 
-        CollectionWidget( const QString &name , QWidget *parent );
-        ~CollectionWidget();
+        explicit CollectionWidget( const QString &name , QWidget *parent );
+        ~CollectionWidget() override;
         static CollectionWidget *instance() { return s_instance; }
 
 
-        QString filter() const;
+        QString filter() const override;
 
         /**
          * Apply a filter to the tree view.
          * @param filter The filter to apply.
          */
-        void setFilter( const QString &filter );
+        void setFilter( const QString &filter ) override;
 
         /** Return the current views selected levels */
-        QList<CategoryId::CatMenuId> levels() const;
+        QList<CategoryId::CatMenuId> levels() const override;
 
         /** Set the current views selected levels */
-        void setLevels( const QList<CategoryId::CatMenuId> &levels );
+        void setLevels( const QList<CategoryId::CatMenuId> &levels ) override;
 
         void focusInputLine();
         CollectionBrowserTreeView *currentView();
         SearchWidget *searchWidget();
         ViewMode viewMode() const;
 
-    public slots:
+    public Q_SLOTS:
         void sortLevelSelected( QAction * );
         void sortByActionPayload( QAction * );
         void slotShowYears( bool checked );
