@@ -32,12 +32,12 @@ namespace PlaylistBrowserNS
 class DynamicBiasDelegate : public QStyledItemDelegate
 {
     public:
-        DynamicBiasDelegate( QWidget* parent = 0 );
-        ~DynamicBiasDelegate();
+        explicit DynamicBiasDelegate( QWidget* parent = nullptr );
+        ~DynamicBiasDelegate() override;
 
         void paint( QPainter* painter,
                     const QStyleOptionViewItem& option,
-                    const QModelIndex& index ) const;
+                    const QModelIndex& index ) const override;
 
     private:
       QFont m_normalFont;
