@@ -33,8 +33,8 @@
 
 #include <KActionMenu>
 #include <KConfigGroup>
-#include <KIcon>
-#include <KStandardDirs>
+#include <QIcon>
+#include <QStandardPaths>
 #include <KToolBar>
 
 #include <QHeaderView>
@@ -44,7 +44,7 @@
 
 using namespace PlaylistBrowserNS;
 
-QString PlaylistBrowserCategory::s_mergeViewKey( "Merged View" );
+QString PlaylistBrowserCategory::s_mergeViewKey( QStringLiteral("Merged View") );
 
 PlaylistBrowserCategory::PlaylistBrowserCategory( int playlistCategory,
                                                   const QString &categoryName,
@@ -56,7 +56,7 @@ PlaylistBrowserCategory::PlaylistBrowserCategory( int playlistCategory,
     m_playlistCategory( playlistCategory )
 {
     setContentsMargins( 0, 0, 0, 0 );
-    setImagePath( KStandardDirs::locate( "data", "amarok/images/hover_info_podcasts.png" ) );
+    setImagePath( QStandardPaths::locate( QStandardPaths::GenericDataLocation, QStringLiteral("amarok/images/hover_info_podcasts.png") ) );
 
     // set background
     if( AmarokConfig::showBrowserBackgroundImage() )
@@ -74,23 +74,23 @@ PlaylistBrowserCategory::PlaylistBrowserCategory( int playlistCategory,
 
     m_toolBar->addSeparator();
 
-    m_addFolderAction = new KAction( KIcon( "folder-new" ), i18n( "Add Folder" ), this  );
+    m_addFolderAction = new QAction( QIcon::fromTheme( QStringLiteral("folder-new") ), i18n( "Add Folder" ), this  );
     m_addFolderAction->setPriority( QAction::LowPriority );
     m_toolBar->addAction( m_addFolderAction );
-    connect( m_addFolderAction, SIGNAL(triggered(bool)), SLOT(createNewFolder()) );
+    connect( m_addFolderAction, &QAction::triggered, this, &PlaylistBrowserCategory::createNewFolder );
 
-    m_providerMenu = new KActionMenu( KIcon( "checkbox" ), i18n( "Visible Sources"), this );
+    m_providerMenu = new KActionMenu( QIcon::fromTheme( QStringLiteral("checkbox") ), i18n( "Visible Sources"), this );
     m_providerMenu->setDelayed( false );
     m_providerMenu->setPriority( QAction::HighPriority );
     m_toolBar->addAction( m_providerMenu );
 
-    KAction *toggleAction = new KAction( KIcon( "view-list-tree" ), i18n( "Merged View" ),
+    QAction *toggleAction = new QAction( QIcon::fromTheme( QStringLiteral("view-list-tree") ), i18n( "Merged View" ),
                                          m_toolBar );
     toggleAction->setCheckable( true );
     toggleAction->setChecked( Amarok::config( m_configGroup ).readEntry( s_mergeViewKey, false ) );
     toggleAction->setPriority( QAction::LowPriority );
     m_toolBar->addAction( toggleAction );
-    connect( toggleAction, SIGNAL(triggered(bool)), SLOT(toggleView(bool)) );
+    connect( toggleAction, &QAction::triggered, this, &PlaylistBrowserCategory::toggleView );
 
     m_toolBar->addSeparator();
 
@@ -128,13 +128,13 @@ PlaylistBrowserCategory::PlaylistBrowserCategory( int playlistCategory,
         createProviderButton( provider );
     }
 
-    connect( The::playlistManager(), SIGNAL(providerAdded(Playlists::PlaylistProvider*,int)),
-             SLOT(slotProviderAdded(Playlists::PlaylistProvider*,int)) );
-    connect( The::playlistManager(), SIGNAL(providerRemoved(Playlists::PlaylistProvider*,int)),
-             SLOT(slotProviderRemoved(Playlists::PlaylistProvider*,int)) );
+    connect( The::playlistManager(), &PlaylistManager::providerAdded,
+             this, &PlaylistBrowserCategory::slotProviderAdded );
+    connect( The::playlistManager(), &PlaylistManager::providerRemoved,
+             this, &PlaylistBrowserCategory::slotProviderRemoved );
 
-    connect( The::paletteHandler(), SIGNAL(newPalette(QPalette)),
-             SLOT(newPalette(QPalette)) );
+    connect( The::paletteHandler(), &PaletteHandler::newPalette,
+             this, &PlaylistBrowserCategory::newPalette );
 }
 
 PlaylistBrowserCategory::~PlaylistBrowserCategory()
@@ -177,14 +177,14 @@ PlaylistBrowserCategory::toggleView( bool merged )
         m_filterProxy->setSourceModel( m_byFolderProxy );
         m_playlistView->setItemDelegate( m_defaultItemDelegate );
         m_playlistView->setRootIsDecorated( true );
-        m_addFolderAction->setHelpText( m_addFolderAction->text() );
+        setHelpText( m_addFolderAction->text(), m_addFolderAction );
     }
     else
     {
         m_filterProxy->setSourceModel( m_byProviderProxy );
         m_playlistView->setItemDelegate( m_byProviderDelegate );
         m_playlistView->setRootIsDecorated( false );
-        m_addFolderAction->setHelpText( i18n( "Folders are only shown in <b>merged view</b>." ) );
+        setHelpText( i18n( "Folders are only shown in <b>merged view</b>." ), m_addFolderAction );
     }
 
     //folders don't make sense in per-provider view
@@ -193,6 +193,16 @@ PlaylistBrowserCategory::toggleView( bool merged )
     Amarok::config( m_configGroup ).writeEntry( s_mergeViewKey, merged );
 }
 
+void
+PlaylistBrowserCategory::setHelpText(const QString &text, QAction *qa)
+{
+    qa->setStatusTip(text);
+    qa->setToolTip(text);
+    if ((qa->whatsThis()).isEmpty()) {
+        qa->setWhatsThis(text);
+    }
+}
+
 void
 PlaylistBrowserCategory::slotProviderAdded( Playlists::PlaylistProvider *provider, int category )
 {
@@ -227,12 +237,12 @@ PlaylistBrowserCategory::createProviderButton( const Playlists::PlaylistProvider
     providerToggle->setCheckable( true );
     providerToggle->setChecked( true );
     providerToggle->setData( QVariant::fromValue( provider ) );
-    connect( providerToggle, SIGNAL(toggled(bool)), SLOT(slotToggleProviderButton()) );
+    connect( providerToggle, &QAction::toggled, this, &PlaylistBrowserCategory::slotToggleProviderButton );
     m_providerMenu->addAction( providerToggle );
 
     //if there is only one provider the button needs to be disabled.
     //When a second is added we can enable the first.
-    if( m_providerActions.count() == 0 )
+    if( m_providerActions.isEmpty() )
         providerToggle->setEnabled( false );
     else if( m_providerActions.count() == 1 )
         m_providerActions.values().first()->setEnabled( true );
@@ -250,7 +260,7 @@ PlaylistBrowserCategory::slotToggleProviderButton()
         QAction *action = m_providerActions.value( p );
         if( action->isChecked() )
         {
-            QString escapedName = QRegExp::escape( p->prettyName() ).replace( ' ', "\\ " );
+            QString escapedName = QRegExp::escape( p->prettyName() ).replace( ' ', QLatin1String("\\ ") );
             filter += QString( filter.isEmpty() ? "%1" : "|%1" ).arg( escapedName );
             checkedActions << action;
             action->setEnabled( true );
@@ -288,7 +298,7 @@ PlaylistBrowserCategory::createNewFolder()
                     folderCount = newNumber;
             }
         }
-        groupName += QString( " (%1)" ).arg( folderCount + 1 );
+        groupName += QStringLiteral( " (%1)" ).arg( folderCount + 1 );
     }
     QModelIndex idx = m_filterProxy->mapFromSource( m_byFolderProxy->createNewFolder( groupName ) );
     m_playlistView->setCurrentIndex( idx );
@@ -303,4 +313,3 @@ PlaylistBrowserCategory::newPalette( const QPalette &palette )
     The::paletteHandler()->updateItemView( m_playlistView );
 }
 
-#include "PlaylistBrowserCategory.moc"
