@@ -25,7 +25,7 @@
 #include "core/support/Debug.h"
 #include "widgets/PrettyTreeRoles.h"
 
-#include <KIcon>
+#include <QIcon>
 
 #include <QAction>
 
@@ -41,17 +41,17 @@ lessThanPlaylistTitles( const Playlists::PlaylistPtr &lhs, const Playlists::Play
 PlaylistBrowserModel::PlaylistBrowserModel( int playlistCategory )
     : m_playlistCategory( playlistCategory )
 {
-    connect( The::playlistManager(), SIGNAL(updated(int)), SLOT(slotUpdate(int)) );
+    connect( The::playlistManager(), &PlaylistManager::updated, this, &PlaylistBrowserModel::slotUpdate );
 
-    connect( The::playlistManager(), SIGNAL(playlistAdded(Playlists::PlaylistPtr,int)),
-             SLOT(slotPlaylistAdded(Playlists::PlaylistPtr,int)) );
-    connect( The::playlistManager(), SIGNAL(playlistRemoved(Playlists::PlaylistPtr,int)),
-             SLOT(slotPlaylistRemoved(Playlists::PlaylistPtr,int)) );
-    connect( The::playlistManager(), SIGNAL(playlistUpdated(Playlists::PlaylistPtr,int)),
-             SLOT(slotPlaylistUpdated(Playlists::PlaylistPtr,int)) );
+    connect( The::playlistManager(), &PlaylistManager::playlistAdded,
+             this, &PlaylistBrowserModel::slotPlaylistAdded );
+    connect( The::playlistManager(), &PlaylistManager::playlistRemoved,
+             this, &PlaylistBrowserModel::slotPlaylistRemoved );
+    connect( The::playlistManager(), &PlaylistManager::playlistUpdated,
+             this, &PlaylistBrowserModel::slotPlaylistUpdated );
 
-    connect( The::playlistManager(), SIGNAL(renamePlaylist(Playlists::PlaylistPtr)),
-             SLOT(slotRenamePlaylist(Playlists::PlaylistPtr)) );
+    connect( The::playlistManager(), &PlaylistManager::renamePlaylist,
+             this, &PlaylistBrowserModel::slotRenamePlaylist );
 
     m_playlists = loadPlaylists();
 }
@@ -63,7 +63,7 @@ PlaylistBrowserModel::data( const QModelIndex &index, int role ) const
     Playlists::PlaylistPtr playlist = m_playlists.value( row );
 
     QString name;
-    KIcon icon;
+    QIcon icon;
     int playlistCount = 0;
     QList<QAction *> providerActions;
     QList<Playlists::PlaylistProvider *> providers =
@@ -79,12 +79,12 @@ PlaylistBrowserModel::data( const QModelIndex &index, int role ) const
             {
                 track = playlist->tracks()[index.row()];
                 name = track->prettyName();
-                icon = KIcon( "amarok_track" );
+                icon = QIcon::fromTheme( QStringLiteral("amarok_track") );
             }
             else
             {
                 name = playlist->prettyName();
-                icon = KIcon( "amarok_playlist" );
+                icon = QIcon::fromTheme( QStringLiteral("amarok_playlist") );
             }
             break;
         }
@@ -93,7 +93,7 @@ PlaylistBrowserModel::data( const QModelIndex &index, int role ) const
             if( !playlist->groups().isEmpty() )
             {
                 name = playlist->groups().first();
-                icon = KIcon( "folder" );
+                icon = QIcon::fromTheme( QStringLiteral("folder") );
             }
             break;
         }
@@ -204,7 +204,7 @@ PlaylistBrowserModel::setData( const QModelIndex &idx, const QVariant &value, in
                     Meta::TrackPtr track = trackFromIndex( idx );
                     if( !track )
                         return false;
-                    debug() << QString( "Copy track \"%1\" to \"%2\"." )
+                    debug() << QStringLiteral( "Copy track \"%1\" to \"%2\"." )
                             .arg( track->prettyName(),  provider->prettyName() );
     //                return !provider->addTrack( track ).isNull();
                     provider->addTrack( track ); //ignore result since UmsPodcastProvider returns NULL
@@ -222,7 +222,7 @@ PlaylistBrowserModel::setData( const QModelIndex &idx, const QVariant &value, in
                             return false;
                     }
 
-                    debug() << QString( "Copy playlist \"%1\" to \"%2\"." )
+                    debug() << QStringLiteral( "Copy playlist \"%1\" to \"%2\"." )
                             .arg( playlist->prettyName(), provider->prettyName() );
 
                     return !provider->addPlaylist( playlist ).isNull();
@@ -337,7 +337,7 @@ PlaylistBrowserModel::canFetchMore( const QModelIndex &parent ) const
     else if( !IS_TRACK(parent) )
     {
         Playlists::PlaylistPtr playlist = m_playlists.value( parent.internalId() );
-        //TODO: imeplement incremental loading of tracks by checking for ==
+        //TODO: implement incremental loading of tracks by checking for ==
         if( playlist->trackCount() != playlist->tracks().count() )
             return true; //tracks still need to be loaded.
     }
@@ -498,7 +498,7 @@ PlaylistBrowserModel::dropMimeData( const QMimeData *data, Qt::DropAction action
 }
 
 void
-PlaylistBrowserModel::metadataChanged( Playlists::PlaylistPtr playlist )
+PlaylistBrowserModel::metadataChanged( const Playlists::PlaylistPtr &playlist )
 {
     int indexNumber = m_playlists.indexOf( playlist );
     if( indexNumber == -1 )
@@ -507,11 +507,11 @@ PlaylistBrowserModel::metadataChanged( Playlists::PlaylistPtr playlist )
         return;
     }
     QModelIndex playlistIdx = index( indexNumber, 0 );
-    emit dataChanged( playlistIdx, playlistIdx );
+    Q_EMIT dataChanged( playlistIdx, playlistIdx );
 }
 
 void
-PlaylistBrowserModel::trackAdded( Playlists::PlaylistPtr playlist, Meta::TrackPtr track,
+PlaylistBrowserModel::trackAdded(const Playlists::PlaylistPtr &playlist, const Meta::TrackPtr &track,
                                           int position )
 {
     Q_UNUSED( track );
@@ -527,7 +527,7 @@ PlaylistBrowserModel::trackAdded( Playlists::PlaylistPtr playlist, Meta::TrackPt
 }
 
 void
-PlaylistBrowserModel::trackRemoved( Playlists::PlaylistPtr playlist, int position )
+PlaylistBrowserModel::trackRemoved(const Playlists::PlaylistPtr &playlist, int position )
 {
     int indexNumber = m_playlists.indexOf( playlist );
     if( indexNumber == -1 )
@@ -551,7 +551,7 @@ PlaylistBrowserModel::slotRenamePlaylist( Playlists::PlaylistPtr playlist )
     {
         if( p == playlist )
         {
-            emit renameIndex( index( row, 0 ) );
+            Q_EMIT renameIndex( index( row, 0 ) );
             break;
         }
         row++;
@@ -649,7 +649,7 @@ PlaylistBrowserModel::slotPlaylistUpdated( Playlists::PlaylistPtr playlist, int
     //TODO: this should work by signaling a change in the model data, but QtGroupingProxy doesn't
     //work like that ATM
 //    const QModelIndex &idx = index( position, 0 );
-//    emit dataChanged( idx, idx );
+//    Q_EMIT dataChanged( idx, idx );
 
     //HACK: remove and readd so QtGroupingProxy can put it in the correct groups.
     beginRemoveRows( QModelIndex(), position, position );
