@@ -1,5 +1,5 @@
 /****************************************************************************************
- * Copyright (c) 2007-2010 Bart Cerneels <bart.cerneels@kde.org>                        *
+ * Copyright (c) 2007-2011 Bart Cerneels <bart.cerneels@kde.org>                        *
  *                                                                                      *
  * This program is free software; you can redistribute it and/or modify it under        *
  * the terms of the GNU General Public License as published by the Free Software        *
@@ -19,28 +19,31 @@
 #include <QDebug>
 #include <QIcon>
 #include <QInputDialog>
+#include <QTimer>
+
+/*!
+    \class QtGroupingProxy
+    \brief The QtGroupingProxy class will group source model rows by adding a new top tree-level.
+    The source model can be flat or tree organized, but only the original top level rows are used
+    for determining the grouping.
+    \ingroup model-view
+*/
 
 
-QtGroupingProxy::QtGroupingProxy( QAbstractItemModel *model, QModelIndex rootNode, int groupedColumn )
-    : QAbstractProxyModel()
-    , m_rootNode( rootNode )
+QtGroupingProxy::QtGroupingProxy( QObject *parent )
+    : QAbstractProxyModel( parent )
+{
+}
+
+QtGroupingProxy::QtGroupingProxy( QAbstractItemModel *model, const QModelIndex &rootIndex,
+                                  int groupedColumn, QObject *parent )
+    : QAbstractProxyModel( parent )
+    , m_rootIndex( rootIndex )
     , m_groupedColumn( 0 )
 {
     setSourceModel( model );
 
-    // signal proxies
-    connect( sourceModel(),
-        SIGNAL( dataChanged( const QModelIndex&, const QModelIndex& ) ),
-        this, SLOT( modelDataChanged( const QModelIndex&, const QModelIndex& ) )
-    );
-    connect( sourceModel(),
-        SIGNAL( rowsInserted( const QModelIndex&, int, int ) ), this,
-        SLOT( modelRowsInserted( const QModelIndex &, int, int ) ) );
-    connect( sourceModel(), SIGNAL( rowsRemoved( const QModelIndex&, int, int ) ),
-        this, SLOT( modelRowsRemoved( const QModelIndex&, int, int ) ) );
-    connect( sourceModel(), SIGNAL(layoutChanged()), SLOT(buildTree()) );
-
-    if( m_groupedColumn != -1 )
+    if( groupedColumn != -1 )
         setGroupedColumn( groupedColumn );
 }
 
@@ -48,13 +51,56 @@ QtGroupingProxy::~QtGroupingProxy()
 {
 }
 
+void
+QtGroupingProxy::setSourceModel( QAbstractItemModel *sourceModel )
+{
+    QAbstractProxyModel::setSourceModel( sourceModel );
+    // signal proxies
+    connect( sourceModel, &QAbstractItemModel::dataChanged,
+             this, &QtGroupingProxy::modelDataChanged );
+    connect( sourceModel, &QAbstractItemModel::rowsInserted,
+             this, &QtGroupingProxy::modelRowsInserted );
+    connect( sourceModel, &QAbstractItemModel::rowsAboutToBeInserted,
+             this, &QtGroupingProxy::modelRowsAboutToBeInserted );
+    connect( sourceModel, &QAbstractItemModel::rowsRemoved,
+             this, &QtGroupingProxy::modelRowsRemoved );
+    connect( sourceModel, &QAbstractItemModel::rowsAboutToBeRemoved,
+             this, &QtGroupingProxy::modelRowsAboutToBeRemoved );
+    connect( sourceModel, &QAbstractItemModel::layoutChanged,
+             this, &QtGroupingProxy::buildTree );
+    connect( sourceModel, &QAbstractItemModel::dataChanged,
+             this, &QtGroupingProxy::modelDataChanged );
+    //set invalid index from source as root index
+    m_rootIndex = sourceModel->index( -1, -1 );
+}
+
+void
+QtGroupingProxy::setRootIndex( const QModelIndex &rootIndex )
+{
+    if( m_rootIndex == rootIndex )
+        return;
+
+    m_rootIndex = rootIndex;
+    //TODO: invalidate tree so buildTree() can be called later.
+}
+
 void
 QtGroupingProxy::setGroupedColumn( int groupedColumn )
 {
     m_groupedColumn = groupedColumn;
+    //TODO: invalidate tree so buildTree() can be called later.
     buildTree();
 }
 
+/** Maps to what groups the source row belongs by returning the data of those groups.
+  *
+  * @returns a list of data for the rows the argument belongs to. In common cases this list will
+  * contain only one entry. An empty list means that the source item will be placed in the root of
+  * this proxyModel. There is no support for hiding source items.
+  *
+  * Group data can be pre-loaded in the return value so it's added to the cache maintained by this
+  * class. This is required if you want to have data that is not present in the source model.
+  */
 QList<RowData>
 QtGroupingProxy::belongsTo( const QModelIndex &idx )
 {
@@ -62,8 +108,8 @@ QtGroupingProxy::belongsTo( const QModelIndex &idx )
     QList<RowData> rowDataList;
 
     //get all the data for this index from the model
-    IndexData indexData = sourceModel()->itemData( idx );
-    QMapIterator<int, QVariant> i( indexData );
+    ItemData itemData = sourceModel()->itemData( idx );
+    QMapIterator<int, QVariant> i( itemData );
     while( i.hasNext() )
     {
         i.next();
@@ -81,11 +127,12 @@ QtGroupingProxy::belongsTo( const QModelIndex &idx )
                                        : RowData();
 
                 //we only gather data for the first column
-                IndexData indexData = rowData.contains( 0 ) ? rowData.take( 0 ) : IndexData();
+                ItemData indexData = rowData.contains( 0 ) ? rowData.take( 0 ) : ItemData();
                 indexData.insert( role, list.value( i ) );
                 rowData.insert( 0, indexData );
                 //for the grouped column the data should not be gathered from the children
-                //this will allow filtering on the content of this column with a QSFP
+                //this will allow filtering on the content of this column with a
+                //QSortFilterProxyModel
                 rowData.insert( m_groupedColumn, indexData );
                 rowDataList.insert( i, rowData );
             }
@@ -94,14 +141,11 @@ QtGroupingProxy::belongsTo( const QModelIndex &idx )
         {
             //it's just a normal item. Copy all the data and break this loop.
             RowData rowData;
-            rowData.insert( 0, indexData );
+            rowData.insert( 0, itemData );
             rowDataList << rowData;
             break;
         }
     }
-    //for normal items (not root node) an empty list here means it's supposed to go in root.
-    if( idx != m_rootNode && rowDataList.isEmpty() )
-        rowDataList << RowData();
 
     return rowDataList;
 }
@@ -126,30 +170,13 @@ QtGroupingProxy::buildTree()
     //don't clear the data maps since most of it will probably be needed again.
     m_parentCreateList.clear();
 
-    //first load empty groups from the rootnode.
-    QModelIndex rootGroupedIndex =
-            sourceModel()->index( m_rootNode.row(), m_groupedColumn, m_rootNode.parent() );
-    if( rootGroupedIndex.column() == m_groupedColumn )
-    {
-        QList<RowData> groupData = belongsTo( rootGroupedIndex );
-        foreach( RowData rowData , groupData )
-        {
-            // qDebug() << rowData;
-            if( rowData.contains( 0 ) && rowData[0].contains( Qt::DisplayRole ) )
-            {
-                // qDebug() << "Creating empty group: " << rowData[0][Qt::DisplayRole].toString();
-                m_groupMaps << rowData;
-            }
-        }
-    }
-
-    int max = sourceModel()->rowCount( m_rootNode );
-    //qDebug() << QString("building tree with %1 leafs.").arg( max );
+    int max = sourceModel()->rowCount( m_rootIndex );
+    //qDebug() << QStringLiteral("building tree with %1 leafs.").arg( max );
     //WARNING: these have to be added in order because the addToGroups function is optimized for
     //modelRowsInserted(). Failure to do so will result in wrong data shown in the view at best.
     for( int row = 0; row < max; row++ )
     {
-        QModelIndex idx = sourceModel()->index( row, m_groupedColumn, m_rootNode );
+        QModelIndex idx = sourceModel()->index( row, m_groupedColumn, m_rootIndex );
         addSourceRow( idx );
     }
 //    dumpGroups();
@@ -163,13 +190,22 @@ QtGroupingProxy::addSourceRow( const QModelIndex &idx )
     QList<int> updatedGroups;
 
     QList<RowData> groupData = belongsTo( idx );
+
+    //an empty list here means it's supposed to go in root.
+    if( groupData.isEmpty() )
+    {
+        updatedGroups << -1;
+        if( !m_groupHash.keys().contains( -1 ) )
+            m_groupHash.insert( -1, QList<int>() ); //add an empty placeholder
+    }
+
     //an item can be in multiple groups
     foreach( RowData data, groupData )
     {
-        int groupIndex = -1;
+        int updatedGroup = -1;
         if( !data.isEmpty() )
         {
-//            qDebug() << QString("index %1 belongs to group %2").arg( row )
+//            qDebug() << QStringLiteral("index %1 belongs to group %2").arg( row )
 //                         .arg( data[0][Qt::DisplayRole].toString() );
 
             foreach( const RowData &cachedData, m_groupMaps )
@@ -182,59 +218,65 @@ QtGroupingProxy::addSourceRow( const QModelIndex &idx )
                 }
             }
 
-            groupIndex = m_groupMaps.indexOf( data );
+            updatedGroup = m_groupMaps.indexOf( data );
             //-1 means not found
-            if( groupIndex == -1 )
+            if( updatedGroup == -1 )
             {
-                //new groups are added to the end of the existing list
-                m_groupMaps << data;
-                groupIndex = m_groupMaps.count() - 1;
+                QModelIndex newGroupIdx = addEmptyGroup( data );
+                updatedGroup = newGroupIdx.row();
+            }
+
+            if( !m_groupHash.keys().contains( updatedGroup ) )
+                m_groupHash.insert( updatedGroup, QList<int>() ); //add an empty placeholder
+        }
+
+        if( !updatedGroups.contains( updatedGroup ) )
+            updatedGroups << updatedGroup;
+    }
+
+
+    //update m_groupHash to the new source-model layout (one row added)
+    QMutableHashIterator<quint32, QList<int> > i( m_groupHash );
+    while( i.hasNext() )
+    {
+        i.next();
+        QList<int> &groupList = i.value();
+        int insertedProxyRow = groupList.count();
+        for( ; insertedProxyRow > 0 ; insertedProxyRow-- )
+        {
+            int &rowValue = groupList[insertedProxyRow-1];
+            if( idx.row() <= rowValue )
+            {
+                //increment the rows that come after the new row since they moved one place up.
+                rowValue++;
+            }
+            else
+            {
+                break;
             }
         }
 
-        if( !updatedGroups.contains( groupIndex ) )
-            updatedGroups << groupIndex;
-
-        //it's possible it's a new group, QHash will create it for us with this call:
-        m_groupHash[groupIndex];
-
-        //update the groupHash to the new source-model layout (one row added)
-        QMutableHashIterator<quint32, QList<int> > i( m_groupHash );
-        while( i.hasNext() )
+        if( updatedGroups.contains( i.key() ) )
         {
-            i.next();
-            QList<int> &groupList = i.value();
-            int insertedProxyRow = groupList.count();
-            for( ; insertedProxyRow > 0 ; insertedProxyRow-- )
-            {
-                int &rowValue = groupList[insertedProxyRow-1];
-                if( idx.row() <= rowValue )
-                {
-                    //increment the rows that come after the new row since they moved one place up.
-                    rowValue++;
-                }
-                else
-                {
-                    break;
-                }
-            }
             //the row needs to be added to this group
-            if( i.key() == (quint32)groupIndex )
-                groupList.insert( insertedProxyRow, idx.row() );
+            beginInsertRows( index( i.key() ), insertedProxyRow, insertedProxyRow );
+            groupList.insert( insertedProxyRow, idx.row() );
+            endInsertRows();
         }
     }
+
     return updatedGroups;
 }
 
 /** Each ModelIndex has in it's internalId a position in the parentCreateList.
   * struct ParentCreate are the instructions to recreate the parent index.
-  * It contains the row number and the postion in this list of the grandfather.
+  * It contains the proxy row number of the parent and the position in this list of the grandfather.
   * This function creates the ParentCreate structs and saves them in a list.
   */
 int
 QtGroupingProxy::indexOfParentCreate( const QModelIndex &parent ) const
 {
-    if( !parent.isValid() || parent == m_rootNode )
+    if( !parent.isValid() )
         return -1;
 
     struct ParentCreate pc;
@@ -244,10 +286,19 @@ QtGroupingProxy::indexOfParentCreate( const QModelIndex &parent ) const
         if( pc.parentCreateIndex == parent.internalId() && pc.row == parent.row() )
             return i;
     }
-    //their was no parentCreate yet for this index, so let's create one.
+    //there is no parentCreate yet for this index, so let's create one.
     pc.parentCreateIndex = parent.internalId();
     pc.row = parent.row();
     m_parentCreateList << pc;
+
+    //dumpParentCreateList();
+//    qDebug() << QString( "m_parentCreateList: (%1)" ).arg( m_parentCreateList.size() );
+//    for( int i = 0 ; i < m_parentCreateList.size() ; i++ )
+//    {
+//        qDebug() << i << " : " << m_parentCreateList[i].parentCreateIndex <<
+//                 " | " << m_parentCreateList[i].row;
+//    }
+
     return m_parentCreateList.size() - 1;
 }
 
@@ -288,7 +339,7 @@ QtGroupingProxy::parent( const QModelIndex &index ) const
 }
 
 int
-QtGroupingProxy::rowCount( const QModelIndex& index ) const
+QtGroupingProxy::rowCount( const QModelIndex &index ) const
 {
     //qDebug() << "rowCount: " << index;
     if( !index.isValid() )
@@ -315,8 +366,14 @@ QtGroupingProxy::rowCount( const QModelIndex& index ) const
 }
 
 int
-QtGroupingProxy::columnCount( const QModelIndex& index ) const
+QtGroupingProxy::columnCount( const QModelIndex &index ) const
 {
+    if( !index.isValid() )
+        return sourceModel()->columnCount( m_rootIndex );
+
+    if( index.column() != 0 )
+        return 0;
+
     return sourceModel()->columnCount( mapToSource( index ) );
 }
 
@@ -324,7 +381,8 @@ QVariant
 QtGroupingProxy::data( const QModelIndex &index, int role ) const
 {
     if( !index.isValid() )
-        return QVariant();
+        return sourceModel()->data( m_rootIndex, role ); //rootNode could have useful data
+
     //qDebug() << __FUNCTION__ << index << " role: " << role;
     int row = index.row();
     int column = index.column();
@@ -361,19 +419,19 @@ QtGroupingProxy::data( const QModelIndex &index, int role ) const
         }
         //qDebug() << "gathered this data from children: " << variantsOfChildren;
         //saving in cache
-        IndexData roleMap = m_groupMaps[row].value( column );
+        ItemData roleMap = m_groupMaps[row].value( column );
         foreach( const QVariant &variant, variantsOfChildren )
         {
             if( roleMap[ role ] != variant )
                 roleMap.insert( role, variantsOfChildren );
         }
 
-        //qDebug() << QString("roleMap[%1]:").arg(role) << roleMap[role];
+        //qDebug() << QStringLiteral("roleMap[%1]:").arg(role) << roleMap[role];
         //only one unique variant? No need to return a list
         if( variantsOfChildren.count() == 1 )
             return variantsOfChildren.first();
 
-        if( variantsOfChildren.count() == 0 )
+        if( variantsOfChildren.isEmpty() )
             return QVariant();
 
         return variantsOfChildren;
@@ -394,7 +452,7 @@ QtGroupingProxy::setData( const QModelIndex &idx, const QVariant &value, int rol
 
     if( isGroup( idx ) )
     {
-        IndexData columnData = m_groupMaps[idx.row()][idx.column()];
+        ItemData columnData = m_groupMaps[idx.row()][idx.column()];
 
         columnData.insert( role, value );
         //QItemDelegate will always use Qt::EditRole
@@ -408,13 +466,13 @@ QtGroupingProxy::setData( const QModelIndex &idx, const QVariant &value, int rol
         foreach( int originalRow, m_groupHash.value( idx.row() ) )
         {
             QModelIndex childIdx = sourceModel()->index( originalRow, columnToChange,
-                                                   m_rootNode );
+                                                   m_rootIndex );
             if( childIdx.isValid() )
                 sourceModel()->setData( childIdx, value, role );
         }
         //TODO: we might need to reload the data from the children at this point
 
-        emit dataChanged( idx, idx );
+        Q_EMIT dataChanged( idx, idx );
         return true;
     }
 
@@ -431,16 +489,16 @@ QtGroupingProxy::isGroup( const QModelIndex &index ) const
 }
 
 QModelIndex
-QtGroupingProxy::mapToSource( const QModelIndex& index ) const
+QtGroupingProxy::mapToSource( const QModelIndex &index ) const
 {
     //qDebug() << "mapToSource: " << index;
     if( !index.isValid() )
-        return m_rootNode;
+        return m_rootIndex;
 
     if( isGroup( index ) )
     {
         //qDebug() << "is a group: " << index.data( Qt::DisplayRole ).toString();
-        return m_rootNode;
+        return m_rootIndex;
     }
 
     QModelIndex proxyParent = index.parent();
@@ -448,7 +506,7 @@ QtGroupingProxy::mapToSource( const QModelIndex& index ) const
     QModelIndex originalParent = mapToSource( proxyParent );
     //qDebug() << "originalParent: " << originalParent;
     int originalRow = index.row();
-    if( originalParent == m_rootNode )
+    if( originalParent == m_rootIndex )
     {
         int indexInGroup = index.row();
         if( !proxyParent.isValid() )
@@ -489,7 +547,7 @@ QtGroupingProxy::mapFromSource( const QModelIndex &idx ) const
     int proxyRow = idx.row();
     int sourceRow = idx.row();
 
-    if( sourceParent.isValid() )
+    if( sourceParent.isValid() && ( sourceParent != m_rootIndex ) )
     {
         //idx is a child of one of the items in the source model
         proxyParent = mapFromSource( sourceParent );
@@ -534,8 +592,16 @@ QtGroupingProxy::mapFromSource( const QModelIndex &idx ) const
 Qt::ItemFlags
 QtGroupingProxy::flags( const QModelIndex &idx ) const
 {
+    if( !idx.isValid() )
+    {
+        Qt::ItemFlags rootFlags = sourceModel()->flags( m_rootIndex );
+        if( rootFlags.testFlag( Qt::ItemIsDropEnabled ) )
+            return Qt::ItemFlags( Qt::ItemIsDropEnabled );
+
+        return 0;
+    }
     //only if the grouped column has the editable flag set allow the
-    //actions leading to setData on the source (edit, drop & drag)
+    //actions leading to setData on the source (edit & drop)
 //    qDebug() << idx;
     if( isGroup( idx ) )
     {
@@ -544,11 +610,11 @@ QtGroupingProxy::flags( const QModelIndex &idx ) const
         bool groupIsEditable = true;
 
         //it's possible to have empty groups
-        if( m_groupHash.value( idx.row() ).count() == 0 )
+        if( m_groupHash.value( idx.row() ).isEmpty() )
         {
             //check the flags of this column with the root node
-            QModelIndex originalRootNode = sourceModel()->index( m_rootNode.row(), m_groupedColumn,
-                                                           m_rootNode.parent() );
+            QModelIndex originalRootNode = sourceModel()->index( m_rootIndex.row(), m_groupedColumn,
+                                                           m_rootIndex.parent() );
             groupIsEditable = originalRootNode.flags().testFlag( Qt::ItemIsEditable );
         }
         else
@@ -556,7 +622,7 @@ QtGroupingProxy::flags( const QModelIndex &idx ) const
             foreach( int originalRow, m_groupHash.value( idx.row() ) )
             {
                 QModelIndex originalIdx = sourceModel()->index( originalRow, m_groupedColumn,
-                                                          m_rootNode );
+                                                          m_rootIndex );
 //                qDebug() << "originalIdx: " << originalIdx;
                 groupIsEditable = groupIsEditable
                                   ? originalIdx.flags().testFlag( Qt::ItemIsEditable )
@@ -584,6 +650,29 @@ QtGroupingProxy::flags( const QModelIndex &idx ) const
     return originalItemFlags;
 }
 
+QModelIndex
+QtGroupingProxy::buddy( const QModelIndex &index ) const
+{
+    /* We need to override this method in case of groups. Otherwise, at least editing
+     * of groups is prevented, following sequence occurs:
+     *
+     * #0  QtGroupingProxy::mapToSource (this=0x15ad8a0, index=...) at /home/strohel/projekty/amarok/src/browsers/playlistbrowser/QtGroupingProxy.cpp:492
+     * #1  0x00007ffff609d7b6 in QAbstractProxyModel::buddy (this=0x15ad8a0, index=...) at itemviews/qabstractproxymodel.cpp:306
+     * #2  0x00007ffff609ed25 in QSortFilterProxyModel::buddy (this=0x15ae730, index=...) at itemviews/qsortfilterproxymodel.cpp:2015
+     * #3  0x00007ffff6012a2c in QAbstractItemView::edit (this=0x15aec30, index=..., trigger=QAbstractItemView::AllEditTriggers, event=0x0) at itemviews/qabstractitemview.cpp:2569
+     * #4  0x00007ffff6f9aa9f in Amarok::PrettyTreeView::edit (this=0x15aec30, index=..., trigger=QAbstractItemView::AllEditTriggers, event=0x0)
+     *     at /home/strohel/projekty/amarok/src/widgets/PrettyTreeView.cpp:58
+     * #5  0x00007ffff6007f1e in QAbstractItemView::edit (this=0x15aec30, index=...) at itemviews/qabstractitemview.cpp:1138
+     * #6  0x00007ffff6dc86e4 in PlaylistBrowserNS::PlaylistBrowserCategory::createNewFolder (this=0x159bf90)
+     *     at /home/strohel/projekty/amarok/src/browsers/playlistbrowser/PlaylistBrowserCategory.cpp:298
+     *
+     * but we return invalid index in mapToSource() for group index.
+     */
+    if( index.isValid() && isGroup( index ) )
+        return index;
+    return QAbstractProxyModel::buddy( index );
+}
+
 QVariant
 QtGroupingProxy::headerData( int section, Qt::Orientation orientation, int role ) const
 {
@@ -611,7 +700,7 @@ QtGroupingProxy::fetchMore ( const QModelIndex & parent )
     if( isGroup( parent ) )
         return;
 
-    return sourceModel()->fetchMore( mapToSource( parent ) );
+    sourceModel()->fetchMore( mapToSource( parent ) );
 }
 
 QModelIndex
@@ -627,7 +716,6 @@ QtGroupingProxy::addEmptyGroup( const RowData &data )
 bool
 QtGroupingProxy::removeGroup( const QModelIndex &idx )
 {
-    //TODO:unset this groups value from the childrens grouped column
     beginRemoveRows( idx.parent(), idx.row(), idx.row() );
     m_groupHash.remove( idx.row() );
     m_groupMaps.removeAt( idx.row() );
@@ -651,67 +739,136 @@ QtGroupingProxy::hasChildren( const QModelIndex &parent ) const
 }
 
 void
-QtGroupingProxy::modelDataChanged( const QModelIndex& start, const QModelIndex& end )
+QtGroupingProxy::modelRowsAboutToBeInserted( const QModelIndex &parent, int start, int end )
 {
-    Q_UNUSED( start )
-    Q_UNUSED( end )
-    //HACK: range might not be continues in the proxy. Worse case it will refresh to much
-    //data though.
-    emit dataChanged( mapFromSource( start ), mapFromSource( end ) );
+    if( parent != m_rootIndex )
+    {
+        //an item will be added to an original index, remap and pass it on
+        QModelIndex proxyParent = mapFromSource( parent );
+        beginInsertRows( proxyParent, start, end );
+    }
 }
 
 void
 QtGroupingProxy::modelRowsInserted( const QModelIndex &parent, int start, int end )
 {
-    if( parent == m_rootNode )
+    if( parent == m_rootIndex )
     {
         //top level of the model changed, these new rows need to be put in groups
         for( int modelRow = start; modelRow <= end ; modelRow++ )
         {
-            QList<int> updatedGroups;
-            updatedGroups << addSourceRow( sourceModel()->index( modelRow, m_groupedColumn, m_rootNode ) );
-            foreach( int groupIndex, updatedGroups )
-            {
-                QModelIndex updatedProxyParent = ( groupIndex == -1 ) ? QModelIndex()
-                    : index( groupIndex, 0 );
-                int insertedProxyRow = m_groupHash[groupIndex].indexOf( modelRow );
-                //non-grouped items are below the groups, so offset the row
-                if( groupIndex == -1 )
-                    insertedProxyRow += m_groupMaps.count();
+            addSourceRow( sourceModel()->index( modelRow, m_groupedColumn, m_rootIndex ) );
+        }
+    }
+    else
+    {
+        //beginInsertRows had to be called in modelRowsAboutToBeInserted()
+        endInsertRows();
+    }
+}
 
-                beginInsertRows( updatedProxyParent, insertedProxyRow, insertedProxyRow );
-                endInsertRows();
+void
+QtGroupingProxy::modelRowsAboutToBeRemoved( const QModelIndex &parent, int start, int end )
+{
+    if( parent == m_rootIndex )
+    {
+        QHash<quint32, QList<int> >::const_iterator i;
+        //HACK, we are going to call beginRemoveRows() multiple times without
+        // endRemoveRows() if a source index is in multiple groups.
+        // This can be a problem for some views/proxies, but Q*Views can handle it.
+        // TODO: investigate a queue for applying proxy model changes in the correct order
+        for( i = m_groupHash.constBegin(); i != m_groupHash.constEnd(); ++i )
+        {
+            int groupIndex = i.key();
+            const QList<int> &groupList = i.value();
+            QModelIndex proxyParent = index( groupIndex, 0 );
+            foreach( int originalRow, groupList )
+            {
+                if( originalRow >= start && originalRow <= end )
+                {
+                    int proxyRow = groupList.indexOf( originalRow );
+                    if( groupIndex == -1 ) //adjust for non-grouped (root level) original items
+                        proxyRow += m_groupMaps.count();
+                    //TODO: optimize for continues original rows in the same group
+                    beginRemoveRows( proxyParent, proxyRow, proxyRow );
+                }
             }
         }
     }
     else
     {
-        //a item was added to one of the original index, remap and pass it on
+        //child item(s) of an original item will be removed, remap and pass it on
+//        qDebug() << parent;
         QModelIndex proxyParent = mapFromSource( parent );
 //        qDebug() << proxyParent;
-        //TODO: move this to slot connected to rowsAboutToBeInserted()
-        beginInsertRows( proxyParent, start, end );
-        endInsertRows();
+        beginRemoveRows( proxyParent, start, end );
     }
 }
 
 void
 QtGroupingProxy::modelRowsRemoved( const QModelIndex &parent, int start, int end )
 {
-    if( parent == m_rootNode )
+    if( parent == m_rootIndex )
     {
-        //rebuild tree, reseting the view
-        //TODO: don't rebuild but remove from
-        buildTree();
+        //TODO: can be optimised by iterating over m_groupHash and checking start <= r < end
+
+        //rather than increasing i we change the stored sourceRows in-place and reuse argument start
+        //X-times (where X = end - start).
+        for( int i = start; i <= end; i++ )
+        {
+            //HACK: we are going to iterate the hash in reverse so calls to endRemoveRows()
+            // are matched up with the beginRemoveRows() in modelRowsAboutToBeRemoved()
+            //NOTE: easier to do reverse with java style iterator
+            QMutableHashIterator<quint32, QList<int> > it( m_groupHash );
+            it.toBack();
+            while( it.hasPrevious() )
+            {
+                it.previous();
+                //has to be a modifiable reference for remove and replace operations
+                QList<int> &groupList = it.value();
+                int rowIndex = groupList.indexOf( start );
+                if( rowIndex != -1 )
+                {
+                    groupList.removeAt( rowIndex );
+                }
+                //Now decrement all source rows that are after the removed row
+                for( int j = 0; j < groupList.count(); j++ )
+                {
+                    int sourceRow = groupList.at( j );
+                    if( sourceRow > start )
+                        groupList.replace( j, sourceRow-1 );
+                }
+                if( rowIndex != -1)
+                    endRemoveRows(); //end remove operation only after group was updated.
+            }
+        }
+
         return;
     }
 
-    QModelIndex proxyParent = mapFromSource( parent );
-    //TODO: move this to slot connected to rowsAboutToBeRemoved()
-    beginRemoveRows( proxyParent, start, end );
+    //beginRemoveRows had to be called in modelRowsAboutToBeRemoved();
     endRemoveRows();
 }
 
+void
+QtGroupingProxy::modelDataChanged( const QModelIndex &topLeft, const QModelIndex &bottomRight )
+{
+    //TODO: need to look in the groupedColumn and see if it changed and changed grouping accordingly
+    QModelIndex proxyTopLeft = mapFromSource( topLeft );
+    if( !proxyTopLeft.isValid() )
+        return;
+
+    if( topLeft == bottomRight )
+    {
+        Q_EMIT dataChanged( proxyTopLeft, proxyTopLeft );
+    }
+    else
+    {
+        QModelIndex proxyBottomRight = mapFromSource( bottomRight );
+        Q_EMIT dataChanged( proxyTopLeft, proxyBottomRight );
+    }
+}
+
 bool
 QtGroupingProxy::isAGroupSelected( const QModelIndexList& list ) const
 {
