@@ -31,10 +31,10 @@ class QtGroupingProxy : public QAbstractProxyModel
 {
     Q_OBJECT
     public:
-        explicit QtGroupingProxy( QObject *parent = 0 );
-        QtGroupingProxy( QAbstractItemModel *model, QModelIndex rootIndex = QModelIndex(),
-                                  int groupedColumn = -1, QObject *parent = 0 );
-        ~QtGroupingProxy();
+        explicit QtGroupingProxy( QObject *parent = nullptr );
+        explicit QtGroupingProxy(QAbstractItemModel *model, const QModelIndex &rootIndex = QModelIndex(),
+                                  int groupedColumn = -1, QObject *parent = nullptr );
+        ~QtGroupingProxy() override;
 
         /* QtGroupingProxy methods */
         void setRootIndex( const QModelIndex &rootIndex );
@@ -44,30 +44,33 @@ class QtGroupingProxy : public QAbstractProxyModel
 
         /* QAbstractProxyModel methods */
         //re-implemented to connect to source signals
-        virtual void setSourceModel( QAbstractItemModel *sourceModel );
-        virtual QModelIndex index( int row, int column = 0,
-                                   const QModelIndex& parent = QModelIndex() ) const;
-        virtual Qt::ItemFlags flags( const QModelIndex &idx ) const;
-        virtual QModelIndex buddy( const QModelIndex &index ) const;
-        virtual QModelIndex parent( const QModelIndex &idx ) const;
-        virtual int rowCount( const QModelIndex &idx = QModelIndex() ) const;
-        virtual int columnCount( const QModelIndex &idx ) const;
-        virtual QModelIndex mapToSource( const QModelIndex &idx ) const;
+        void setSourceModel( QAbstractItemModel *sourceModel ) override;
+        QModelIndex index( int row, int column = 0,
+                                   const QModelIndex& parent = QModelIndex() ) const override;
+        Qt::ItemFlags flags( const QModelIndex &idx ) const override;
+        QModelIndex buddy( const QModelIndex &index ) const override;
+        QModelIndex parent( const QModelIndex &idx ) const override;
+        int rowCount( const QModelIndex &idx = QModelIndex() ) const override;
+        int columnCount( const QModelIndex &idx ) const override;
+        QModelIndex mapToSource( const QModelIndex &idx ) const override;
         virtual QModelIndexList mapToSource( const QModelIndexList &list ) const;
-        virtual QModelIndex mapFromSource( const QModelIndex &idx ) const;
-        virtual QVariant data( const QModelIndex &idx, int role ) const;
-        virtual bool setData( const QModelIndex &index, const QVariant &value,
-                              int role = Qt::EditRole );
-        virtual QVariant headerData ( int section, Qt::Orientation orientation,
-                                      int role ) const;
-        virtual bool canFetchMore( const QModelIndex &parent ) const;
-        virtual void fetchMore( const QModelIndex &parent );
-        virtual bool hasChildren( const QModelIndex &parent = QModelIndex() ) const;
+        QModelIndex mapFromSource( const QModelIndex &idx ) const override;
+        QVariant data( const QModelIndex &idx, int role ) const override;
+        bool setData( const QModelIndex &index, const QVariant &value,
+                              int role = Qt::EditRole ) override;
+        QVariant headerData ( int section, Qt::Orientation orientation,
+                                      int role ) const override;
+        bool canFetchMore( const QModelIndex &parent ) const override;
+        void fetchMore( const QModelIndex &parent ) override;
+        bool hasChildren( const QModelIndex &parent = QModelIndex() ) const override;
 
-    protected slots:
+    Q_SIGNALS:
+        void renameIndex( const QModelIndex &idx );
+
+    protected Q_SLOTS:
         virtual void buildTree();
 
-    private slots:
+    private Q_SLOTS:
         void modelDataChanged( const QModelIndex &, const QModelIndex & );
         void modelRowsInserted( const QModelIndex &, int, int );
         void modelRowsAboutToBeInserted( const QModelIndex &, int ,int );
@@ -104,12 +107,12 @@ class QtGroupingProxy : public QAbstractProxyModel
           */
         QList<RowData> m_groupMaps;
 
-        /** "instuctions" how to create an item in the tree.
+        /** "instructions" how to create an item in the tree.
           * This is used by parent( QModelIndex )
         */
         struct ParentCreate
         {
-            int parentCreateIndex;
+            quintptr parentCreateIndex;
             int row;
         };
         mutable QList<struct ParentCreate> m_parentCreateList;
