@@ -19,13 +19,14 @@
 #include <PluginManager.h>
 #include <core/support/Amarok.h>
 #include <core/support/Debug.h>
+#include "core/support/PluginFactory.h"
 
 #include <KConfigDialogManager>
 #include <KMessageBox>
 #include <KCMultiDialog>
 
 
-DatabaseConfig::DatabaseConfig( QWidget* parent, KConfigSkeleton *config )
+DatabaseConfig::DatabaseConfig( Amarok2ConfigDialog* parent, KConfigSkeleton *config )
     : ConfigDialogBase( parent )
     , m_configManager( new KConfigDialogManager( this, config ) )
 {
@@ -39,10 +40,9 @@ DatabaseConfig::DatabaseConfig( QWidget* parent, KConfigSkeleton *config )
 
     // enable the test button if one of the plugin factories has a correct testSettings slot
     // get all storage factories
-    QList<Plugins::PluginFactory*> factories;
-    factories = Plugins::PluginManager::instance()->factories( Plugins::PluginManager::Storage );
+    auto factories = Plugins::PluginManager::instance()->factories( Plugins::PluginManager::Storage );
     bool testFunctionAvailable = false;
-    foreach( Plugins::PluginFactory* factory, factories )
+    for( const auto &factory : factories )
     {
         // check the meta object if there is a testSettings slot available
         if( factory->metaObject()->
@@ -52,11 +52,11 @@ DatabaseConfig::DatabaseConfig( QWidget* parent, KConfigSkeleton *config )
     button_Test->setEnabled( testFunctionAvailable );
 
     // connect slots
-    connect( kcfg_UseServer, SIGNAL(stateChanged(int)), SLOT(toggleExternalConfigAvailable(int)) );
+    connect( kcfg_UseServer, &QCheckBox::stateChanged, this, &DatabaseConfig::toggleExternalConfigAvailable );
 
-    connect( kcfg_Database, SIGNAL(textChanged(QString)), SLOT(updateSQLQuery()) );
-    connect( kcfg_User,     SIGNAL(textChanged(QString)), SLOT(updateSQLQuery()) );
-    connect( button_Test,   SIGNAL(clicked(bool)),  SLOT(testDatabaseConnection()));
+    connect( kcfg_Database, &QLineEdit::textChanged, this, &DatabaseConfig::updateSQLQuery );
+    connect( kcfg_User,     &QLineEdit::textChanged, this, &DatabaseConfig::updateSQLQuery );
+    connect( button_Test,   &QAbstractButton::clicked,  this, &DatabaseConfig::testDatabaseConnection );
 
     toggleExternalConfigAvailable( kcfg_UseServer->checkState() );
 
@@ -78,16 +78,15 @@ void
 DatabaseConfig::testDatabaseConnection() //SLOT
 {
     // get all storage factories
-    QList<Plugins::PluginFactory*> factories;
-    factories = Plugins::PluginManager::instance()->factories( Plugins::PluginManager::Storage );
+    auto factories = Plugins::PluginManager::instance()->factories( Plugins::PluginManager::Storage );
 
     // try if they have a testSettings slot that we can call
-    foreach( Plugins::PluginFactory* factory, factories )
+    for( const auto &factory : factories )
     {
         bool callSucceeded = false;
         QStringList connectionErrors;
 
-        callSucceeded = QMetaObject::invokeMethod( factory,
+        callSucceeded = QMetaObject::invokeMethod( factory.data(),
                                "testSettings",
                                Q_RETURN_ARG( QStringList, connectionErrors ),
                                Q_ARG( QString, kcfg_Host->text() ),
@@ -106,8 +105,8 @@ DatabaseConfig::testDatabaseConnection() //SLOT
             else
                 KMessageBox::error( this, i18n( "The amarok database reported "
                                                 "the following errors:\n%1\nIn most cases you will need to resolve "
-                                                "these errors before Amarok will run properly." ).
-                                    arg( connectionErrors.join( "\n" ) ),
+                                                "these errors before Amarok will run properly.",
+                                    connectionErrors.join( QStringLiteral("\n") ) ),
                                     i18n( "Database Error" ));
         }
     }
@@ -133,7 +132,7 @@ void
 DatabaseConfig::updateSettings()
 {
     if( m_configManager->hasChanged() )
-        KMessageBox::messageBox( 0, KMessageBox::Information,
+        KMessageBox::messageBox( nullptr, KMessageBox::Information,
                  i18n( "Changes to database settings only take\neffect after Amarok is restarted." ),
                  i18n( "Database settings changed" ) );
 }
@@ -155,10 +154,8 @@ DatabaseConfig::updateSQLQuery() //SLOT
 
         // Don't print the actual password!
         const QString examplePassword = i18nc( "A default password for insertion into an example SQL command (so as not to print the real one). To be manually replaced by the user.", "password" );
-        query = QString( "CREATE DATABASE %1;\nGRANT ALL PRIVILEGES ON %1.* TO '%2' IDENTIFIED BY '%3'; FLUSH PRIVILEGES;" )
-                   .arg( kcfg_Database->text() )
-                   .arg( kcfg_User->text() )
-                   .arg( examplePassword );
+        query = QStringLiteral( "CREATE DATABASE %1;\nGRANT ALL PRIVILEGES ON %1.* TO '%2' IDENTIFIED BY '%3'; FLUSH PRIVILEGES;" )
+                   .arg( kcfg_Database->text(), kcfg_User->text(), examplePassword );
     }
     text_SQL->setPlainText( query );
 }
@@ -171,6 +168,5 @@ DatabaseConfig::isSQLInfoPresent() const
 }
 
 
-#include "DatabaseConfig.moc"
 
 
