@@ -114,7 +114,7 @@ void
 SimilarArtistsEngine::similarArtistsRequest( const QString &artistName )
 {
     // we generate the url for the demand on the lastFM Api
-    KUrl url;
+    QUrl url;
     url.setScheme( "http" );
     url.setHost( "ws.audioscrobbler.com" );
     url.setPath( "/2.0/" );
@@ -124,11 +124,11 @@ SimilarArtistsEngine::similarArtistsRequest( const QString &artistName )
     url.addQueryItem( "limit",  QString::number( m_maxArtists ) );
 
     The::networkAccessManager()->getData( url, this,
-         SLOT(parseSimilarArtists(KUrl,QByteArray,NetworkAccessManagerProxy::Error)) );
+         SLOT(parseSimilarArtists(QUrl,QByteArray,NetworkAccessManagerProxy::Error)) );
 }
 
 void
-SimilarArtistsEngine::parseSimilarArtists( const KUrl &url, QByteArray data,
+SimilarArtistsEngine::parseSimilarArtists( const QUrl &url, consr QByteArray &data,
                                            NetworkAccessManagerProxy::Error e )
 {
     if( e.code != QNetworkReply::NoError )
@@ -146,7 +146,7 @@ SimilarArtistsEngine::parseSimilarArtists( const KUrl &url, QByteArray data,
     debug() << "Found" << saList.size() << "similar artists to" << m_artist;
     Plasma::DataEngine::Data eData;
     eData[ "artist"  ] = m_artist;
-    eData[ "similar" ] = qVariantFromValue( saList );
+    eData[ "similar" ] = QVariant::fromValue( saList );
     setData( "similarArtists", eData );
 }
 
