@@ -24,7 +24,7 @@
 #include <QtDebug>
 #include <QGraphicsItem>
 #include <QGraphicsScene>
-#include <QtSvg/QSvgRenderer>
+#include <QSvgRenderer>
 #include <QAction>
 #include <QMenu>
 #include <QPalette>
@@ -68,6 +68,7 @@ PopupDropperPrivate::PopupDropperPrivate( PopupDropper* parent, bool sa, QWidget
 {
     if( widget )
         widgetRect = widget->rect();
+
     windowBackgroundBrush.setColor( windowColor );
     hoveredBorderPen.setColor( Qt::blue );
     hoveredBorderPen.setWidth( 2 );
@@ -81,11 +82,11 @@ PopupDropperPrivate::PopupDropperPrivate( PopupDropper* parent, bool sa, QWidget
     //qDebug() << "on create, view size = " << view->size();
     deleteTimer.setSingleShot( true );
     fadeHideTimer.setDirection( QTimeLine::Backward );
-    connect( &fadeHideTimer, SIGNAL(frameChanged(int)), this, SLOT(fadeHideTimerFrameChanged(int)) );
-    connect( &fadeShowTimer, SIGNAL(frameChanged(int)), this, SLOT(fadeShowTimerFrameChanged(int)) );
-    connect( &fadeHideTimer, SIGNAL(finished()), this, SLOT(fadeHideTimerFinished()) );
-    connect( &fadeShowTimer, SIGNAL(finished()), this, SLOT(fadeShowTimerFinished()) );
-    connect( &deleteTimer, SIGNAL(timeout()), this, SLOT(deleteTimerFinished()) );
+    connect( &fadeHideTimer, &QTimeLine::frameChanged, this, &PopupDropperPrivate::fadeHideTimerFrameChanged );
+    connect( &fadeShowTimer, &QTimeLine::frameChanged, this, &PopupDropperPrivate::fadeShowTimerFrameChanged );
+    connect( &fadeHideTimer, &QTimeLine::finished, this, &PopupDropperPrivate::fadeHideTimerFinished );
+    connect( &fadeShowTimer, &QTimeLine::finished, this, &PopupDropperPrivate::fadeShowTimerFinished );
+    connect( &deleteTimer, &QTimer::timeout, this, &PopupDropperPrivate::deleteTimerFinished );
 }
 
 PopupDropperPrivate::~PopupDropperPrivate()
@@ -139,7 +140,7 @@ void PopupDropperPrivate::fadeHideTimerFinished() //SLOT
 {
     view->hide();
     //qDebug() << "Emitting fadeHideFinished in d pointer " << this;
-    emit q->fadeHideFinished();
+    Q_EMIT q->fadeHideFinished();
 }
 
 void PopupDropperPrivate::fadeShowTimerFinished() //SLOT
@@ -164,7 +165,7 @@ void PopupDropperPrivate::dragLeft()
     {
         view->setAcceptDrops( false );
         //qDebug() << "View entered, hiding";
-        connect( q, SIGNAL(fadeHideFinished()), q, SLOT(subtractOverlay()) );
+        connect( q, &PopupDropper::fadeHideFinished, q, &PopupDropper::subtractOverlay );
         q->hide();
     }
     q->updateAllOverlays();
@@ -184,7 +185,7 @@ void PopupDropperPrivate::deleteTimerFinished() //SLOT
     //qDebug() << "Delete Timer Finished";
     if( !view->entered() && quitOnDragLeave )
     {
-        connect( q, SIGNAL(fadeHideFinished()), q, SLOT(subtractOverlay()) );
+        connect( q, &PopupDropper::fadeHideFinished, q, &PopupDropper::subtractOverlay );
         q->hide();
     }
 }
@@ -320,11 +321,11 @@ void PopupDropper::addOverlay( PopupDropperPrivate* newD )
 bool PopupDropper::subtractOverlay()
 {
     //qDebug() << "subtractOverlay, with d pointer " << d;
-    disconnect( this, SLOT(subtractOverlay()) );
+    disconnect( this, &PopupDropper::fadeHideFinished, this, &PopupDropper::subtractOverlay );
     while( !isHidden() && d->fadeHideTimer.state() == QTimeLine::Running )
     {
         //qDebug() << "singleshotting subtractOverlay";
-        QTimer::singleShot( 0, this, SLOT(subtractOverlay()) );
+        QTimer::singleShot( 0, this, &PopupDropper::subtractOverlay );
         return false;
     }
     //qDebug() << "in PopupDropper " << this;
@@ -375,7 +376,7 @@ PopupDropperItem* PopupDropper::addSubmenu( PopupDropper** pd, const QString &te
 
     QAction* action = new QAction( text, this );
 
-    connect( action, SIGNAL(hovered()), this, SLOT(activateSubmenu()) );
+    connect( action, &QAction::hovered, this, &PopupDropper::activateSubmenu );
     pdi->setAction( action );
     pdi->setSubmenuTrigger( true );
     pdi->setHoverIndicatorShowStyle( PopupDropperItem::OnHover );
@@ -409,10 +410,10 @@ bool PopupDropper::addMenu( const QMenu *menu )
     if( !menu )
         return false;
         
-    if( menu->actions().size() == 0 )
+    if( menu->actions().isEmpty() )
         return true;
 
-    PopupDropperItem *pdi = 0;
+    PopupDropperItem *pdi = nullptr;
     foreach( QAction *action, menu->actions() )
     {
         if( !action->menu() )
@@ -423,12 +424,12 @@ bool PopupDropper::addMenu( const QMenu *menu )
         }
         else
         {
-            PopupDropper *pd = new PopupDropper( 0 );
+            PopupDropper *pd = new PopupDropper( nullptr );
             bool success = pd->addMenu( action->menu() );
             if( success )
                 pdi = addSubmenu( &pd, action->text() );
         }
-        pdi = 0;
+        pdi = nullptr;
     }
     
     return true;
@@ -501,8 +502,8 @@ void PopupDropper::hide()
         //qDebug() << "show timer running, queueing hide";
         d->fadeShowTimer.stop();
         d->queuedHide = true;
-        QTimer::singleShot( 0, d, SLOT(fadeShowTimerFinished()) );
-        QTimer::singleShot( 0, this, SLOT(hide()) );
+        QTimer::singleShot( 0, d, &PopupDropperPrivate::fadeShowTimerFinished );
+        QTimer::singleShot( 0, this, &PopupDropper::hide );
         return;
     }
 
@@ -511,7 +512,7 @@ void PopupDropper::hide()
     if( d->fadeHideTimer.state() == QTimeLine::Running || d->queuedHide )
     {
         //qDebug() << "hide timer running or queued hide";
-        QTimer::singleShot( 0, this, SLOT(hide()) );
+        QTimer::singleShot( 0, this, &PopupDropper::hide );
         return;
     }
 
@@ -527,7 +528,7 @@ void PopupDropper::hide()
     else  //time is zero, or no fade
     {
         //qDebug() << "time is zero, or no fade";
-        QTimer::singleShot( 0, d, SLOT(fadeHideTimerFinished()) );
+        QTimer::singleShot( 0, d, &PopupDropperPrivate::fadeHideTimerFinished );
         return;
     }
 }
@@ -535,7 +536,7 @@ void PopupDropper::hide()
 void PopupDropper::hideAllOverlays()
 {
     //qDebug() << "Entered hideAllOverlays";
-    connect( this, SIGNAL(fadeHideFinished()), this, SLOT(slotHideAllOverlays()) );
+    connect( this, &PopupDropper::fadeHideFinished, this, &PopupDropper::slotHideAllOverlays );
     hide();
     //qDebug() << "Leaving hideAllOverlays";
 }
@@ -543,7 +544,7 @@ void PopupDropper::hideAllOverlays()
 void PopupDropper::slotHideAllOverlays()
 {
     //qDebug() << "Entered slotHideAllOverlays()";
-    disconnect( this, SIGNAL(fadeHideFinished()), this, SLOT(slotHideAllOverlays()) );
+    disconnect( this, &PopupDropper::fadeHideFinished, this, &PopupDropper::slotHideAllOverlays );
     //qDebug() << "m_viewStack.size() = " << m_viewStack.size();
     for( int i = m_viewStack.size() - 1; i >= 0; --i )
     {
@@ -580,11 +581,11 @@ void PopupDropper::clear()
 {
     while( !isHidden() && d->fadeHideTimer.state() == QTimeLine::Running )
     {
-        QTimer::singleShot(0, this, SLOT(clear()) );
+        QTimer::singleShot(0, this, &PopupDropper::clear );
         return;
     }
     //qDebug() << "Clear happening!";
-    disconnect( this, SLOT(clear()) );
+//     disconnect( this, 0, this, &PopupDropper::clear ); Unused at this point.
     do
     {
         foreach( QGraphicsItem* item, d->allItems )
@@ -594,7 +595,7 @@ void PopupDropper::clear()
                 if( dynamic_cast<PopupDropperItem*>(item)->isSubmenuTrigger() )
                 {
                     //qDebug() << "Disconnecting action";
-                    disconnect( dynamic_cast<PopupDropperItem*>(item)->action(), SIGNAL(hovered()), this, SLOT(activateSubmenu()) );
+                    disconnect( dynamic_cast<PopupDropperItem*>(item)->action(), &QAction::hovered, this, &PopupDropper::activateSubmenu );
                 }
                 dynamic_cast<PopupDropperItem*>(item)->deleteLater();
             }
@@ -919,6 +920,7 @@ QList<PopupDropperItem*> PopupDropper::submenuItems( const PopupDropperItem *ite
         return list;
 
     PopupDropperPrivate *pdp = d->submenuMap[item->action()];
+    list.reserve(pdp->pdiItems.count());
     foreach( PopupDropperItem *pdi, pdp->pdiItems )
         list.append( pdi );
 
@@ -977,7 +979,3 @@ void PopupDropper::addSeparator( PopupDropperItem* separator )
     d->reposItems();
     d->scene->addItem( lineItem );
 }
-
-#include "PopupDropper_p.moc"
-#include "PopupDropper.moc"
-
