@@ -18,8 +18,6 @@
 
 #include "DaapCollection.h"
 
-#include <Solid/Networking>
-
 using namespace Meta;
 
 DaapTrack::DaapTrack( Collections::DaapCollection *collection, const QString &host, quint16 port, const QString &dbId, const QString &itemId, const QString &format)
@@ -37,7 +35,7 @@ DaapTrack::DaapTrack( Collections::DaapCollection *collection, const QString &ho
     , m_displayUrl()
     , m_playableUrl()
 {
-    QString url = QString( "daap://%1:%2/databases/%3/items/%4.%5" )
+    QString url = QStringLiteral( "daap://%1:%2/databases/%3/items/%4.%5" )
                     .arg( host, QString::number( port ), dbId, itemId, format );
     m_displayUrl = url;
     m_playableUrl = url;
@@ -54,11 +52,11 @@ DaapTrack::name() const
     return m_name;
 }
 
-KUrl
+QUrl
 DaapTrack::playableUrl() const
 {
-    KUrl url( m_playableUrl );
-    url.setProtocol( "http" );
+    QUrl url( m_playableUrl );
+    url.setScheme( "http" );
     return url;
 }
 
@@ -74,20 +72,10 @@ DaapTrack::prettyUrl() const
     return m_displayUrl;
 }
 
-bool
-DaapTrack::isPlayable() const
+QString
+DaapTrack::notPlayableReason() const
 {
-    //daap tracks are accessed over the network, so check if network connectivity is present
-    if( Solid::Networking::status() != Solid::Networking::Connected )
-        return false;
-
-    return true;
-}
-
-bool
-DaapTrack::isEditable() const
-{
-    return false;
+    return networkNotPlayableReason();
 }
 
 AlbumPtr
@@ -173,30 +161,6 @@ DaapTrack::setComment( const QString &newComment )
     Q_UNUSED( newComment )
 }
 
-double
-DaapTrack::score() const
-{
-    return 0.0;
-}
-
-void
-DaapTrack::setScore( double newScore )
-{
-    Q_UNUSED( newScore )
-}
-
-int
-DaapTrack::rating() const
-{
-    return 0;
-}
-
-void
-DaapTrack::setRating( int newRating )
-{
-    Q_UNUSED( newRating )
-}
-
 qint64
 DaapTrack::length() const
 {
@@ -245,30 +209,12 @@ DaapTrack::setDiscNumber( int newDiscNumber )
     Q_UNUSED( newDiscNumber )
 }
 
-int
-DaapTrack::playCount() const
-{
-    return 0;
-}
-
 QString
 DaapTrack::type() const
 {
     return m_type;
 }
 
-void
-DaapTrack::subscribe( Observer *observer )
-{
-    Q_UNUSED( observer )    //read only
-}
-
-void
-DaapTrack::unsubscribe( Observer *observer )
-{
-    Q_UNUSED( observer )    //read only
-}
-
 bool
 DaapTrack::inCollection() const
 {
@@ -282,31 +228,31 @@ DaapTrack::collection() const
 }
 
 void
-DaapTrack::setAlbum( DaapAlbumPtr album )
+DaapTrack::setAlbum( const DaapAlbumPtr &album )
 {
     m_album = album;
 }
 
 void
-DaapTrack::setArtist( DaapArtistPtr artist )
+DaapTrack::setArtist( const DaapArtistPtr &artist )
 {
     m_artist = artist;
 }
 
 void
-DaapTrack::setGenre( DaapGenrePtr genre )
+DaapTrack::setGenre( const DaapGenrePtr &genre )
 {
     m_genre = genre;
 }
 
 void
-DaapTrack::setComposer( DaapComposerPtr composer )
+DaapTrack::setComposer( const DaapComposerPtr &composer )
 {
     m_composer = composer;
 }
 
 void
-DaapTrack::setYear( DaapYearPtr year )
+DaapTrack::setYear( const DaapYearPtr &year )
 {
     m_year = year;
 }
@@ -358,7 +304,7 @@ DaapArtist::albums()
 }
 
 void
-DaapArtist::addTrack( DaapTrackPtr track )
+DaapArtist::addTrack( const DaapTrackPtr &track )
 {
     m_tracks.append( TrackPtr::staticCast( track ) );
 }
@@ -409,13 +355,13 @@ DaapAlbum::tracks()
 }
 
 void
-DaapAlbum::addTrack( DaapTrackPtr track )
+DaapAlbum::addTrack( const DaapTrackPtr &track )
 {
     m_tracks.append( TrackPtr::staticCast( track ) );
 }
 
 void
-DaapAlbum::setAlbumArtist( DaapArtistPtr artist )
+DaapAlbum::setAlbumArtist( const DaapArtistPtr &artist )
 {
     m_albumArtist = artist;
 }
@@ -448,7 +394,7 @@ DaapGenre::tracks()
 }
 
 void
-DaapGenre::addTrack( DaapTrackPtr track )
+DaapGenre::addTrack( const DaapTrackPtr &track )
 {
     m_tracks.append( TrackPtr::staticCast( track ) );
 }
@@ -481,7 +427,7 @@ DaapComposer::tracks()
 }
 
 void
-DaapComposer::addTrack( DaapTrackPtr track )
+DaapComposer::addTrack( const DaapTrackPtr &track )
 {
     m_tracks.append( TrackPtr::staticCast( track ) );
 }
@@ -514,7 +460,7 @@ DaapYear::tracks()
 }
 
 void
-DaapYear::addTrack( DaapTrackPtr track )
+DaapYear::addTrack( const DaapTrackPtr &track )
 {
     m_tracks.append( TrackPtr::staticCast( track ) );
 }
