@@ -56,9 +56,9 @@
 #include <QCryptographicHash>
 
 #include <KCodecs>
-#include <KLocale>
-#include <KSharedPtr>
-#include <ThreadWeaver/Weaver>
+#include <KLocalizedString>
+#include <ThreadWeaver/Queue>
+
 
 // additional constants
 namespace Meta
@@ -106,12 +106,12 @@ SqlTrack::getTrackJoinConditions()
 int
 SqlTrack::getTrackReturnValueCount()
 {
-    static int count = getTrackReturnValues().split( ',' ).count();
+    static int count = getTrackReturnValues().split( QLatin1Char(',') ).count();
     return count;
 }
 
 SqlTrack::SqlTrack( Collections::SqlCollection *collection, int deviceId,
-                    const QString &rpath, int directoryId, const QString uidUrl )
+                    const QString &rpath, int directoryId, const QString &uidUrl )
     : Track()
     , m_collection( collection )
     , m_batchUpdate( 0 )
@@ -125,7 +125,7 @@ SqlTrack::SqlTrack( Collections::SqlCollection *collection, int deviceId,
     m_statisticsId = -1;
 
     setUrl( deviceId, rpath, directoryId );
-    m_url = m_cache.value( Meta::valUrl ).toString(); // SqlRegistry already has this url
+    m_url = QUrl::fromUserInput(m_cache.value( Meta::valUrl ).toString()); // SqlRegistry already has this url
     setUidUrl( uidUrl );
     m_uid = m_cache.value( Meta::valUniqueId ).toString(); // SqlRegistry already has this uid
 
@@ -175,7 +175,7 @@ SqlTrack::SqlTrack( Collections::SqlCollection *collection, const QStringList &r
     m_rpath = *(iter++);
     m_directoryId = (*(iter++)).toInt();
     Q_ASSERT( m_directoryId > 0 && "refusing to create SqlTrack with non-positive directoryId, please file a bug" );
-    m_url = KUrl( m_collection->mountPointManager()->getAbsolutePath( m_deviceId, m_rpath ) );
+    m_url = QUrl::fromLocalFile( m_collection->mountPointManager()->getAbsolutePath( m_deviceId, m_rpath ) );
     m_uid = *(iter++);
     m_trackId = (*(iter++)).toInt();
     m_title = *(iter++);
@@ -191,15 +191,15 @@ SqlTrack::SqlTrack( Collections::SqlCollection *collection, const QStringList &r
     m_statisticsId = (*(iter++)).toInt();
     uint time = (*(iter++)).toUInt();
     if( time > 0 )
-        m_firstPlayed = QDateTime::fromTime_t(time);
+        m_firstPlayed = QDateTime::fromSecsSinceEpoch(time);
     time = (*(iter++)).toUInt();
     if( time > 0 )
-        m_lastPlayed = QDateTime::fromTime_t(time);
+        m_lastPlayed = QDateTime::fromSecsSinceEpoch(time);
     m_playCount = (*(iter++)).toInt();
     m_filetype = Amarok::FileType( (*(iter++)).toInt() );
     m_bpm = (*(iter++)).toFloat();
-    m_createDate = QDateTime::fromTime_t((*(iter++)).toUInt());
-    m_modifyDate = QDateTime::fromTime_t((*(iter++)).toUInt());
+    m_createDate = QDateTime::fromSecsSinceEpoch((*(iter++)).toUInt());
+    m_modifyDate = QDateTime::fromSecsSinceEpoch((*(iter++)).toUInt());
 
     // if there is no track gain, we assume a gain of 0
     // if there is no album gain, we use the track gain
@@ -282,7 +282,7 @@ SqlTrack::setTitle( const QString &newTitle )
 }
 
 
-KUrl
+QUrl
 SqlTrack::playableUrl() const
 {
     QReadLocker locker( &m_lock );
@@ -794,16 +794,16 @@ SqlTrack::commitIfInNonBatchUpdate()
 
     // for all the following objects we need to invalidate the cache and
     // notify the observers after the update
-    KSharedPtr<SqlArtist>   oldArtist;
-    KSharedPtr<SqlArtist>   newArtist;
-    KSharedPtr<SqlAlbum>    oldAlbum;
-    KSharedPtr<SqlAlbum>    newAlbum;
-    KSharedPtr<SqlComposer> oldComposer;
-    KSharedPtr<SqlComposer> newComposer;
-    KSharedPtr<SqlGenre>    oldGenre;
-    KSharedPtr<SqlGenre>    newGenre;
-    KSharedPtr<SqlYear>     oldYear;
-    KSharedPtr<SqlYear>     newYear;
+    AmarokSharedPointer<SqlArtist>   oldArtist;
+    AmarokSharedPointer<SqlArtist>   newArtist;
+    AmarokSharedPointer<SqlAlbum>    oldAlbum;
+    AmarokSharedPointer<SqlAlbum>    newAlbum;
+    AmarokSharedPointer<SqlComposer> oldComposer;
+    AmarokSharedPointer<SqlComposer> newComposer;
+    AmarokSharedPointer<SqlGenre>    oldGenre;
+    AmarokSharedPointer<SqlGenre>    newGenre;
+    AmarokSharedPointer<SqlYear>     oldYear;
+    AmarokSharedPointer<SqlYear>     newYear;
 
     if( m_cache.contains( Meta::valFormat ) )
         m_filetype = Amarok::FileType(m_cache.value( Meta::valFormat ).toInt());
@@ -850,8 +850,8 @@ SqlTrack::commitIfInNonBatchUpdate()
         // existing track, which is forbidden by the database
         // At least the ScanResultProcessor handles this problem
 
-        KUrl oldUrl = m_url;
-        KUrl newUrl = m_cache.value( Meta::valUrl ).toString();
+        QUrl oldUrl = m_url;
+        QUrl newUrl = QUrl::fromUserInput(m_cache.value( Meta::valUrl ).toString());
         if( oldUrl != newUrl )
             m_collection->registry()->updateCachedUrl( oldUrl.path(), newUrl.path() );
         m_url = newUrl;
@@ -1056,7 +1056,7 @@ SqlTrack::updatePlaylistsToDb( const FieldHash &fields, const QString &oldUid )
     if( fields.isEmpty() )
         return; // nothing to do
 
-    SqlStorage *storage = m_collection->sqlStorage();
+    auto storage = m_collection->sqlStorage();
     QStringList tags;
 
     // keep this in sync with SqlPlaylist::saveTracks()!
@@ -1091,7 +1091,7 @@ SqlTrack::updateEmbeddedCoversToDb( const FieldHash &fields, const QString &oldU
     if( fields.isEmpty() )
         return; // nothing to do
 
-    SqlStorage *storage = m_collection->sqlStorage();
+    auto storage = m_collection->sqlStorage();
     QString tags;
 
     if( fields.contains( Meta::valUniqueId ) )
@@ -1116,8 +1116,8 @@ SqlTrack::prettyTitle( const QString &filename ) //static
         s = s.left( s.length() - 5 );
 
     //remove file extension, s/_/ /g and decode %2f-like sequences
-    s = s.left( s.lastIndexOf( '.' ) ).replace( '_', ' ' );
-    s = KUrl::fromPercentEncoding( s.toAscii() );
+    s = s.left( s.lastIndexOf( QLatin1Char('.') ) ).replace( '_', ' ' );
+    s = QUrl::fromPercentEncoding( s.toLatin1() );
 
     return s;
 }
@@ -1139,7 +1139,7 @@ QString
 SqlTrack::cachedLyrics() const
 {
     /* We don't cache the string as it may be potentially very long */
-    QString query = QString( "SELECT lyrics FROM lyrics WHERE url = %1" ).arg( m_urlId );
+    QString query = QStringLiteral( "SELECT lyrics FROM lyrics WHERE url = %1" ).arg( m_urlId );
     QStringList result = m_collection->sqlStorage()->query( query );
     if( result.isEmpty() )
         return QString();
@@ -1236,11 +1236,11 @@ SqlTrack::addLabel( const QString &label )
 void
 SqlTrack::addLabel( const Meta::LabelPtr &label )
 {
-    KSharedPtr<SqlLabel> sqlLabel = KSharedPtr<SqlLabel>::dynamicCast( label );
+    AmarokSharedPointer<SqlLabel> sqlLabel = AmarokSharedPointer<SqlLabel>::dynamicCast( label );
     if( !sqlLabel )
     {
         Meta::LabelPtr tmp = m_collection->registry()->getLabel( label->name() );
-        sqlLabel = KSharedPtr<SqlLabel>::dynamicCast( tmp );
+        sqlLabel = AmarokSharedPointer<SqlLabel>::dynamicCast( tmp );
     }
     if( sqlLabel )
     {
@@ -1287,11 +1287,11 @@ SqlTrack::urlId() const
 void
 SqlTrack::removeLabel( const Meta::LabelPtr &label )
 {
-    KSharedPtr<SqlLabel> sqlLabel = KSharedPtr<SqlLabel>::dynamicCast( label );
+    AmarokSharedPointer<SqlLabel> sqlLabel = AmarokSharedPointer<SqlLabel>::dynamicCast( label );
     if( !sqlLabel )
     {
         Meta::LabelPtr tmp = m_collection->registry()->getLabel( label->name() );
-        sqlLabel = KSharedPtr<SqlLabel>::dynamicCast( tmp );
+        sqlLabel = AmarokSharedPointer<SqlLabel>::dynamicCast( tmp );
     }
     if( sqlLabel )
     {
@@ -1469,7 +1469,7 @@ SqlAlbum::SqlAlbum( Collections::SqlCollection *collection, int id, const QStrin
     , m_hasImage( false )
     , m_hasImageChecked( false )
     , m_unsetImageId( -1 )
-    , m_tracksLoaded( false )
+    , m_tracksLoaded( NotLoaded )
     , m_suppressAutoFetch( false )
     , m_mutex( QMutex::Recursive )
 {
@@ -1486,7 +1486,7 @@ void
 SqlAlbum::invalidateCache()
 {
     QMutexLocker locker( &m_mutex );
-    m_tracksLoaded = false;
+    m_tracksLoaded = NotLoaded;
     m_hasImage = false;
     m_hasImageChecked = false;
     m_tracks.clear();
@@ -1495,28 +1495,50 @@ SqlAlbum::invalidateCache()
 TrackList
 SqlAlbum::tracks()
 {
+    bool startQuery = false;
+
     {
         QMutexLocker locker( &m_mutex );
-        if( m_tracksLoaded )
+        if( m_tracksLoaded == Loaded )
             return m_tracks;
+        else if( m_tracksLoaded == NotLoaded )
+        {
+            startQuery = true;
+            m_tracksLoaded = Loading;
+        }
     }
 
-    // when running the query maker don't lock. might lead to deadlock via registry
-    Collections::SqlQueryMaker *qm = static_cast< Collections::SqlQueryMaker* >( m_collection->queryMaker() );
-    qm->setQueryType( Collections::QueryMaker::Track );
-    qm->addMatch( Meta::AlbumPtr( this ) );
-    qm->orderBy( Meta::valDiscNr );
-    qm->orderBy( Meta::valTrackNr );
-    qm->orderBy( Meta::valTitle );
-    qm->setBlocking( true );
-    qm->run();
-
+    if( startQuery )
     {
-        QMutexLocker locker( &m_mutex );
-        m_tracks = qm->tracks();
-        m_tracksLoaded = true;
-        delete qm;
-        return m_tracks;
+        // when running the query maker don't lock. might lead to deadlock via registry
+        Collections::SqlQueryMaker *qm = static_cast< Collections::SqlQueryMaker* >( m_collection->queryMaker() );
+        qm->setQueryType( Collections::QueryMaker::Track );
+        qm->addMatch( Meta::AlbumPtr( this ) );
+        qm->orderBy( Meta::valDiscNr );
+        qm->orderBy( Meta::valTrackNr );
+        qm->orderBy( Meta::valTitle );
+        qm->setBlocking( true );
+        qm->run();
+
+        {
+            QMutexLocker locker( &m_mutex );
+            m_tracks = qm->tracks();
+            m_tracksLoaded = Loaded;
+            delete qm;
+            return m_tracks;
+        }
+    }
+    else
+    {
+        // Wait for tracks to be loaded
+        forever
+        {
+            QMutexLocker locker( &m_mutex );
+            if( m_tracksLoaded == Loaded )
+                return m_tracks;
+            else
+                QThread::yieldCurrentThread();
+        }
     }
 }
 
@@ -1608,27 +1630,27 @@ SqlAlbum::image( int size ) const
     if( size > 1 && size < 1000 )
     {
         image = image.scaled( size, size, Qt::KeepAspectRatio, Qt::SmoothTransformation );
-        image.save( cachedImagePath, "PNG" );
+        image.save( cachedImagePath, "PNG", -1 );
     }
 
     return image;
 }
 
-KUrl
+QUrl
 SqlAlbum::imageLocation( int size )
 {
     if( !hasImage() )
-        return KUrl();
+        return QUrl();
 
     // findCachedImage looks for a scaled version of the fullsize image
     // which may have been saved on a previous lookup
     if( size <= 1 )
-        return m_imagePath;
+        return QUrl::fromLocalFile( m_imagePath );
 
     QString cachedImagePath = scaledDiskCachePath( size );
 
     if( cachedImagePath.isEmpty() )
-        return KUrl();
+        return QUrl();
 
     if( !QFile( cachedImagePath ).exists() )
     {
@@ -1639,9 +1661,9 @@ SqlAlbum::imageLocation( int size )
     }
 
     if( !QFile( cachedImagePath ).exists() )
-        return KUrl();
+        return QUrl();
 
-    return cachedImagePath;
+    return QUrl::fromLocalFile(cachedImagePath);
 }
 
 void
@@ -1651,10 +1673,11 @@ SqlAlbum::setImage( const QImage &image )
     if( m_name.isEmpty() )
         return;
 
-    QMutexLocker locker( &m_mutex );
     if( image.isNull() )
         return;
 
+    QMutexLocker locker( &m_mutex );
+
     // removeImage() will destroy all scaled cached versions of the artwork
     // and remove references from the database if required.
     removeImage();
@@ -1664,7 +1687,7 @@ SqlAlbum::setImage( const QImage &image )
     while( QFile(path).exists() )
         path += '_'; // not that nice but it shouldn't happen that often.
 
-    image.save( path, "JPG" );
+    image.save( path, "JPG", -1 );
     setImage( path );
 
     locker.unlock();
@@ -1689,8 +1712,8 @@ SqlAlbum::setImage( const QImage &image )
                 Meta::FieldHash fields;
                 fields.insert( Meta::valImage, scaledImage );
                 WriteTagsJob *job = new WriteTagsJob( metaTrack->playableUrl().path(), fields );
-                QObject::connect( job, SIGNAL(done(ThreadWeaver::Job*)), job, SLOT(deleteLater()) );
-                ThreadWeaver::Weaver::instance()->enqueue( job );
+                QObject::connect( job, &WriteTagsJob::done, job, &WriteTagsJob::deleteLater );
+                ThreadWeaver::Queue::instance()->enqueue( QSharedPointer<ThreadWeaver::Job>(job) );
             }
             // note: we might want to update the track file size after writing the image
         }
@@ -1743,7 +1766,7 @@ SqlAlbum::removeImage()
             foreach( const QString &image, cachedImages )
             {
                 bool r = QFile::remove( cacheDir.filePath( image ) );
-                debug() << "deleting cached image: " << image << " : " + ( r ? QString("ok") : QString("fail") );
+                debug() << "deleting cached image: " << image << " : " + ( r ? QStringLiteral("ok") : QStringLiteral("fail") );
             }
 
             CoverCache::invalidateAlbum( this );
@@ -1810,11 +1833,12 @@ SqlAlbum::albumArtist() const
 QByteArray
 SqlAlbum::md5sum( const QString& artist, const QString& album, const QString& file ) const
 {
-    // FIXME: names with unicode characters are not supported.
-    // FIXME: "The Beatles"."Collection" and "The"."Beatles Collection" will produce the same hash.
-    // FIXME: Correcting this now would invalidate all existing image stores.
-    KMD5 context( artist.toLower().toLocal8Bit() + album.toLower().toLocal8Bit() + file.toLocal8Bit() );
-    return context.hexDigest();
+    // FIXME: All existing image stores have been invalidated.
+    return QCryptographicHash::hash( artist.toLower().toUtf8() + QByteArray( "#" ) +
+                                     album.toLower().toUtf8() + QByteArray( "?" ) +
+                                     file.toUtf8(),
+                                     QCryptographicHash::Md5
+    ).toHex();
 }
 
 QString
@@ -1827,7 +1851,11 @@ SqlAlbum::largeDiskCachePath() const
 
     QDir largeCoverDir( Amarok::saveLocation( "albumcovers/large/" ) );
     const QString key = md5sum( artist, m_name, QString() );
+
+    if( !key.isEmpty() )
         return largeCoverDir.filePath( key );
+
+    return QString();
 }
 
 QString
@@ -1908,23 +1936,22 @@ SqlAlbum::largeImagePath()
 void
 SqlAlbum::setImage( const QString &path )
 {
-    if( m_imagePath == path )
-        return;
     if( m_name.isEmpty() ) // the empty album never has an image
         return;
 
     QMutexLocker locker( &m_mutex );
 
-    QString imagePath = path;
+    if( m_imagePath == path )
+        return;
 
     QString query = "SELECT id FROM images WHERE path = '%1'";
-    query = query.arg( m_collection->sqlStorage()->escape( imagePath ) );
+    query = query.arg( m_collection->sqlStorage()->escape( path ) );
     QStringList res = m_collection->sqlStorage()->query( query );
 
     if( res.isEmpty() )
     {
         QString insert = QString( "INSERT INTO images( path ) VALUES ( '%1' )" )
-                            .arg( m_collection->sqlStorage()->escape( imagePath ) );
+        .arg( m_collection->sqlStorage()->escape( path ) );
         m_imageId = m_collection->sqlStorage()->insert( insert, "images" );
     }
     else
@@ -1932,11 +1959,11 @@ SqlAlbum::setImage( const QString &path )
 
     if( m_imageId >= 0 )
     {
-        query = QString("UPDATE albums SET image = %1 WHERE albums.id = %2" )
+        query = QStringLiteral("UPDATE albums SET image = %1 WHERE albums.id = %2" )
                     .arg( QString::number( m_imageId ), QString::number( m_id ) );
         m_collection->sqlStorage()->query( query );
 
-        m_imagePath = imagePath;
+        m_imagePath = path;
         m_hasImage = true;
         m_hasImageChecked = true;
         CoverCache::invalidateAlbum( this );
@@ -1944,7 +1971,7 @@ SqlAlbum::setImage( const QString &path )
 }
 
 /** Set the compilation flag.
- *  Actually it does not cange this album but instead moves
+ *  Actually it does not change this album but instead moves
  *  the tracks to other albums (e.g. one with the same name which is a
  *  compilation)
  *  If the compilation flag is set to "false" then all songs
@@ -1969,7 +1996,7 @@ SqlAlbum::setCompilation( bool compilation )
         {
             // get the new compilation album
             Meta::AlbumPtr metaAlbum = m_collection->registry()->getAlbum( name(), QString() );
-            KSharedPtr<SqlAlbum> sqlAlbum = KSharedPtr<SqlAlbum>::dynamicCast( metaAlbum );
+            AmarokSharedPointer<SqlAlbum> sqlAlbum = AmarokSharedPointer<SqlAlbum>::dynamicCast( metaAlbum );
 
             Meta::FieldHash changes;
             changes.insert( Meta::valCompilation, 1);
@@ -2006,7 +2033,7 @@ SqlAlbum::setCompilation( bool compilation )
                 Meta::AlbumPtr metaAlbum = m_collection->registry()->getAlbum(
                     sqlTrack->album()->name(),
                     trackArtist ? ArtistHelper::realTrackArtist( trackArtist->name() ) : QString() );
-                KSharedPtr<SqlAlbum> sqlAlbum = KSharedPtr<SqlAlbum>::dynamicCast( metaAlbum );
+                AmarokSharedPointer<SqlAlbum> sqlAlbum = AmarokSharedPointer<SqlAlbum>::dynamicCast( metaAlbum );
 
                 // copy over the cover image
                 if( sqlTrack->album()->hasImage() && !sqlAlbum->hasImage() )
