@@ -26,6 +26,7 @@
 #include "amarok_sqlcollection_export.h"
 #include "FileType.h"
 
+#include <QAtomicInt>
 #include <QByteArray>
 #include <QMutex>
 #include <QReadWriteLock>
@@ -34,11 +35,7 @@
 #include <QVariant>
 
 namespace Capabilities {
-    class AlbumCapabilityDelegate;
-    class ArtistCapabilityDelegate;
-    class TrackCapabilityDelegate;
 }
-class QAction;
 
 class SqlRegistry;
 class TrackUrlsTableCommitter;
@@ -70,85 +67,85 @@ class AMAROK_SQLCOLLECTION_EXPORT SqlTrack : public Track, public Statistics, pu
          *  It is advisable to set at least the path.
          */
         SqlTrack( Collections::SqlCollection *collection, int deviceId,
-                  const QString &rpath, int directoryId, const QString uidUrl );
+                  const QString &rpath, int directoryId, const QString &uidUrl );
         SqlTrack( Collections::SqlCollection *collection, const QStringList &queryResult );
-        ~ SqlTrack();
+        ~ SqlTrack() override;
 
-        virtual QString name() const;
-        virtual QString prettyName() const;
-        virtual KUrl playableUrl() const;
-        virtual QString prettyUrl() const;
-        virtual QString uidUrl() const;
-        virtual QString notPlayableReason() const;
+        QString name() const override;
+        QString prettyName() const override;
+        QUrl playableUrl() const override;
+        QString prettyUrl() const override;
+        QString uidUrl() const override;
+        QString notPlayableReason() const override;
 
-        virtual Meta::AlbumPtr album() const;
-        virtual Meta::ArtistPtr artist() const;
-        virtual Meta::ComposerPtr composer() const;
-        virtual Meta::YearPtr year() const;
-        virtual Meta::GenrePtr genre() const;
+        Meta::AlbumPtr album() const override;
+        Meta::ArtistPtr artist() const override;
+        Meta::ComposerPtr composer() const override;
+        Meta::YearPtr year() const override;
+        Meta::GenrePtr genre() const override;
 
-        virtual QString type() const;
-        virtual qreal bpm() const;
-        virtual QString comment() const;
-        virtual qint64 length() const;
-        virtual int filesize() const;
-        virtual int sampleRate() const;
-        virtual int bitrate() const;
-        virtual QDateTime createDate() const;
-        virtual QDateTime modifyDate() const;
-        virtual int trackNumber() const;
-        virtual int discNumber() const;
-        virtual qreal replayGain( Meta::ReplayGainTag mode ) const;
+        QString type() const override;
+        qreal bpm() const override;
+        QString comment() const override;
+        qint64 length() const override;
+        int filesize() const override;
+        int sampleRate() const override;
+        int bitrate() const override;
+        QDateTime createDate() const override;
+        QDateTime modifyDate() const override;
+        int trackNumber() const override;
+        int discNumber() const override;
+        qreal replayGain( Meta::ReplayGainTag mode ) const override;
 
-        virtual bool inCollection() const;
-        virtual Collections::Collection* collection() const;
+        bool inCollection() const override;
+        Collections::Collection* collection() const override;
 
-        virtual QString cachedLyrics() const;
-        virtual void setCachedLyrics( const QString &lyrics );
+        QString cachedLyrics() const override;
+        void setCachedLyrics( const QString &lyrics ) override;
 
-        virtual bool hasCapabilityInterface( Capabilities::Capability::Type type ) const;
-        virtual Capabilities::Capability* createCapabilityInterface( Capabilities::Capability::Type type );
+        bool hasCapabilityInterface( Capabilities::Capability::Type type ) const override;
+        Capabilities::Capability* createCapabilityInterface( Capabilities::Capability::Type type ) override;
 
-        virtual void addLabel( const QString &label );
-        virtual void addLabel( const Meta::LabelPtr &label );
-        virtual void removeLabel( const Meta::LabelPtr &label );
-        virtual Meta::LabelList labels() const;
+        void addLabel( const QString &label ) override;
+        void addLabel( const Meta::LabelPtr &label ) override;
+        void removeLabel( const Meta::LabelPtr &label ) override;
+        Meta::LabelList labels() const override;
 
-        virtual TrackEditorPtr editor();
-        virtual StatisticsPtr statistics();
+        TrackEditorPtr editor() override;
+        StatisticsPtr statistics() override;
 
         // Meta::TrackEditor methods:
-        virtual void setAlbum( const QString &newAlbum );
-        virtual void setAlbumArtist( const QString &newAlbumArtist );
-        virtual void setArtist( const QString &newArtist );
-        virtual void setComposer( const QString &newComposer );
-        virtual void setGenre( const QString &newGenre );
-        virtual void setYear( int newYear );
-        virtual void setTitle( const QString &newTitle );
-        virtual void setComment( const QString &newComment );
-        virtual void setTrackNumber( int newTrackNumber );
-        virtual void setDiscNumber( int newDiscNumber );
-        virtual void setBpm( const qreal newBpm );
+        void setAlbum( const QString &newAlbum ) override;
+        void setAlbumArtist( const QString &newAlbumArtist ) override;
+        void setArtist( const QString &newArtist ) override;
+        void setComposer( const QString &newComposer ) override;
+        void setGenre( const QString &newGenre ) override;
+        void setYear( int newYear ) override;
+        void setTitle( const QString &newTitle ) override;
+        void setComment( const QString &newComment ) override;
+        void setTrackNumber( int newTrackNumber ) override;
+        void setDiscNumber( int newDiscNumber ) override;
+        void setBpm( const qreal newBpm ) override;
 
         // Meta::Statistics methods:
-        virtual double score() const;
-        virtual void setScore( double newScore );
+        double score() const override;
+        void setScore( double newScore ) override;
 
-        virtual int rating() const;
-        virtual void setRating( int newRating );
+        int rating() const override;
+        void setRating( int newRating ) override;
 
-        virtual QDateTime firstPlayed() const;
-        virtual void setFirstPlayed( const QDateTime &newTime );
+        QDateTime firstPlayed() const override;
+        void setFirstPlayed( const QDateTime &newTime ) override;
 
-        virtual QDateTime lastPlayed() const;
-        virtual void setLastPlayed( const QDateTime &newTime );
+        QDateTime lastPlayed() const override;
+        void setLastPlayed( const QDateTime &newTime ) override;
 
-        virtual int playCount() const;
-        virtual void setPlayCount( const int newCount );
+        int playCount() const override;
+        void setPlayCount( const int newCount ) override;
 
         // combined Meta::Statistics and Meta::TrackEditor methods:
-        virtual void beginUpdate();
-        virtual void endUpdate();
+        void beginUpdate() override;
+        void endUpdate() override;
 
         // SqlTrack specific methods
         /** true if there is a collection, the file exists on disk and is writable */
@@ -236,7 +233,7 @@ class AMAROK_SQLCOLLECTION_EXPORT SqlTrack : public Track, public Statistics, pu
         int m_deviceId;
         QString m_rpath;
         int m_directoryId; // only set when the urls table needs to be written
-        KUrl m_url;
+        QUrl m_url;
         QString m_uid;
 
         // the rest
@@ -281,7 +278,7 @@ class AMAROK_SQLCOLLECTION_EXPORT SqlTrack : public Track, public Statistics, pu
         FieldHash m_cache;
 
         /** This ReadWriteLock is protecting all internal variables.
-            It is ensuring that m_cache, m_batchUpdate and the othre internal variable are
+            It is ensuring that m_cache, m_batchUpdate and the other internal variable are
             in a consistent state all the time.
         */
         mutable QReadWriteLock m_lock;
@@ -299,17 +296,17 @@ class AMAROK_SQLCOLLECTION_EXPORT SqlArtist : public Meta::Artist
 {
     public:
         SqlArtist( Collections::SqlCollection* collection, int id, const QString &name );
-        ~SqlArtist();
+        ~SqlArtist() override;
 
-        virtual QString name() const { return m_name; }
+        QString name() const override { return m_name; }
 
         virtual void invalidateCache();
 
-        virtual Meta::TrackList tracks();
+        Meta::TrackList tracks() override;
 
-        virtual bool hasCapabilityInterface( Capabilities::Capability::Type type ) const;
+        bool hasCapabilityInterface( Capabilities::Capability::Type type ) const override;
 
-        virtual Capabilities::Capability* createCapabilityInterface( Capabilities::Capability::Type type );
+        Capabilities::Capability* createCapabilityInterface( Capabilities::Capability::Type type ) override;
 
         //SQL specific methods
         int id() const { return m_id; }
@@ -334,28 +331,28 @@ class AMAROK_SQLCOLLECTION_EXPORT SqlAlbum : public Meta::Album
 {
     public:
         SqlAlbum( Collections::SqlCollection* collection, int id, const QString &name, int artist );
-        ~SqlAlbum();
+        ~SqlAlbum() override;
 
-        virtual QString name() const { return m_name; }
+        QString name() const override { return m_name; }
 
         virtual void invalidateCache();
 
-        virtual Meta::TrackList tracks();
+        Meta::TrackList tracks() override;
 
-        virtual bool isCompilation() const;
-        virtual bool canUpdateCompilation() const { return true; }
-        void setCompilation( bool compilation );
+        bool isCompilation() const override;
+        bool canUpdateCompilation() const override { return true; }
+        void setCompilation( bool compilation ) override;
 
         /** Returns true if this album has an artist.
          *  The following equation is always true: isCompilation() != hasAlbumArtist()
          */
-        virtual bool hasAlbumArtist() const;
+        bool hasAlbumArtist() const override;
 
         /** Returns the album artist.
          *  Note that setting the album artist is not supported.
          *  A compilation does not have an artist and not only an empty artist.
          */
-        virtual Meta::ArtistPtr albumArtist() const;
+        Meta::ArtistPtr albumArtist() const override;
 
         //updating album images is possible for local tracks, but let's ignore it for now
 
@@ -363,8 +360,8 @@ class AMAROK_SQLCOLLECTION_EXPORT SqlAlbum : public Meta::Album
          *  @param size The maximum width or height of the result.
          *  when size is <= 1, return the full size image
          */
-        virtual bool hasImage(int size = 0) const;
-        virtual bool canUpdateImage() const { return true; }
+        bool hasImage(int size = 0) const override;
+        bool canUpdateImage() const override { return true; }
 
         /** Returns the album cover image.
          *  Returns a default image if no specific album image could be found.
@@ -373,17 +370,17 @@ class AMAROK_SQLCOLLECTION_EXPORT SqlAlbum : public Meta::Album
          *  @param size is the maximum width or height of the resulting image.
          *  when size is <= 1, return the full size image
          */
-        virtual QImage image( int size = 0 ) const;
+        QImage image( int size = 0 ) const override;
 
-        virtual KUrl imageLocation( int size = 0 );
-        virtual void setImage( const QImage &image );
-        virtual void removeImage();
-        virtual void setSuppressImageAutoFetch( const bool suppress ) { m_suppressAutoFetch = suppress; }
-        virtual bool suppressImageAutoFetch() const { return m_suppressAutoFetch; }
+        QUrl imageLocation( int size = 0 ) override;
+        void setImage( const QImage &image ) override;
+        void removeImage() override;
+        void setSuppressImageAutoFetch( const bool suppress ) override { m_suppressAutoFetch = suppress; }
+        bool suppressImageAutoFetch() const override { return m_suppressAutoFetch; }
 
-        virtual bool hasCapabilityInterface( Capabilities::Capability::Type type ) const;
+        bool hasCapabilityInterface( Capabilities::Capability::Type type ) const override;
 
-        virtual Capabilities::Capability* createCapabilityInterface( Capabilities::Capability::Type type );
+        Capabilities::Capability* createCapabilityInterface( Capabilities::Capability::Type type ) override;
 
         //SQL specific methods
         int id() const { return m_id; }
@@ -423,19 +420,24 @@ class AMAROK_SQLCOLLECTION_EXPORT SqlAlbum : public Meta::Album
          *  The path should point to a valid image.
          *  Note: setImage will not delete the already set image.
          */
-       void setImage( const QString &path );
+        void setImage( const QString &path );
 
-       /** Finds or creates a magic value in the database which tells Amarok not to auto fetch an image since it has been explicitly unset.
-       */
-       int unsetImageId() const;
+        /** Finds or creates a magic value in the database which tells Amarok not to auto fetch an image since it has been explicitly unset.
+        */
+        int unsetImageId() const;
 
-    private:
         Collections::SqlCollection* const m_collection;
 
+        enum TracksLoadingStatus
+        {
+            NotLoaded,
+            Loading,
+            Loaded
+        };
 
-        QString m_name;
-        int m_id; // the id of this album in the database
-        int m_artistId;
+        const QString m_name;
+        const int m_id; // the id of this album in the database
+        const int m_artistId;
         int m_imageId;
         mutable QString m_imagePath; // path read from the database
         mutable bool m_hasImage; // true if we have an original image
@@ -444,7 +446,7 @@ class AMAROK_SQLCOLLECTION_EXPORT SqlAlbum : public Meta::Album
         mutable int m_unsetImageId; // this is the id of the unset magic value in the image sql database
         static const QString AMAROK_UNSET_MAGIC;
 
-        bool m_tracksLoaded;
+        TracksLoadingStatus m_tracksLoaded;
         bool m_suppressAutoFetch;
         Meta::ArtistPtr m_artist;
         Meta::TrackList m_tracks;
@@ -462,11 +464,11 @@ class AMAROK_SQLCOLLECTION_EXPORT SqlComposer : public Meta::Composer
     public:
         SqlComposer( Collections::SqlCollection* collection, int id, const QString &name );
 
-        virtual QString name() const { return m_name; }
+        QString name() const override { return m_name; }
 
         virtual void invalidateCache();
 
-        virtual Meta::TrackList tracks();
+        Meta::TrackList tracks() override;
 
         //SQL specific methods
         int id() const { return m_id; }
@@ -478,6 +480,7 @@ class AMAROK_SQLCOLLECTION_EXPORT SqlComposer : public Meta::Composer
         const QString m_name;
 
         bool m_tracksLoaded;
+        bool m_tracksLoading;
         Meta::TrackList m_tracks;
         QMutex m_mutex;
 
@@ -490,13 +493,13 @@ class SqlGenre : public Meta::Genre
     public:
         SqlGenre( Collections::SqlCollection* collection, int id, const QString &name );
 
-        virtual QString name() const { return m_name; }
+        QString name() const override { return m_name; }
 
         /** Invalidates the tracks cache */
         /** Invalidates the tracks cache */
         virtual void invalidateCache();
 
-        virtual Meta::TrackList tracks();
+        Meta::TrackList tracks() override;
 
         //SQL specific methods
         int id() const { return m_id; }
@@ -520,14 +523,14 @@ class AMAROK_SQLCOLLECTION_EXPORT SqlYear : public Meta::Year
     public:
         SqlYear( Collections::SqlCollection* collection, int id, int year );
 
-        virtual QString name() const { return QString::number(m_year); }
+        QString name() const override { return QString::number(m_year); }
 
-        virtual int year() const { return m_year; }
+        int year() const override { return m_year; }
 
         /** Invalidates the tracks cache */
         virtual void invalidateCache();
 
-        virtual Meta::TrackList tracks();
+        Meta::TrackList tracks() override;
 
         //SQL specific methods
         int id() const { return m_id; }
@@ -551,7 +554,7 @@ class AMAROK_SQLCOLLECTION_EXPORT SqlLabel : public Meta::Label
 public:
     SqlLabel( Collections::SqlCollection *collection, int id, const QString &name );
 
-    virtual QString name() const { return m_name; }
+    QString name() const override { return m_name; }
 
     /** Invalidates the tracks cache */
     virtual void invalidateCache();
@@ -574,12 +577,12 @@ private:
     friend class Meta::SqlTrack; // needs to call notifyObservers
 };
 
-typedef KSharedPtr<SqlTrack> SqlTrackPtr;
-typedef KSharedPtr<SqlArtist> SqlArtistPtr;
-typedef KSharedPtr<SqlAlbum> SqlAlbumPtr;
-typedef KSharedPtr<SqlComposer> SqlComposerPtr;
-typedef KSharedPtr<SqlGenre> SqlGenrePtr;
-typedef KSharedPtr<SqlYear> SqlYearPtr;
+typedef AmarokSharedPointer<SqlTrack> SqlTrackPtr;
+typedef AmarokSharedPointer<SqlArtist> SqlArtistPtr;
+typedef AmarokSharedPointer<SqlAlbum> SqlAlbumPtr;
+typedef AmarokSharedPointer<SqlComposer> SqlComposerPtr;
+typedef AmarokSharedPointer<SqlGenre> SqlGenrePtr;
+typedef AmarokSharedPointer<SqlYear> SqlYearPtr;
 
 }
 
