@@ -33,6 +33,7 @@
 
 #include <KMessageBox>
 
+#include <QAbstractEventDispatcher>
 #include <QApplication>
 
 SqlScanResultProcessor::SqlScanResultProcessor( GenericScanManager* manager,
@@ -71,8 +72,8 @@ SqlScanResultProcessor::scanSucceeded()
     // -- error reporting
     m_messages.append( m_collection->sqlStorage()->getLastErrors() );
 
-    if( !m_messages.isEmpty() && QApplication::type() != QApplication::Tty )
-        QTimer::singleShot(0, this, SLOT(displayMessages())); // do in the UI thread
+    if( !m_messages.isEmpty() && qobject_cast<QGuiApplication*>(qApp) )
+        QTimer::singleShot(0, this, &SqlScanResultProcessor::displayMessages); // do in the UI thread
 
     unblockUpdates();
 }
@@ -94,6 +95,8 @@ SqlScanResultProcessor::displayMessages()
 void
 SqlScanResultProcessor::blockUpdates()
 {
+    DEBUG_BLOCK
+
     m_collection->blockUpdatedSignal();
     m_collection->registry()->blockDatabaseUpdate();
 }
@@ -101,6 +104,8 @@ SqlScanResultProcessor::blockUpdates()
 void
 SqlScanResultProcessor::unblockUpdates()
 {
+    DEBUG_BLOCK
+
     m_collection->registry()->unblockDatabaseUpdate();
     m_collection->unblockUpdatedSignal();
 }
@@ -198,7 +203,7 @@ SqlScanResultProcessor::commitTrack( CollectionScanner::Track *track,
     }
     uid = m_collection->generateUidUrl( uid );
 
-    int deviceId = m_collection->mountPointManager()->getIdForUrl( track->path() );
+    int deviceId = m_collection->mountPointManager()->getIdForUrl( QUrl::fromUserInput(track->path()) );
     QString rpath = m_collection->mountPointManager()->getRelativePath( deviceId, track->path() );
 
     if( m_foundTracks.contains( uid ) )
@@ -263,7 +268,7 @@ SqlScanResultProcessor::commitTrack( CollectionScanner::Track *track,
     urlsCacheInsert( entry ); // removes the previous entry (by id) first if necessary
     m_foundTracks.insert( uid, entry.id );
 
-    // TODO: we need to check the modified date of the file agains the last updated of the file
+    // TODO: we need to check the modified date of the file against the last updated of the file
     // to figure out if the track information was updated from outside Amarok.
     // In such a case we would fully reread all the information as if in a FullScan
 
@@ -365,7 +370,7 @@ SqlScanResultProcessor::commitTrack( CollectionScanner::Track *track,
 void
 SqlScanResultProcessor::deleteDeletedDirectories()
 {
-    SqlStorage *storage = m_collection->sqlStorage();
+    auto storage = m_collection->sqlStorage();
 
     QList<DirectoryEntry> toCheck;
     switch( m_type )
@@ -479,7 +484,7 @@ SqlScanResultProcessor::relocateTracksToNewDirectory( int oldDirId, int newDirId
 
     MountPointManager *manager = m_collection->mountPointManager();
     SqlRegistry *reg = m_collection->registry();
-    SqlStorage *storage = m_collection->sqlStorage();
+    auto storage = m_collection->sqlStorage();
 
     // sanity checking, not strictly needed, but imagine new device appearing in the
     // middle of the scan, so rather prevent db corruption:
@@ -501,7 +506,7 @@ SqlScanResultProcessor::relocateTracksToNewDirectory( int oldDirId, int newDirId
         Q_ASSERT( track );
 
         // not strictly needed, but we want to sanity check it to prevent corrupt db
-        int deviceId = manager->getIdForUrl( entry.path );
+        int deviceId = manager->getIdForUrl( QUrl::fromUserInput(entry.path) );
         if( newDirDeviceId != deviceId )
         {
             warning() << "relocateTracksToNewDirectory(): device id from newDirId ("
@@ -536,7 +541,7 @@ SqlScanResultProcessor::removeTrack( const UrlEntry &entry )
 QList<SqlScanResultProcessor::DirectoryEntry>
 SqlScanResultProcessor::mountedDirectories() const
 {
-    SqlStorage *storage = m_collection->sqlStorage();
+    auto storage = m_collection->sqlStorage();
 
     // -- get a list of all mounted device ids
     QList<int> idList = m_collection->mountPointManager()->getMountedDeviceIds();
@@ -569,7 +574,7 @@ SqlScanResultProcessor::mountedDirectories() const
 QList<SqlScanResultProcessor::DirectoryEntry>
 SqlScanResultProcessor::deletedDirectories() const
 {
-    SqlStorage *storage = m_collection->sqlStorage();
+    auto storage = m_collection->sqlStorage();
 
     QHash<int, DirectoryEntry> idToDirEntryMap; // for faster processing during filtering
     foreach( int directoryId, m_scannedDirectoryIds )
@@ -599,9 +604,9 @@ SqlScanResultProcessor::deletedDirectories() const
         }
     }
 
-    // now we must fileter-out all found directories *and their children*, because the
+    // now we must filter out all found directories *and their children*, because the
     // children are *not* in m_foundDirectories and deleteDeletedDirectories() would
-    // remove them errorneously
+    // remove them erroneously
     foreach( int foundDirectoryId, m_foundDirectories )
     {
         if( idToDirEntryMap.contains( foundDirectoryId ) )
@@ -627,9 +632,11 @@ SqlScanResultProcessor::deletedDirectories() const
 void
 SqlScanResultProcessor::urlsCacheInit()
 {
-    SqlStorage *storage = m_collection->sqlStorage();
+    DEBUG_BLOCK
 
-    QString query = QString( "SELECT id, deviceid, rpath, directory, uniqueid FROM urls;");
+    auto storage = m_collection->sqlStorage();
+
+    QString query = QStringLiteral( "SELECT id, deviceid, rpath, directory, uniqueid FROM urls;");
     QStringList res = storage->query( query );
 
     for( int i = 0; i < res.count(); )
@@ -660,6 +667,8 @@ SqlScanResultProcessor::urlsCacheInit()
         }
 
         urlsCacheInsert( entry );
+
+        QAbstractEventDispatcher::instance()->processEvents( QEventLoop::AllEvents );
     }
 }
 
@@ -670,7 +679,7 @@ SqlScanResultProcessor::urlsCacheInsert( const UrlEntry &entry )
     if( m_urlsCache.contains( entry.id ) )
         urlsCacheRemove( m_urlsCache[ entry.id ] );
 
-    // following shoudn't normally happen:
+    // following shouldn't normally happen:
     if( m_pathCache.contains( entry.path ) )
     {
         int oldId = m_pathCache.value( entry.path );
