@@ -21,7 +21,8 @@
 #include "core/support/Debug.h"
 #include <core/storage/SqlStorage.h>
 
-#include <KUrl>
+#include <QUrl>
+#include <QDir>
 #include <Solid/Device>
 #include <Solid/StorageAccess>
 #include <Solid/StorageVolume>
@@ -64,14 +65,15 @@ const QString &MassStorageDeviceHandler::getDevicePath() const
     return m_mountPoint;
 }
 
-void MassStorageDeviceHandler::getURL( KUrl &absolutePath, const KUrl &relativePath )
+void MassStorageDeviceHandler::getURL( QUrl &absolutePath, const QUrl &relativePath )
 {
     absolutePath.setPath( m_mountPoint );
-    absolutePath.addPath( relativePath.path() );
-    absolutePath.cleanPath();
+    absolutePath = absolutePath.adjusted(QUrl::StripTrailingSlash);
+    absolutePath.setPath(absolutePath.path() + QLatin1Char('/') + ( relativePath.path() ));
+    absolutePath.setPath( QDir::cleanPath(absolutePath.path()) );
 }
 
-void MassStorageDeviceHandler::getPlayableURL( KUrl &absolutePath, const KUrl &relativePath )
+void MassStorageDeviceHandler::getPlayableURL( QUrl &absolutePath, const QUrl &relativePath )
 {
     getURL( absolutePath, relativePath );
 }
@@ -123,12 +125,12 @@ MassStorageDeviceHandlerFactory::~MassStorageDeviceHandlerFactory( )
 {
 }
 
-DeviceHandler * MassStorageDeviceHandlerFactory::createHandler( KSharedConfigPtr, SqlStorage* ) const
+DeviceHandler * MassStorageDeviceHandlerFactory::createHandler( const KSharedConfigPtr&, QSharedPointer<SqlStorage> ) const
 {
     return 0;
 }
 
-DeviceHandler * MassStorageDeviceHandlerFactory::createHandler( const Solid::Device &device, const QString &udi, SqlStorage *s ) const
+DeviceHandler * MassStorageDeviceHandlerFactory::createHandler( const Solid::Device &device, const QString &udi, QSharedPointer<SqlStorage> s ) const
 {
     DEBUG_BLOCK
     if( !s )
@@ -156,16 +158,16 @@ DeviceHandler * MassStorageDeviceHandlerFactory::createHandler( const Solid::Dev
         debug() << "Found existing UUID config for ID " << ids[0] << " , uuid " << volume->uuid();
         s->query( QString( "UPDATE devices SET lastmountpoint = '%2' WHERE "
                            "id = %1;" )
-                           .arg( ids[0] )
-                           .arg( s->escape( volumeAccess->filePath() ) ) );
+                           .arg( ids[0],
+                                 s->escape( volumeAccess->filePath() ) ) );
         return new MassStorageDeviceHandler( ids[0].toInt(), volumeAccess->filePath(), udi );
     }
     else
     {
         const int id = s->insert( QString( "INSERT INTO devices( type, uuid, lastmountpoint ) "
                                            "VALUES ( 'uuid', '%1', '%2' );" )
-                                           .arg( volume->uuid() )
-                                           .arg( s->escape( volumeAccess->filePath() ) ),
+                                           .arg( volume->uuid(),
+                                                 s->escape( volumeAccess->filePath() ) ),
                                            "devices" );
         if ( id == 0 )
         {
