@@ -22,7 +22,8 @@
 #include "core/support/Debug.h"
 #include <core/storage/SqlStorage.h>
 
-#include <KUrl>
+#include <QUrl>
+#include <QDir>
 #include <Solid/Device>
 #include <Solid/StorageAccess>
 #include <Solid/NetworkShare>
@@ -75,14 +76,15 @@ const QString &SmbDeviceHandler::getDevicePath() const
     return m_mountPoint;
 }
 
-void SmbDeviceHandler::getURL( KUrl &absolutePath, const KUrl &relativePath )
+void SmbDeviceHandler::getURL( QUrl &absolutePath, const QUrl &relativePath )
 {
     absolutePath.setPath( m_mountPoint );
-    absolutePath.addPath( relativePath.path() );
-    absolutePath.cleanPath();
+    absolutePath = absolutePath.adjusted(QUrl::StripTrailingSlash);
+    absolutePath.setPath(absolutePath.path() + QLatin1Char('/') + ( relativePath.path() ));
+    absolutePath.setPath( QDir::cleanPath(absolutePath.path()) );
 }
 
-void SmbDeviceHandler::getPlayableURL( KUrl &absolutePath, const KUrl &relativePath )
+void SmbDeviceHandler::getPlayableURL( QUrl &absolutePath, const QUrl &relativePath )
 {
     getURL( absolutePath, relativePath );
 }
@@ -145,13 +147,13 @@ SmbDeviceHandlerFactory::~SmbDeviceHandlerFactory( )
 }
 
 DeviceHandler *
-SmbDeviceHandlerFactory::createHandler( KSharedConfigPtr, SqlStorage* ) const
+SmbDeviceHandlerFactory::createHandler( const KSharedConfigPtr&, QSharedPointer<SqlStorage> ) const
 {
     return 0;
 }
 
 DeviceHandler *
-SmbDeviceHandlerFactory::createHandler( const Solid::Device &device, const QString &udi, SqlStorage *s ) const
+SmbDeviceHandlerFactory::createHandler( const Solid::Device &device, const QString &udi, QSharedPointer<SqlStorage> s ) const
 {
     DEBUG_BLOCK
     if( !s )
@@ -175,15 +177,15 @@ SmbDeviceHandlerFactory::createHandler( const Solid::Device &device, const QStri
     QStringList ids = s->query( QString( "SELECT id, label, lastmountpoint "
                                          "FROM devices WHERE type = 'smb' "
                                          "AND servername = '%1' AND sharename = '%2';" )
-                                         .arg( s->escape( server ) )
-                                         .arg( s->escape( share ) ) );
+                                         .arg( s->escape( server ),
+                                               s->escape( share ) ) );
     if ( ids.size() == 3 )
     {
         debug() << "Found existing SMB config for ID " << ids[0] << " , server " << server << " ,share " << share;
         s->query( QString( "UPDATE devices SET lastmountpoint = '%2' WHERE "
                            "id = %1;" )
-                           .arg( ids[0] )
-                           .arg( s->escape( mountPoint ) ) );
+                           .arg( ids[0],
+                                 s->escape( mountPoint ) ) );
         return new SmbDeviceHandler( ids[0].toInt(), server, share, mountPoint, udi );
     }
     else
@@ -191,9 +193,9 @@ SmbDeviceHandlerFactory::createHandler( const Solid::Device &device, const QStri
         int id = s->insert( QString( "INSERT INTO devices"
                                      "( type, servername, sharename, lastmountpoint ) "
                                      "VALUES ( 'smb', '%1', '%2', '%3' );" )
-                                     .arg( s->escape( server ) )
-                                     .arg( s->escape( share ) )
-                                     .arg( s->escape( mountPoint ) ),
+                                     .arg( s->escape( server ),
+                                           s->escape( share ),
+                                           s->escape( mountPoint ) ),
                                      "devices" );
         if ( id == 0 )
         {
