@@ -26,7 +26,7 @@
 #include "support/IpodTranscodeCapability.h"
 
 #include "core/capabilities/ActionsCapability.h"
-#include "core/interfaces/Logger.h"
+#include "core/logger/Logger.h"
 #include "core/support/Components.h"
 #include "core/support/Debug.h"
 #include "core-impl/collections/support/MemoryCollection.h"
@@ -38,12 +38,16 @@
 #include <solid/device.h>
 #include <solid/predicate.h>
 #include <solid/storageaccess.h>
-#include <ThreadWeaver/Weaver>
+#include <ThreadWeaver/Queue>
 
 #include <QTemporaryFile>
 #include <QWeakPointer>
 
 #include <gpod/itdb.h>
+#include <KConfigGroup>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <QVBoxLayout>
 
 
 const QString IpodCollection::s_uidUrlProtocol = QString( "amarok-ipodtrackuid" );
@@ -99,31 +103,31 @@ bool IpodCollection::init()
         return false;  // we have already displayed sorry message
 
     m_updateTimer.setSingleShot( true );
-    connect( this, SIGNAL(startUpdateTimer()), SLOT(slotStartUpdateTimer()) );
-    connect( &m_updateTimer, SIGNAL(timeout()), SLOT(collectionUpdated()) );
+    connect( this, &IpodCollection::startUpdateTimer, this, &IpodCollection::slotStartUpdateTimer );
+    connect( &m_updateTimer, &QTimer::timeout, this, &IpodCollection::collectionUpdated );
 
     m_writeDatabaseTimer.setSingleShot( true );
-    connect( this, SIGNAL(startWriteDatabaseTimer()), SLOT(slotStartWriteDatabaseTimer()) );
-    connect( &m_writeDatabaseTimer, SIGNAL(timeout()), SLOT(slotInitiateDatabaseWrite()) );
+    connect( this, &IpodCollection::startWriteDatabaseTimer, this, &IpodCollection::slotStartWriteDatabaseTimer );
+    connect( &m_writeDatabaseTimer, &QTimer::timeout, this, &IpodCollection::slotInitiateDatabaseWrite );
 
-    m_configureAction = new QAction( KIcon( "configure" ), i18n( "&Configure Device" ), this );
+    m_configureAction = new QAction( QIcon::fromTheme( "configure" ), i18n( "&Configure Device" ), this );
     m_configureAction->setProperty( "popupdropper_svg_id", "configure" );
-    connect( m_configureAction, SIGNAL(triggered()), SLOT(slotShowConfigureDialog()) );
+    connect( m_configureAction, &QAction::triggered, this, &IpodCollection::slotShowConfigureDialog );
 
-    m_ejectAction = new QAction( KIcon( "media-eject" ), i18n( "&Eject Device" ), this );
+    m_ejectAction = new QAction( QIcon::fromTheme( "media-eject" ), i18n( "&Eject Device" ), this );
     m_ejectAction->setProperty( "popupdropper_svg_id", "eject" );
-    connect( m_ejectAction, SIGNAL(triggered()), SLOT(slotEject()) );
+    connect( m_ejectAction, &QAction::triggered, this, &IpodCollection::slotEject );
 
     QString parseErrorMessage;
     m_itdb = IpodDeviceHelper::parseItdb( m_mountPoint, parseErrorMessage );
     m_prettyName = IpodDeviceHelper::collectionName( m_itdb ); // allows null m_itdb
 
     // m_consolidateAction is used by the provider
-    m_consolidateAction = new QAction( KIcon( "dialog-ok-apply" ), i18n( "Re-add orphaned and forget stale tracks" ), this );
+    m_consolidateAction = new QAction( QIcon::fromTheme( "dialog-ok-apply" ), i18n( "Re-add orphaned and forget stale tracks" ), this );
     // provider needs to be up before IpodParseTracksJob is started
     m_playlistProvider = new IpodPlaylistProvider( this );
-    connect( m_playlistProvider, SIGNAL(startWriteDatabaseTimer()), SIGNAL(startWriteDatabaseTimer()) );
-    connect( m_consolidateAction, SIGNAL(triggered()), m_playlistProvider, SLOT(slotConsolidateStaleOrphaned()) );
+    connect( m_playlistProvider, &IpodPlaylistProvider::startWriteDatabaseTimer, this, &IpodCollection::startWriteDatabaseTimer );
+    connect( m_consolidateAction, &QAction::triggered, m_playlistProvider, &IpodPlaylistProvider::slotConsolidateStaleOrphaned );
     The::playlistManager()->addProvider( m_playlistProvider, m_playlistProvider->category() );
 
     if( m_itdb )
@@ -131,11 +135,11 @@ bool IpodCollection::init()
         // parse tracks in a thread in order not to block main thread
         IpodParseTracksJob *job = new IpodParseTracksJob( this );
         m_parseTracksJob = job;
-        connect( job, SIGNAL(done(ThreadWeaver::Job*)), job, SLOT(deleteLater()) );
-        ThreadWeaver::Weaver::instance()->enqueue( job );
+        connect( job, &IpodParseTracksJob::done, job, &QObject::deleteLater );
+        ThreadWeaver::Queue::instance()->enqueue( QSharedPointer<ThreadWeaver::Job>(job) );
     }
     else
-        slotShowConfigureDialog( parseErrorMessage ); // shows error message and allows initializing
+        slotShowConfigureDialogWithError( parseErrorMessage ); // shows error message and allows initializing
 
     return true;  // we have found iPod, even if it might not be initialised
 }
@@ -153,7 +157,7 @@ IpodCollection::~IpodCollection()
         // call directly from main thread in destructor, we have no other chance:
         writeDatabase();
     }
-    delete m_preventUnmountTempFile; // this should have been certaily 0, but why not
+    delete m_preventUnmountTempFile; // this should have been certainly 0, but why not
     m_preventUnmountTempFile = 0;
 
     /* because m_itdb takes ownership of the tracks added to it, we need to remove the
@@ -168,13 +172,13 @@ IpodCollection::~IpodCollection()
 }
 
 bool
-IpodCollection::possiblyContainsTrack( const KUrl &url ) const
+IpodCollection::possiblyContainsTrack( const QUrl &url ) const
 {
     return url.toLocalFile().startsWith( m_mountPoint );
 }
 
 Meta::TrackPtr
-IpodCollection::trackForUrl( const KUrl &url )
+IpodCollection::trackForUrl( const QUrl &url )
 {
     QString relativePath = url.toLocalFile().mid( m_mountPoint.size() + 1 );
     QString uidUrl = QString( "%1/%2" ).arg( collectionId(), relativePath );
@@ -239,7 +243,7 @@ IpodCollection::uidUrlProtocol() const
 QString
 IpodCollection::collectionId() const
 {
-    return QString( "%1://%2" ).arg( s_uidUrlProtocol, m_uuid );
+    return QStringLiteral( "%1://%2" ).arg( s_uidUrlProtocol, m_uuid );
 }
 
 QString
@@ -248,10 +252,10 @@ IpodCollection::prettyName() const
     return m_prettyName;
 }
 
-KIcon
+QIcon
 IpodCollection::icon() const
 {
-    return KIcon("multimedia-player-apple-ipod");
+    return QIcon::fromTheme("multimedia-player-apple-ipod");
 }
 
 bool
@@ -275,7 +279,7 @@ IpodCollection::totalCapacity() const
 Collections::CollectionLocation*
 IpodCollection::location()
 {
-    return new IpodCollectionLocation( QWeakPointer<IpodCollection>( this ) );
+    return new IpodCollectionLocation( QPointer<IpodCollection>( this ) );
 }
 
 bool
@@ -291,14 +295,14 @@ IpodCollection::isOrganizable() const
 }
 
 void
-IpodCollection::metadataChanged( Meta::TrackPtr track )
+IpodCollection::metadataChanged(const Meta::TrackPtr &track )
 {
-    // reflect change to ouside world:
+    // reflect change to outside world:
     bool mapsChanged = MemoryMeta::MapChanger( m_mc.data() ).trackChanged( track );
     if( mapsChanged )
-        // while docs say somehting different, collection browser doesn't update unless we emit updated()
-        emit startUpdateTimer();
-    emit startWriteDatabaseTimer();
+        // while docs say something different, collection browser doesn't update unless we Q_EMIT updated()
+        Q_EMIT startUpdateTimer();
+    Q_EMIT startWriteDatabaseTimer();
 }
 
 QString
@@ -341,14 +345,14 @@ void
 IpodCollection::slotDestroy()
 {
     // guard against user hitting the button twice or hitting it while there is another
-    // write database job alreaddy running
+    // write database job already running
     if( m_writeDatabaseJob )
     {
         IpodWriteDatabaseJob *job = m_writeDatabaseJob.data();
         // don't create duplicate connections:
-        disconnect( job, SIGNAL(destroyed(QObject*)), this, SLOT(slotRemove()) );
-        disconnect( job, SIGNAL(destroyed(QObject*)), this, SLOT(slotPerformTeardownAndRemove()) );
-        connect( job, SIGNAL(destroyed(QObject*)), SLOT(slotRemove()) );
+        disconnect( job, &QObject::destroyed, this, &IpodCollection::slotRemove );
+        disconnect( job, &QObject::destroyed, this, &IpodCollection::slotPerformTeardownAndRemove );
+        connect( job, &QObject::destroyed, this, &IpodCollection::slotRemove );
     }
     // this is not racy: slotDestroy() is delivered to main thread, the timer fires in the
     // same thread
@@ -358,9 +362,9 @@ IpodCollection::slotDestroy()
         m_writeDatabaseTimer.stop();
         IpodWriteDatabaseJob *job = new IpodWriteDatabaseJob( this );
         m_writeDatabaseJob = job;
-        connect( job, SIGNAL(done(ThreadWeaver::Job*)), job, SLOT(deleteLater()) );
-        connect( job, SIGNAL(destroyed(QObject*)), SLOT(slotRemove()) );
-        ThreadWeaver::Weaver::instance()->enqueue( job );
+        connect( job, &IpodWriteDatabaseJob::done, job, &QObject::deleteLater );
+        connect( job, &QObject::destroyed, this, &IpodCollection::slotRemove );
+        ThreadWeaver::Queue::instance()->enqueue( QSharedPointer<ThreadWeaver::Job>(job) );
     }
     else
         slotRemove();
@@ -370,14 +374,14 @@ void
 IpodCollection::slotEject()
 {
     // guard against user hitting the button twice or hitting it while there is another
-    // write database job alreaddy running
+    // write database job already running
     if( m_writeDatabaseJob )
     {
         IpodWriteDatabaseJob *job = m_writeDatabaseJob.data();
         // don't create duplicate connections:
-        disconnect( job, SIGNAL(destroyed(QObject*)), this, SLOT(slotRemove()) );
-        disconnect( job, SIGNAL(destroyed(QObject*)), this, SLOT(slotPerformTeardownAndRemove()) );
-        connect( job, SIGNAL(destroyed(QObject*)), SLOT(slotPerformTeardownAndRemove()) );
+        disconnect( job, &QObject::destroyed, this, &IpodCollection::slotRemove );
+        disconnect( job, &QObject::destroyed, this, &IpodCollection::slotPerformTeardownAndRemove );
+        connect( job, &QObject::destroyed, this, &IpodCollection::slotPerformTeardownAndRemove );
     }
     // this is not racy: slotEject() is delivered to main thread, the timer fires in the
     // same thread
@@ -387,26 +391,44 @@ IpodCollection::slotEject()
         m_writeDatabaseTimer.stop();
         IpodWriteDatabaseJob *job = new IpodWriteDatabaseJob( this );
         m_writeDatabaseJob = job;
-        connect( job, SIGNAL(done(ThreadWeaver::Job*)), job, SLOT(deleteLater()) );
-        connect( job, SIGNAL(destroyed(QObject*)), SLOT(slotPerformTeardownAndRemove()) );
-        ThreadWeaver::Weaver::instance()->enqueue( job );
+        connect( job, &IpodWriteDatabaseJob::done, job, &QObject::deleteLater );
+        connect( job, &QObject::destroyed, this, &IpodCollection::slotPerformTeardownAndRemove );
+        ThreadWeaver::Queue::instance()->enqueue( QSharedPointer<ThreadWeaver::Job>(job) );
     }
     else
         slotPerformTeardownAndRemove();
 }
 
 void
-IpodCollection::slotShowConfigureDialog( const QString &errorMessage )
+IpodCollection::slotShowConfigureDialog()
+{
+    slotShowConfigureDialogWithError( QString() );
+}
+
+void
+IpodCollection::slotShowConfigureDialogWithError( const QString &errorMessage )
 {
     if( !m_configureDialog )
     {
         // create the dialog
-        m_configureDialog = new KDialog();
+        m_configureDialog = new QDialog();
         QWidget *settingsWidget = new QWidget( m_configureDialog );
         m_configureDialogUi.setupUi( settingsWidget );
 
-        m_configureDialog->setButtons( KDialog::Ok | KDialog::Cancel );
-        m_configureDialog->setMainWidget( settingsWidget );
+        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+        QWidget *mainWidget = new QWidget;
+        QVBoxLayout *mainLayout = new QVBoxLayout;
+        m_configureDialog->setLayout(mainLayout);
+        mainLayout->addWidget(mainWidget);
+        QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+        okButton->setDefault(true);
+        okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+        connect(buttonBox, &QDialogButtonBox::accepted, m_configureDialog, &QDialog::accept);
+        connect(buttonBox, &QDialogButtonBox::rejected, m_configureDialog, &QDialog::reject);
+
+        mainLayout->addWidget(settingsWidget);
+        mainLayout->addWidget(buttonBox);
+
         m_configureDialog->setWindowTitle( settingsWidget->windowTitle() );  // setupUi() sets this
         if( m_itdb )
         {
@@ -417,8 +439,8 @@ IpodCollection::slotShowConfigureDialog( const QString &errorMessage )
             m_configureDialogUi.initializeButton->hide();
         }
 
-        connect( m_configureDialogUi.initializeButton, SIGNAL(clicked(bool)), SLOT(slotInitialize()) );
-        connect( m_configureDialog, SIGNAL(okClicked()), SLOT(slotApplyConfiguration()) );
+        connect( m_configureDialogUi.initializeButton, &QPushButton::clicked, this, &IpodCollection::slotInitialize );
+        connect( m_configureDialog, &QDialog::accepted, this, &IpodCollection::slotApplyConfiguration );
     }
     QScopedPointer<Capabilities::TranscodeCapability> tc( create<Capabilities::TranscodeCapability>() );
     IpodDeviceHelper::fillInConfigureDialog( m_configureDialog, &m_configureDialogUi,
@@ -434,7 +456,7 @@ IpodCollection::slotShowConfigureDialog( const QString &errorMessage )
 void IpodCollection::collectionUpdated()
 {
     m_lastUpdated = QDateTime::currentMSecsSinceEpoch();
-    emit updated();
+    Q_EMIT updated();
 }
 
 void
@@ -448,7 +470,7 @@ IpodCollection::slotInitialize()
     bool success = IpodDeviceHelper::initializeIpod( m_mountPoint, &m_configureDialogUi, errorMessage );
     if( !success )
     {
-        slotShowConfigureDialog( errorMessage );
+        slotShowConfigureDialogWithError( errorMessage );
         return;
     }
 
@@ -467,11 +489,11 @@ IpodCollection::slotInitialize()
         // there will be probably 0 tracks, but it may do more in future, for example stale
         // & orphaned track search.
         IpodParseTracksJob *job = new IpodParseTracksJob( this );
-        connect( job, SIGNAL(done(ThreadWeaver::Job*)), job, SLOT(deleteLater()) );
-        ThreadWeaver::Weaver::instance()->enqueue( job );
+        connect( job, &IpodParseTracksJob::done, job, &QObject::deleteLater );
+        ThreadWeaver::Queue::instance()->enqueue( QSharedPointer<ThreadWeaver::Job>(job) );
     }
     else
-        slotShowConfigureDialog( errorMessage ); // shows error message and allows initializing
+        slotShowConfigureDialogWithError( errorMessage ); // shows error message and allows initializing
 }
 
 void
@@ -485,8 +507,8 @@ IpodCollection::slotApplyConfiguration()
     {
         IpodDeviceHelper::setIpodName( m_itdb, newName );
         m_prettyName = IpodDeviceHelper::collectionName( m_itdb );
-        emit startWriteDatabaseTimer(); // the change should be written down to the database
-        emit startUpdateTimer();
+        Q_EMIT startWriteDatabaseTimer(); // the change should be written down to the database
+        Q_EMIT startUpdateTimer();
     }
 
     QScopedPointer<Capabilities::TranscodeCapability> tc( create<Capabilities::TranscodeCapability>() );
@@ -526,20 +548,20 @@ void IpodCollection::slotInitiateDatabaseWrite()
     if( m_writeDatabaseJob )
     {
         warning() << __PRETTY_FUNCTION__ << "called while m_writeDatabaseJob still points"
-                  << "to an older job. Not doing anyhing.";
+                  << "to an older job. Not doing anything.";
         return;
     }
     IpodWriteDatabaseJob *job = new IpodWriteDatabaseJob( this );
     m_writeDatabaseJob = job;
-    connect( job, SIGNAL(done(ThreadWeaver::Job*)), job, SLOT(deleteLater()) );
-    ThreadWeaver::Weaver::instance()->enqueue( job );
+    connect( job, &IpodWriteDatabaseJob::done, job, &QObject::deleteLater );
+    ThreadWeaver::Queue::instance()->enqueue( QSharedPointer<ThreadWeaver::Job>(job) );
 }
 
 void IpodCollection::slotPerformTeardownAndRemove()
 {
     /* try to eject the device from system. Following technique potentially catches more
      * cases than simply passing the udi from IpodCollectionFactory, think of fuse-based
-     * filesystems for mounting iPhones et caetera.. */
+     * filesystems for mounting iPhones et cetera.. */
     Solid::Predicate query( Solid::DeviceInterface::StorageAccess, QString( "filePath" ),
                             m_mountPoint );
     QList<Solid::Device> devices = Solid::Device::listFromQuery( query );
@@ -560,14 +582,14 @@ void IpodCollection::slotRemove()
     // in the main thread
     if( m_parseTracksJob )
     {
-        // we need to wait until parseTracksJob finishes, because it acceses IpodCollection
+        // we need to wait until parseTracksJob finishes, because it accesses IpodCollection
         // and IpodPlaylistProvider in an asynchronous way that cannot safely cope with
         // IpodCollection disappearing
-        connect( m_parseTracksJob.data(), SIGNAL(destroyed(QObject*)), SIGNAL(remove()) );
-        m_parseTracksJob.data()->abort();
+        connect( m_parseTracksJob.data(), &QObject::destroyed, this, &IpodCollection::remove );
+        m_parseTracksJob->abort();
     }
     else
-        emit remove();
+        Q_EMIT remove();
 }
 
 Meta::TrackPtr
@@ -589,9 +611,9 @@ IpodCollection::addTrack( IpodMeta::Track *track )
         itdb_playlist_add_track( itdb_playlist_mpl( m_itdb ), itdbTrack, -1 );
 
         justAdded = true;
-        emit startWriteDatabaseTimer();
+        Q_EMIT startWriteDatabaseTimer();
     }
-    track->setCollection( QWeakPointer<IpodCollection>( this ) );
+    track->setCollection( QPointer<IpodCollection>( this ) );
 
     Meta::TrackPtr trackPtr( track );
     Meta::TrackPtr memTrack = MemoryMeta::MapChanger( m_mc.data() ).addTrack( trackPtr );
@@ -607,7 +629,7 @@ IpodCollection::addTrack( IpodMeta::Track *track )
     if( memTrack )
     {
         subscribeTo( trackPtr );
-        emit startUpdateTimer();
+        Q_EMIT startUpdateTimer();
     }
     return memTrack;
 }
@@ -646,10 +668,10 @@ IpodCollection::removeTrack( const Meta::TrackPtr &track )
         itdb_playlist_remove_track( itdb_playlist_mpl( m_itdb ), itdbTrack );
         // remove it from the db:
         itdb_track_unlink( itdbTrack );
-        emit startWriteDatabaseTimer();
+        Q_EMIT startWriteDatabaseTimer();
     }
 
-    emit startUpdateTimer();
+    Q_EMIT startUpdateTimer();
 }
 
 bool IpodCollection::writeDatabase()
@@ -681,7 +703,7 @@ bool IpodCollection::writeDatabase()
     {
         QString message = i18nc( "%1: iPod collection name",
                          "iTunes database successfully written to %1", prettyName() );
-        Amarok::Components::logger()->shortMessage( message );
+        Amarok::Logger::shortMessage( message );
     }
     else
     {
@@ -693,9 +715,8 @@ bool IpodCollection::writeDatabase()
         else
             message = i18nc( "%1: iPod collection name, %2: technical error from libgpod",
                              "Writing iTunes database to %1 failed: %2", prettyName(), gpodError );
-        Amarok::Components::logger()->longMessage( message );
+        Amarok::Logger::longMessage( message );
     }
     return success;
 }
 
-#include "IpodCollection.moc"
