@@ -17,18 +17,18 @@
 #include "IpodCollectionLocation.h"
 
 #include "jobs/IpodDeleteTracksJob.h"
-#include "core/interfaces/Logger.h"
+#include "core/logger/Logger.h"
 #include "core/support/Components.h"
 #include "core/support/Debug.h"
 
-#include <ThreadWeaver/Weaver>
+#include <ThreadWeaver/Queue>
 
 #include <QDir>
 #include <QFile>
 
 #include <gpod/itdb.h>
 
-IpodCollectionLocation::IpodCollectionLocation( QWeakPointer<IpodCollection> parentCollection )
+IpodCollectionLocation::IpodCollectionLocation( const QPointer<IpodCollection> &parentCollection )
     : CollectionLocation()  // we implement collection(), we need not pass parentCollection
     , m_coll( parentCollection )
 {
@@ -49,7 +49,7 @@ QString
 IpodCollectionLocation::prettyLocation() const
 {
     if( m_coll )
-        return m_coll.data()->prettyName();
+        return m_coll->prettyName();
     // match string with IpodCopyTracksJob::slotDisplaySorryDialog()
     return i18n( "Disconnected iPod/iPad/iPhone" );
 }
@@ -59,11 +59,11 @@ IpodCollectionLocation::isWritable() const
 {
     if( !m_coll )
         return false;
-    return m_coll.data()->isWritable(); // no infinite loop, IpodCollection iplements this
+    return m_coll->isWritable(); // no infinite loop, IpodCollection implements this
 }
 
 void
-IpodCollectionLocation::copyUrlsToCollection( const QMap<Meta::TrackPtr,KUrl> &sources,
+IpodCollectionLocation::copyUrlsToCollection( const QMap<Meta::TrackPtr,QUrl> &sources,
                                               const Transcoding::Configuration &configuration )
 {
     if( !isWritable() )
@@ -72,15 +72,16 @@ IpodCollectionLocation::copyUrlsToCollection( const QMap<Meta::TrackPtr,KUrl> &s
 
     IpodCopyTracksJob *job = new IpodCopyTracksJob( sources, m_coll, configuration, isGoingToRemoveSources() );
     int trackCount = sources.size();
-    Amarok::Components::logger()->newProgressOperation( job,
-        operationInProgressText( configuration, trackCount ), trackCount, job, SLOT(abort()) );
+    Amarok::Logger::newProgressOperation( job,
+                                                        operationInProgressText( configuration, trackCount ),
+                                                        trackCount, job, &IpodCopyTracksJob::abort );
 
     qRegisterMetaType<IpodCopyTracksJob::CopiedStatus>( "IpodCopyTracksJob::CopiedStatus" );
-    connect( job, SIGNAL(signalTrackProcessed(Meta::TrackPtr,Meta::TrackPtr,IpodCopyTracksJob::CopiedStatus)),
-             this, SLOT(slotCopyTrackProcessed(Meta::TrackPtr,Meta::TrackPtr,IpodCopyTracksJob::CopiedStatus)) );
-    connect( job, SIGNAL(done(ThreadWeaver::Job*)), this, SLOT(slotCopyOperationFinished()) );
-    connect( job, SIGNAL(done(ThreadWeaver::Job*)), job, SLOT(deleteLater()) );
-    ThreadWeaver::Weaver::instance()->enqueue( job );
+    connect( job, &IpodCopyTracksJob::signalTrackProcessed,
+             this, &IpodCollectionLocation::slotCopyTrackProcessed );
+    connect( job, &IpodCopyTracksJob::done, this, &IpodCollectionLocation::slotCopyOperationFinished );
+    connect( job, &IpodCopyTracksJob::done, job, &QObject::deleteLater );
+    ThreadWeaver::Queue::instance()->enqueue( QSharedPointer<ThreadWeaver::Job>(job) );
 }
 
 void
@@ -90,20 +91,20 @@ IpodCollectionLocation::removeUrlsFromCollection( const Meta::TrackList &sources
         return;
 
     IpodDeleteTracksJob *job = new IpodDeleteTracksJob( sources, m_coll );
-    connect( job, SIGNAL(done(ThreadWeaver::Job*)), this, SLOT(slotRemoveOperationFinished()) );
-    connect( job, SIGNAL(done(ThreadWeaver::Job*)), job, SLOT(deleteLater()) );
-    ThreadWeaver::Weaver::instance()->enqueue( job );
+    connect( job, &IpodDeleteTracksJob::done, this, &IpodCollectionLocation::slotRemoveOperationFinished );
+    connect( job, &IpodDeleteTracksJob::done, job, &QObject::deleteLater );
+    ThreadWeaver::Queue::instance()->enqueue( QSharedPointer<ThreadWeaver::Job>(job) );
 }
 
 void
-IpodCollectionLocation::setDestinationPlaylist( Playlists::PlaylistPtr destPlaylist, const QMap<Meta::TrackPtr, int> &trackPlaylistPositions )
+IpodCollectionLocation::setDestinationPlaylist( const Playlists::PlaylistPtr &destPlaylist, const QMap<Meta::TrackPtr, int> &trackPlaylistPositions )
 {
     m_destPlaylist = destPlaylist;
     m_trackPlaylistPositions = trackPlaylistPositions;
 }
 
 void
-IpodCollectionLocation::slotCopyTrackProcessed( Meta::TrackPtr srcTrack, Meta::TrackPtr destTrack,
+IpodCollectionLocation::slotCopyTrackProcessed( const Meta::TrackPtr &srcTrack, const Meta::TrackPtr &destTrack,
                                                 IpodCopyTracksJob::CopiedStatus status )
 {
     if( status == IpodCopyTracksJob::Success )
@@ -120,7 +121,7 @@ IpodCollectionLocation::slotCopyTrackProcessed( Meta::TrackPtr srcTrack, Meta::T
 
 void IpodCollectionLocation::ensureDirectoriesExist()
 {
-    QByteArray mountPoint = m_coll ? QFile::encodeName( m_coll.data()->mountPoint() ) : QByteArray();
+    QByteArray mountPoint = m_coll ? QFile::encodeName( m_coll->mountPoint() ) : QByteArray();
     if( mountPoint.isEmpty() )
         return;
 
@@ -151,4 +152,3 @@ void IpodCollectionLocation::ensureDirectoriesExist()
     }
 }
 
-#include "IpodCollectionLocation.moc"
