@@ -15,76 +15,23 @@
  ****************************************************************************************/
 
 #include "MediaDeviceMeta.h"
-#include "MediaDeviceCollection.h"
-#include "MediaDeviceHandler.h"
 
-#include "handler/capabilities/ArtworkCapability.h"
-
-// HACK: used to test disconnect
-#include "MediaDeviceMonitor.h"
-
-#include "covermanager/CoverFetchingActions.h"
-#include "core/support/Debug.h"
 #include "SvgHandler.h"
 #include "core/capabilities/ActionsCapability.h"
-#include "core/capabilities/EditCapability.h"
-#include "core/capabilities/UpdateCapability.h"
+#include "core/support/Debug.h"
+#include "core-impl/capabilities/AlbumActionsCapability.h"
+#include "core-impl/collections/mediadevicecollection/MediaDeviceCollection.h"
+#include "core-impl/collections/mediadevicecollection/MediaDeviceTrackEditor.h"
+#include "core-impl/collections/mediadevicecollection/handler/capabilities/ArtworkCapability.h"
+#include "covermanager/CoverCache.h"
+#include "covermanager/CoverFetchingActions.h"
 
-#include <KIcon>
-#include <KUrl>
+#include <QIcon>
+#include <QUrl>
 
 #include <QAction>
 
 using namespace Meta;
-// Currently complaining about some vtable issue
-
-class EditCapabilityMediaDevice : public Capabilities::EditCapability
-{
-    Q_OBJECT
-    public:
-        EditCapabilityMediaDevice( MediaDeviceTrack *track )
-            : Capabilities::EditCapability()
-            , m_track( track ) {}
-
-        virtual bool isEditable() const { return m_track->isEditable(); }
-        virtual void setAlbum( const QString &newAlbum ) { m_track->setAlbum( newAlbum ); }
-        virtual void setAlbumArtist( const QString &newAlbumArtist ) { m_track->setAlbumArtist( newAlbumArtist ); }
-        virtual void setArtist( const QString &newArtist ) { m_track->setArtist( newArtist ); }
-        virtual void setComposer( const QString &newComposer ) { m_track->setComposer( newComposer ); }
-        virtual void setGenre( const QString &newGenre ) { m_track->setGenre( newGenre ); }
-        virtual void setYear( int newYear ) { m_track->setYear( newYear ); }
-        virtual void setBpm( const qreal newBpm ) { m_track->setBpm( newBpm ); }
-        virtual void setTitle( const QString &newTitle ) { m_track->setTitle( newTitle ); }
-        virtual void setComment( const QString &newComment ) { m_track->setComment( newComment ); }
-        virtual void setTrackNumber( int newTrackNumber ) { m_track->setTrackNumber( newTrackNumber ); }
-        virtual void setDiscNumber( int newDiscNumber ) { m_track->setDiscNumber( newDiscNumber ); }
-        virtual void setUidUrl( const QString &newUidUrl ) { m_track->setUidUrl( newUidUrl ); }
-        virtual void beginMetaDataUpdate() { m_track->beginMetaDataUpdate(); }
-        virtual void endMetaDataUpdate() { m_track->endMetaDataUpdate(); }
-
-    private:
-        KSharedPtr<MediaDeviceTrack> m_track;
-};
-
-class UpdateCapabilityMediaDevice : public Capabilities::UpdateCapability
-{
-    Q_OBJECT
-    public:
-        UpdateCapabilityMediaDevice( Collections::MediaDeviceCollection *coll )
-            : Capabilities::UpdateCapability()
-            , m_coll( coll )
-        {}
-
-        virtual void collectionUpdated() const
-        {
-            m_coll->collectionUpdated();
-            m_coll->writeDatabase();
-        }
-
-    private:
-        Collections::MediaDeviceCollection *m_coll;
-};
-
 
 MediaDeviceTrack::MediaDeviceTrack( Collections::MediaDeviceCollection *collection )
     : Meta::Track()
@@ -122,7 +69,7 @@ MediaDeviceTrack::name() const
     return m_name;
 }
 
-KUrl
+QUrl
 MediaDeviceTrack::playableUrl() const
 {
     return m_playableUrl;
@@ -134,29 +81,32 @@ MediaDeviceTrack::uidUrl() const
     return m_playableUrl.isLocalFile() ? m_playableUrl.toLocalFile() : m_playableUrl.url();
 }
 
-void
-MediaDeviceTrack::setUidUrl( const QString &newUidUrl ) const
-{
-    Q_UNUSED( newUidUrl )
-}
-
 QString
 MediaDeviceTrack::prettyUrl() const
 {
-    return m_playableUrl.isLocalFile() ? m_playableUrl.toLocalFile() : QString( collection()->prettyName() + ": " + artist()->prettyName() + " - " + prettyName() );
+    if( m_playableUrl.isLocalFile() )
+        return m_playableUrl.toLocalFile();
+
+    QString collName = m_collection ? m_collection->prettyName() : i18n( "Unknown Collection" );
+    QString artistName = artist()? artist()->prettyName() : i18n( "Unknown Artist" );
+    // Check name() to prevent infinite recursion
+    QString trackName = !name().isEmpty()? prettyName() : i18n( "Unknown track" );
+
+    return  QStringLiteral( "%1: %2 - %3" ).arg( collName, artistName, trackName );
 }
 
-bool
-MediaDeviceTrack::isPlayable() const
+QString
+MediaDeviceTrack::notPlayableReason() const
 {
-    return true;
+    return localFileNotPlayableReason( playableUrl().toLocalFile() );
 }
 
 bool
 MediaDeviceTrack::isEditable() const
 {
-    // TODO: Should only be true if disk mounted read/write, implement check later
-    return true;
+    if( m_collection )
+        return m_collection->isWritable();
+    return false;
 }
 
 AlbumPtr
@@ -222,7 +172,10 @@ MediaDeviceTrack::rating() const
 void
 MediaDeviceTrack::setRating( int newRating )
 {
+    if( newRating == m_rating )
+        return;
     m_rating = newRating;
+    // this method is _not_ called though TrackEditor, notify observers manually
     notifyObservers();
 }
 
@@ -241,7 +194,6 @@ MediaDeviceTrack::setFileSize( int newFileSize )
 int
 MediaDeviceTrack::filesize() const
 {
-    // TODO: NYI, seems to cause crashing on transferring tracks to mediadevice
     return m_filesize;
 }
 
@@ -328,13 +280,36 @@ MediaDeviceTrack::setLastPlayed( const QDateTime &newTime )
     m_lastPlayed = newTime;
 }
 
+qreal
+MediaDeviceTrack::replayGain( ReplayGainTag mode ) const
+{
+    /* no known non-UMS portable media player is able to differentiante between different
+     * replay gain modes (track & album), so store only one value */
+    switch( mode ) {
+        case Meta::ReplayGain_Track_Gain:
+        case Meta::ReplayGain_Album_Gain:
+            return m_replayGain;
+        case Meta::ReplayGain_Track_Peak:
+        case Meta::ReplayGain_Album_Peak:
+            // no default label so that compiler emits a warning when new enum value is added
+            break;
+    }
+    return 0.0;
+}
+
+void
+MediaDeviceTrack::setReplayGain( qreal newReplayGain )
+{
+    m_replayGain = newReplayGain;
+}
+
 QString
 MediaDeviceTrack::type() const
 {
     if( m_type.isEmpty() && !m_playableUrl.path().isEmpty() )
     {
         QString path = m_playableUrl.path();
-        return path.mid( path.lastIndexOf( '.' ) + 1 );
+        return path.mid( path.lastIndexOf( QLatin1Char('.') ) + 1 );
     }
     return m_type;
 }
@@ -350,8 +325,8 @@ MediaDeviceTrack::prepareToPlay()
 {
     Meta::MediaDeviceTrackPtr ptr = Meta::MediaDeviceTrackPtr( this );
 
-    if( m_collection && m_collection.data()->handler() )
-        m_collection.data()->handler()->prepareToPlay( ptr );
+    if( m_collection && m_collection->handler() )
+        m_collection->handler()->prepareToPlay( ptr );
 }
 
 // TODO: employ observers (e.g. Handler) to take care of updated
@@ -373,7 +348,7 @@ MediaDeviceTrack::unsubscribe( Observer *observer )
 bool
 MediaDeviceTrack::inCollection() const
 {
-    return true;
+    return m_collection;  // true is m_collection is not null pointer, false otherwise
 }
 
 Collections::Collection*
@@ -382,54 +357,43 @@ MediaDeviceTrack::collection() const
     return m_collection.data();
 }
 
-bool
-MediaDeviceTrack::hasCapabilityInterface( Capabilities::Capability::Type type ) const
+TrackEditorPtr
+MediaDeviceTrack::editor()
 {
-    switch( type )
-    {
-        case Capabilities::Capability::Editable:
-            return m_collection ? m_collection.data()->isWritable() : false;
-
-        case Capabilities::Capability::Updatable:
-            return m_collection ? m_collection.data()->isWritable() : false;
-
-        default:
-            return false;
-    }
+    return TrackEditorPtr( isEditable() ? new MediaDeviceTrackEditor( this ) : 0 );
 }
 
-Capabilities::Capability*
-MediaDeviceTrack::createCapabilityInterface( Capabilities::Capability::Type type )
+StatisticsPtr
+MediaDeviceTrack::statistics()
 {
-    switch( type )
-    {
-        case Capabilities::Capability::Editable:
-            return new EditCapabilityMediaDevice( this );
-        case Capabilities::Capability::Updatable:
-            return new UpdateCapabilityMediaDevice( m_collection.data() );
-
-        default:
-            return 0;
-    }
+    return StatisticsPtr( this );
 }
 
 void
 MediaDeviceTrack::setAlbum( const QString &newAlbum )
 {
+    if( !m_collection )
+        return;
+
     MediaDeviceAlbumPtr albumPtr;
     MediaDeviceTrackPtr track( this );
-    AlbumMap albumMap = m_collection.data()->memoryCollection()->albumMap();
+    AlbumMap albumMap = m_collection->memoryCollection()->albumMap();
 
     // do cleanup of soon to be previous album
 
+    MediaDeviceArtistPtr albumArtist;
+    QString albumArtistName;
     albumPtr = m_album;
     if ( !albumPtr.isNull() )
     {
+        albumArtist = MediaDeviceArtistPtr::staticCast( albumPtr->albumArtist() );
+        if( albumArtist )
+            albumArtistName = albumArtist->name();
         // remove track from previous album's tracklist
         albumPtr->remTrack( track );
         // if album's tracklist is empty, remove album from albummap
         if( albumPtr->tracks().isEmpty() )
-            albumMap.remove( albumPtr->name() );
+            albumMap.remove( AlbumPtr::staticCast( albumPtr ) );
     }
 
     // change to a new album
@@ -437,14 +401,15 @@ MediaDeviceTrack::setAlbum( const QString &newAlbum )
     // check for the existence of the album to be set to,
     // if album exists, reuse, else create
 
-    if ( albumMap.contains( newAlbum ) )
+    if ( albumMap.contains( newAlbum, albumArtistName ) )
     {
-        albumPtr = MediaDeviceAlbumPtr::staticCast( albumMap.value( newAlbum ) );
+        albumPtr = MediaDeviceAlbumPtr::staticCast( albumMap.value( newAlbum, albumArtistName ) );
     }
     else
     {
         albumPtr = MediaDeviceAlbumPtr( new MediaDeviceAlbum( m_collection.data(), newAlbum ) );
-        albumMap.insert( newAlbum, AlbumPtr::staticCast( albumPtr ) );
+        albumPtr->setAlbumArtist( albumArtist );
+        albumMap.insert( AlbumPtr::staticCast( albumPtr ) );
     }
 
     // add track to album's tracklist
@@ -452,29 +417,22 @@ MediaDeviceTrack::setAlbum( const QString &newAlbum )
     // set track's album to the new album
     setAlbum( albumPtr );
 
-    m_collection.data()->memoryCollection()->acquireWriteLock();
-    m_collection.data()->memoryCollection()->setAlbumMap( albumMap );
-    m_collection.data()->memoryCollection()->releaseLock();
+    m_collection->memoryCollection()->acquireWriteLock();
+    m_collection->memoryCollection()->setAlbumMap( albumMap );
+    m_collection->memoryCollection()->releaseLock();
 }
 
 void
 MediaDeviceTrack::setAlbumArtist( const QString &newAlbumArtist )
 {
-    DEBUG_BLOCK
+    if( !m_collection )
+        return;
 
     if( m_album.isNull() || newAlbumArtist.isEmpty() )
         return;
 
     MediaDeviceArtistPtr artistPtr;
-    ArtistMap artistMap = m_collection.data()->memoryCollection()->artistMap();
-    artistPtr = MediaDeviceArtistPtr::staticCast( m_album->albumArtist() );
-
-    if( !artistPtr.isNull() )
-    {
-        artistPtr->remAlbum( m_album );
-        if( artistPtr->tracks().isEmpty() && artistPtr->albums().isEmpty() )
-            artistMap.remove( artistPtr->name() );
-    }
+    ArtistMap artistMap = m_collection->memoryCollection()->artistMap();
 
     if( artistMap.contains( newAlbumArtist ) )
         artistPtr = MediaDeviceArtistPtr::staticCast( artistMap.value( newAlbumArtist ) );
@@ -484,22 +442,22 @@ MediaDeviceTrack::setAlbumArtist( const QString &newAlbumArtist )
         artistMap.insert( newAlbumArtist, ArtistPtr::staticCast( artistPtr ) );
     }
 
-    artistPtr->addAlbum( m_album );
     m_album->setAlbumArtist( artistPtr );
 
-    m_collection.data()->memoryCollection()->acquireWriteLock();
-    m_collection.data()->memoryCollection()->setArtistMap( artistMap );
-    m_collection.data()->memoryCollection()->releaseLock();
+    m_collection->memoryCollection()->acquireWriteLock();
+    m_collection->memoryCollection()->setArtistMap( artistMap );
+    m_collection->memoryCollection()->releaseLock();
 }
 
 void
 MediaDeviceTrack::setArtist( const QString &newArtist )
 {
-    DEBUG_BLOCK
+    if( !m_collection )
+        return;
 
     MediaDeviceArtistPtr artistPtr;
     MediaDeviceTrackPtr track( this );
-    ArtistMap artistMap = m_collection.data()->memoryCollection()->artistMap();
+    ArtistMap artistMap = m_collection->memoryCollection()->artistMap();
 
     // do cleanup of soon to be previous artist
 
@@ -509,7 +467,7 @@ MediaDeviceTrack::setArtist( const QString &newArtist )
     {
         artistPtr->remTrack( track );
         // if artist's tracklist is empty, remove artist from artistmap
-        if( artistPtr->tracks().isEmpty() && artistPtr->albums().isEmpty() )
+        if( artistPtr->tracks().isEmpty() )
             artistMap.remove( artistPtr->name() );
     }
 
@@ -533,19 +491,20 @@ MediaDeviceTrack::setArtist( const QString &newArtist )
     // set track's artist to the new artist
     setArtist( artistPtr );
 
-    m_collection.data()->memoryCollection()->acquireWriteLock();
-    m_collection.data()->memoryCollection()->setArtistMap( artistMap );
-    m_collection.data()->memoryCollection()->releaseLock();
+    m_collection->memoryCollection()->acquireWriteLock();
+    m_collection->memoryCollection()->setArtistMap( artistMap );
+    m_collection->memoryCollection()->releaseLock();
 }
 
 void
 MediaDeviceTrack::setGenre( const QString &newGenre )
 {
-    DEBUG_BLOCK
+    if( !m_collection )
+        return;
 
     MediaDeviceGenrePtr genrePtr;
     MediaDeviceTrackPtr track( this );
-    GenreMap genreMap = m_collection.data()->memoryCollection()->genreMap();
+    GenreMap genreMap = m_collection->memoryCollection()->genreMap();
 
     // do cleanup of soon to be previous genre
 
@@ -579,19 +538,20 @@ MediaDeviceTrack::setGenre( const QString &newGenre )
     // set track's genre to the new genre
     setGenre( genrePtr );
 
-    m_collection.data()->memoryCollection()->acquireWriteLock();
-    m_collection.data()->memoryCollection()->setGenreMap( genreMap );
-    m_collection.data()->memoryCollection()->releaseLock();
+    m_collection->memoryCollection()->acquireWriteLock();
+    m_collection->memoryCollection()->setGenreMap( genreMap );
+    m_collection->memoryCollection()->releaseLock();
 }
 
 void
 MediaDeviceTrack::setComposer( const QString &newComposer )
 {
-    DEBUG_BLOCK
+    if( !m_collection )
+        return;
 
     MediaDeviceComposerPtr composerPtr;
     MediaDeviceTrackPtr track( this );
-    ComposerMap composerMap = m_collection.data()->memoryCollection()->composerMap();
+    ComposerMap composerMap = m_collection->memoryCollection()->composerMap();
 
     // do cleanup of soon to be previous composer
 
@@ -625,19 +585,20 @@ MediaDeviceTrack::setComposer( const QString &newComposer )
     // set track's composer to the new composer
     setComposer( composerPtr );
 
-    m_collection.data()->memoryCollection()->acquireWriteLock();
-    m_collection.data()->memoryCollection()->setComposerMap( composerMap );
-    m_collection.data()->memoryCollection()->releaseLock();
+    m_collection->memoryCollection()->acquireWriteLock();
+    m_collection->memoryCollection()->setComposerMap( composerMap );
+    m_collection->memoryCollection()->releaseLock();
 }
 
 void
 MediaDeviceTrack::setYear( int newYear )
 {
-    DEBUG_BLOCK
+    if( !m_collection )
+        return;
 
     MediaDeviceYearPtr yearPtr;
     MediaDeviceTrackPtr track( this );
-    YearMap yearMap = m_collection.data()->memoryCollection()->yearMap();
+    YearMap yearMap = m_collection->memoryCollection()->yearMap();
 
     // do cleanup of soon to be previous year
 
@@ -671,9 +632,9 @@ MediaDeviceTrack::setYear( int newYear )
     // set track's year to the new year
     setYear( yearPtr );
 
-    m_collection.data()->memoryCollection()->acquireWriteLock();
-    m_collection.data()->memoryCollection()->setYearMap( yearMap );
-    m_collection.data()->memoryCollection()->releaseLock();
+    m_collection->memoryCollection()->acquireWriteLock();
+    m_collection->memoryCollection()->setYearMap( yearMap );
+    m_collection->memoryCollection()->releaseLock();
 }
 
 void
@@ -725,11 +686,8 @@ MediaDeviceTrack::setLength( qint64 length )
 }
 
 void
-MediaDeviceTrack::endMetaDataUpdate()
+MediaDeviceTrack::commitChanges()
 {
-    DEBUG_BLOCK
-    // Update info in local mediadevice database struct
-    debug() << "Observer number: " << m_observers.count();
     notifyObservers();
 }
 
@@ -760,12 +718,6 @@ MediaDeviceArtist::tracks()
     return m_tracks;
 }
 
-AlbumList
-MediaDeviceArtist::albums()
-{
-    return m_albums;
-}
-
 void
 MediaDeviceArtist::addTrack( MediaDeviceTrackPtr track )
 {
@@ -778,28 +730,16 @@ MediaDeviceArtist::remTrack( MediaDeviceTrackPtr track )
     m_tracks.removeOne( TrackPtr::staticCast( track ) );
 }
 
-void
-MediaDeviceArtist::addAlbum( MediaDeviceAlbumPtr album )
-{
-    m_albums.append( AlbumPtr::staticCast( album ) );
-}
-
-void
-MediaDeviceArtist::remAlbum( MediaDeviceAlbumPtr album )
-{
-    m_albums.removeOne( AlbumPtr::staticCast( album ) );
-}
-
 //---------------MediaDeviceAlbum-----------------------------------
 
 MediaDeviceAlbum::MediaDeviceAlbum( Collections::MediaDeviceCollection *collection, const QString &name )
     : Meta::Album()
     , m_collection( collection )
-    , m_artworkCapability( 0 )
+    , m_artworkCapability()
     , m_name( name )
     , m_tracks()
     , m_isCompilation( false )
-    , m_hasImage( true ) // assume it has a cover until proven otherwise
+    , m_hasImagePossibility( true ) // assume it has a cover until proven otherwise
     , m_hasImageChecked( false )
     , m_image( QImage() )
     , m_albumArtist( 0 )
@@ -811,7 +751,9 @@ MediaDeviceAlbum::MediaDeviceAlbum( Collections::MediaDeviceCollection *collecti
 
 MediaDeviceAlbum::~MediaDeviceAlbum()
 {
-    //nothing to do
+    if( m_artworkCapability )
+        m_artworkCapability->deleteLater();
+    CoverCache::invalidateAlbum( this );
 }
 
 QString
@@ -856,38 +798,30 @@ MediaDeviceAlbum::hasImage( int size ) const
     Q_UNUSED( size )
 
     if( !m_hasImageChecked )
-        m_hasImage = ! const_cast<MediaDeviceAlbum*>( this )->image().isNull();
-    return m_hasImage;
+        m_hasImagePossibility = ! const_cast<MediaDeviceAlbum*>( this )->image().isNull();
+    return m_hasImagePossibility;
 }
 
-QPixmap
-MediaDeviceAlbum::image( int size )
+QImage
+MediaDeviceAlbum::image( int size ) const
 {
-    if( m_name.isEmpty() || !m_hasImage )
+    if( m_name.isEmpty() || !m_hasImagePossibility || m_tracks.isEmpty() )
         return Meta::Album::image( size );
 
+    if( m_image.isNull() && m_artworkCapability )
+    {
+        MediaDeviceTrackPtr track = MediaDeviceTrackPtr::staticCast( m_tracks.first() );
+        m_image = m_artworkCapability->getCover( track );
+        m_hasImagePossibility = !m_image.isNull();
+        m_hasImageChecked = true;
+        CoverCache::invalidateAlbum( this );
+    }
+
     if( !m_image.isNull() )
     {
         if( !size )
-            return QPixmap::fromImage(m_image);
-        return QPixmap::fromImage(m_image).scaled( QSize( size, size ), Qt::KeepAspectRatio );
-    }
-    if( m_artworkCapability )
-    {
-        MediaDeviceTrackPtr track = MediaDeviceTrackPtr::dynamicCast( m_tracks.first() );
-        QImage cover = m_artworkCapability->getCover( track );
-
-        if( !cover.isNull() )
-        {
-            m_hasImage = true;
-            m_image = cover;
-            if( !size )
-                return QPixmap::fromImage(cover);
-            return QPixmap::fromImage(cover.scaled( QSize( size, size ), Qt::KeepAspectRatio ));
-        }
-        else
-            m_hasImage = false;
-        m_hasImageChecked = true;
+            return m_image;
+        return m_image.scaled( QSize( size, size ), Qt::KeepAspectRatio );
     }
     return Meta::Album::image( size );
 }
@@ -900,15 +834,17 @@ MediaDeviceAlbum::canUpdateImage() const
     return false;
 }
 
-// TODO: forward setImage calls to handler
 void
 MediaDeviceAlbum::setImage( const QImage &image )
 {
     if( m_artworkCapability && m_artworkCapability->canUpdateCover() )
     {
-        m_image = image;
-        m_hasImage = true;
+        // reset to initial values, let next call to image() re-fetch it
+        m_hasImagePossibility = true;
+        m_hasImageChecked = false;
+
         m_artworkCapability->setCover( MediaDeviceAlbumPtr( this ), image );
+        CoverCache::invalidateAlbum( this );
     }
 }
 
@@ -917,16 +853,13 @@ MediaDeviceAlbum::setImagePath( const QString &path )
 {
     if( m_artworkCapability && m_artworkCapability->canUpdateCover() )
     {
-        m_hasImage = true;
-        m_artworkCapability->setCoverPath( MediaDeviceAlbumPtr( this ), path );
-    }
-}
+        // reset to initial values, let next call to image() re-fetch it
+        m_hasImagePossibility = true;
+        m_hasImageChecked = false;
 
-// TODO: forward call to handler to remove image, etc.
-void
-MediaDeviceAlbum::removeImage()
-{
-    Meta::Album::removeImage();
+        m_artworkCapability->setCoverPath( MediaDeviceAlbumPtr( this ), path );
+        CoverCache::invalidateAlbum( this );
+    }
 }
 
 bool
@@ -947,29 +880,7 @@ MediaDeviceAlbum::createCapabilityInterface( Capabilities::Capability::Type type
     switch( type )
     {
         case Capabilities::Capability::Actions:
-        {
-            QList<QAction*> actions;
-            if( canUpdateImage() )
-            {
-                QAction *separator          = new QAction( m_collection );
-                QAction *displayCoverAction = new DisplayCoverAction( m_collection, AlbumPtr::dynamicCast( MediaDeviceAlbumPtr(this) ) );
-                QAction *unsetCoverAction   = new UnsetCoverAction( m_collection, AlbumPtr::dynamicCast( MediaDeviceAlbumPtr(this) ) );
-
-                separator->setSeparator( true );
-
-                actions.append( separator );
-                actions.append( displayCoverAction );
-                actions.append( new FetchCoverAction( m_collection, AlbumPtr::staticCast( MediaDeviceAlbumPtr(this) ) ) );
-                actions.append( new SetCustomCoverAction( m_collection, AlbumPtr::staticCast( MediaDeviceAlbumPtr(this) ) ) );
-                if( !hasImage() )
-                {
-                    displayCoverAction->setEnabled( false );
-                    unsetCoverAction->setEnabled( false );
-                }
-                actions.append( unsetCoverAction );
-            }
-            return new Capabilities::ActionsCapability( actions );
-        }
+            return new Capabilities::AlbumActionsCapability( Meta::AlbumPtr( this ) );
 
         default:
             return 0;
@@ -1111,5 +1022,3 @@ MediaDeviceYear::remTrack( MediaDeviceTrackPtr track )
 {
     m_tracks.removeOne( TrackPtr::staticCast( track ) );
 }
-
-#include "mediadevicemeta.moc"
