@@ -23,7 +23,6 @@
 #include "core/collections/MetaQueryMaker.h"
 #include "core/support/Amarok.h"
 #include "core/support/Debug.h"
-#include "core/support/SmartPointerList.h"
 #include "core-impl/meta/file/FileTrackProvider.h"
 #include "core-impl/meta/stream/Stream.h"
 #include "core-impl/meta/timecode/TimecodeTrackProvider.h"
@@ -37,6 +36,7 @@
 #include <QTimer>
 #include <QReadWriteLock>
 
+
 typedef QPair<Collections::Collection*, CollectionManager::CollectionStatus> CollectionPair;
 
 
@@ -44,7 +44,7 @@ typedef QPair<Collections::Collection*, CollectionManager::CollectionStatus> Col
 struct CollectionManager::Private
 {
     QList<CollectionPair> collections;
-    QList<Plugins::PluginFactory*> factories; // factories belong to PluginManager
+    QList<QSharedPointer<Plugins::PluginFactory> > factories; // factories belong to PluginManager
 
     QList<Collections::TrackProvider*> trackProviders;
     TimecodeTrackProvider *timecodeTrackProvider;
@@ -55,7 +55,7 @@ struct CollectionManager::Private
     QReadWriteLock lock; ///< protects all other variables against threading issues
 };
 
-CollectionManager *CollectionManager::s_instance = 0;
+CollectionManager *CollectionManager::s_instance = nullptr;
 
 CollectionManager *
 CollectionManager::instance()
@@ -73,7 +73,7 @@ CollectionManager::destroy()
 {
     if( s_instance ) {
         delete s_instance;
-        s_instance = 0;
+        s_instance = nullptr;
     }
 }
 
@@ -85,7 +85,7 @@ CollectionManager::CollectionManager()
     // ensure this object is created in a main thread
     Q_ASSERT( thread() == QCoreApplication::instance()->thread() );
 
-    setObjectName( "CollectionManager" );
+    setObjectName( QStringLiteral("CollectionManager") );
     d->primaryCollection = 0;
     d->timecodeTrackProvider = 0;
     d->fileTrackProvider = 0;
@@ -98,14 +98,12 @@ CollectionManager::~CollectionManager()
     {
         QWriteLocker locker( &d->lock );
 
-        d->collections.clear();
+        while (!d->collections.isEmpty() )
+            delete d->collections.takeFirst().first;
+
         d->trackProviders.clear();
         delete d->timecodeTrackProvider;
         delete d->fileTrackProvider;
-
-        // Hmm, qDeleteAll from Qt 4.8 crashes with our SmartPointerList, do it manually. Bug 285951
-        while (!d->factories.isEmpty() )
-            delete d->factories.takeFirst();
     }
 
     delete d;
@@ -125,13 +123,13 @@ CollectionManager::init()
 }
 
 void
-CollectionManager::setFactories( const QList<Plugins::PluginFactory*> &factories )
+CollectionManager::setFactories( const QList<QSharedPointer<Plugins::PluginFactory> > &factories )
 {
     using Collections::CollectionFactory;
 
 
-    QSet<Plugins::PluginFactory*> newFactories = factories.toSet();
-    QSet<Plugins::PluginFactory*> oldFactories;
+    QSet<QSharedPointer<Plugins::PluginFactory> > newFactories = factories.toSet();
+    QSet<QSharedPointer<Plugins::PluginFactory> > oldFactories;
 
     {
         QReadLocker locker( &d->lock );
@@ -139,15 +137,15 @@ CollectionManager::setFactories( const QList<Plugins::PluginFactory*> &factories
     }
 
     // remove old factories
-    foreach( Plugins::PluginFactory* pFactory, oldFactories - newFactories )
+    for( const auto &pFactory : oldFactories - newFactories )
     {
 
-        CollectionFactory *factory = qobject_cast<CollectionFactory*>( pFactory );
+        auto factory = qobject_cast<CollectionFactory*>( pFactory );
         if( !factory )
             continue;
 
-        disconnect( factory, SIGNAL(newCollection(Collections::Collection*)),
-                    this, SLOT(slotNewCollection(Collections::Collection*)) );
+        disconnect( factory.data(), &CollectionFactory::newCollection,
+                    this, &CollectionManager::slotNewCollection );
         {
             QWriteLocker locker( &d->lock );
             d->factories.removeAll( factory );
@@ -155,21 +153,19 @@ CollectionManager::setFactories( const QList<Plugins::PluginFactory*> &factories
     }
 
     // create new factories
-    foreach( Plugins::PluginFactory* pFactory, newFactories - oldFactories )
+    for( const auto &pFactory : newFactories - oldFactories )
     {
-        CollectionFactory *factory = qobject_cast<CollectionFactory*>( pFactory );
+        auto factory = qobject_cast<CollectionFactory*>( pFactory );
         if( !factory )
             continue;
 
-        connect( factory, SIGNAL(newCollection(Collections::Collection*)),
-                 this, SLOT(slotNewCollection(Collections::Collection*)) );
+        connect( factory.data(), &CollectionFactory::newCollection,
+                 this, &CollectionManager::slotNewCollection );
         {
             QWriteLocker locker( &d->lock );
             d->factories.append( factory );
         }
     }
-
-    d->factories = factories;
 }
 
 
@@ -180,7 +176,7 @@ CollectionManager::startFullScan()
 
     foreach( const CollectionPair &pair, d->collections )
     {
-        QScopedPointer<Capabilities::CollectionScanCapability> csc( pair.first->create<Capabilities::CollectionScanCapability>());
+        QScopedPointer<Capabilities::CollectionScanCapability> csc( pair.first->create<Capabilities::CollectionScanCapability>() );
         if( csc )
             csc->startFullScan();
     }
@@ -193,7 +189,7 @@ CollectionManager::startIncrementalScan( const QString &directory )
 
     foreach( const CollectionPair &pair, d->collections )
     {
-        QScopedPointer<Capabilities::CollectionScanCapability> csc( pair.first->create<Capabilities::CollectionScanCapability>());
+        QScopedPointer<Capabilities::CollectionScanCapability> csc( pair.first->create<Capabilities::CollectionScanCapability>() );
         if( csc )
             csc->startIncrementalScan( directory );
     }
@@ -206,7 +202,7 @@ CollectionManager::stopScan()
 
     foreach( const CollectionPair &pair, d->collections )
     {
-        QScopedPointer<Capabilities::CollectionScanCapability> csc( pair.first->create<Capabilities::CollectionScanCapability>());
+        QScopedPointer<Capabilities::CollectionScanCapability> csc( pair.first->create<Capabilities::CollectionScanCapability>() );
         if( csc )
             csc->stopScan();
     }
@@ -258,7 +254,7 @@ CollectionManager::slotNewCollection( Collections::Collection* newCollection )
 
     const QMetaObject *mo = metaObject();
     const QMetaEnum me = mo->enumerator( mo->indexOfEnumerator( "CollectionStatus" ) );
-    const QString &value = KGlobal::config()->group( "CollectionManager" ).readEntry( newCollection->collectionId() );
+    const QString &value = Amarok::config( QStringLiteral("CollectionManager") ).readEntry( newCollection->collectionId() );
     int enumValue = me.keyToValue( value.toLocal8Bit().constData() );
     CollectionStatus status;
     enumValue == -1 ? status = CollectionEnabled : status = (CollectionStatus) enumValue;
@@ -277,16 +273,16 @@ CollectionManager::slotNewCollection( Collections::Collection* newCollection )
             d->collections.append( pair );
             d->trackProviders.append( newCollection );
         }
-        connect( newCollection, SIGNAL(remove()), SLOT(slotRemoveCollection()), Qt::QueuedConnection );
-        connect( newCollection, SIGNAL(updated()), SLOT(slotCollectionChanged()), Qt::QueuedConnection );
+        connect( newCollection, &Collections::Collection::remove, this, &CollectionManager::slotRemoveCollection, Qt::QueuedConnection );
+        connect( newCollection, &Collections::Collection::updated, this, &CollectionManager::slotCollectionChanged, Qt::QueuedConnection );
 
         debug() << "new Collection " << newCollection->collectionId();
     }
 
     if( status & CollectionViewable )
     {
-        emit collectionAdded( newCollection );
-        emit collectionAdded( newCollection, status );
+//         Q_EMIT collectionAdded( newCollection );
+        Q_EMIT collectionAdded( newCollection, status );
     }
 }
 
@@ -305,8 +301,8 @@ CollectionManager::slotRemoveCollection()
             d->trackProviders.removeAll( collection );
         }
 
-        emit collectionRemoved( collection->collectionId() );
-        QTimer::singleShot( 500, collection, SLOT(deleteLater()) ); // give the tree some time to update itself until we really delete the collection pointers.
+        Q_EMIT collectionRemoved( collection->collectionId() );
+        QTimer::singleShot( 500, collection, &QObject::deleteLater ); // give the tree some time to update itself until we really delete the collection pointers.
     }
 }
 
@@ -319,7 +315,7 @@ CollectionManager::slotCollectionChanged()
         CollectionStatus status = collectionStatus( collection->collectionId() );
         if( status & CollectionViewable )
         {
-            emit collectionDataChanged( collection );
+            Q_EMIT collectionDataChanged( collection );
         }
     }
 }
@@ -349,7 +345,7 @@ CollectionManager::primaryCollection() const
 }
 
 Meta::TrackPtr
-CollectionManager::trackForUrl( const KUrl &url )
+CollectionManager::trackForUrl( const QUrl &url )
 {
     QReadLocker locker( &d->lock );
 
@@ -371,8 +367,8 @@ CollectionManager::trackForUrl( const KUrl &url )
 
     // TODO: create specific TrackProviders for these:
     static const QSet<QString> remoteProtocols = QSet<QString>()
-            << "http" << "https" << "mms" << "smb"; // consider unifying with TrackLoader::tracksLoaded()
-    if( remoteProtocols.contains( url.protocol() ) )
+            << QStringLiteral("http") << QStringLiteral("https") << QStringLiteral("mms") << QStringLiteral("smb"); // consider unifying with TrackLoader::tracksLoaded()
+    if( remoteProtocols.contains( url.scheme() ) )
         return Meta::TrackPtr( new MetaStream::Track( url ) );
 
     return Meta::TrackPtr( 0 );
@@ -414,7 +410,7 @@ CollectionManager::addTrackProvider( Collections::TrackProvider *provider )
         QWriteLocker locker( &d->lock );
         d->trackProviders.append( provider );
     }
-    emit trackProviderAdded( provider );
+    Q_EMIT trackProviderAdded( provider );
 }
 
 void
