@@ -48,7 +48,7 @@ MemoryMatcher::setNext( MemoryMatcher *next )
     m_next = next;
 }
 
-TrackMatcher::TrackMatcher( TrackPtr track )
+TrackMatcher::TrackMatcher( const TrackPtr &track )
     : MemoryMatcher()
     , m_track( track )
 {}
@@ -81,7 +81,7 @@ TrackList TrackMatcher::match( const TrackList &tracks )
 
 
 
-ArtistMatcher::ArtistMatcher( ArtistPtr artist, Collections::QueryMaker::ArtistMatchBehaviour artistMode )
+ArtistMatcher::ArtistMatcher( const ArtistPtr &artist, Collections::QueryMaker::ArtistMatchBehaviour artistMode )
     : MemoryMatcher()
     , m_artist( artist )
     , m_queryMode( artistMode )
@@ -107,7 +107,7 @@ TrackList ArtistMatcher::match( Collections::MemoryCollection *memColl )
                     matchingTracks.append( album->tracks() );
             if( m_queryMode != Collections::QueryMaker::AlbumOrTrackArtists )
                 break;
-            /* Falls through. */
+            Q_FALLTHROUGH();
         case Collections::QueryMaker::TrackArtists:
             matchingTracks.append( artist->tracks() );
     }
@@ -135,7 +135,7 @@ TrackList ArtistMatcher::match( const TrackList &tracks )
                     matchingTracks.append( track );
                 if( m_queryMode != Collections::QueryMaker::AlbumOrTrackArtists )
                     break;
-                /* Falls through. */
+                Q_FALLTHROUGH();
             case Collections::QueryMaker::TrackArtists:
                 if( track->artist()->name() == name )
                     matchingTracks.append( track );
@@ -149,7 +149,7 @@ TrackList ArtistMatcher::match( const TrackList &tracks )
 
 
 
-AlbumMatcher::AlbumMatcher( AlbumPtr album )
+AlbumMatcher::AlbumMatcher( const AlbumPtr &album )
     : MemoryMatcher()
     , m_album( album )
 {}
@@ -181,7 +181,7 @@ TrackList AlbumMatcher::match( const TrackList &tracks )
     foreach( TrackPtr track, tracks )
         if ( track->album()->name() == name )
             matchingTracks.append( track );
-    if ( isLast() || matchingTracks.count() == 0)
+    if ( isLast() || matchingTracks.isEmpty())
         return matchingTracks;
     else
         return next()->match( matchingTracks );
@@ -189,7 +189,7 @@ TrackList AlbumMatcher::match( const TrackList &tracks )
 
 
 
-GenreMatcher::GenreMatcher( GenrePtr genre )
+GenreMatcher::GenreMatcher( const GenrePtr &genre )
     : MemoryMatcher()
     , m_genre( genre )
 {}
@@ -221,7 +221,7 @@ TrackList GenreMatcher::match( const TrackList &tracks )
     foreach( TrackPtr track, tracks )
         if ( track->genre()->name() == name )
             matchingTracks.append( track );
-    if ( isLast() || matchingTracks.count() == 0)
+    if ( isLast() || matchingTracks.isEmpty())
         return matchingTracks;
     else
         return next()->match( matchingTracks );
@@ -229,7 +229,7 @@ TrackList GenreMatcher::match( const TrackList &tracks )
 
 
 
-ComposerMatcher::ComposerMatcher( ComposerPtr composer )
+ComposerMatcher::ComposerMatcher( const ComposerPtr &composer )
     : MemoryMatcher()
     , m_composer( composer )
 {}
@@ -261,7 +261,7 @@ TrackList ComposerMatcher::match( const TrackList &tracks )
     foreach( TrackPtr track, tracks )
         if ( track->composer()->name() == name )
             matchingTracks.append( track );
-    if ( isLast() || matchingTracks.count() == 0)
+    if ( isLast() || matchingTracks.isEmpty())
         return matchingTracks;
     else
         return next()->match( matchingTracks );
@@ -269,7 +269,7 @@ TrackList ComposerMatcher::match( const TrackList &tracks )
 
 
 
-YearMatcher::YearMatcher( YearPtr year )
+YearMatcher::YearMatcher( const YearPtr &year )
     : MemoryMatcher()
     , m_year( year )
 {}
@@ -301,7 +301,7 @@ TrackList YearMatcher::match( const TrackList &tracks )
     foreach( TrackPtr track, tracks )
         if ( track->year()->year() == year )
             matchingTracks.append( track );
-    if ( isLast() || matchingTracks.count() == 0)
+    if ( isLast() || matchingTracks.isEmpty())
         return matchingTracks;
     else
         return next()->match( matchingTracks );
@@ -334,7 +334,7 @@ LabelMatcher::match( const Meta::TrackList &tracks )
             }
         }
     }
-    if( isLast() || matchingTracks.count() == 0 )
+    if( isLast() || matchingTracks.isEmpty() )
         return matchingTracks;
     else
         return next()->match( matchingTracks );
@@ -354,7 +354,7 @@ LabelMatcher::match( Collections::MemoryCollection *memColl )
         Meta::LabelPtr realLabel = memColl->labelMap().value( m_label->name() );
         matchingTracks = memColl->labelToTrackMap().value( realLabel );
     }
-    if( isLast() || matchingTracks.count() == 0 )
+    if( isLast() || matchingTracks.isEmpty() )
         return matchingTracks;
     else
         return next()->match( matchingTracks );
