@@ -17,31 +17,30 @@
 
 #include <QMutexLocker>
 
-#include <KDateTime>
 #include "upnptypes.h"
 
 #include "UpnpMeta.h"
 #include "UpnpCollectionBase.h"
 
 // TODO : move this to CollectionBase
-static qint64 duration( QString duration ) {
+static qint64 duration( const QString &duration ) {
     if( duration.isEmpty() )
         return 0;
 
-    QStringList parts = duration.split( ':' );
+    QStringList parts = duration.split( QLatin1Char(':') );
     int hours = parts.takeFirst().toInt();
     int minutes = parts.takeFirst().toInt();
     QString rest = parts.takeFirst();
     int seconds = 0;
     int mseconds = 0;
-    if( rest.contains( '.' ) ) {
+    if( rest.contains( QLatin1Char('.') ) ) {
         int dotIndex = rest.indexOf( "." );
-        seconds = rest.left( dotIndex ).toInt();
+        seconds = rest.leftRef( dotIndex ).toInt();
         QString frac = rest.mid( dotIndex + 1 );
-        if( frac.contains( '/' ) ) {
-            int slashIndex = frac.indexOf( '/' );
-            int num = frac.left( frac.indexOf( '/' ) ).toInt();
-            int den = frac.mid( slashIndex + 1 ).toInt();
+        if( frac.contains( QLatin1Char('/') ) ) {
+            int slashIndex = frac.indexOf( QLatin1Char('/') );
+            int num = frac.leftRef( frac.indexOf( QLatin1Char('/') ) ).toInt();
+            int den = frac.midRef( slashIndex + 1 ).toInt();
             mseconds = num * 1000 / den;
         }
         else {
@@ -103,7 +102,7 @@ Meta::TrackPtr UpnpCache::getTrack( const KIO::UDSEntry &entry, bool refresh )
     track->setAlbum( album );
     // album art
     if( ! album->imageLocation().isValid() )
-        album->setAlbumArtUrl( entry.stringValue( KIO::UPNP_ALBUMART_URI ) );
+        album->setAlbumArtUrl( QUrl(entry.stringValue( KIO::UPNP_ALBUMART_URI )) );
 
     Meta::UpnpGenrePtr genre = Meta::UpnpGenrePtr::staticCast( getGenre( entry.stringValue( KIO::UPNP_GENRE ) ) );
     genre->addTrack( track );
@@ -163,7 +162,7 @@ Meta::YearPtr UpnpCache::getYear(int name)
     return m_yearMap[name];
 }
 
-void UpnpCache::removeTrack( Meta::TrackPtr t )
+void UpnpCache::removeTrack( const Meta::TrackPtr &t )
 {
 #define DOWNCAST( Type, item ) Meta::Upnp##Type##Ptr::staticCast( item )
     Meta::UpnpTrackPtr track = DOWNCAST( Track, t );
