@@ -33,33 +33,31 @@ class UpnpGenre;
 class UpnpComposer;
 class UpnpYear;
 
-typedef KSharedPtr<UpnpTrack> UpnpTrackPtr;
-typedef KSharedPtr<UpnpArtist> UpnpArtistPtr;
-typedef KSharedPtr<UpnpAlbum> UpnpAlbumPtr;
-typedef KSharedPtr<UpnpGenre> UpnpGenrePtr;
-typedef KSharedPtr<UpnpComposer> UpnpComposerPtr;
-typedef KSharedPtr<UpnpYear> UpnpYearPtr;
+typedef AmarokSharedPointer<UpnpTrack> UpnpTrackPtr;
+typedef AmarokSharedPointer<UpnpArtist> UpnpArtistPtr;
+typedef AmarokSharedPointer<UpnpAlbum> UpnpAlbumPtr;
+typedef AmarokSharedPointer<UpnpGenre> UpnpGenrePtr;
+typedef AmarokSharedPointer<UpnpComposer> UpnpComposerPtr;
+typedef AmarokSharedPointer<UpnpYear> UpnpYearPtr;
 
 class UpnpTrack : public Meta::Track
 {
     public:
-        UpnpTrack( Collections::UpnpCollectionBase *collection );
-        virtual ~UpnpTrack();
+        explicit UpnpTrack( Collections::UpnpCollectionBase *collection );
+        ~UpnpTrack() override;
 
-        virtual QString name() const;
+        QString name() const override;
 
-        virtual KUrl playableUrl() const;
-        virtual QString uidUrl() const;
-        virtual QString prettyUrl() const;
+        QUrl playableUrl() const override;
+        QString uidUrl() const override;
+        QString prettyUrl() const override;
+        QString notPlayableReason() const override;
 
-        virtual bool isPlayable() const;
-        virtual bool isEditable() const;
-
-        virtual AlbumPtr album() const;
-        virtual ArtistPtr artist() const;
-        virtual GenrePtr genre() const;
-        virtual ComposerPtr composer() const;
-        virtual YearPtr year() const;
+        AlbumPtr album() const override;
+        ArtistPtr artist() const override;
+        GenrePtr genre() const override;
+        ComposerPtr composer() const override;
+        YearPtr year() const override;
 
         virtual void setAlbum ( const QString &newAlbum );
         virtual void setArtist ( const QString &newArtist );
@@ -71,50 +69,34 @@ class UpnpTrack : public Meta::Track
 
         virtual void setUidUrl( const QString &url );
 
-        virtual qreal bpm() const;
+        qreal bpm() const override;
 
-        virtual QString comment() const;
+        QString comment() const override;
         virtual void setComment ( const QString &newComment );
 
-        virtual double score() const;
-        virtual void setScore ( double newScore );
+        qint64 length() const override;
 
-        virtual int rating() const;
-        virtual void setRating ( int newRating );
+        int filesize() const override;
+        int sampleRate() const override;
+        int bitrate() const override;
 
-        virtual qint64 length() const;
-
-        virtual int filesize() const;
-        virtual int sampleRate() const;
-        virtual int bitrate() const;
-
-        virtual int trackNumber() const;
+        int trackNumber() const override;
         virtual void setTrackNumber ( int newTrackNumber );
 
-        virtual int discNumber() const;
+        int discNumber() const override;
         virtual void setDiscNumber ( int newDiscNumber );
 
-        virtual QDateTime lastPlayed() const;
-        virtual int playCount() const;
+        QString type() const override;
 
-        virtual QString type() const;
-
-        virtual void beginMetaDataUpdate() {}    //read only
-        virtual void endMetaDataUpdate() {}      //read only
-        virtual void abortMetaDataUpdate() {}    //read only
-
-        virtual void subscribe ( Observer *observer );
-        virtual void unsubscribe ( Observer *observer );
-
-        virtual bool inCollection() const;
-        virtual Collections::Collection* collection() const;
+        bool inCollection() const override;
+        Collections::Collection* collection() const override;
 
         //UpnpTrack specific methods
-        void setAlbum( UpnpAlbumPtr album );
-        void setArtist( UpnpArtistPtr artist );
-        void setComposer( UpnpComposerPtr composer );
-        void setGenre( UpnpGenrePtr genre );
-        void setYear( UpnpYearPtr year );
+        void setAlbum( const UpnpAlbumPtr &album );
+        void setArtist( const UpnpArtistPtr &artist );
+        void setComposer( const UpnpComposerPtr &composer );
+        void setGenre( const UpnpGenrePtr &genre );
+        void setYear( const UpnpYearPtr &year );
         void setPlayableUrl( const QString &url );
 
         void setLength( qint64 length );
@@ -142,16 +124,16 @@ class UpnpTrack : public Meta::Track
 class UpnpArtist : public Meta::Artist
 {
     public:
-        UpnpArtist( const QString &name );
-        virtual ~UpnpArtist();
+        explicit UpnpArtist( const QString &name );
+        ~UpnpArtist() override;
 
-        virtual QString name() const;
+        QString name() const override;
 
-        virtual TrackList tracks();
+        TrackList tracks() override;
 
         //UpnpArtist specific methods
-        void addTrack( UpnpTrackPtr track );
-        void removeTrack( UpnpTrackPtr track );
+        void addTrack( const UpnpTrackPtr &track );
+        void removeTrack( const UpnpTrackPtr &track );
 
     private:
         QString m_name;
@@ -162,27 +144,27 @@ class UpnpAlbum : public QObject, public Meta::Album
 {
   Q_OBJECT
     public:
-        UpnpAlbum( const QString &name );
-        virtual ~UpnpAlbum();
+        explicit UpnpAlbum( const QString &name );
+        ~UpnpAlbum() override;
 
-        virtual QString name() const;
+        QString name() const override;
 
-        virtual bool isCompilation() const;
-        virtual bool hasAlbumArtist() const;
-        virtual ArtistPtr albumArtist() const;
-        virtual TrackList tracks();
+        bool isCompilation() const override;
+        bool hasAlbumArtist() const override;
+        ArtistPtr albumArtist() const override;
+        TrackList tracks() override;
 
-        virtual bool hasImage( int size = 0 ) const;
-        virtual QImage image( int size = 0 ) const;
-        virtual KUrl imageLocation( int size = 0 );
+        bool hasImage( int size = 0 ) const override;
+        QImage image( int size = 0 ) const override;
+        QUrl imageLocation( int size = 0 ) override;
 
-        virtual Capabilities::Capability* createCapabilityInterface( Capabilities::Capability::Type type );
+        Capabilities::Capability* createCapabilityInterface( Capabilities::Capability::Type type ) override;
 
         //UpnpAlbum specific methods
-        void addTrack( UpnpTrackPtr track );
-        void removeTrack( UpnpTrackPtr track );
-        void setAlbumArtist( UpnpArtistPtr artist );
-        void setAlbumArtUrl( const KUrl &url );
+        void addTrack( const UpnpTrackPtr &track );
+        void removeTrack( const UpnpTrackPtr &track );
+        void setAlbumArtist( const UpnpArtistPtr &artist );
+        void setAlbumArtUrl( const QUrl &url );
 
     private:
         QString m_name;
@@ -190,22 +172,22 @@ class UpnpAlbum : public QObject, public Meta::Album
         TrackList m_tracks;
         bool m_isCompilation;
         UpnpArtistPtr m_albumArtist;
-        KUrl m_albumArtUrl;
+        QUrl m_albumArtUrl;
 };
 
 class UpnpGenre : public Meta::Genre
 {
     public:
-        UpnpGenre( const QString &name );
-        virtual ~UpnpGenre();
+        explicit UpnpGenre( const QString &name );
+        ~UpnpGenre() override;
 
-        virtual QString name() const;
+        QString name() const override;
 
-        virtual TrackList tracks();
+        TrackList tracks() override;
 
         //UpnpGenre specific methods
-        void addTrack( UpnpTrackPtr track );
-        void removeTrack( UpnpTrackPtr track );
+        void addTrack( const UpnpTrackPtr &track );
+        void removeTrack( const UpnpTrackPtr &track );
 
     private:
         QString m_name;
@@ -215,16 +197,16 @@ class UpnpGenre : public Meta::Genre
 class UpnpComposer : public Meta::Composer
 {
     public:
-        UpnpComposer( const QString &name );
-        virtual ~UpnpComposer();
+        explicit UpnpComposer( const QString &name );
+        ~UpnpComposer() override;
 
-        virtual QString name() const;
+        QString name() const override;
 
-        virtual TrackList tracks();
+        TrackList tracks() override;
 
         //UpnpComposer specific methods
-        void addTrack( UpnpTrackPtr track );
-        void removeTrack( UpnpTrackPtr track );
+        void addTrack( const UpnpTrackPtr &track );
+        void removeTrack( const UpnpTrackPtr &track );
 
     private:
         QString m_name;
@@ -234,16 +216,16 @@ class UpnpComposer : public Meta::Composer
 class UpnpYear : public Meta::Year
 {
     public:
-        UpnpYear( int year );
-        virtual ~UpnpYear();
+        explicit UpnpYear( int year );
+        ~UpnpYear() override;
 
-        virtual QString name() const;
+        QString name() const override;
 
-        virtual TrackList tracks();
+        TrackList tracks() override;
 
         //UpnpYear specific methods
-        void addTrack( UpnpTrackPtr track );
-        void removeTrack( UpnpTrackPtr track );
+        void addTrack( const UpnpTrackPtr &track );
+        void removeTrack( const UpnpTrackPtr &track );
 
     private:
         QString m_name;
