@@ -35,24 +35,23 @@ using namespace MetaCue;
 * @author (C) 2005 by Martin Ehmke <ehmke@gmx.de>
 */
 
-CueFileItemMap CueFileSupport::loadCueFile( const KUrl &cuefile, const Meta::TrackPtr track )
+CueFileItemMap CueFileSupport::loadCueFile( const QUrl &cuefile, const Meta::TrackPtr &track )
 {
     return loadCueFile( cuefile, track->playableUrl(), track->length() );
 }
 
 
-CueFileItemMap CueFileSupport::loadCueFile( const KUrl &cuefile, const KUrl &trackUrl, qint64 trackLen )
+CueFileItemMap CueFileSupport::loadCueFile( const QUrl &cuefile, const QUrl &trackUrl, qint64 trackLen )
 {
-
     DEBUG_BLOCK
 
     CueFileItemMap cueItems;
 
-    debug() << "CUEFILE: " << cuefile.pathOrUrl();
-    if ( QFile::exists ( cuefile.pathOrUrl() ) )
+    debug() << "CUEFILE: " << cuefile.toDisplayString();
+    if ( QFile::exists ( cuefile.toLocalFile() ) )
     {
         debug() << "  EXISTS!";
-        QFile file ( cuefile.pathOrUrl() );
+        QFile file ( cuefile.toLocalFile() );
         int trackNr = 0;
         QString defaultArtist;
         QString defaultAlbum;
@@ -84,7 +83,7 @@ CueFileItemMap CueFileSupport::loadCueFile( const KUrl &cuefile, const KUrl &tra
             {
                 line = stream.readLine().simplified();
 
-                if ( line.startsWith ( "title", Qt::CaseInsensitive ) )
+                if ( line.startsWith ( QLatin1String("title"), Qt::CaseInsensitive ) )
                 {
                     title = line.mid ( 6 ).remove ( '"' );
                     if ( mode == BEGIN && !filesSection )
@@ -102,7 +101,7 @@ CueFileItemMap CueFileSupport::loadCueFile( const KUrl &cuefile, const KUrl &tra
                         debug() << "Title: " << title;
                 }
 
-                else if ( line.startsWith ( "performer", Qt::CaseInsensitive ) )
+                else if ( line.startsWith ( QLatin1String("performer"), Qt::CaseInsensitive ) )
                 {
                     artist = line.mid ( 10 ).remove ( '"' );
                     if ( mode == BEGIN && !filesSection  )
@@ -120,7 +119,7 @@ CueFileItemMap CueFileSupport::loadCueFile( const KUrl &cuefile, const KUrl &tra
                         debug() << "Artist: " << artist;
                 }
 
-                else if ( line.startsWith ( "track", Qt::CaseInsensitive ) && fileFound )
+                else if ( line.startsWith ( QLatin1String("track"), Qt::CaseInsensitive ) && fileFound )
                 {
                     if ( mode == TRACK_FOUND )
                     {
@@ -146,7 +145,7 @@ CueFileItemMap CueFileSupport::loadCueFile( const KUrl &cuefile, const KUrl &tra
                     debug() << "Track: " << trackNr;
                     mode = TRACK_FOUND;
                 }
-                else if ( line.startsWith ( "index", Qt::CaseInsensitive ) && fileFound  )
+                else if ( line.startsWith ( QLatin1String("index"), Qt::CaseInsensitive ) && fileFound  )
                 {
                     if ( mode == TRACK_FOUND )
                     {
@@ -154,7 +153,7 @@ CueFileItemMap CueFileSupport::loadCueFile( const KUrl &cuefile, const KUrl &tra
 
                         if ( indexNo == 1 )
                         {
-                            QStringList time = line.section ( ' ', -1, -1 ).split ( ':' );
+                            QStringList time = line.section ( ' ', -1, -1 ).split ( QLatin1Char(':') );
 
                             index = time[0].toLong() *60*1000 + time[1].toLong() *1000 + time[2].toLong() *1000/75; //75 frames per second
 
@@ -172,7 +171,7 @@ CueFileItemMap CueFileSupport::loadCueFile( const KUrl &cuefile, const KUrl &tra
 
                         else if ( indexNo == 0 ) // gap, use to calc prev track length
                         {
-                            QStringList time = line.section ( ' ', -1, -1 ).split ( ':' );
+                            QStringList time = line.section ( ' ', -1, -1 ).split ( QLatin1Char(':') );
 
                             length = time[0].toLong() * 60 * 1000 + time[1].toLong() * 1000 + time[2].toLong() *1000/75; //75 frames per second
 
@@ -200,7 +199,7 @@ CueFileItemMap CueFileSupport::loadCueFile( const KUrl &cuefile, const KUrl &tra
                     }
                     debug() << "index: " << index;
                 }
-                else if( line.startsWith ( "file", Qt::CaseInsensitive ) )
+                else if( line.startsWith ( QLatin1String("file"), Qt::CaseInsensitive ) )
                 {
                     QString file = line.mid ( 5 ).remove ( '"' );
                     if( fileFound )
@@ -223,7 +222,7 @@ CueFileItemMap CueFileSupport::loadCueFile( const KUrl &cuefile, const KUrl &tra
         /**
         *  Because there is no way to set the length for the last track in a normal way,
         *  we have to do some magic here. Having the total length of the media file given
-        *  we can set the lenth for the last track after all the cue file was loaded into array.
+        *  we can set the length for the last track after all the cue file was loaded into array.
         */
 
         cueItems[index].setLength ( trackLen - index );
@@ -234,25 +233,25 @@ CueFileItemMap CueFileSupport::loadCueFile( const KUrl &cuefile, const KUrl &tra
     return CueFileItemMap();
 }
 
-KUrl CueFileSupport::locateCueSheet ( const KUrl &trackurl )
+QUrl CueFileSupport::locateCueSheet ( const QUrl &trackurl )
 {
     if ( !trackurl.isValid() || !trackurl.isLocalFile() )
-        return KUrl();
+        return QUrl();
     // look for the cue file that matches the media file
     QString path    = trackurl.path();
-    QString cueFile = path.left ( path.lastIndexOf ( '.' ) ) + ".cue";
+    QString cueFile = path.left ( path.lastIndexOf ( QLatin1Char('.') ) ) + ".cue";
 
     if ( validateCueSheet ( cueFile ) )
     {
         debug() << "[CUEFILE]: " << cueFile << " - Shoot blindly, found and loaded. ";
-        return KUrl ( cueFile );
+        return QUrl::fromLocalFile( cueFile );
     }
     debug() << "[CUEFILE]: " << cueFile << " - Shoot blindly and missed, searching for other cue files.";
 
     bool foundCueFile = false;
-    QDir dir ( trackurl.directory() );
+    QDir dir ( trackurl.adjusted(QUrl::RemoveFilename|QUrl::StripTrailingSlash).path() );
     QStringList filters;
-    filters << "*.cue" << "*.CUE";
+    filters << QStringLiteral("*.cue") << QStringLiteral("*.CUE");
     dir.setNameFilters ( filters );
 
     QStringList cueFilesList = dir.entryList();
@@ -271,7 +270,7 @@ KUrl CueFileSupport::locateCueSheet ( const KUrl &trackurl )
                 {
                     line = stream.readLine().simplified();
 
-                    if ( line.startsWith ( "file", Qt::CaseInsensitive ) )
+                    if ( line.startsWith ( QLatin1String("file"), Qt::CaseInsensitive ) )
                     {
                         line = line.mid ( 5 ).remove ( '"' );
 
@@ -293,9 +292,9 @@ KUrl CueFileSupport::locateCueSheet ( const KUrl &trackurl )
         }
 
     if ( foundCueFile )
-        return KUrl ( cueFile );
+        return QUrl::fromLocalFile( cueFile );
     debug() << "[CUEFILE]: - Didn't find any matching cue file." << endl;
-    return KUrl();
+    return QUrl();
 }
 
 bool CueFileSupport::validateCueSheet ( const QString& cuefile )
@@ -324,7 +323,7 @@ bool CueFileSupport::validateCueSheet ( const QString& cuefile )
         {
             line = stream.readLine().simplified();
 
-            if ( line.startsWith ( "title", Qt::CaseInsensitive ) )
+            if ( line.startsWith ( QLatin1String("title"), Qt::CaseInsensitive ) )
             {
                 title = line.mid ( 6 ).remove ( '"' );
                 if ( mode == BEGIN )
@@ -337,7 +336,7 @@ bool CueFileSupport::validateCueSheet ( const QString& cuefile )
                     debug() << "Title: " << title;
             }
 
-            else if ( line.startsWith ( "performer", Qt::CaseInsensitive ) )
+            else if ( line.startsWith ( QLatin1String("performer"), Qt::CaseInsensitive ) )
             {
                 artist = line.mid ( 10 ).remove ( '"' );
                 if ( mode == BEGIN )
@@ -350,7 +349,7 @@ bool CueFileSupport::validateCueSheet ( const QString& cuefile )
                     debug() << "Artist: " << artist;
             }
 
-            else if ( line.startsWith ( "track", Qt::CaseInsensitive ) )
+            else if ( line.startsWith ( QLatin1String("track"), Qt::CaseInsensitive ) )
             {
                 if ( mode == TRACK_FOUND )
                 {
@@ -373,7 +372,7 @@ bool CueFileSupport::validateCueSheet ( const QString& cuefile )
                 debug() << "Track: " << track;
                 mode = TRACK_FOUND;
             }
-            else if ( line.startsWith ( "index", Qt::CaseInsensitive ) )
+            else if ( line.startsWith ( QLatin1String("index"), Qt::CaseInsensitive ) )
             {
                 if ( mode == TRACK_FOUND )
                 {
@@ -381,7 +380,7 @@ bool CueFileSupport::validateCueSheet ( const QString& cuefile )
 
                     if ( indexNo == 1 )
                     {
-                        QStringList time = line.section ( ' ', -1, -1 ).split ( ':' );
+                        QStringList time = line.section ( ' ', -1, -1 ).split ( QLatin1Char(':') );
 
                         index = time[0].toLong() *60*1000 + time[1].toLong() *1000 + time[2].toLong() *1000/75; //75 frames per second
 
@@ -397,7 +396,7 @@ bool CueFileSupport::validateCueSheet ( const QString& cuefile )
 
                     else if ( indexNo == 0 ) // gap, use to calc prev track length
                     {
-                        QStringList time = line.section ( ' ', -1, -1 ).split ( ':' );
+                        QStringList time = line.section ( ' ', -1, -1 ).split ( QLatin1Char(':') );
 
                         length = time[0].toLong() *60*1000 + time[1].toLong() *1000 + time[2].toLong() *1000/75; //75 frames per second
 
@@ -449,7 +448,7 @@ CueFileSupport::generateTimeCodeTracks( Meta::TrackPtr baseTrack, CueFileItemMap
     foreach( const CueFileItem &item, itemMap )
     {
         Meta::TimecodeTrack *track = new Meta::TimecodeTrack( item.title(),
-                baseTrack->playableUrl().url(), item.index(), item.index() + item.length() );
+                baseTrack->playableUrl(), item.index(), item.index() + item.length() );
         track->beginUpdate();
         track->setArtist( item.artist() );
         track->setAlbum( item.album() );
