@@ -26,6 +26,7 @@
 #include "MainWindow.h"
 #include "amarokurls/BookmarkMetaActions.h"
 #include "amarokurls/PlayUrlRunner.h"
+#include "browsers/BrowserDock.h"
 #include "browsers/filebrowser/FileBrowser.h"
 #include "core/capabilities/BookmarkThisCapability.h"
 #include "core/capabilities/FindInSourceCapability.h"
@@ -37,13 +38,13 @@
 #include "core-impl/capabilities/timecode/TimecodeLoadCapability.h"
 #include "core-impl/support/UrlStatisticsStore.h"
 
-#include <KMimeType>
-
 #include <QAction>
 #include <QFileInfo>
 #include <QList>
 #include <QWeakPointer>
 #include <QString>
+#include <QMimeDatabase>
+#include <QMimeType>
 
 using namespace MetaFile;
 
@@ -55,20 +56,20 @@ class TimecodeWriteCapabilityImpl : public Capabilities::TimecodeWriteCapability
             , m_track( track )
         {}
 
-    virtual bool writeTimecode ( qint64 miliseconds )
+    bool writeTimecode ( qint64 miliseconds ) override
     {
         DEBUG_BLOCK
         return Capabilities::TimecodeWriteCapability::writeTimecode( miliseconds, Meta::TrackPtr( m_track.data() ) );
     }
 
-    virtual bool writeAutoTimecode ( qint64 miliseconds )
+    bool writeAutoTimecode ( qint64 miliseconds ) override
     {
         DEBUG_BLOCK
         return Capabilities::TimecodeWriteCapability::writeAutoTimecode( miliseconds, Meta::TrackPtr( m_track.data() ) );
     }
 
     private:
-        KSharedPtr<MetaFile::Track> m_track;
+        AmarokSharedPointer<MetaFile::Track> m_track;
 };
 
 class TimecodeLoadCapabilityImpl : public Capabilities::TimecodeLoadCapability
@@ -79,21 +80,21 @@ class TimecodeLoadCapabilityImpl : public Capabilities::TimecodeLoadCapability
         , m_track( track )
         {}
 
-        virtual bool hasTimecodes()
+        bool hasTimecodes() override
         {
             if ( loadTimecodes().size() > 0 )
                 return true;
             return false;
         }
 
-        virtual BookmarkList loadTimecodes()
+        BookmarkList loadTimecodes() override
         {
             BookmarkList list = PlayUrlRunner::bookmarksFromUrl( m_track->playableUrl() );
             return list;
         }
 
     private:
-        KSharedPtr<MetaFile::Track> m_track;
+        AmarokSharedPointer<MetaFile::Track> m_track;
 };
 
 
@@ -105,13 +106,13 @@ public:
         , m_track( track )
         {}
 
-    virtual void findInSource( QFlags<TargetTag> tag )
+    void findInSource( QFlags<TargetTag> tag ) override
     {
         Q_UNUSED( tag )
         //first show the filebrowser
         AmarokUrl url;
-        url.setCommand( "navigate" );
-        url.setPath( "files" );
+        url.setCommand( QStringLiteral("navigate") );
+        url.setPath( QStringLiteral("files") );
         url.run();
 
         //then navigate to the correct directory
@@ -122,18 +123,18 @@ public:
             if( fileBrowser )
             {
                 //get the path of the parent directory of the file
-                KUrl playableUrl = m_track->playableUrl();
-                fileBrowser->setDir( playableUrl.directory() );       
+                QUrl playableUrl = m_track->playableUrl();
+                fileBrowser->setDir( playableUrl.adjusted(QUrl::RemoveFilename|QUrl::StripTrailingSlash) );       
             }
         }
     }
 
 private:
-    KSharedPtr<MetaFile::Track> m_track;
+    AmarokSharedPointer<MetaFile::Track> m_track;
 };
 
 
-Track::Track( const KUrl &url )
+Track::Track( const QUrl &url )
     : Meta::Track()
     , d( new Track::Private( this ) )
 {
@@ -160,10 +161,10 @@ Track::name() const
         const QString trackName = d->m_data.title;
         return trackName;
     }
-    return "This is a bug!";
+    return QStringLiteral("This is a bug!");
 }
 
-KUrl
+QUrl
 Track::playableUrl() const
 {
     return d->url;
@@ -197,7 +198,7 @@ Track::notPlayableReason() const
 bool
 Track::isEditable() const
 {
-    QFileInfo info = QFileInfo( playableUrl().pathOrUrl() );
+    QFileInfo info = QFileInfo( playableUrl().toLocalFile() );
     return info.isFile() && info.isWritable();
 }
 
@@ -373,7 +374,7 @@ QDateTime
 Track::createDate() const
 {
     if( d->m_data.created > 0 )
-        return QDateTime::fromTime_t(d->m_data.created);
+        return QDateTime::fromSecsSinceEpoch(d->m_data.created);
     else
         return QDateTime();
 }
@@ -402,7 +403,7 @@ Track::type() const
 }
 
 bool
-Track::isTrack( const KUrl &url )
+Track::isTrack( const QUrl &url )
 {
     // some playlists lay under audio/ mime category, filter them
     if( Playlists::isPlaylist( url ) )
@@ -419,10 +420,10 @@ Track::isTrack( const KUrl &url )
     // We can't play directories
     if( fileInfo.isDir() )
         return false;
-
-    const KMimeType::Ptr mimeType = KMimeType::findByPath( url.toLocalFile() );
-    const QString name = mimeType->name();
-    return name.startsWith( "audio/" ) || name.startsWith( "video/" );
+    QMimeDatabase db;
+    const QMimeType mimeType = db.mimeTypeForFile( url.toLocalFile() );
+    const QString name = mimeType.name();
+    return name.startsWith( QLatin1String("audio/") ) || name.startsWith( QLatin1String("video/") );
 }
 
 void
@@ -586,10 +587,8 @@ Track::commitIfInNonBatchUpdate()
         return;
     }
 
-    d->writeMetaData(); // clears d->chages
+    d->writeMetaData(); // clears d->changes
     d->lock.unlock(); // rather call notifyObservers() without a lock
     notifyObservers();
     d->lock.lockForWrite(); // return to original state
 }
-
-#include "File_p.moc"
