@@ -24,15 +24,16 @@
 #include "core/capabilities/Capability.h"
 #include "core/capabilities/BoundedPlaybackCapability.h"
 #include "core-impl/capabilities/AlbumActionsCapability.h"
-#include "core-impl/capabilities/timecode/TimecodeEditCapability.h"
 #include "core-impl/capabilities/timecode/TimecodeBoundedPlaybackCapability.h"
 
+#include <KLocalizedString>
+
 using namespace Meta;
 using namespace Capabilities;
 
 ////////////////// TRACK //////////////////
 
-TimecodeTrack::TimecodeTrack( const QString & name, const QString & url, qint64 start, qint64 end )
+TimecodeTrack::TimecodeTrack( const QString &name, const QUrl &url, qint64 start, qint64 end )
     : m_name( name )
     , m_start( start )
     , m_end( end )
@@ -44,11 +45,7 @@ TimecodeTrack::TimecodeTrack( const QString & name, const QString & url, qint64
     , m_playableUrl( url )
     , m_updatedFields( 0 )
 {
-    DEBUG_BLOCK
-    m_displayUrl = url + ':' + QString::number( start ) + '-' + QString::number( end );
-
-    debug() << "created with length: " << m_length;
-
+    m_displayUrl = url.toDisplayString() + QLatin1Char(':') + QString::number( start ) + '-' + QString::number( end );
 }
 
 TimecodeTrack::~ TimecodeTrack()
@@ -61,7 +58,7 @@ TimecodeTrack::name() const
     return m_name;
 }
 
-KUrl
+QUrl
 TimecodeTrack::playableUrl() const
 {
     return m_playableUrl;
@@ -79,24 +76,21 @@ TimecodeTrack::prettyUrl() const
     return m_displayUrl;
 }
 
+QString
+TimecodeTrack::notPlayableReason() const
+{
+    if( !m_playableUrl.isLocalFile() )
+        return i18n( "Url is not a local file" );
+
+    return localFileNotPlayableReason( m_playableUrl.toLocalFile() );
+}
+
 AlbumPtr
 TimecodeTrack::album() const
 {
     return AlbumPtr::staticCast( m_album );
 }
 
-bool
-TimecodeTrack::isEditable() const
-{
-    return true;
-}
-
-bool
-TimecodeTrack::isPlayable() const
-{
-     return true;
-}
-
 ArtistPtr
 TimecodeTrack::artist() const
 {
@@ -133,24 +127,6 @@ TimecodeTrack::comment() const
     return m_comment;
 }
 
-double
-TimecodeTrack::score() const
-{
-    return 0.0;
-}
-
-void
-TimecodeTrack::setScore( double newScore )
-{
-    Q_UNUSED( newScore )
-}
-
-int
-TimecodeTrack::rating() const
-{
-    return -1;
-}
-
 int
 TimecodeTrack::bitrate() const
 {
@@ -175,12 +151,6 @@ TimecodeTrack::length() const
     return m_length;
 }
 
-void
-TimecodeTrack::setRating( int newRating )
-{
-    Q_UNUSED( newRating )
-}
-
 int
 TimecodeTrack::trackNumber() const
 {
@@ -193,12 +163,6 @@ TimecodeTrack::discNumber() const
     return m_discNumber;
 }
 
-int
-TimecodeTrack::playCount() const
-{
-    return 0;
-}
-
 QString
 TimecodeTrack::type() const
 {
@@ -275,13 +239,13 @@ TimecodeTrack::setDiscNumber( int newDiscNumber )
     m_fields.insert( DISCNUMBER_UPDATED, QString::number( newDiscNumber ) );
 }
 
-void TimecodeTrack::beginMetaDataUpdate()
+void TimecodeTrack::beginUpdate()
 {
     m_updatedFields = 0;
     m_fields.clear();
 }
 
-void TimecodeTrack::endMetaDataUpdate()
+void TimecodeTrack::endUpdate()
 {
 
     bool updateCover = false;
@@ -369,31 +333,37 @@ void TimecodeTrack::endMetaDataUpdate()
 }
 
 void
-TimecodeTrack::setAlbum( TimecodeAlbumPtr album )
+TimecodeTrack::setAlbum( const TimecodeAlbumPtr &album )
 {
     m_album = album;
 }
 
 void
-TimecodeTrack::setYear( TimecodeYearPtr year )
+TimecodeTrack::setAlbumArtist( const QString & )
+{
+    // no support for it
+}
+
+void
+TimecodeTrack::setYear( const TimecodeYearPtr &year )
 {
     m_year = year;
 }
 
 void
-TimecodeTrack::setGenre( TimecodeGenrePtr genre )
+TimecodeTrack::setGenre( const TimecodeGenrePtr &genre )
 {
     m_genre = genre;
 }
 
 void
-TimecodeTrack::setComposer( TimecodeComposerPtr composer )
+TimecodeTrack::setComposer( const TimecodeComposerPtr &composer )
 {
     m_composer = composer;
 }
 
 void
-TimecodeTrack::setArtist( TimecodeArtistPtr artist )
+TimecodeTrack::setArtist( const TimecodeArtistPtr &artist )
 {
     m_artist = artist;
 }
@@ -402,8 +372,7 @@ TimecodeTrack::setArtist( TimecodeArtistPtr artist )
 bool
 TimecodeTrack::hasCapabilityInterface( Capabilities::Capability::Type type ) const
 {
-    return type == Capabilities::Capability::BoundedPlayback
-           || type == Capabilities::Capability::Editable;
+    return type == Capabilities::Capability::BoundedPlayback;
 }
 
 Capabilities::Capability *
@@ -413,12 +382,16 @@ TimecodeTrack::createCapabilityInterface( Capabilities::Capability::Type type )
 
     if ( type == Capabilities::Capability::BoundedPlayback )
         return new Capabilities::TimecodeBoundedPlaybackCapability( this );
-    else if( type == Capabilities::Capability::Editable )
-        return new Capabilities::TimecodeEditCapability( this );
     else
         return 0;
 }
 
+TrackEditorPtr
+TimecodeTrack::editor()
+{
+    return TrackEditorPtr( this );
+}
+
 qint64 Meta::TimecodeTrack::start()
 {
     return m_start;
@@ -460,7 +433,7 @@ TimecodeArtist::albums()
 }
 
 void
-TimecodeArtist::addTrack( TimecodeTrackPtr track )
+TimecodeArtist::addTrack( const TimecodeTrackPtr &track )
 {
     m_tracks.append( TrackPtr::staticCast( track ) );
 }
@@ -471,11 +444,6 @@ TimecodeAlbum::TimecodeAlbum( const QString & name )
     : QObject()
     , m_name( name )
     , m_isCompilation( false )
-    , m_separator( 0 )
-    , m_displayCoverAction( 0 )
-    , m_fetchCoverAction( 0 )
-    , m_setCustomCoverAction( 0 )
-    , m_unsetCoverAction( 0 )
 {
 }
 
@@ -536,12 +504,12 @@ TimecodeAlbum::setImage( const QImage &image )
 }
 
 void
-TimecodeAlbum::addTrack( TimecodeTrackPtr track )
+TimecodeAlbum::addTrack( const TimecodeTrackPtr &track )
 {
     m_tracks.append( TrackPtr::staticCast( track ) );
 }
 
-void TimecodeAlbum::setAlbumArtist( TimecodeArtistPtr artist )
+void TimecodeAlbum::setAlbumArtist( const TimecodeArtistPtr &artist )
 {
     m_albumArtist = artist;
 }
@@ -588,11 +556,11 @@ TimecodeGenre::name() const
 TrackList
 TimecodeGenre::tracks()
 {
-    return tracks();
+    return m_tracks;
 }
 
 void
-TimecodeGenre::addTrack( TimecodeTrackPtr track )
+TimecodeGenre::addTrack( const TimecodeTrackPtr &track )
 {
     m_tracks.append( TrackPtr::staticCast( track ) );
 }
@@ -621,7 +589,7 @@ TimecodeComposer::tracks()
 }
 
 void
-TimecodeComposer::addTrack( TimecodeTrackPtr track )
+TimecodeComposer::addTrack( const TimecodeTrackPtr &track )
 {
     m_tracks.append( TrackPtr::staticCast( track ) );
 }
@@ -650,9 +618,8 @@ TimecodeYear::tracks()
 }
 
 void
-TimecodeYear::addTrack( TimecodeTrackPtr track )
+TimecodeYear::addTrack( const TimecodeTrackPtr &track )
 {
     m_tracks.append( TrackPtr::staticCast( track ) );
 }
 
-#include "TimecodeMeta.moc"
