@@ -43,7 +43,6 @@ MySqlEmbeddedStorage::MySqlEmbeddedStorage()
 bool
 MySqlEmbeddedStorage::init( const QString &storageLocation )
 {
-
     // -- figuring out and setting the database path.
     QString storagePath = storageLocation;
     QString databaseDir;
@@ -62,7 +61,7 @@ MySqlEmbeddedStorage::init( const QString &storageLocation )
     }
 
     QVector<const char*> mysql_args;
-    QByteArray dataDir = QString( "--datadir=%1" ).arg( databaseDir ).toLocal8Bit();
+    QByteArray dataDir = QStringLiteral( "--datadir=%1" ).arg( databaseDir ).toLocal8Bit();
     mysql_args << "amarok"
                << dataDir.constData()
                // CAUTION: if we ever change the table type we will need to fix a number of MYISAM specific
@@ -142,10 +141,7 @@ MySqlEmbeddedStorage::~MySqlEmbeddedStorage()
     if( m_db )
     {
         mysql_close( m_db );
-        if( !libraryInitRef.deref() )
-        {
-            mysql_library_end();
-        }
+        libraryInitRef.deref();
     }
 }
 
