@@ -30,6 +30,7 @@
 #include "core/transcoding/TranscodingConfiguration.h"
 #include "core/transcoding/TranscodingController.h"
 
+#include <KLocalizedString>
 #include <QDir>
 #include <QTimer>
 
@@ -99,7 +100,7 @@ CollectionLocation::isOrganizable() const
 }
 
 void
-CollectionLocation::prepareCopy( Meta::TrackPtr track, CollectionLocation *destination )
+CollectionLocation::prepareCopy( const Meta::TrackPtr &track, CollectionLocation *destination )
 {
     Q_ASSERT(destination);
     Meta::TrackList list;
@@ -140,14 +141,14 @@ CollectionLocation::prepareCopy( Collections::QueryMaker *qm, CollectionLocation
     m_destination = destination;
     m_removeSources = false;
     m_isRemoveAction = false;
-    connect( qm, SIGNAL(newResultReady(Meta::TrackList)), SLOT(resultReady(Meta::TrackList)) );
-    connect( qm, SIGNAL(queryDone()), SLOT(queryDone()) );
+    connect( qm, &Collections::QueryMaker::newTracksReady, this, &CollectionLocation::resultReady );
+    connect( qm, &Collections::QueryMaker::queryDone, this, &CollectionLocation::queryDone );
     qm->setQueryType( Collections::QueryMaker::Track );
     qm->run();
 }
 
 void
-CollectionLocation::prepareMove( Meta::TrackPtr track, CollectionLocation *destination )
+CollectionLocation::prepareMove( const Meta::TrackPtr &track, CollectionLocation *destination )
 {
     Meta::TrackList list;
     list.append( track );
@@ -188,8 +189,8 @@ CollectionLocation::prepareMove( Collections::QueryMaker *qm, CollectionLocation
     m_destination = destination;
     m_isRemoveAction = false;
     m_removeSources = true;
-    connect( qm, SIGNAL(newResultReady(Meta::TrackList)), SLOT(resultReady(Meta::TrackList)) );
-    connect( qm, SIGNAL(queryDone()), SLOT(queryDone()) );
+    connect( qm, &Collections::QueryMaker::newTracksReady, this, &CollectionLocation::resultReady );
+    connect( qm, &Collections::QueryMaker::queryDone, this, &CollectionLocation::queryDone );
     qm->setQueryType( Collections::QueryMaker::Track );
     qm->run();
 }
@@ -224,8 +225,8 @@ CollectionLocation::prepareRemove( Collections::QueryMaker *qm )
     m_isRemoveAction = true;
     m_removeSources = false;
 
-    connect( qm, SIGNAL(newResultReady(Meta::TrackList)), SLOT(resultReady(Meta::TrackList)) );
-    connect( qm, SIGNAL(queryDone()), SLOT(queryDone()) );
+    connect( qm, &Collections::QueryMaker::newTracksReady, this, &CollectionLocation::resultReady );
+    connect( qm, &Collections::QueryMaker::queryDone, this, &CollectionLocation::queryDone );
     qm->setQueryType( Collections::QueryMaker::Track );
     qm->run();
 }
@@ -243,14 +244,14 @@ CollectionLocation::insert( const Meta::TrackPtr &track, const QString &url )
 void
 CollectionLocation::abort()
 {
-    emit aborted();
+    Q_EMIT aborted();
 }
 
 void
 CollectionLocation::getKIOCopyableUrls( const Meta::TrackList &tracks )
 {
     DEBUG_BLOCK
-    QMap<Meta::TrackPtr, KUrl> urls;
+    QMap<Meta::TrackPtr, QUrl> urls;
     foreach( Meta::TrackPtr track, tracks )
     {
         if( track->isPlayable() )
@@ -264,7 +265,7 @@ CollectionLocation::getKIOCopyableUrls( const Meta::TrackList &tracks )
 }
 
 void
-CollectionLocation::copyUrlsToCollection( const QMap<Meta::TrackPtr, KUrl> &sources,
+CollectionLocation::copyUrlsToCollection( const QMap<Meta::TrackPtr, QUrl> &sources,
                                           const Transcoding::Configuration &configuration )
 {
     DEBUG_BLOCK
@@ -433,39 +434,39 @@ CollectionLocation::operationInProgressText( const Transcoding::Configuration &c
 }
 
 void
-CollectionLocation::slotGetKIOCopyableUrlsDone( const QMap<Meta::TrackPtr, KUrl> &sources )
+CollectionLocation::slotGetKIOCopyableUrlsDone( const QMap<Meta::TrackPtr, QUrl> &sources )
 {
-    emit startCopy( sources, m_transcodingConfiguration );
+    Q_EMIT startCopy( sources, m_transcodingConfiguration );
 }
 
 void
 CollectionLocation::slotCopyOperationFinished()
 {
-    emit finishCopy();
+    Q_EMIT finishCopy();
 }
 
 void
 CollectionLocation::slotRemoveOperationFinished()
 {
-    emit finishRemove();
+    Q_EMIT finishRemove();
 }
 
 void
 CollectionLocation::slotShowSourceDialogDone()
 {
-    emit prepareOperation( m_sourceTracks, m_removeSources, m_transcodingConfiguration );
+    Q_EMIT prepareOperation( m_sourceTracks, m_removeSources, m_transcodingConfiguration );
 }
 
 void
 CollectionLocation::slotShowDestinationDialogDone()
 {
-    emit operationPrepared();
+    Q_EMIT operationPrepared();
 }
 
 void
 CollectionLocation::slotShowRemoveDialogDone()
 {
-    emit startRemove();
+    Q_EMIT startRemove();
 }
 
 void
@@ -489,7 +490,7 @@ CollectionLocation::slotOperationPrepared()
 }
 
 void
-CollectionLocation::slotStartCopy( const QMap<Meta::TrackPtr, KUrl> &sources,
+CollectionLocation::slotStartCopy( const QMap<Meta::TrackPtr, QUrl> &sources,
                                    const Transcoding::Configuration &configuration )
 {
     DEBUG_BLOCK
@@ -545,7 +546,7 @@ CollectionLocation::slotFinishRemove()
             continue;
 
         if( track->playableUrl().isLocalFile() )
-            dirsToRemove.append( track->playableUrl().directory( KUrl::AppendTrailingSlash ) );
+            dirsToRemove.append( track->playableUrl().adjusted( QUrl::RemoveFilename ).path() );
     }
 
     if( !dirsToRemove.isEmpty() && delegate->deleteEmptyDirs( this ) )
@@ -560,7 +561,7 @@ CollectionLocation::slotFinishRemove()
                 continue;
 
             dir.setFilter( QDir::NoDotAndDotDot );
-            while( !dir.isRoot() && dir.count() == 0 )
+            while( !dir.isRoot() && dir.isEmpty() )
             {
                 const QString name = dir.dirName();
                 dir.cdUp();
@@ -620,25 +621,27 @@ CollectionLocation::queryDone()
 void
 CollectionLocation::setupConnections()
 {
-    connect( this, SIGNAL(prepareOperation(Meta::TrackList,bool,Transcoding::Configuration)),
-             m_destination, SLOT(slotPrepareOperation(Meta::TrackList,bool,Transcoding::Configuration)) );
-    connect( m_destination, SIGNAL(operationPrepared()), SLOT(slotOperationPrepared()) );
-    connect( this, SIGNAL(startCopy(QMap<Meta::TrackPtr,KUrl>,Transcoding::Configuration)),
-             m_destination, SLOT(slotStartCopy(QMap<Meta::TrackPtr,KUrl>,Transcoding::Configuration)) );
-    connect( m_destination, SIGNAL(finishCopy()),
-             this, SLOT(slotFinishCopy()) );
-    connect( this, SIGNAL(aborted()), SLOT(slotAborted()) );
-    connect( m_destination, SIGNAL(aborted()), SLOT(slotAborted()) );
+    connect( this, &CollectionLocation::prepareOperation,
+             m_destination, &Collections::CollectionLocation::slotPrepareOperation );
+    connect( m_destination, &Collections::CollectionLocation::operationPrepared,
+             this, &CollectionLocation::slotOperationPrepared );
+    connect( this, &CollectionLocation::startCopy,
+             m_destination, &Collections::CollectionLocation::slotStartCopy );
+    connect( m_destination, &Collections::CollectionLocation::finishCopy,
+             this, &CollectionLocation::slotFinishCopy );
+    connect( this, &CollectionLocation::aborted, this, &CollectionLocation::slotAborted );
+    connect( m_destination, &Collections::CollectionLocation::aborted, this, &CollectionLocation::slotAborted );
 }
 
 void
 CollectionLocation::setupRemoveConnections()
 {
-    connect( this, SIGNAL(aborted()), SLOT(slotAborted()) );
-    connect( this, SIGNAL(startRemove()),
-             this, SLOT(slotStartRemove()) );
-    connect( this, SIGNAL(finishRemove()),
-             this, SLOT(slotFinishRemove()) );
+    connect( this, &CollectionLocation::aborted,
+             this, &CollectionLocation::slotAborted );
+    connect( this, &CollectionLocation::startRemove,
+             this, &CollectionLocation::slotStartRemove );
+    connect( this, &CollectionLocation::finishRemove,
+             this, &CollectionLocation::slotFinishRemove );
 }
 
 void
@@ -652,7 +655,7 @@ CollectionLocation::startWorkflow( const Meta::TrackList &tracks, bool removeSou
         abort();
     else
         // show dialog in next mainloop iteration so that prepare[Something]() returns quickly
-        QTimer::singleShot( 0, this, SLOT(slotShowSourceDialog()) );
+        QTimer::singleShot( 0, this, &CollectionLocation::slotShowSourceDialog );
 }
 
 void
@@ -740,4 +743,3 @@ CollectionLocation::transferError( const Meta::TrackPtr &track, const QString &e
     m_tracksWithError.insert( track, error );
 }
 
-#include "CollectionLocation.moc"
