@@ -23,11 +23,8 @@
 #include "core/support/Debug.h"
 #include "core/meta/support/MetaUtility.h"
 
-#include <kio/job.h>
-#include <kurl.h>
-#include <KDateTime>
+#include <QUrl>
 
-#include <QTextDocument>
 #include <QDate>
 #include <QSet>
 
@@ -57,8 +54,8 @@ PodcastReader::PodcastReader( PodcastProvider *podcastProvider, QObject *parent
         : QObject( parent )
         , m_xmlReader()
         , m_podcastProvider( podcastProvider )
-        , m_transferJob( 0 )
-        , m_current( 0 )
+        , m_transferJob( )
+        , m_current( nullptr )
         , m_actionStack()
         , m_contentType( TextContent )
         , m_buffer()
@@ -87,7 +84,7 @@ PodcastReader::Action::characters( PodcastReader *podcastReader ) const
 
 // initialization of the feed parser automata:
 PodcastReader::StaticData::StaticData()
-        : removeScripts( "<script[^<]*</script>|<script[^>]*>", Qt::CaseInsensitive )
+        : removeScripts( QStringLiteral("<script[^<]*</script>|<script[^>]*>"), Qt::CaseInsensitive )
         , mightBeHtml( "<\\?xml[^>]*\\?>|<br[^>]*>|<p[^>]*>|&lt;|&gt;|&amp;|&quot;|"
                        "<([-:\\w\\d]+)[^>]*(/>|>.*</\\1>)|<hr[>]*>|&#\\d+;|&#x[a-fA-F\\d]+;", Qt::CaseInsensitive )
         , linkify( "\\b(" RE_URL ")|\\b(" RE_MAIL ")|(\n)" )
@@ -278,37 +275,37 @@ PodcastReader::StaticData::StaticData()
             &PodcastReader::readAtomTextCharacters )
 {
     // known elements:
-    knownElements[ "rss"          ] = Rss;
-    knownElements[ "RDF"          ] = Rdf;
-    knownElements[ "feed"         ] = Feed;
-    knownElements[ "channel"      ] = Channel;
-    knownElements[ "item"         ] = Item;
-    knownElements[ "image"        ] = Image;
-    knownElements[ "link"         ] = Link;
-    knownElements[ "url"          ] = Url;
-    knownElements[ "title"        ] = Title;
-    knownElements[ "author"       ] = Author;
-    knownElements[ "enclosure"    ] = EnclosureElement;
-    knownElements[ "guid"         ] = Guid;
-    knownElements[ "pubDate"      ] = PubDate;
-    knownElements[ "description"  ] = Description;
-    knownElements[ "summary"      ] = Summary;
-    knownElements[ "body"         ] = Body;
-    knownElements[ "entry"        ] = Entry;
-    knownElements[ "content"      ] = Content;
-    knownElements[ "name"         ] = Name;
-    knownElements[ "id"           ] = Id;
-    knownElements[ "subtitle"     ] = Subtitle;
-    knownElements[ "updated"      ] = Updated;
-    knownElements[ "published"    ] = Published;
-    knownElements[ "logo"         ] = Logo;
-    knownElements[ "icon"         ] = Icon;
-    knownElements[ "encoded"      ] = Encoded;
-    knownElements[ "creator"      ] = Creator;
-    knownElements[ "keywords"     ] = Keywords;
-    knownElements[ "new-feed-url" ] = NewFeedUrl;
-    knownElements[ "html"         ] = Html;
-    knownElements[ "HTML"         ] = Html;
+    knownElements[ QStringLiteral("rss")          ] = Rss;
+    knownElements[ QStringLiteral("RDF")          ] = Rdf;
+    knownElements[ QStringLiteral("feed")         ] = Feed;
+    knownElements[ QStringLiteral("channel")      ] = Channel;
+    knownElements[ QStringLiteral("item")         ] = Item;
+    knownElements[ QStringLiteral("image")        ] = Image;
+    knownElements[ QStringLiteral("link")         ] = Link;
+    knownElements[ QStringLiteral("url")          ] = Url;
+    knownElements[ QStringLiteral("title")        ] = Title;
+    knownElements[ QStringLiteral("author")       ] = Author;
+    knownElements[ QStringLiteral("enclosure")    ] = EnclosureElement;
+    knownElements[ QStringLiteral("guid")         ] = Guid;
+    knownElements[ QStringLiteral("pubDate")      ] = PubDate;
+    knownElements[ QStringLiteral("description")  ] = Description;
+    knownElements[ QStringLiteral("summary")      ] = Summary;
+    knownElements[ QStringLiteral("body")         ] = Body;
+    knownElements[ QStringLiteral("entry")        ] = Entry;
+    knownElements[ QStringLiteral("content")      ] = Content;
+    knownElements[ QStringLiteral("name")         ] = Name;
+    knownElements[ QStringLiteral("id")           ] = Id;
+    knownElements[ QStringLiteral("subtitle")     ] = Subtitle;
+    knownElements[ QStringLiteral("updated")      ] = Updated;
+    knownElements[ QStringLiteral("published")    ] = Published;
+    knownElements[ QStringLiteral("logo")         ] = Logo;
+    knownElements[ QStringLiteral("icon")         ] = Icon;
+    knownElements[ QStringLiteral("encoded")      ] = Encoded;
+    knownElements[ QStringLiteral("creator")      ] = Creator;
+    knownElements[ QStringLiteral("keywords")     ] = Keywords;
+    knownElements[ QStringLiteral("new-feed-url") ] = NewFeedUrl;
+    knownElements[ QStringLiteral("html")         ] = Html;
+    knownElements[ QStringLiteral("HTML")         ] = Html;
 
     // before start document/after end document
     rootMap.insert( Document, &docAction );
@@ -431,7 +428,7 @@ bool PodcastReader::read( QIODevice *device )
 }
 
 bool
-PodcastReader::read( const KUrl &url )
+PodcastReader::read( const QUrl &url )
 {
     DEBUG_BLOCK
 
@@ -439,19 +436,17 @@ PodcastReader::read( const KUrl &url )
 
     m_transferJob = KIO::get( m_url, KIO::Reload, KIO::HideProgressInfo );
 
-    connect( m_transferJob, SIGNAL(data(KIO::Job*,QByteArray)),
-             SLOT(slotAddData(KIO::Job*,QByteArray)) );
+    connect( m_transferJob, &KIO::TransferJob::data,
+             this, &PodcastReader::slotAddData );
 
-    connect( m_transferJob, SIGNAL(result(KJob*)),
-             SLOT(downloadResult(KJob*)) );
+    connect( m_transferJob, &KIO::TransferJob::result,
+             this, &PodcastReader::downloadResult );
 
-    connect( m_transferJob, SIGNAL(redirection(KIO::Job*,KUrl)),
-             SLOT(slotRedirection(KIO::Job*,KUrl)) );
+    connect( m_transferJob, &KIO::TransferJob::redirection,
+             this, &PodcastReader::slotRedirection );
 
-    connect( m_transferJob, SIGNAL( permanentRedirection( KIO::Job *,
-                                    const KUrl &, const KUrl & ) ),
-             SLOT( slotPermanentRedirection( KIO::Job *, const KUrl &,
-                                             const KUrl & ) ) );
+    connect( m_transferJob, &KIO::TransferJob::permanentRedirection,
+             this, &PodcastReader::slotPermanentRedirection );
 
     QString description = i18n( "Importing podcast channel from %1", url.url() );
     if( m_channel )
@@ -461,7 +456,7 @@ PodcastReader::read( const KUrl &url )
                       : i18n( "Updating \"%1\"", m_channel->title() );
     }
 
-    emit statusBarNewProgressOperation( m_transferJob, description, this );
+    Q_EMIT statusBarNewProgressOperation( m_transferJob, description, this );
 
     // parse data
     return read();
@@ -474,7 +469,7 @@ PodcastReader::slotAbort()
 }
 
 bool
-PodcastReader::update( PodcastChannelPtr channel )
+PodcastReader::update( const PodcastChannelPtr &channel )
 {
     DEBUG_BLOCK
     m_channel = channel;
@@ -515,7 +510,7 @@ PodcastReader::downloadResult( KJob * job )
         }
         errorMessage = errorMessage.append( job->errorString() );
 
-        emit statusBarSorryMessage( errorMessage );
+        Q_EMIT statusBarSorryMessage( errorMessage );
     }
     else if( job->error() )
     {
@@ -529,10 +524,10 @@ PodcastReader::downloadResult( KJob * job )
         }
         errorMessage = errorMessage.append( job->errorString() );
 
-        emit statusBarSorryMessage( errorMessage );
+        Q_EMIT statusBarSorryMessage( errorMessage );
     }
 
-    m_transferJob = 0;
+    m_transferJob = nullptr;
 }
 
 PodcastReader::ElementType
@@ -618,8 +613,8 @@ PodcastReader::read()
 {
     DEBUG_BLOCK
 
-    m_current = 0;
-    m_item    = 0;
+    m_current = nullptr;
+    m_item    = nullptr;
     m_contentType = TextContent;
     m_buffer.clear();
     m_actionStack.clear();
@@ -634,7 +629,7 @@ PodcastReader::continueRead()
 {
     // this is some kind of pushdown automata
     // with this it should be possible to parse feeds in parallel
-    // woithout using threads
+    // without using threads
     DEBUG_BLOCK
 
     while( !m_xmlReader.atEnd() && m_xmlReader.error() != QXmlStreamReader::CustomError )
@@ -648,7 +643,7 @@ PodcastReader::continueRead()
 
         if( m_xmlReader.hasError() )
         {
-            emit finished( this );
+            Q_EMIT finished( this );
             return false;
         }
 
@@ -659,7 +654,7 @@ PodcastReader::continueRead()
         }
 
         const Action* action = m_actionStack.top();
-        const Action* subAction = 0;
+        const Action* subAction = nullptr;
 
         switch( token )
         {
@@ -696,8 +691,8 @@ PodcastReader::continueRead()
                 {
                     action->characters( this );
                 }
-
-                // ignoreable whitespaces
+            break;
+                // ignorable whitespaces
             case QXmlStreamReader::Comment:
             case QXmlStreamReader::EntityReference:
             case QXmlStreamReader::ProcessingInstruction:
@@ -719,10 +714,10 @@ PodcastReader::stopWithError( const QString &message )
     if( m_transferJob )
     {
         m_transferJob->kill(KJob::EmitResult);
-        m_transferJob = 0;
+        m_transferJob = nullptr;
     }
 
-    emit finished( this );
+    Q_EMIT finished( this );
 }
 
 void
@@ -791,7 +786,7 @@ PodcastReader::unescape( const QString &text )
 
         if( c == '&' )
         {
-            int endIndex = text.indexOf( ';', i );
+            int endIndex = text.indexOf( QLatin1Char(';'), i );
 
             if( endIndex == -1 )
             {
@@ -828,29 +823,29 @@ PodcastReader::unescape( const QString &text )
             {
                 QString entity( text.mid( i + 1, endIndex - i - 1 ) );
 
-                if( entity == "lt" )
+                if( entity == QLatin1String("lt") )
                 {
-                    buf += '<';
+                    buf += QLatin1Char('<');
                     i = endIndex;
                 }
-                else if( entity == "gt" )
+                else if( entity == QLatin1String("gt") )
                 {
-                    buf += '>';
+                    buf += QLatin1Char('>');
                     i = endIndex;
                 }
-                else if( entity == "amp" )
+                else if( entity == QLatin1String("amp") )
                 {
-                    buf += '&';
+                    buf += QLatin1Char('&');
                     i = endIndex;
                 }
-                else if( entity == "apos" )
+                else if( entity == QLatin1String("apos") )
                 {
-                    buf += '\'';
+                    buf += QLatin1Char('\'');
                     i = endIndex;
                 }
-                else if( entity == "quot" )
+                else if( entity == QLatin1String("quot") )
                 {
-                    buf += '"';
+                    buf += QLatin1Char('"');
                     i = endIndex;
                 }
                 else
@@ -931,7 +926,7 @@ PodcastReader::textToHtml( const QString &text )
 
         if( next != index )
         {
-            buf += Qt::escape( text.mid( index, next - index ) );
+            buf += text.mid( index, next - index ).toHtmlEscaped();
         }
 
         QString s;
@@ -941,28 +936,28 @@ PodcastReader::textToHtml( const QString &text )
             if( s.startsWith( QLatin1String( "javascript:" ), Qt::CaseInsensitive ) ||
                 s.startsWith( QLatin1String( "exec:" ), Qt::CaseInsensitive ) )
             {
-                buf += Qt::escape( s );
+                buf += s.toHtmlEscaped();
             }
             else
             {
-                buf += QString( "<a href=\"%1\">%1</a>" )
-                    .arg( Qt::escape( s ) );
+                buf += QStringLiteral( "<a href=\"%1\">%1</a>" )
+                    .arg( s.toHtmlEscaped() );
             }
         }
         else if( !(s = re.cap( 2 )).isEmpty() )
         {
-            buf += QString( "<a href=\"mailto:%1\">%1</a>" )
-                .arg( Qt::escape( s ) );
+            buf += QStringLiteral( "<a href=\"mailto:%1\">%1</a>" )
+                .arg( s.toHtmlEscaped() );
         }
         else if( !re.cap( 3 ).isEmpty() )
         {
-            buf += "<br/>\n";
+            buf += QLatin1String("<br/>\n");
         }
 
         index = re.pos() + re.matchedLength();
     }
 
-    buf += Qt::escape( text.mid( index ) );
+    buf += text.mid( index ).toHtmlEscaped();
 
     return buf;
 }
@@ -989,7 +984,7 @@ PodcastReader::endLink()
 {
     // TODO: change to m_current->... when the field
     //       is moved to the PodcastMetaCommon class.
-    m_channel->setWebLink( KUrl( m_buffer ) );
+    m_channel->setWebLink( QUrl( m_buffer ) );
 }
 
 void
@@ -1008,7 +1003,7 @@ PodcastReader::beginUnknownFeedType()
 void
 PodcastReader::beginRss()
 {
-    if( m_xmlReader.attributes().value( "version" ) != "2.0" )
+    if( m_xmlReader.attributes().value( QStringLiteral("version") ) != "2.0" )
     {
         // TODO: change this string once we support more
         stopWithError( i18n( "%1 is not an RSS version 2.0 feed.", m_url.url() ) );
@@ -1061,7 +1056,7 @@ void
 PodcastReader::endDocument()
 {
     debug() << "successfully parsed feed: " << m_url.url();
-    emit finished( this );
+    Q_EMIT finished( this );
 }
 
 void
@@ -1092,8 +1087,8 @@ PodcastReader::beginChannel()
     // they only get changed when longer information is read as there is stored in
     // the appropriate field already. In order to still be able to correctly update
     // the feed's description/summary I set it here to the empty string:
-    m_channel->setDescription( "" );
-    m_channel->setSummary( "" );
+    m_channel->setDescription( QLatin1String("") );
+    m_channel->setSummary( QLatin1String("") );
     m_channel->setKeywords( QStringList() );
 }
 
@@ -1131,22 +1126,22 @@ PodcastReader::endItem()
         if( !m_enclosures.isEmpty() )
         {
             QString description( m_item->description() );
-            description += "\n<p><b>";
+            description += QLatin1String("\n<p><b>");
             description += i18n( "Alternative Enclosures:" );
-            description += "</b><br/>\n<ul>";
+            description += QLatin1String("</b><br/>\n<ul>");
 
             foreach( const Enclosure& enclosure, m_enclosures )
             {
-                description += QString( "<li><a href=\"%1\">%2</a> (%3, %4)</li>" )
-                               .arg( Qt::escape( enclosure.url().url() ) )
-                               .arg( Qt::escape( enclosure.url().fileName() ) )
-                               .arg( Meta::prettyFilesize( enclosure.fileSize() ) )
-                               .arg( enclosure.mimeType().isEmpty() ?
+                description += QStringLiteral( "<li><a href=\"%1\">%2</a> (%3, %4)</li>" )
+                               .arg( enclosure.url().url().toHtmlEscaped(),
+                                     enclosure.url().fileName().toHtmlEscaped(),
+                                     Meta::prettyFilesize( enclosure.fileSize() ),
+                                     enclosure.mimeType().isEmpty() ?
                                      i18n( "unknown type" ) :
-                                     Qt::escape( enclosure.mimeType() ) );
+                                     enclosure.mimeType().toHtmlEscaped() );
             }
 
-            description += "</ul></p>";
+            description += QLatin1String("</ul></p>");
             m_item->setDescription( description );
         }
 
@@ -1155,7 +1150,7 @@ PodcastReader::endItem()
         if( guid.isEmpty() )
         {
              episode = Podcasts::PodcastEpisodePtr::dynamicCast(
-                                              m_podcastProvider->trackForUrl( m_item->uidUrl() )
+                                              m_podcastProvider->trackForUrl( QUrl::fromUserInput(m_item->uidUrl()) )
                                           );
         }
         else
@@ -1164,7 +1159,7 @@ PodcastReader::endItem()
         }
 
         //make sure that the episode is not a bogus match. The channel has to be correct.
-        // See http://bugs.kde.org/show_bug.cgi?id=227515
+        // See https://bugs.kde.org/show_bug.cgi?id=227515
         if( !episode.isNull() && episode->channel() == m_channel )
         {
             debug() << "updating episode: " << episode->title();
@@ -1174,7 +1169,7 @@ PodcastReader::endItem()
             episode->setSummary( m_item->summary() );
             episode->setDescription( m_item->description() );
             episode->setAuthor( m_item->author() );
-            episode->setUidUrl( m_item->uidUrl() );
+            episode->setUidUrl( QUrl::fromUserInput(m_item->uidUrl()) );
             episode->setFilesize( m_item->filesize() );
             episode->setMimeType( m_item->mimeType() );
             episode->setPubDate( m_item->pubDate() );
@@ -1208,7 +1203,7 @@ PodcastReader::beginEnclosure()
     //    http://www.xs4all.nl/~foz/mod_enclosure.html
     QStringRef str;
 
-    str = m_xmlReader.attributes().value( "url" );
+    str = m_xmlReader.attributes().value( QStringLiteral("url") );
 
     if( str.isEmpty() )
         str = attribute( RDF_NS, "about" );
@@ -1219,16 +1214,16 @@ PodcastReader::beginEnclosure()
         return;
     }
 
-    KUrl url( str.toString() );
+    QUrl url( str.toString() );
 
-    str = m_xmlReader.attributes().value( "length" );
+    str = m_xmlReader.attributes().value( QStringLiteral("length") );
 
     if( str.isEmpty() )
         str = attribute( ENC_NS, "length" );
 
     int length = str.toString().toInt();
 
-    str = m_xmlReader.attributes().value( "type" );
+    str = m_xmlReader.attributes().value( QStringLiteral("type") );
 
     if( str.isEmpty() )
         str = attribute( ENC_NS, "type" );
@@ -1263,7 +1258,7 @@ PodcastReader::beginImage()
 {
     if( m_xmlReader.namespaceUri() == ITUNES_NS )
     {
-        m_channel->setImageUrl( KUrl( m_xmlReader.attributes().value( "href" ).toString() ) );
+        m_channel->setImageUrl( QUrl( m_xmlReader.attributes().value( QStringLiteral("href") ).toString() ) );
     }
 }
 
@@ -1271,7 +1266,7 @@ void
 PodcastReader::endImageUrl()
 {
     // TODO save image data
-    m_channel->setImageUrl( KUrl( m_buffer ) );
+    m_channel->setImageUrl( QUrl( m_buffer ) );
 }
 
 void
@@ -1279,7 +1274,7 @@ PodcastReader::endKeywords()
 {
     QList<QString> keywords( m_current->keywords() );
 
-    foreach( const QString &keyword, m_buffer.split( ',' ) )
+    foreach( const QString &keyword, m_buffer.split( QLatin1Char(',') ) )
     {
         QString kwd( keyword.simplified() );
         if( !kwd.isEmpty() && !keywords.contains( kwd ) )
@@ -1296,7 +1291,7 @@ PodcastReader::endNewFeedUrl()
 {
     if( m_xmlReader.namespaceUri() == ITUNES_NS )
     {
-        m_url = KUrl( m_buffer.trimmed() );
+        m_url = QUrl( m_buffer.trimmed() );
 
         if( m_channel && m_channel->url() != m_url )
         {
@@ -1330,9 +1325,9 @@ PodcastReader::beginXml()
 
     foreach( const QXmlStreamAttribute &attr, m_xmlReader.attributes() )
     {
-        m_buffer += QString( " %1=\"%2\"" )
-                    .arg( attr.name().toString() )
-                    .arg( Qt::escape( attr.value().toString() ) );
+        m_buffer += QStringLiteral( " %1=\"%2\"" )
+                    .arg( attr.name().toString(),
+                          attr.value().toString().toHtmlEscaped() );
     }
 
     m_buffer += '>';
@@ -1424,7 +1419,7 @@ PodcastReader::readAtomTextCharacters()
     switch( m_contentType )
     {
     case XHtmlContent:
-        m_buffer += Qt::escape( m_xmlReader.text().toString() );
+        m_buffer += m_xmlReader.text().toString().toHtmlEscaped();
         break;
 
     case HtmlContent:
@@ -1445,11 +1440,11 @@ PodcastReader::beginAtomFeedLink()
     if( !hasAttribute( ATOM_NS, "rel" ) ||
             attribute( ATOM_NS, "rel" ) == "alternate" )
     {
-        m_channel->setWebLink( KUrl( attribute( ATOM_NS, "href" ).toString() ) );
+        m_channel->setWebLink( QUrl( attribute( ATOM_NS, "href" ).toString() ) );
     }
     else if( attribute( ATOM_NS, "rel" ) == "self" )
     {
-        m_url = KUrl( attribute( ATOM_NS, "href" ).toString() );
+        m_url = QUrl( attribute( ATOM_NS, "href" ).toString() );
 
         if( m_channel && m_channel->url() != m_url )
         {
@@ -1464,7 +1459,7 @@ PodcastReader::beginAtomEntryLink()
 {
     if( attribute( ATOM_NS, "rel" ) == "enclosure" )
     {
-        KUrl url( attribute( ATOM_NS, "href" ).toString() );
+        QUrl url( attribute( ATOM_NS, "href" ).toString() );
         int filesize = 0;
         QString mimeType;
 
@@ -1522,7 +1517,7 @@ PodcastReader::endAtomContent()
 void
 PodcastReader::endAtomPublished()
 {
-    QDateTime date( KDateTime::fromString( m_buffer, KDateTime::ISODate ).dateTime() );
+    QDateTime date = QDateTime::fromString( m_buffer, Qt::ISODate );
 
     if( !date.isValid() )
     {
@@ -1539,7 +1534,7 @@ PodcastReader::endAtomPublished()
 void
 PodcastReader::endAtomUpdated()
 {
-    QDateTime date( KDateTime::fromString( m_buffer, KDateTime::ISODate ).dateTime() );
+    QDateTime date = QDateTime::fromString( m_buffer, Qt::ISODate );
 
     if( !date.isValid() )
     {
@@ -1564,7 +1559,7 @@ PodcastReader::readNoCharacters()
 void
 PodcastReader::endXml()
 {
-    m_buffer += "</";
+    m_buffer += QLatin1String("</");
     m_buffer += m_xmlReader.name().toString();
     m_buffer += '>';
 }
@@ -1578,7 +1573,7 @@ PodcastReader::readCharacters()
 void
 PodcastReader::readEscapedCharacters()
 {
-    m_buffer += Qt::escape( m_xmlReader.text().toString() );
+    m_buffer += m_xmlReader.text().toString().toHtmlEscaped() ;
 }
 
 QStringRef
@@ -1590,7 +1585,7 @@ PodcastReader::attribute( const char *namespaceUri, const char *name ) const
     if( m_xmlReader.attributes().hasAttribute( namespaceUri, name ) )
         return m_xmlReader.attributes().value( namespaceUri, name );
     else
-        return m_xmlReader.attributes().value( NULL, name );
+        return m_xmlReader.attributes().value( QString(), name );
 }
 
 bool
@@ -1600,7 +1595,7 @@ PodcastReader::hasAttribute( const char *namespaceUri, const char *name ) const
     if( m_xmlReader.attributes().hasAttribute( namespaceUri, name ) )
         return true;
     else
-        return m_xmlReader.attributes().hasAttribute( NULL, name );
+        return m_xmlReader.attributes().hasAttribute( QString(), name );
 }
 
 QDateTime
@@ -1610,14 +1605,14 @@ PodcastReader::parsePubDate( const QString &dateString )
     QString parseInput = dateString;
     debug() << "Parsing pubdate: " << parseInput;
 
-    QRegExp rfcDateDayRegex( "^[A-Z]{1}[a-z]{2}\\s*,\\s*(.*)" );
+    QRegExp rfcDateDayRegex( QStringLiteral("^[A-Z]{1}[a-z]{2}\\s*,\\s*(.*)") );
     if( rfcDateDayRegex.indexIn( parseInput ) != -1 )
     {
         parseInput = rfcDateDayRegex.cap(1);
     }
     //Hack around a to strict RFCDate implementation in KDateTime.
-    //See http://bugs.kde.org/show_bug.cgi?id=231062
-    QRegExp rfcMonthLowercase( "^\\d+\\s+\\b(jan|feb|mar|apr|may|jun|jul|aug|sep|oct|nov|dec)\\b" );
+    //See https://bugs.kde.org/show_bug.cgi?id=231062
+    QRegExp rfcMonthLowercase( QStringLiteral("^\\d+\\s+\\b(jan|feb|mar|apr|may|jun|jul|aug|sep|oct|nov|dec)\\b") );
     if( rfcMonthLowercase.indexIn( parseInput ) != -1 )
     {
         QString lowerMonth = rfcMonthLowercase.cap( 1 );
@@ -1626,14 +1621,14 @@ PodcastReader::parsePubDate( const QString &dateString )
         parseInput.replace( lowerMonth, upperMonth );
     }
 
-    QDateTime pubDate = KDateTime::fromString( parseInput, KDateTime::RFCDate ).dateTime();
+    QDateTime pubDate = QDateTime::fromString( parseInput, Qt::RFC2822Date );
 
     debug() << "result: " << pubDate.toString();
     return pubDate;
 }
 
 void
-PodcastReader::slotRedirection( KIO::Job * job, const KUrl & url )
+PodcastReader::slotRedirection( KIO::Job * job, const QUrl &url )
 {
     DEBUG_BLOCK
     Q_UNUSED( job );
@@ -1641,8 +1636,8 @@ PodcastReader::slotRedirection( KIO::Job * job, const KUrl & url )
 }
 
 void
-PodcastReader::slotPermanentRedirection( KIO::Job * job, const KUrl & fromUrl,
-        const KUrl & toUrl )
+PodcastReader::slotPermanentRedirection( KIO::Job * job, const QUrl &fromUrl,
+        const QUrl &toUrl )
 {
     DEBUG_BLOCK
     Q_UNUSED( job );
@@ -1650,7 +1645,7 @@ PodcastReader::slotPermanentRedirection( KIO::Job * job, const KUrl & fromUrl,
     debug() << "permanently redirected to: " << toUrl.url();
     m_url = toUrl;
     /* change the url for existing feeds as well. Permanent redirection means the old one
-    might dissapear soon. */
+    might disappear soon. */
     if( m_channel )
         m_channel->setUrl( m_url );
 }
@@ -1691,4 +1686,3 @@ PodcastReader::podcastEpisodeCheck( Podcasts::PodcastEpisodePtr episode )
     return episodeMatch;
 }
 
-#include "PodcastReader.moc"
