@@ -21,20 +21,18 @@
 #include "core/capabilities/SourceInfoCapability.h"
 #include "core/playlists/PlaylistFormat.h"
 
-#include <KCalendarSystem>
 #include <KConfigGroup>
-#include <KDirLister>
-#include <KGlobalSettings>
-#include <KIcon>
-#include <KIconEffect>
-#include <KStandardDirs>
-#include <KUniqueApplication>
+#include <KLocalizedString>
+#include <KSharedConfig>
 
+#include <QApplication>
 #include <QDateTime>
+#include <QIcon>
+#include <QLocale>
 #include <QPixmapCache>
-#include <QTextDocument>
+#include <QStandardPaths>
 
-QWeakPointer<KActionCollection> Amarok::actionCollectionObject;
+QPointer<KActionCollection> Amarok::actionCollectionObject;
 QMutex Amarok::globalDirsMutex;
 
 namespace Amarok
@@ -44,7 +42,7 @@ namespace Amarok
     //   in such a case we should maybe display "Unknown" and not "Never"
     QString verboseTimeSince( const QDateTime &datetime )
     {
-        if( datetime.isNull() || !datetime.toTime_t() )
+        if( datetime.isNull() || !datetime.toSecsSinceEpoch() )
             return i18nc( "The amount of time since last played", "Never" );
 
         const QDateTime now = QDateTime::currentDateTime();
@@ -56,10 +54,8 @@ namespace Amarok
             return i18nc( "When this track was last played", "Unknown" );
 
         if( datediff >= 6*7 /*six weeks*/ ) {  // return absolute month/year
-            const KCalendarSystem *cal = KGlobal::locale()->calendar();
-            const QDate date = datetime.date();
-            return i18nc( "monthname year", "%1 %2", cal->monthName(date),
-                          cal->formatDate( date, KLocale::Year, KLocale::LongNumber ) );
+            QString month_year = datetime.date().toString(QStringLiteral("MM yyyy"));
+            return i18nc( "monthname year", "%1", month_year );
         }
 
         //TODO "last week" = maybe within 7 days, but prolly before last Sunday
@@ -93,7 +89,7 @@ namespace Amarok
             return i18nc( "The amount of time since last played", "Never" );
 
         QDateTime dt;
-        dt.setTime_t( time_t );
+        dt.setSecsSinceEpoch( time_t );
         return verboseTimeSince( dt );
     }
 
@@ -103,7 +99,7 @@ namespace Amarok
             return i18nc( "The amount of time since last played", "0" );
 
         QDateTime datetime;
-        datetime.setTime_t( time_t );
+        datetime.setSecsSinceEpoch( time_t );
 
         const QDateTime now = QDateTime::currentDateTime();
         const int datediff = datetime.daysTo( now );
@@ -130,9 +126,9 @@ namespace Amarok
         //TODO are we too specific here? Be more fuzzy? ie, use units of 5 minutes, or "Recently"
 
         if( timediff >= 60 )  // return difference in minutes
-            return QString("%1'").arg( ( timediff + 30 )/60 );
+            return QStringLiteral("%1'").arg( ( timediff + 30 )/60 );
         if( timediff >= 0 )  // return difference in seconds
-            return QString("%1\"").arg( ( timediff + 1 )/60 );
+            return QStringLiteral("%1\"").arg( ( timediff + 1 )/60 );
 
         return i18n( "0" );
     }
@@ -141,7 +137,7 @@ namespace Amarok
     {
         if( reverse )
         {
-            if( !str.startsWith( "the ", Qt::CaseInsensitive ) )
+            if( !str.startsWith( QLatin1String("the "), Qt::CaseInsensitive ) )
                 return;
 
             QString begin = str.left( 3 );
@@ -150,7 +146,7 @@ namespace Amarok
             return;
         }
 
-        if( !str.endsWith( ", the", Qt::CaseInsensitive ) )
+        if( !str.endsWith( QLatin1String(", the"), Qt::CaseInsensitive ) )
             return;
 
         QString end = str.right( 3 );
@@ -161,13 +157,13 @@ namespace Amarok
         str.truncate( newLen );
     }
 
-    QString generatePlaylistName( const Meta::TrackList tracks )
+    QString generatePlaylistName( const Meta::TrackList& tracks )
     {
-        QString datePart = KGlobal::locale()->formatDateTime( QDateTime::currentDateTime(),
-                                                              KLocale::ShortDate, true );
-        if( tracks.count() == 0 )
+        QString datePart = QLocale::system().toString( QDateTime::currentDateTime(),
+                                                       QLocale::ShortFormat );
+        if( tracks.isEmpty() )
         {
-            return i18nc( "A saved playlist with the current time (KLocale::Shortdate) added between \
+            return i18nc( "A saved playlist with the current time (KLocalizedString::Shortdate) added between \
                           the parentheses",
                           "Empty Playlist (%1)", datePart );
         }
@@ -195,7 +191,7 @@ namespace Amarok
 
         if( ( !singleArtist && !singleAlbum ) ||
             ( !artist && !album ) )
-            return i18nc( "A saved playlist with the current time (KLocale::Shortdate) added between \
+            return i18nc( "A saved playlist with the current time (KLocalizedString::Shortdate) added between \
                           the parentheses",
                           "Various Tracks (%1)", datePart );
 
@@ -231,12 +227,12 @@ namespace Amarok
                       artistPart, albumPart );
     }
 
-   KActionCollection* actionCollection()  // TODO: constify?
+    KActionCollection* actionCollection()  // TODO: constify?
     {
         if( !actionCollectionObject )
         {
-            actionCollectionObject = new KActionCollection( kapp );
-            actionCollectionObject.data()->setObjectName( "Amarok-KActionCollection" );
+            actionCollectionObject = new KActionCollection( qApp );
+            actionCollectionObject->setObjectName( QStringLiteral("Amarok-KActionCollection") );
         }
 
         return actionCollectionObject.data();
@@ -245,7 +241,7 @@ namespace Amarok
     KConfigGroup config( const QString &group )
     {
         //Slightly more useful config() that allows setting the group simultaneously
-        return KGlobal::config()->group( group );
+        return KSharedConfig::openConfig()->group( group );
     }
 
     namespace ColorScheme
@@ -272,7 +268,15 @@ namespace Amarok
     QString saveLocation( const QString &directory )
     {
         globalDirsMutex.lock();
-        QString result = KGlobal::dirs()->saveLocation( "data", QString("amarok/") + directory, true );
+        QString result = QStandardPaths::writableLocation( QStandardPaths::AppDataLocation ) + QDir::separator() + directory;
+
+        if( !result.endsWith( QDir::separator() ) )
+            result.append( QDir::separator() );
+
+        QDir dir( result );
+        if( !dir.exists() )
+            dir.mkpath( QStringLiteral( "." ) );
+
         globalDirsMutex.unlock();
         return result;
     }
@@ -292,17 +296,17 @@ namespace Amarok
         QString result = path;
 
         // German umlauts
-        result.replace( QChar(0x00e4), "ae" ).replace( QChar(0x00c4), "Ae" );
-        result.replace( QChar(0x00f6), "oe" ).replace( QChar(0x00d6), "Oe" );
-        result.replace( QChar(0x00fc), "ue" ).replace( QChar(0x00dc), "Ue" );
-        result.replace( QChar(0x00df), "ss" );
+        result.replace( QChar(0x00e4), QLatin1String("ae") ).replace( QChar(0x00c4), QLatin1String("Ae") );
+        result.replace( QChar(0x00f6), QLatin1String("oe") ).replace( QChar(0x00d6), QLatin1String("Oe") );
+        result.replace( QChar(0x00fc), QLatin1String("ue") ).replace( QChar(0x00dc), QLatin1String("Ue") );
+        result.replace( QChar(0x00df), QLatin1String("ss") );
 
         // other special cases
-        result.replace( QChar(0x00C6), "AE" );
-        result.replace( QChar(0x00E6), "ae" );
+        result.replace( QChar(0x00C6), QLatin1String("AE") );
+        result.replace( QChar(0x00E6), QLatin1String("ae") );
 
-        result.replace( QChar(0x00D8), "OE" );
-        result.replace( QChar(0x00F8), "oe" );
+        result.replace( QChar(0x00D8), QLatin1String("OE") );
+        result.replace( QChar(0x00F8), QLatin1String("oe") );
 
         // normalize in a form where accents are separate characters
         result = result.normalized( QString::NormalizationForm_D );
@@ -333,6 +337,9 @@ namespace Amarok
 
     QString vfatPath( const QString &path, PathSeparatorBehaviour behaviour )
     {
+        if( path.isEmpty() )
+            return QString();
+
         QString s = path;
 
         QChar separator = ( behaviour == AutoBehaviour ) ? QDir::separator() : ( behaviour == UnixBehaviour ) ? '/' : '\\';
@@ -340,11 +347,11 @@ namespace Amarok
         if( behaviour == UnixBehaviour ) // we are on *nix, \ is a valid character in file or directory names, NOT the dir separator
             s.replace( '\\', '_' );
         else
-            s.replace( '/', '_' ); // on windows we have to replace / instead
+            s.replace( QLatin1Char('/'), '_' ); // on windows we have to replace / instead
 
         int start = 0;
 #ifdef Q_OS_WIN
-        // exclude the leading "C:/" from special character replecement in the loop below
+        // exclude the leading "C:/" from special character replacement in the loop below
         // bug 279560, bug 302251
         if( QDir::isAbsolutePath( s ) )
             start = 3;
@@ -368,22 +375,22 @@ namespace Amarok
         if( len == 3 || (len > 3 && s[3] == '.') )
         {
             QString l = s.left(3).toLower();
-            if( l=="aux" || l=="con" || l=="nul" || l=="prn" )
+            if( l==QLatin1String("aux") || l==QLatin1String("con") || l==QLatin1String("nul") || l==QLatin1String("prn") )
                 s = '_' + s;
         }
         else if( len == 4 || (len > 4 && s[4] == '.') )
         {
             QString l = s.left(3).toLower();
             QString d = s.mid(3,1);
-            if( (l=="com" || l=="lpt") &&
-                    (d=="0" || d=="1" || d=="2" || d=="3" || d=="4" ||
-                     d=="5" || d=="6" || d=="7" || d=="8" || d=="9") )
+            if( (l==QLatin1String("com") || l==QLatin1String("lpt")) &&
+                    (d==QLatin1String("0") || d==QLatin1String("1") || d==QLatin1String("2") || d==QLatin1String("3") || d==QLatin1String("4") ||
+                     d==QLatin1String("5") || d==QLatin1String("6") || d==QLatin1String("7") || d==QLatin1String("8") || d==QLatin1String("9")) )
                 s = '_' + s;
         }
 
         // "clock$" is only allowed WITH extension, according to:
         // http://en.wikipedia.org/w/index.php?title=Filename&oldid=303934888#Comparison_of_file_name_limitations
-        if( QString::compare( s, "clock$", Qt::CaseInsensitive ) == 0 )
+        if( QString::compare( s, QStringLiteral("clock$"), Qt::CaseInsensitive ) == 0 )
             s = '_' + s;
 
         /* max path length of Windows API */
@@ -413,7 +420,7 @@ namespace Amarok
         }
 
         /* correct trailing spaces in file name itself, not needed for dots */
-        int extensionIndex = s.lastIndexOf( '.' );
+        int extensionIndex = s.lastIndexOf( QLatin1Char('.') );
         if( ( s.length() > 1 ) &&  ( extensionIndex > 0 ) )
             if( s.at(extensionIndex - 1) == ' ' )
                 s[extensionIndex - 1] = '_';
@@ -427,9 +434,16 @@ namespace Amarok
         #define AMAROK_LOGO_CACHE_KEY QLatin1String("AmarokSemiTransparentLogo")+QString::number(dim)
         if( !QPixmapCache::find( AMAROK_LOGO_CACHE_KEY, &logo ) )
         {
-            QImage amarokIcon = KIcon( QLatin1String("amarok") ).pixmap( dim, dim ).toImage();
-            KIconEffect::toGray( amarokIcon, 1 );
-            KIconEffect::semiTransparent( amarokIcon );
+            QImage amarokIcon = QIcon::fromTheme( QStringLiteral("amarok") ).pixmap( dim, dim ).toImage();
+            amarokIcon = amarokIcon.convertToFormat( QImage::Format_ARGB32 );
+            QRgb *data = reinterpret_cast<QRgb*>( amarokIcon.bits() );
+            QRgb *end = data + amarokIcon.byteCount() / 4;
+            while(data != end)
+            {
+                unsigned char gray = qGray(*data);
+                *data = qRgba(gray, gray, gray, 127);
+                ++data;
+            }
             logo = QPixmap::fromImage( amarokIcon );
             QPixmapCache::insert( AMAROK_LOGO_CACHE_KEY, logo );
         }
