@@ -25,10 +25,9 @@
 #undef KDE_NO_DEBUG_OUTPUT
 
 #include "core/amarokcore_export.h"
-
-#include <kdebug.h>
-
+#include <QDebug>
 #include <QMutex>
+#include <QVariant>
 
 // BEGIN: DEBUG_ASSERT
 /**
@@ -69,11 +68,7 @@
 #define DEBUG_ASSERT_STRINGIFY(x) DEBUG_ASSERT_STRINGIFY_INTERNAL(x)
 // END__: DEBUG_ASSERT
 
-#if QT_VERSION >= 0x040700
 # include <QElapsedTimer>
-#else
-# include <QTime>
-#endif
 
 // Platform specific macros
 #ifdef _WIN32
@@ -121,7 +116,7 @@
  */
 namespace Debug
 {
-    extern AMAROK_CORE_EXPORT QMutex mutex;
+    extern AMAROKCORE_EXPORT QMutex mutex;
 
     // from kdebug.h
     enum DebugLevel {
@@ -131,12 +126,12 @@ namespace Debug
         KDEBUG_FATAL = 3
     };
 
-    AMAROK_CORE_EXPORT QDebug dbgstream( DebugLevel level = KDEBUG_INFO );
-    AMAROK_CORE_EXPORT bool debugEnabled();
-    AMAROK_CORE_EXPORT bool debugColorEnabled();
-    AMAROK_CORE_EXPORT void setDebugEnabled( bool enable );
-    AMAROK_CORE_EXPORT void setColoredDebug( bool enable );
-    AMAROK_CORE_EXPORT QString indent();
+    AMAROKCORE_EXPORT QDebug dbgstream( DebugLevel level = KDEBUG_INFO );
+    AMAROKCORE_EXPORT bool debugEnabled();
+    AMAROKCORE_EXPORT bool debugColorEnabled();
+    AMAROKCORE_EXPORT void setDebugEnabled( bool enable );
+    AMAROKCORE_EXPORT void setColoredDebug( bool enable );
+    AMAROKCORE_EXPORT QString indent();
 
     static inline QDebug dbgstreamwrapper( DebugLevel level ) {
 #ifdef DEBUG_PREFIX
@@ -151,7 +146,7 @@ namespace Debug
     static inline QDebug error()   { return dbgstreamwrapper( KDEBUG_ERROR ); }
     static inline QDebug fatal()   { return dbgstreamwrapper( KDEBUG_FATAL ); }
 
-    AMAROK_CORE_EXPORT void perfLog( const QString &message, const QString &func );
+    AMAROKCORE_EXPORT void perfLog( const QString &message, const QString &func );
 }
 
 using Debug::debug;
@@ -160,10 +155,10 @@ using Debug::error;
 using Debug::fatal;
 
 /// Standard function announcer
-#define DEBUG_FUNC_INFO { Debug::mutex.lock(); kDebug() << Debug::indent() ; Debug::mutex.unlock(); }
+#define DEBUG_FUNC_INFO { Debug::mutex.lock(); qDebug() << Debug::indent() ; Debug::mutex.unlock(); }
 
 /// Announce a line
-#define DEBUG_LINE_INFO { Debug::mutex.lock(); kDebug() << Debug::indent() << "Line: " << __LINE__; Debug::mutex.unlock(); }
+#define DEBUG_LINE_INFO { Debug::mutex.lock(); qDebug() << Debug::indent() << "Line: " << __LINE__; Debug::mutex.unlock(); }
 
 /// Convenience macro for making a standard Debug::Block
 #define DEBUG_BLOCK Debug::Block uniquelyNamedStackAllocatedStandardBlock( __PRETTY_FUNCTION__ );
@@ -206,15 +201,12 @@ namespace Debug
     class Block
     {
     public:
-        AMAROK_CORE_EXPORT Block( const char *name );
-        AMAROK_CORE_EXPORT ~Block();
+        AMAROKCORE_EXPORT explicit Block( const char *name );
+        AMAROKCORE_EXPORT ~Block();
 
     private:
-#if QT_VERSION >= 0x040700
         QElapsedTimer m_startTime;
-#else
-        QTime m_startTime;
-#endif
+
         const char *m_label;
         int m_color;
     };
@@ -239,13 +231,8 @@ namespace Debug
      *     app: Stamp: 2
      *
      */
-    AMAROK_CORE_EXPORT void stamp();
-}
+    AMAROKCORE_EXPORT void stamp();
 
-#include <QVariant>
-
-namespace Debug
-{
     /**
      * @class Debug::List
      * @short You can pass anything to this and it will output it as a list
@@ -256,12 +243,12 @@ namespace Debug
     typedef QList<QVariant> List;
 }
 
-template<class T> class KSharedPtr;
+template<class T> class AmarokSharedPointer;
 
 template<class T> QDebug &
-operator<<( QDebug dbg, const KSharedPtr<T> &ptr )
+operator<<( QDebug dbg, const AmarokSharedPointer<T> &ptr )
 {
-    dbg.nospace() << "KSharedPtr(" << *ptr.data() << ")";
+    dbg.nospace() << "AmarokSharedPointer(" << *ptr.data() << ")";
     return dbg.space();
 }
 
