@@ -16,15 +16,15 @@
 
 #include "TranscodingOpusFormat.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 
 using namespace Transcoding;
 
 OpusFormat::OpusFormat()
 {
     m_encoder = OPUS;
-    m_fileExtension = "opus";
-    QString description1 =
+    m_fileExtension = QStringLiteral("opus");
+    const QString description1 =
         i18n( "The bitrate is a measure of the quantity of data used to represent a "
         "second of the audio track.<br>The <b>Opus</b> encoder used by Amarok supports "
         "a <a href=http://en.wikipedia.org/wiki/Variable_bitrate>variable bitrate (VBR)</a> "
@@ -81,17 +81,17 @@ OpusFormat::description() const
                   "a patent-free digital audio codec using a form of lossy data compression.");
 }
 
-KIcon
+QIcon
 OpusFormat::icon() const
 {
-    return KIcon( "audio-x-generic" );  //TODO: get a *real* icon!
+    return QIcon::fromTheme( QStringLiteral("audio-x-generic") );  //TODO: get a *real* icon!
 }
 
 QStringList
 OpusFormat::ffmpegParameters( const Configuration &configuration ) const
 {
     QStringList parameters;
-    parameters << "-acodec" << "libopus";
+    parameters << QStringLiteral("-acodec") << QStringLiteral("libopus");
     foreach( const Property &property, m_propertyList )
     {
         if( !configuration.property( property.name() ).isNull()
@@ -100,11 +100,11 @@ OpusFormat::ffmpegParameters( const Configuration &configuration ) const
             if( property.name() == "bitrate" )
             {
                 int ffmpegBitrate = toFfmpegBitrate( configuration.property( "bitrate" ).toInt() );
-                parameters << "-ab" << QString::number( ffmpegBitrate );
+                parameters << QStringLiteral("-ab") << QString::number( ffmpegBitrate );
             }
         }
     }
-    parameters << "-vn"; // no video stream or album art
+    parameters << QStringLiteral("-vn"); // no video stream or album art
     return parameters;
 }
 
@@ -117,5 +117,5 @@ OpusFormat::toFfmpegBitrate( int setting ) const
 bool
 OpusFormat::verifyAvailability( const QString &ffmpegOutput ) const
 {
-    return ffmpegOutput.contains( QRegExp( "^ .EA... opus +.*libopus" ) );
+    return ffmpegOutput.contains( QRegExp( QStringLiteral("^ .EA... opus +.*libopus") ) );
 }
