@@ -25,12 +25,14 @@
 #include <QPixmapCache>
 #include <QReadWriteLock>
 #include <QReadLocker>
+#include <QStandardPaths>
 #include <QWriteLocker>
 
-#include <KStandardDirs>
-#include <KLocale>
+#include <KLocalizedString>
 
-CoverCache* CoverCache::s_instance = 0;
+#include <thread>
+
+CoverCache* CoverCache::s_instance = nullptr;
 
 CoverCache*
 CoverCache::instance()
@@ -43,7 +45,7 @@ void CoverCache::destroy()
     if( s_instance )
     {
         delete s_instance;
-        s_instance = 0;
+        s_instance = nullptr;
     }
 }
 
@@ -53,6 +55,7 @@ CoverCache::CoverCache()
 CoverCache::~CoverCache()
 {
     m_lock.lockForWrite();
+    m_lock.unlock();
 }
 
 void
@@ -112,9 +115,10 @@ CoverCache::getCover( const Meta::AlbumPtr &album, int size ) const
         }
         else
         {
-            const QPixmap orgPixmap( KStandardDirs::locate( "data", "amarok/images/nocover.png" ) );
+            const QPixmap orgPixmap( QStandardPaths::locate( QStandardPaths::GenericDataLocation, "amarok/images/nocover.png" ) );
             pixmap = orgPixmap.scaled( size, size, Qt::KeepAspectRatio, Qt::SmoothTransformation );
-            pixmap.save( cacheCoverDir.filePath( noCoverKey ), "PNG" );
+            std::thread thread( QOverload<const QString&, const char*, int>::of( &QPixmap::save ), pixmap, cacheCoverDir.filePath( noCoverKey ), "PNG", -1 );
+            thread.detach();
         }
         QPixmapCache::insert( noCoverKey, pixmap );
         return pixmap;
