@@ -17,17 +17,16 @@
 #ifndef AMAROK_COVERFETCHQUEUE_H
 #define AMAROK_COVERFETCHQUEUE_H
 
-#include "core/meta/Meta.h"
+#include "core/meta/forward_declarations.h"
 #include "CoverFetchUnit.h"
 
 #include <KIO/Job>
-#include <KUrl>
 
 #include <QByteArray>
 #include <QList>
 #include <QObject>
+#include <QUrl>
 
-class CoverFetchPayload;
 
 typedef QList< CoverFetchUnit::Ptr > CoverFetchUnitList;
 
@@ -44,8 +43,8 @@ class CoverFetchQueue : public QObject
     Q_OBJECT
 
 public:
-    CoverFetchQueue( QObject *parent = 0 );
-    ~CoverFetchQueue();
+    explicit CoverFetchQueue( QObject *parent = nullptr );
+    ~CoverFetchQueue() override;
 
     /**
      * Add an album-associated work unit to the queue.
@@ -55,7 +54,7 @@ public:
      * @param xml xml document from the cover provider. Can be empty on first
      * pass of the fetching process.
      */
-    void add( const Meta::AlbumPtr album,
+    void add( const Meta::AlbumPtr &album,
               const CoverFetch::Option opt = CoverFetch::Automatic,
               const CoverFetch::Source src = CoverFetch::LastFm,
               const QByteArray &xml = QByteArray() );
@@ -81,25 +80,22 @@ public:
     void addQuery( const QString &query,
                    const CoverFetch::Source src = CoverFetch::LastFm,
                    unsigned int page = 0,
-                   Meta::AlbumPtr album = Meta::AlbumPtr(0) );
-
-    bool contains( const Meta::AlbumPtr album ) const;
-    int index( const Meta::AlbumPtr album ) const;
-    int size() const;
-    bool isEmpty() const;
+                   const Meta::AlbumPtr &album = Meta::AlbumPtr(0) );
 
     void clear();
-    const CoverFetchUnit::Ptr take( const Meta::AlbumPtr album );
 
-public slots:
-    void remove( const CoverFetchUnit::Ptr unit );
-    void remove( const Meta::AlbumPtr album );
+public Q_SLOTS:
+    void remove( const CoverFetchUnit::Ptr &unit );
+    void remove( const Meta::AlbumPtr &album );
 
-signals:
+Q_SIGNALS:
     void fetchUnitAdded( CoverFetchUnit::Ptr );
 
 private:
-    void add( const CoverFetchUnit::Ptr unit );
+    void add( const CoverFetchUnit::Ptr &unit );
+    bool contains( const Meta::AlbumPtr &album ) const;
+    int index( const Meta::AlbumPtr &album ) const;
+    const CoverFetchUnit::Ptr take( const Meta::AlbumPtr &album );
 
     CoverFetchUnitList m_queue;
     Q_DISABLE_COPY( CoverFetchQueue )
