@@ -19,39 +19,37 @@
 #include "CoverFetchUnit.h"
 
 #include "core/support/Amarok.h"
+#include "core/support/Debug.h"
 
 #include <QRegExp>
 #include <QSet>
+#include <QUrlQuery>
 #include <QXmlStreamReader>
 
-#include "core/support/Debug.h"
 #include <KLocalizedString>
 
 /*
  * CoverFetchUnit
  */
 
-CoverFetchUnit::CoverFetchUnit( Meta::AlbumPtr album,
+CoverFetchUnit::CoverFetchUnit( const Meta::AlbumPtr &album,
                                 const CoverFetchPayload *payload,
                                 CoverFetch::Option opt )
-    : QSharedData()
-    , m_album( album )
+    : m_album( album )
     , m_options( opt )
     , m_payload( payload )
 {
 }
 
 CoverFetchUnit::CoverFetchUnit( const CoverFetchPayload *payload, CoverFetch::Option opt )
-    : QSharedData()
-    , m_album( payload->album() )
+    : m_album( payload->album() )
     , m_options( opt )
     , m_payload( payload )
 {
 }
 
 CoverFetchUnit::CoverFetchUnit( const CoverFetchSearchPayload *payload )
-    : QSharedData()
-    , m_album( payload->album() )
+    : m_album( payload->album() )
     , m_options( CoverFetch::WildInteractive )
     , m_payload( payload )
 {
@@ -125,7 +123,7 @@ bool CoverFetchUnit::operator!=( const CoverFetchUnit &other ) const
  * CoverFetchPayload
  */
 
-CoverFetchPayload::CoverFetchPayload( const Meta::AlbumPtr album,
+CoverFetchPayload::CoverFetchPayload( const Meta::AlbumPtr &album,
                                       CoverFetchPayload::Type type,
                                       CoverFetch::Source src )
     : m_src( src )
@@ -204,7 +202,7 @@ CoverFetchPayload::isPrepared() const
  * CoverFetchInfoPayload
  */
 
-CoverFetchInfoPayload::CoverFetchInfoPayload( const Meta::AlbumPtr album, const CoverFetch::Source src )
+CoverFetchInfoPayload::CoverFetchInfoPayload( const Meta::AlbumPtr &album, const CoverFetch::Source src )
     : CoverFetchPayload( album, CoverFetchPayload::Info, src )
 {
     prepareUrls();
@@ -231,7 +229,7 @@ CoverFetchInfoPayload::~CoverFetchInfoPayload()
 void
 CoverFetchInfoPayload::prepareUrls()
 {
-    KUrl url;
+    QUrl url;
     CoverFetch::Metadata metadata;
 
     switch( m_src )
@@ -241,14 +239,16 @@ CoverFetchInfoPayload::prepareUrls()
         url.setScheme( "http" );
         url.setHost( "ws.audioscrobbler.com" );
         url.setPath( "/2.0/" );
-        url.addQueryItem( "api_key", Amarok::lastfmApiKey() );
-        url.addQueryItem( "album", sanitizeQuery( album()->name() ) );
+        QUrlQuery query;
+        query.addQueryItem( "api_key", Amarok::lastfmApiKey() );
+        query.addQueryItem( "album", sanitizeQuery( album()->name() ) );
 
         if( album()->hasAlbumArtist() )
         {
-            url.addQueryItem( "artist", sanitizeQuery( album()->albumArtist()->name() ) );
+            query.addQueryItem( "artist", sanitizeQuery( album()->albumArtist()->name() ) );
         }
-        url.addQueryItem( "method", method() );
+        query.addQueryItem( "method", method() );
+        url.setQuery( query );
 
         metadata[ "source" ] = "Last.fm";
         metadata[ "method" ] = method();
@@ -287,16 +287,18 @@ CoverFetchInfoPayload::prepareDiscogsUrls( const QByteArray &data )
                             continue;
                         if( xml.name() == "uri" )
                         {
-                            KUrl releaseUrl( xml.readElementText() );
-                            QString releaseStr = releaseUrl.url( KUrl::RemoveTrailingSlash );
-                            QString releaseId = releaseStr.split( '/' ).last();
+                            QUrl releaseUrl( xml.readElementText() );
+                            QString releaseStr = releaseUrl.adjusted(QUrl::StripTrailingSlash).toString();
+                            QString releaseId = releaseStr.split( QLatin1Char('/') ).last();
 
-                            KUrl url;
+                            QUrl url;
                             url.setScheme( "http" );
                             url.setHost( "www.discogs.com" );
                             url.setPath( "/release/" + releaseId );
-                            url.addQueryItem( "api_key", Amarok::discogsApiKey() );
-                            url.addQueryItem( "f", "xml" );
+                            QUrlQuery query;
+                            query.addQueryItem( "api_key", Amarok::discogsApiKey() );
+                            query.addQueryItem( "f", "xml" );
+                            url.setQuery( query );
 
                             CoverFetch::Metadata metadata;
                             metadata[ "source" ] = "Discogs";
@@ -322,7 +324,7 @@ CoverFetchInfoPayload::prepareDiscogsUrls( const QByteArray &data )
 CoverFetchSearchPayload::CoverFetchSearchPayload( const QString &query,
                                                   const CoverFetch::Source src,
                                                   unsigned int page,
-                                                  Meta::AlbumPtr album )
+                                                  const Meta::AlbumPtr &album )
     : CoverFetchPayload( album, CoverFetchPayload::Search, src )
     , m_page( page )
     , m_query( query )
@@ -343,7 +345,8 @@ CoverFetchSearchPayload::query() const
 void
 CoverFetchSearchPayload::prepareUrls()
 {
-    KUrl url;
+    QUrl url;
+    QUrlQuery query;
     url.setScheme( "http" );
     CoverFetch::Metadata metadata;
 
@@ -353,11 +356,11 @@ CoverFetchSearchPayload::prepareUrls()
     case CoverFetch::LastFm:
         url.setHost( "ws.audioscrobbler.com" );
         url.setPath( "/2.0/" );
-        url.addQueryItem( "api_key", Amarok::lastfmApiKey() );
-        url.addQueryItem( "limit", QString::number( 20 ) );
-        url.addQueryItem( "page", QString::number( m_page ) );
-        url.addQueryItem( "album", sanitizeQuery( m_query ) );
-        url.addQueryItem( "method", method() );
+        query.addQueryItem( "api_key", Amarok::lastfmApiKey() );
+        query.addQueryItem( "limit", QString::number( 20 ) );
+        query.addQueryItem( "page", QString::number( m_page ) );
+        query.addQueryItem( "album", sanitizeQuery( m_query ) );
+        query.addQueryItem( "method", method() );
         metadata[ "source" ] = "Last.fm";
         metadata[ "method" ] = method();
         break;
@@ -366,11 +369,11 @@ CoverFetchSearchPayload::prepareUrls()
         debug() << "Setting up a Discogs fetch";
         url.setHost( "www.discogs.com" );
         url.setPath( "/search" );
-        url.addQueryItem( "api_key", Amarok::discogsApiKey() );
-        url.addQueryItem( "page", QString::number( m_page + 1 ) );
-        url.addQueryItem( "type", "all" );
-        url.addQueryItem( "q", sanitizeQuery( m_query ) );
-        url.addQueryItem( "f", "xml" );
+        query.addQueryItem( "api_key", Amarok::discogsApiKey() );
+        query.addQueryItem( "page", QString::number( m_page + 1 ) );
+        query.addQueryItem( "type", "all" );
+        query.addQueryItem( "q", sanitizeQuery( m_query ) );
+        query.addQueryItem( "f", "xml" );
         debug() << "Discogs Url: " << url;
         metadata[ "source" ] = "Discogs";
         break;
@@ -378,13 +381,14 @@ CoverFetchSearchPayload::prepareUrls()
     case CoverFetch::Google:
         url.setHost( "images.google.com" );
         url.setPath( "/images" );
-        url.addQueryItem( "q", sanitizeQuery( m_query ) );
-        url.addQueryItem( "gbv", QChar( '1' ) );
-        url.addQueryItem( "filter", QChar( '1' ) );
-        url.addQueryItem( "start", QString::number( 20 * m_page ) );
+        query.addQueryItem( "q", sanitizeQuery( m_query ) );
+        query.addQueryItem( "gbv", QChar( '1' ) );
+        query.addQueryItem( "filter", QChar( '1' ) );
+        query.addQueryItem( "start", QString::number( 20 * m_page ) );
         metadata[ "source" ] = "Google";
         break;
     }
+    url.setQuery( query );
     debug() << "Fetching From URL: " << url;
     if( url.isValid() )
         m_urls.insert( url, metadata );
@@ -394,7 +398,7 @@ CoverFetchSearchPayload::prepareUrls()
  * CoverFetchArtPayload
  */
 
-CoverFetchArtPayload::CoverFetchArtPayload( const Meta::AlbumPtr album,
+CoverFetchArtPayload::CoverFetchArtPayload( const Meta::AlbumPtr &album,
                                             const CoverFetch::ImageSize size,
                                             const CoverFetch::Source src,
                                             bool wild )
@@ -447,6 +451,7 @@ CoverFetchArtPayload::prepareUrls()
     }
 
     QXmlStreamReader xml( m_xml );
+    xml.setNamespaceProcessing( false );
     switch( m_src )
     {
     default:
@@ -460,7 +465,7 @@ CoverFetchArtPayload::prepareUrls()
 
     if( xml.hasError() )
     {
-        debug() << QString( "Error occurred when preparing %1 urls for %2: %3" )
+        warning() << QString( "Error occurred when preparing %1 urls for %2: %3" )
             .arg( sourceString(), (album() ? album()->name() : "'unknown'"), xml.errorString() );
         debug() << urls();
     }
@@ -507,9 +512,9 @@ CoverFetchArtPayload::prepareDiscogsUrls( QXmlStreamReader &xml )
                     if( xml.name() == "image" )
                     {
                         const QXmlStreamAttributes &attr = xml.attributes();
-                        const KUrl thburl( attr.value( "uri150" ).toString() );
-                        const KUrl uri( attr.value( "uri" ).toString() );
-                        const KUrl url = (m_size == CoverFetch::ThumbSize) ? thburl : uri;
+                        const QUrl thburl( attr.value( "uri150" ).toString() );
+                        const QUrl uri( attr.value( "uri" ).toString() );
+                        const QUrl url = (m_size == CoverFetch::ThumbSize) ? thburl : uri;
                         if( !url.isValid() )
                             continue;
 
@@ -545,14 +550,15 @@ CoverFetchArtPayload::prepareGoogleUrls()
 
     while( ( (pos = rx.indexIn( html, pos ) ) != -1 ) )
     {
-        KUrl url( "http://www.google.com" + rx.cap( 1 ) );
+        QUrl url( "http://www.google.com" + rx.cap( 1 ) );
+        QUrlQuery query( url.query() );
 
         CoverFetch::Metadata metadata;
-        metadata[ "width" ] = url.queryItemValue( "w" );
-        metadata[ "height" ] = url.queryItemValue( "h" );
-        metadata[ "size" ] = url.queryItemValue( "sz" );
-        metadata[ "imgrefurl" ] = url.queryItemValue( "imgrefurl" );
-        metadata[ "normalarturl" ] = url.queryItemValue("imgurl");
+        metadata[ "width" ] = query.queryItemValue( "w" );
+        metadata[ "height" ] = query.queryItemValue( "h" );
+        metadata[ "size" ] = query.queryItemValue( "sz" );
+        metadata[ "imgrefurl" ] = query.queryItemValue( "imgrefurl" );
+        metadata[ "normalarturl" ] = query.queryItemValue("imgurl");
         metadata[ "source" ] = "Google";
 
         if( !rx.cap( 2 ).isEmpty() )
@@ -563,10 +569,10 @@ CoverFetchArtPayload::prepareGoogleUrls()
         {
         default:
         case CoverFetch::ThumbSize:
-            url = KUrl( metadata.value( "thumbarturl" ) );
+            url = QUrl( metadata.value( "thumbarturl" ) );
             break;
         case CoverFetch::NormalSize:
-            url = KUrl( metadata.value( "normalarturl" ) );
+            url = QUrl( metadata.value( "normalarturl" ) );
             break;
         }
 
@@ -649,7 +655,7 @@ CoverFetchArtPayload::prepareLastFmUrls( QXmlStreamReader &xml )
         acceptableSizes << "extralarge" << "large";
         metadata[ "normalarturl" ] = firstAvailableValue( acceptableSizes, coverUrlHash );
 
-        KUrl url( m_size == CoverFetch::ThumbSize ? metadata["thumbarturl"] : metadata["normalarturl"] );
+        QUrl url( m_size == CoverFetch::ThumbSize ? metadata["thumbarturl"] : metadata["normalarturl"] );
         if( url.isValid() )
             m_urls.insert( url , metadata );
     }
