@@ -21,7 +21,7 @@
 #include "core/meta/Observer.h"
 #include "covermanager/CoverFetcher.h"
 
-#include <KDialog>
+#include <QDialog>
 
 #include <QDropEvent>
 #include <QLabel>
@@ -36,17 +36,16 @@ class CoverViewItem;
 class QTreeWidget;
 class QTreeWidgetItem;
 class KSqueezedTextLabel;
-class KPushButton;
-class KMenu;
+class QPushButton;
+class QMenu;
 class QLabel;
 class CoverView;
-class KHBox;
-class QProgressBar;
+class QHBoxLayout;
 class QHBoxLayout;
 class QColorGroup;
 class QSplitter;
 
-class CoverManager : public KDialog, public Meta::Observer
+class CoverManager : public QDialog, public Meta::Observer
 {
         Q_OBJECT
 
@@ -54,33 +53,34 @@ class CoverManager : public KDialog, public Meta::Observer
         static bool s_constructed;
 
     public:
-        CoverManager( QWidget *parent = 0 );
-       ~CoverManager();
+        explicit CoverManager( QWidget *parent = nullptr );
+       ~CoverManager() override;
 
         static bool isConstructed() { return s_constructed; }
         static CoverManager *instance() { return s_instance; }
 
-        static void showOnce( const QString &artist = QString(), QWidget* parent = 0 );
-        static void viewCover( Meta::AlbumPtr album, QWidget* parent = 0 );
+        static void showOnce( const QString &artist = QString(), QWidget* parent = nullptr );
+        static void viewCover( const Meta::AlbumPtr &album, QWidget* parent = nullptr );
 
-        void setStatusText( QString text );
+        void setStatusText(const QString &text );
 
         // Reimplemented from Meta::Observer
         using Observer::metadataChanged;
-        void metadataChanged( Meta::AlbumPtr album );
+        void metadataChanged( const Meta::AlbumPtr &album ) override;
 
-    public slots:
+    public Q_SLOTS:
         void updateStatusBar();
+        void delayedDestruct();
 
     private:
         enum View { AllAlbums = 0, AlbumsWithCover, AlbumsWithoutCover };
 
-    private slots:
+    private Q_SLOTS:
         void slotArtistQueryResult( Meta::ArtistList artists );
         void slotContinueConstruction();
 
         void slotArtistSelected();
-        void slotAlbumQueryResult( Meta::AlbumList albums );
+        void slotAlbumQueryResult( const Meta::AlbumList &albums );
         void slotAlbumFilterTriggered( QAction *action );
         void slotArtistQueryDone();
         void coverItemClicked( QListWidgetItem *item );
@@ -109,9 +109,9 @@ class CoverManager : public KDialog, public Meta::Observer
         //hack to have something to show while the real list is hidden when loading thumbnails
         CoverView        *m_coverViewSpacer;
         Amarok::LineEdit *m_searchEdit;
-        KPushButton      *m_fetchButton;
-        KPushButton      *m_viewButton;
-        KMenu            *m_viewMenu;
+        QPushButton      *m_fetchButton;
+        QPushButton      *m_viewButton;
+        QMenu            *m_viewMenu;
         View              m_currentView;
 
         Meta::ArtistList m_artistList;
@@ -150,12 +150,12 @@ class CoverView : public QListWidget
     Q_OBJECT
 
     public:
-        explicit CoverView( QWidget *parent = 0, const char *name = 0, Qt::WFlags f = 0 );
+        explicit CoverView( QWidget *parent = nullptr, const char *name = 0, Qt::WindowFlags f = {} );
 
     protected:
-        void contextMenuEvent( QContextMenuEvent *event );
+        void contextMenuEvent( QContextMenuEvent *event ) override;
 
-    private slots:
+    private Q_SLOTS:
         void setStatusText( QListWidgetItem *item );
 };
 
@@ -163,7 +163,7 @@ class CoverViewItem : public QListWidgetItem
 {
     public:
         CoverViewItem( QListWidget *parent, Meta::AlbumPtr album );
-        ~CoverViewItem();
+        ~CoverViewItem() override;
 
         void loadCover();
         bool hasCover() const;
