@@ -27,7 +27,7 @@
 #include "dynamic/DynamicModel.h"
 #include "dynamic/biases/SearchQueryBias.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 
 #include <QPainter>
 #include <QBuffer>
@@ -81,7 +81,7 @@ Dynamic::AbstractBias::clone() const
 QString
 Dynamic::AbstractBias::sName()
 {
-    return QLatin1String( "abstractBias" );
+    return QStringLiteral( "abstractBias" );
 }
 
 QString
@@ -110,9 +110,9 @@ Dynamic::AbstractBias::invalidate()
 { }
 
 void
-Dynamic::AbstractBias::replace( Dynamic::BiasPtr newBias )
+Dynamic::AbstractBias::replace( const Dynamic::BiasPtr &newBias )
 {
-    emit replaced( BiasPtr(const_cast<Dynamic::AbstractBias*>(this)), newBias );
+    Q_EMIT replaced( BiasPtr(const_cast<Dynamic::AbstractBias*>(this)), newBias );
 }
 
 // -------- RandomBias ------
@@ -126,7 +126,7 @@ Dynamic::RandomBias::~RandomBias()
 QString
 Dynamic::RandomBias::sName()
 {
-    return QLatin1String( "randomBias" );
+    return QStringLiteral( "randomBias" );
 }
 
 QString
@@ -151,7 +151,7 @@ Dynamic::RandomBias::widget( QWidget* parent )
 Dynamic::TrackSet
 Dynamic::RandomBias::matchingTracks( const Meta::TrackList& playlist,
                                      int contextCount, int finalCount,
-                                     Dynamic::TrackCollectionPtr universe ) const
+                                     const Dynamic::TrackCollectionPtr &universe ) const
 {
     Q_UNUSED( playlist );
     Q_UNUSED( contextCount );
@@ -218,7 +218,7 @@ Dynamic::AndBias::toXml( QXmlStreamWriter *writer ) const
 QString
 Dynamic::AndBias::sName()
 {
-    return QLatin1String( "andBias" );
+    return QStringLiteral( "andBias" );
 }
 
 QString
@@ -255,7 +255,7 @@ Dynamic::AndBias::paintOperator( QPainter* painter, const QRect& rect, Dynamic::
 Dynamic::TrackSet
 Dynamic::AndBias::matchingTracks( const Meta::TrackList& playlist,
                                   int contextCount, int finalCount,
-                                  Dynamic::TrackCollectionPtr universe ) const
+                                  const Dynamic::TrackCollectionPtr &universe ) const
 {
     DEBUG_BLOCK;
 debug() << "universe:" << universe.data();
@@ -309,7 +309,7 @@ Dynamic::AndBias::invalidate()
 }
 
 void
-Dynamic::AndBias::appendBias( Dynamic::BiasPtr bias )
+Dynamic::AndBias::appendBias(const BiasPtr &bias )
 {
     bool newInModel = DynamicModel::instance()->index( bias ).isValid();
     if (newInModel) {
@@ -325,18 +325,18 @@ Dynamic::AndBias::appendBias( Dynamic::BiasPtr bias )
     if( inModel )
         DynamicModel::instance()->endInsertBias();
 
-    connect( bias.data(), SIGNAL(resultReady(Dynamic::TrackSet)),
-             this,  SLOT(resultReceived(Dynamic::TrackSet)) );
-    connect( bias.data(), SIGNAL(replaced(Dynamic::BiasPtr,Dynamic::BiasPtr)),
-             this, SLOT(biasReplaced(Dynamic::BiasPtr,Dynamic::BiasPtr)) );
-    connect( bias.data(), SIGNAL(changed(Dynamic::BiasPtr)),
-             this, SLOT(biasChanged(Dynamic::BiasPtr)) );
-    emit biasAppended( bias );
+    connect( bias.data(), &Dynamic::AbstractBias::resultReady,
+             this, &AndBias::resultReceived );
+    connect( bias.data(), &Dynamic::AbstractBias::replaced,
+             this, &AndBias::biasReplaced );
+    connect( bias.data(), &Dynamic::AbstractBias::changed,
+             this, &AndBias::biasChanged );
+    Q_EMIT biasAppended( bias );
 
     // creating a shared pointer and destructing it just afterwards would
     // also destruct this object.
     // so we give the object creating this bias a chance to increment the refcount
-    emit changed( thisPtr );
+    Q_EMIT changed( thisPtr );
 }
 
 void
@@ -357,8 +357,8 @@ Dynamic::AndBias::moveBias( int from, int to )
     if( inModel )
         DynamicModel::instance()->endMoveBias();
 
-    emit biasMoved( from, to );
-    emit changed( BiasPtr( this ) );
+    Q_EMIT biasMoved( from, to );
+    Q_EMIT changed( BiasPtr( this ) );
 }
 
 
@@ -371,11 +371,11 @@ Dynamic::AndBias::resultReceived( const Dynamic::TrackSet &tracks )
     if( m_outstandingMatches < 0 )
         warning() << "Received more results than expected.";
     else if( m_outstandingMatches == 0 )
-        emit resultReady( m_tracks );
+        Q_EMIT resultReady( m_tracks );
 }
 
 void
-Dynamic::AndBias::biasReplaced( Dynamic::BiasPtr oldBias, Dynamic::BiasPtr newBias )
+Dynamic::AndBias::biasReplaced( const Dynamic::BiasPtr &oldBias, const Dynamic::BiasPtr &newBias )
 {
     DEBUG_BLOCK;
     BiasPtr thisPtr( this );
@@ -389,16 +389,16 @@ Dynamic::AndBias::biasReplaced( Dynamic::BiasPtr oldBias, Dynamic::BiasPtr newBi
     m_biases.removeAt( index );
     if( inModel )
         DynamicModel::instance()->endRemoveBias();
-    emit biasRemoved( index );
+    Q_EMIT biasRemoved( index );
 
     if( newBias )
     {
-        connect( newBias.data(), SIGNAL(resultReady(Dynamic::TrackSet)),
-                 this,  SLOT(resultReceived(Dynamic::TrackSet)) );
-        connect( newBias.data(), SIGNAL(replaced(Dynamic::BiasPtr,Dynamic::BiasPtr)),
-                 this, SLOT(biasReplaced(Dynamic::BiasPtr,Dynamic::BiasPtr)) );
-        connect( newBias.data(), SIGNAL(changed(Dynamic::BiasPtr)),
-                 this, SIGNAL(changed(Dynamic::BiasPtr)) );
+        connect( newBias.data(), &Dynamic::AbstractBias::resultReady,
+                 this, &AndBias::resultReceived );
+        connect( newBias.data(), &Dynamic::AbstractBias::replaced,
+                 this, &AndBias::biasReplaced );
+        connect( newBias.data(), &Dynamic::AbstractBias::changed,
+                 this, &AndBias::changed );
 
         if( inModel )
             DynamicModel::instance()->beginInsertBias( thisPtr, index );
@@ -407,18 +407,18 @@ Dynamic::AndBias::biasReplaced( Dynamic::BiasPtr oldBias, Dynamic::BiasPtr newBi
             DynamicModel::instance()->endInsertBias();
 
         // we don't have an bias inserted signal
-        emit biasAppended( newBias );
-        emit biasMoved( m_biases.count()-1, index );
+        Q_EMIT biasAppended( newBias );
+        Q_EMIT biasMoved( m_biases.count()-1, index );
     }
 
-    emit changed( thisPtr );
+    Q_EMIT changed( thisPtr );
 }
 
 void
-Dynamic::AndBias::biasChanged( Dynamic::BiasPtr bias )
+Dynamic::AndBias::biasChanged( const Dynamic::BiasPtr &bias )
 {
     BiasPtr thisPtr( this );
-    emit changed( thisPtr );
+    Q_EMIT changed( thisPtr );
     bool inModel = DynamicModel::instance()->index( thisPtr ).isValid();
     if( inModel )
         DynamicModel::instance()->biasChanged( bias );
@@ -433,7 +433,7 @@ Dynamic::OrBias::OrBias()
 QString
 Dynamic::OrBias::sName()
 {
-    return QLatin1String( "orBias" );
+    return QStringLiteral( "orBias" );
 }
 
 QString
@@ -463,7 +463,7 @@ Dynamic::OrBias::toString() const
 Dynamic::TrackSet
 Dynamic::OrBias::matchingTracks( const Meta::TrackList& playlist,
                                  int contextCount, int finalCount,
-                                 Dynamic::TrackCollectionPtr universe ) const
+                                 const Dynamic::TrackCollectionPtr &universe ) const
 {
     m_tracks = Dynamic::TrackSet( universe, false );
     m_outstandingMatches = 0;
@@ -508,8 +508,7 @@ Dynamic::OrBias::resultReceived( const Dynamic::TrackSet &tracks )
     if( m_outstandingMatches < 0 )
         warning() << "Received more results than expected.";
     else if( m_outstandingMatches == 0 )
-        emit resultReady( m_tracks );
+        Q_EMIT resultReady( m_tracks );
 }
 
-#include "Bias.moc"
 
