@@ -24,7 +24,7 @@
 #include "App.h"
 #include "amarokconfig.h"
 #include "core/collections/Collection.h"
-#include "core/interfaces/Logger.h"
+#include "core/logger/Logger.h"
 #include "core/meta/Meta.h"
 #include "core/support/Components.h"
 #include "core/support/Debug.h"
@@ -34,8 +34,6 @@
 #include "dynamic/DynamicModel.h"
 #include "playlist/PlaylistModelStack.h" // for The::playlist
 
-#include <ThreadWeaver/Weaver>
-
 #include <QThread>
 #include <QXmlStreamReader>
 #include <QXmlStreamWriter>
@@ -93,7 +91,7 @@ Dynamic::BiasedPlaylist::~BiasedPlaylist()
 void
 Dynamic::BiasedPlaylist::toXml( QXmlStreamWriter *writer ) const
 {
-    writer->writeTextElement( "title", m_title );
+    writer->writeTextElement( QStringLiteral("title"), m_title );
     writer->writeStartElement( m_bias->name() );
     m_bias->toXml( writer );
     writer->writeEndElement();
@@ -120,13 +118,14 @@ Dynamic::BiasedPlaylist::startSolver( int numRequested )
     {
         debug() << "assigning new m_solver";
         m_solver = new BiasSolver( numRequested, m_bias, getContext() );
-        connect( m_solver, SIGNAL(done(ThreadWeaver::Job*)), SLOT(solverFinished()) );
+        connect( m_solver, &BiasSolver::done, this, &BiasedPlaylist::solverFinished );
 
-        Amarok::Components::logger()->newProgressOperation( m_solver,
+        Amarok::Logger::newProgressOperation( m_solver,
                                                             i18n( "Generating playlist..." ), 100,
-                                                            this, SLOT(requestAbort()) );
+                                                            this, &BiasedPlaylist::requestAbort );
+
+        ThreadWeaver::Queue::instance()->enqueue( QSharedPointer<ThreadWeaver::Job>(m_solver) );
 
-        ThreadWeaver::Weaver::instance()->enqueue( m_solver );
         debug() << "called prepareToRun";
     }
     else
@@ -136,14 +135,14 @@ Dynamic::BiasedPlaylist::startSolver( int numRequested )
 void
 Dynamic::BiasedPlaylist::biasChanged()
 {
-    emit changed( this );
+    Q_EMIT changed( this );
     bool inModel = DynamicModel::instance()->index( this ).isValid();
     if( inModel )
         DynamicModel::instance()->biasChanged( m_bias );
 }
 
 void
-Dynamic::BiasedPlaylist::biasReplaced( Dynamic::BiasPtr oldBias, Dynamic::BiasPtr newBias )
+Dynamic::BiasedPlaylist::biasReplaced( const Dynamic::BiasPtr &oldBias, const Dynamic::BiasPtr &newBias )
 {
     if( oldBias && !newBias ) // don't move the last bias away from this playlist without replacement
         return;
@@ -166,12 +165,12 @@ Dynamic::BiasedPlaylist::biasReplaced( Dynamic::BiasPtr oldBias, Dynamic::BiasPt
     if( inModel )
         Dynamic::DynamicModel::instance()->endInsertBias();
 
-    connect( m_bias.data(), SIGNAL(changed(Dynamic::BiasPtr)),
-             this, SLOT(biasChanged()) );
-    connect( m_bias.data(), SIGNAL(replaced(Dynamic::BiasPtr,Dynamic::BiasPtr)),
-             this, SLOT(biasReplaced(Dynamic::BiasPtr,Dynamic::BiasPtr)) );
+    connect( m_bias.data(), &AbstractBias::changed,
+             this, &BiasedPlaylist::biasChanged );
+    connect( m_bias.data(), &AbstractBias::replaced,
+             this, &BiasedPlaylist::biasReplaced );
 
-    if( oldBias ) // don't emit a changed during construction
+    if( oldBias ) // don't Q_EMIT a changed during construction
         biasChanged();
 }
 
@@ -202,7 +201,7 @@ Dynamic::BiasedPlaylist::solverFinished()
         // remove the additional requested track
         if( list.count() > 1 )
             list.removeLast();
-        emit tracksReady( list );
+        Q_EMIT tracksReady( list );
     }
 
     m_solver->deleteLater();
