@@ -35,7 +35,7 @@
 
 #include "playlist/PlaylistActions.h"
 
-#include <KIcon>
+#include <QIcon>
 
 #include <QFile>
 #include <QBuffer>
@@ -45,21 +45,19 @@
 #include <QXmlStreamReader>
 #include <QXmlStreamWriter>
 
-#include <klocale.h>
-
 /* general note:
    For the sake of this file we are handling a modified active playlist as
    a different one.
 */
 
-Dynamic::DynamicModel* Dynamic::DynamicModel::s_instance = 0;
+Dynamic::DynamicModel* Dynamic::DynamicModel::s_instance = nullptr;
 
 Dynamic::DynamicModel*
 Dynamic::DynamicModel::instance()
 {
     if( !s_instance )
     {
-        s_instance = new DynamicModel( App::instance() );
+        s_instance = new DynamicModel( pApp );
         s_instance->loadPlaylists();
     }
     return s_instance;
@@ -85,13 +83,13 @@ Dynamic::DynamicModel::setActivePlaylist( int index )
     if( m_activePlaylistIndex == index )
         return m_playlists[m_activePlaylistIndex];
 
-    emit dataChanged( this->index( m_activePlaylistIndex, 0 ),
+    Q_EMIT dataChanged( this->index( m_activePlaylistIndex, 0 ),
                       this->index( m_activePlaylistIndex, 0 ) );
     m_activePlaylistIndex = index;
-    emit dataChanged( this->index( m_activePlaylistIndex, 0 ),
+    Q_EMIT dataChanged( this->index( m_activePlaylistIndex, 0 ),
                       this->index( m_activePlaylistIndex, 0 ) );
 
-    emit activeChanged( index );
+    Q_EMIT activeChanged( index );
     savePlaylists(); // save in between to prevent loosing too much in case of a crash
 
     return m_playlists[m_activePlaylistIndex];
@@ -163,7 +161,7 @@ Dynamic::DynamicModel::insertPlaylist( int index, Dynamic::DynamicPlaylist* play
 }
 
 QModelIndex
-Dynamic::DynamicModel::insertBias( int row, const QModelIndex &parentIndex, Dynamic::BiasPtr bias )
+Dynamic::DynamicModel::insertBias( int row, const QModelIndex &parentIndex, const Dynamic::BiasPtr &bias )
 {
     QObject* o = static_cast<QObject*>(parentIndex.internalPointer());
     BiasedPlaylist* parentPlaylist = qobject_cast<BiasedPlaylist*>(o);
@@ -259,9 +257,9 @@ Dynamic::DynamicModel::data( const QModelIndex& i, int role ) const
 
         case Qt::DecorationRole:
             if( activePlaylist() == indexPlaylist )
-                return KIcon( "amarok_playlist" );
+                return QIcon::fromTheme( QStringLiteral("amarok_playlist") );
             else
-                return KIcon( "amarok_playlist_clear" );
+                return QIcon::fromTheme( QStringLiteral("amarok_playlist_clear") );
 
         case Qt::FontRole:
             {
@@ -287,7 +285,7 @@ Dynamic::DynamicModel::data( const QModelIndex& i, int role ) const
         {
         case Qt::DisplayRole:
             return QVariant(indexBias->toString());
-            // return QVariant(QString("and: ")+indexBias->toString());
+            // return QVariant(QStringLiteral("and: ")+indexBias->toString());
 
         case Qt::ToolTipRole:
             {
@@ -433,7 +431,7 @@ Dynamic::DynamicModel::index( int row, int column, const QModelIndex& parent ) c
 }
 
 QModelIndex
-Dynamic::DynamicModel::parent( int row, BiasedPlaylist* list, BiasPtr bias ) const
+Dynamic::DynamicModel::parent( int row, BiasedPlaylist* list, const BiasPtr &bias ) const
 {
     if( list->bias() == bias )
         return createIndex( row, 0, list );
@@ -441,7 +439,7 @@ Dynamic::DynamicModel::parent( int row, BiasedPlaylist* list, BiasPtr bias ) con
 }
 
 QModelIndex
-Dynamic::DynamicModel::parent( int row, BiasPtr parent, BiasPtr bias ) const
+Dynamic::DynamicModel::parent( int row, const BiasPtr &parent, const BiasPtr &bias ) const
 {
     Dynamic::AndBias* andBias = qobject_cast<Dynamic::AndBias*>(parent.data());
     if( !andBias )
@@ -525,7 +523,7 @@ QStringList
 Dynamic::DynamicModel::mimeTypes() const
 {
     QStringList types;
-    types << "application/amarok.biasModel.index";
+    types << QStringLiteral("application/amarok.biasModel.index");
     return types;
 }
 
@@ -546,7 +544,7 @@ Dynamic::DynamicModel::mimeData(const QModelIndexList &indexes) const
     QDataStream stream( &bytes, QIODevice::WriteOnly );
     serializeIndex( &stream, index );
     QMimeData *mimeData = new QMimeData();
-    mimeData->setData("application/amarok.biasModel.index", bytes);
+    mimeData->setData(QStringLiteral("application/amarok.biasModel.index"), bytes);
     return mimeData;
 }
 
@@ -562,10 +560,10 @@ Dynamic::DynamicModel::dropMimeData(const QMimeData *data,
     if( action == Qt::IgnoreAction )
         return true;
 
-    if( data->hasFormat("application/amarok.biasModel.index") )
+    if( data->hasFormat(QStringLiteral("application/amarok.biasModel.index")) )
     {
         // get the source index from the mime data
-        QByteArray bytes = data->data("application/amarok.biasModel.index");
+        QByteArray bytes = data->data(QStringLiteral("application/amarok.biasModel.index"));
         QDataStream stream( &bytes, QIODevice::ReadOnly );
         QModelIndex index = unserializeIndex( &stream );
 
@@ -629,7 +627,7 @@ debug() << "dropMimeData action" << action;
 
 
 QModelIndex
-Dynamic::DynamicModel::index( Dynamic::BiasPtr bias ) const
+Dynamic::DynamicModel::index( const Dynamic::BiasPtr &bias ) const
 {
     QModelIndex res;
 
@@ -674,13 +672,13 @@ Dynamic::DynamicModel::index( Dynamic::DynamicPlaylist* playlist ) const
 void
 Dynamic::DynamicModel::savePlaylists()
 {
-    savePlaylists( "dynamic.xml" );
+    savePlaylists( QStringLiteral("dynamic.xml") );
 }
 
 void
 Dynamic::DynamicModel::loadPlaylists()
 {
-    loadPlaylists( "dynamic.xml" );
+    loadPlaylists( QStringLiteral("dynamic.xml") );
 }
 
 void
@@ -799,13 +797,13 @@ Dynamic::DynamicModel::savePlaylists( const QString &filename )
     QXmlStreamWriter xmlWriter( &xmlFile );
     xmlWriter.setAutoFormatting( true );
     xmlWriter.writeStartDocument();
-    xmlWriter.writeStartElement("biasedPlaylists");
-    xmlWriter.writeAttribute("version", "2" );
-    xmlWriter.writeAttribute("current", QString::number( m_activePlaylistIndex ) );
+    xmlWriter.writeStartElement(QStringLiteral("biasedPlaylists"));
+    xmlWriter.writeAttribute(QStringLiteral("version"), QStringLiteral("2") );
+    xmlWriter.writeAttribute(QStringLiteral("current"), QString::number( m_activePlaylistIndex ) );
 
     foreach( Dynamic::DynamicPlaylist *playlist, m_playlists )
     {
-        xmlWriter.writeStartElement("playlist");
+        xmlWriter.writeStartElement(QStringLiteral("playlist"));
         playlist->toXml( &xmlWriter );
         xmlWriter.writeEndElement();
     }
@@ -891,7 +889,7 @@ Dynamic::DynamicModel::loadPlaylists( const QString &filename )
 
     m_activePlaylistIndex = qBound( 0, newPlaylistIndex, m_playlists.count()-1 );
 
-    emit activeChanged( m_activePlaylistIndex );
+    Q_EMIT activeChanged( m_activePlaylistIndex );
     endResetModel();
 
     return true;
@@ -910,18 +908,18 @@ Dynamic::DynamicModel::initPlaylists()
 
     // -- create the empty default random playlists
 
-    // - first one rantom playlist
+    // - first one random playlist
     playlist = new Dynamic::BiasedPlaylist( this );
     insertPlaylist( 0, playlist );
 
     // - a playlist demonstrating the SearchQueryBias
     playlist = new Dynamic::BiasedPlaylist( this );
     playlist->setTitle( i18n("Rock and Pop") );
-    QString query = Meta::shortI18nForField( Meta::valGenre ) + ':' + i18n( "Rock" );
+    QString query = Meta::shortI18nForField( Meta::valGenre ) + QLatin1Char(':') + i18n( "Rock" );
     /* following cannot be currently translated, see ExpressionParser::isAdvancedExpression()
      * and ExpressionParser::finishedToken() */
-    query += " AND ";
-    query += Meta::shortI18nForField( Meta::valGenre ) + ':' + i18n( "Pop" );
+    query += QLatin1String(" AND ");
+    query += Meta::shortI18nForField( Meta::valGenre ) + QLatin1Char(':') + i18n( "Pop" );
     playlist->bias()->replace( Dynamic::BiasPtr( new Dynamic::SearchQueryBias( query ) ) );
     insertPlaylist( 1, playlist );
 
@@ -967,7 +965,7 @@ Dynamic::DynamicModel::initPlaylists()
 
     m_activePlaylistIndex = 0;
 
-    emit activeChanged( m_activePlaylistIndex );
+    Q_EMIT activeChanged( m_activePlaylistIndex );
     endResetModel();
 }
 
@@ -1011,7 +1009,7 @@ Dynamic::DynamicModel::cloneList( Dynamic::BiasedPlaylist* list )
 
     // write the list
     QXmlStreamWriter xmlWriter( &buffer );
-    xmlWriter.writeStartElement( QLatin1String("playlist") );
+    xmlWriter.writeStartElement( QStringLiteral("playlist") );
     list->toXml( &xmlWriter );
     xmlWriter.writeEndElement();
 
@@ -1034,14 +1032,14 @@ Dynamic::DynamicModel::playlistChanged( Dynamic::DynamicPlaylist* p )
 {
     DEBUG_BLOCK;
     QModelIndex index = this->index( p );
-    emit dataChanged( index, index );
+    Q_EMIT dataChanged( index, index );
 }
 
 void
-Dynamic::DynamicModel::biasChanged( Dynamic::BiasPtr b )
+Dynamic::DynamicModel::biasChanged( const Dynamic::BiasPtr &b )
 {
     QModelIndex index = this->index( b );
-    emit dataChanged( index, index );
+    Q_EMIT dataChanged( index, index );
 }
 
 void
@@ -1052,7 +1050,7 @@ Dynamic::DynamicModel::beginRemoveBias( Dynamic::BiasedPlaylist* parent )
 }
 
 void
-Dynamic::DynamicModel::beginRemoveBias( Dynamic::BiasPtr parent, int index )
+Dynamic::DynamicModel::beginRemoveBias( const Dynamic::BiasPtr &parent, int index )
 {
     QModelIndex parentIndex = this->index( parent );
     beginRemoveRows( parentIndex, index, index );
@@ -1073,7 +1071,7 @@ Dynamic::DynamicModel::beginInsertBias( Dynamic::BiasedPlaylist* parent )
 
 
 void
-Dynamic::DynamicModel::beginInsertBias( Dynamic::BiasPtr parent, int index )
+Dynamic::DynamicModel::beginInsertBias( const Dynamic::BiasPtr &parent, int index )
 {
     QModelIndex parentIndex = this->index( parent );
     beginInsertRows( parentIndex, index, index );
@@ -1086,7 +1084,7 @@ Dynamic::DynamicModel::endInsertBias()
 }
 
 void
-Dynamic::DynamicModel::beginMoveBias( Dynamic::BiasPtr parent, int from, int to )
+Dynamic::DynamicModel::beginMoveBias( const Dynamic::BiasPtr &parent, int from, int to )
 {
     QModelIndex parentIndex = this->index( parent );
     beginMoveRows( parentIndex, from, from, parentIndex, to );
@@ -1105,7 +1103,7 @@ static QString
 biasToString( Dynamic::BiasPtr bias, int level )
 {
     QString result;
-    result += QString(" ").repeated(level) + bias->toString() + ' ' + QString::number(quintptr(bias.data()), 16) + '\n';
+    result += QStringLiteral(" ").repeated(level) + bias->toString() + ' ' + QString::number(quintptr(bias.data()), 16) + '\n';
     if( Dynamic::AndBias* aBias = qobject_cast<Dynamic::AndBias*>(bias.data()) )
     {
         foreach( Dynamic::BiasPtr bias2, aBias->biases() )
