@@ -45,7 +45,7 @@ Dynamic::TrackCollection::uids() const
 
 Dynamic::TrackSet::TrackSet()
     : m_bits()
-    , m_collection( 0 )
+    , m_collection( nullptr )
 { }
 
 Dynamic::TrackSet::TrackSet( const TrackSet& other )
@@ -53,7 +53,7 @@ Dynamic::TrackSet::TrackSet( const TrackSet& other )
     , m_collection( other.m_collection )
 { }
 
-Dynamic::TrackSet::TrackSet( const Dynamic::TrackCollectionPtr collection, bool value )
+Dynamic::TrackSet::TrackSet( const Dynamic::TrackCollectionPtr &collection, bool value )
     : m_bits( collection->count(), value )
     , m_collection( collection )
 {}
@@ -224,8 +224,8 @@ Dynamic::TrackSet::subtract( const Meta::TrackPtr& B )
         // that seems to happen. e.g. for tracks from the file collection
         warning() << "TrackSet::subtract called for a track not even known to the collection. "<<
             "Track uid is"<<str<<
-            "example from collection"<<(m_collection->m_ids.isEmpty()?QString("no example"):QString(m_collection->m_ids.keys().first()))<<
-            "track is from collection"<<(B->collection()?B->collection()->collectionId():QString("no collection"));
+            "example from collection"<<(m_collection->m_ids.isEmpty()?QStringLiteral("no example"):QString(m_collection->m_ids.keys().first()))<<
+            "track is from collection"<<(B->collection()?B->collection()->collectionId():QStringLiteral("no collection"));
         return;
     }
 
