@@ -24,7 +24,7 @@
 #include "core/support/Debug.h"
 #include "widgets/SliderWidget.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 #include <KRandom>
 
 #include <QtGlobal> // for qRound
@@ -75,7 +75,6 @@ class MatchState
 {
     public:
         /** Creates the matching
-            @param ignoreTrack a track number that should be ignored for matching. -1 if no track should be ignored.
         */
         MatchState( const Dynamic::PartBias *bias,
                     const Meta::TrackList& playlist,
@@ -224,17 +223,17 @@ Dynamic::PartBiasWidget::PartBiasWidget( Dynamic::PartBias* bias, QWidget* paren
     , m_inSignal( false )
     , m_bias( bias )
 {
-    connect( bias, SIGNAL(biasAppended(Dynamic::BiasPtr)),
-             this, SLOT(biasAppended(Dynamic::BiasPtr)) );
+    connect( bias, &PartBias::biasAppended,
+             this, &PartBiasWidget::biasAppended );
 
-    connect( bias, SIGNAL(biasRemoved(int)),
-             this, SLOT(biasRemoved(int)) );
+    connect( bias, &PartBias::biasRemoved,
+             this, &PartBiasWidget::biasRemoved );
 
-    connect( bias, SIGNAL(biasMoved(int,int)),
-             this, SLOT(biasMoved(int,int)) );
+    connect( bias, &PartBias::biasMoved,
+             this, &PartBiasWidget::biasMoved );
 
-    connect( bias, SIGNAL(weightsChanged()),
-             this, SLOT(biasWeightsChanged()) );
+    connect( bias, &PartBias::weightsChanged,
+             this, &PartBiasWidget::biasWeightsChanged );
 
     m_layout = new QGridLayout( this );
 
@@ -254,7 +253,7 @@ Dynamic::PartBiasWidget::biasAppended( Dynamic::BiasPtr bias )
     slider = new Amarok::Slider( Qt::Horizontal, 100 );
     slider->setValue( m_bias->weights()[ m_bias->biases().indexOf( bias ) ] * 100.0 );
     slider->setToolTip( i18n( "This controls what portion of the playlist should match the criteria" ) );
-    connect( slider, SIGNAL(valueChanged(int)), SLOT(sliderValueChanged(int)) );
+    connect( slider, &Amarok::Slider::valueChanged, this, &PartBiasWidget::sliderValueChanged );
 
     QLabel* label = new QLabel( bias->toString() );
 
@@ -295,7 +294,7 @@ void
 Dynamic::PartBiasWidget::sliderValueChanged( int val )
 {
     DEBUG_BLOCK;
-    // protect agains recursion
+    // protect against recursion
     if( m_inSignal )
         return;
 
@@ -310,7 +309,7 @@ void
 Dynamic::PartBiasWidget::biasWeightsChanged()
 {
     DEBUG_BLOCK;
-    // protect agains recursion
+    // protect against recursion
     if( m_inSignal )
         return;
 
@@ -345,7 +344,7 @@ Dynamic::PartBias::fromXml( QXmlStreamReader *reader )
 
         if( reader->isStartElement() )
         {
-            float weight = reader->attributes().value( "weight" ).toString().toFloat();
+            float weight = reader->attributes().value( QStringLiteral("weight") ).toString().toFloat();
             Dynamic::BiasPtr bias( Dynamic::BiasFactory::fromXml( reader ) );
             if( bias )
             {
@@ -373,7 +372,7 @@ Dynamic::PartBias::toXml( QXmlStreamWriter *writer ) const
     for( int i = 0; i < m_biases.count(); i++ )
     {
         writer->writeStartElement( m_biases[i]->name() );
-        writer->writeAttribute( "weight", QString::number(m_weights[i]) );
+        writer->writeAttribute( QStringLiteral("weight"), QString::number(m_weights[i]) );
         m_biases[i]->toXml( writer );
         writer->writeEndElement();
     }
@@ -382,7 +381,7 @@ Dynamic::PartBias::toXml( QXmlStreamWriter *writer ) const
 QString
 Dynamic::PartBias::sName()
 {
-    return QLatin1String( "partBias" );
+    return QStringLiteral( "partBias" );
 }
 
 QString
@@ -429,7 +428,7 @@ Dynamic::PartBias::weights() const
 Dynamic::TrackSet
 Dynamic::PartBias::matchingTracks( const Meta::TrackList& playlist,
                                    int contextCount, int finalCount,
-                                   Dynamic::TrackCollectionPtr universe ) const
+                                   const Dynamic::TrackCollectionPtr &universe ) const
 {
     DEBUG_BLOCK;
 
@@ -517,7 +516,7 @@ Dynamic::PartBias::resultReceived( const Dynamic::TrackSet &tracks )
     updateResults();
 
     if( !m_tracks.isOutstanding() )
-        emit resultReady( m_tracks );
+        Q_EMIT resultReady( m_tracks );
 }
 
 bool
@@ -531,7 +530,7 @@ Dynamic::PartBias::trackMatches( int position,
 }
 
 void
-Dynamic::PartBias::appendBias( Dynamic::BiasPtr bias )
+Dynamic::PartBias::appendBias( const Dynamic::BiasPtr &bias )
 {
     DEBUG_BLOCK;
     m_weights.append( qreal(0.0) );
@@ -561,7 +560,7 @@ Dynamic::PartBias::changeBiasWeight( int biasNum, qreal value )
         if( m_weights.at(0) != 1.0 )
         {
             m_weights[0] = 1.0;
-            emit weightsChanged();
+            Q_EMIT weightsChanged();
         }
         return;
     }
@@ -610,12 +609,12 @@ Dynamic::PartBias::changeBiasWeight( int biasNum, qreal value )
     for( int i = 0; i < m_weights.count(); i++ )
         debug() << "Weight"<<i<<":"<<m_weights[i];
 
-    emit weightsChanged();
-    emit changed( BiasPtr( this ) );
+    Q_EMIT weightsChanged();
+    Q_EMIT changed( BiasPtr( this ) );
 }
 
 void
-Dynamic::PartBias::biasReplaced( Dynamic::BiasPtr oldBias, Dynamic::BiasPtr newBias )
+Dynamic::PartBias::biasReplaced( const Dynamic::BiasPtr &oldBias, const Dynamic::BiasPtr &newBias )
 {
     DEBUG_BLOCK;
     int index = m_biases.indexOf( oldBias );
@@ -629,5 +628,4 @@ Dynamic::PartBias::biasReplaced( Dynamic::BiasPtr oldBias, Dynamic::BiasPtr newB
     AndBias::biasReplaced( oldBias, newBias );
 }
 
-#include "PartBias.moc"
 
