@@ -65,14 +65,14 @@ Dynamic::SimpleMatchBias::SimpleMatchBias()
 void
 Dynamic::SimpleMatchBias::fromXml( QXmlStreamReader *reader )
 {
-    m_invert = reader->attributes().value( "invert" ).toString().toInt();
+    m_invert = reader->attributes().value( QStringLiteral("invert") ).toString().toInt();
 }
 
 void
 Dynamic::SimpleMatchBias::toXml( QXmlStreamWriter *writer ) const
 {
     if( m_invert )
-        writer->writeAttribute("invert", "1");
+        writer->writeAttribute(QStringLiteral("invert"), QStringLiteral("1"));
 }
 
 bool
@@ -90,14 +90,14 @@ Dynamic::SimpleMatchBias::setInvert( bool value )
 
     m_invert = value;
     // setting "invert" does not invalidate the search results
-    emit changed( BiasPtr(this) );
+    Q_EMIT changed( BiasPtr(this) );
 }
 
 
 Dynamic::TrackSet
 Dynamic::SimpleMatchBias::matchingTracks( const Meta::TrackList& playlist,
                                           int contextCount, int finalCount,
-                                          Dynamic::TrackCollectionPtr universe ) const
+                                          const Dynamic::TrackCollectionPtr &universe ) const
 {
     Q_UNUSED( playlist );
     Q_UNUSED( contextCount );
@@ -110,13 +110,13 @@ Dynamic::SimpleMatchBias::matchingTracks( const Meta::TrackList& playlist,
 
     QTimer::singleShot(0,
                        const_cast<SimpleMatchBias*>(this),
-                       SLOT(newQuery())); // create the new query from my parent thread
+                       &SimpleMatchBias::newQuery); // create the new query from my parent thread
 
     return Dynamic::TrackSet();
 }
 
 void
-Dynamic::SimpleMatchBias::updateReady( QStringList uids )
+Dynamic::SimpleMatchBias::updateReady( const QStringList &uids )
 {
     if( m_invert )
         m_tracks.subtract( uids );
@@ -130,7 +130,7 @@ Dynamic::SimpleMatchBias::updateFinished()
     m_tracksTime = QDateTime::currentDateTime();
     m_qm.reset();
     debug() << "SimpleMatchBias::"<<name()<<"updateFinished"<<m_tracks.trackCount();
-    emit resultReady( m_tracks );
+    Q_EMIT resultReady( m_tracks );
 }
 
 bool
@@ -185,10 +185,10 @@ Dynamic::TagMatchBiasWidget::TagMatchBiasWidget( Dynamic::TagMatchBias* bias,
 
     syncControlsToBias();
 
-    connect( m_invertBox, SIGNAL(toggled(bool)),
-             SLOT(syncBiasToControls()));
-    connect( m_queryWidget, SIGNAL(changed(MetaQueryWidget::Filter)),
-             SLOT(syncBiasToControls()));
+    connect( m_invertBox, &QCheckBox::toggled,
+             this, &TagMatchBiasWidget::syncBiasToControls );
+    connect( m_queryWidget, &MetaQueryWidget::changed,
+             this, &TagMatchBiasWidget::syncBiasToControls );
 }
 
 void
@@ -250,25 +250,25 @@ void
 Dynamic::TagMatchBias::toXml( QXmlStreamWriter *writer ) const
 {
     SimpleMatchBias::toXml( writer );
-    writer->writeTextElement( "field", Meta::playlistNameForField( m_filter.field() ) );
+    writer->writeTextElement( QStringLiteral("field"), Meta::playlistNameForField( m_filter.field() ) );
 
     if( m_filter.isNumeric() )
     {
-        writer->writeTextElement( "numValue",  QString::number( m_filter.numValue ) );
-        writer->writeTextElement( "numValue2", QString::number( m_filter.numValue2 ) );
+        writer->writeTextElement( QStringLiteral("numValue"),  QString::number( m_filter.numValue ) );
+        writer->writeTextElement( QStringLiteral("numValue2"), QString::number( m_filter.numValue2 ) );
     }
     else
     {
-        writer->writeTextElement( "value", m_filter.value );
+        writer->writeTextElement( QStringLiteral("value"), m_filter.value );
     }
 
-    writer->writeTextElement( "condition", nameForCondition( m_filter.condition ) );
+    writer->writeTextElement( QStringLiteral("condition"), nameForCondition( m_filter.condition ) );
 }
 
 QString
 Dynamic::TagMatchBias::sName()
 {
-    return QLatin1String( "tagMatchBias" );
+    return QStringLiteral( "tagMatchBias" );
 }
 
 QString
@@ -317,7 +317,7 @@ Dynamic::TagMatchBias::setFilter( const MetaQueryWidget::Filter &filter)
     DEBUG_BLOCK;
     m_filter = filter;
     invalidate();
-    emit changed( BiasPtr(this) );
+    Q_EMIT changed( BiasPtr(this) );
 }
 
 void
@@ -348,7 +348,7 @@ Dynamic::TagMatchBias::newQuery()
             m_qm->endAndOr();
             break;
         case MetaQueryWidget::OlderThan:
-            m_qm->addNumberFilter( m_filter.field(), QDateTime::currentDateTime().toTime_t() - m_filter.numValue,
+            m_qm->addNumberFilter( m_filter.field(), QDateTime::currentDateTimeUtc().toSecsSinceEpoch() - m_filter.numValue,
                                 Collections::QueryMaker::LessThan );
             break;
         default:
@@ -412,10 +412,10 @@ Dynamic::TagMatchBias::newQuery()
     m_qm->setQueryType( Collections::QueryMaker::Custom );
     m_qm->addReturnValue( Meta::valUniqueId );
 
-    connect( m_qm.data(), SIGNAL(newResultReady(QStringList)),
-             this, SLOT(updateReady(QStringList)), Qt::QueuedConnection );
-    connect( m_qm.data(), SIGNAL(queryDone()),
-             this, SLOT(updateFinished()), Qt::QueuedConnection );
+    connect( m_qm.data(), &Collections::QueryMaker::newResultReady,
+             this, &TagMatchBias::updateReady, Qt::QueuedConnection );
+    connect( m_qm.data(), &Collections::QueryMaker::queryDone,
+             this, &TagMatchBias::updateFinished, Qt::QueuedConnection );
     m_qm.data()->run();
 }
 
@@ -424,12 +424,12 @@ Dynamic::TagMatchBias::nameForCondition( MetaQueryWidget::FilterCondition cond )
 {
     switch( cond )
     {
-    case MetaQueryWidget::Equals:      return "equals";
-    case MetaQueryWidget::GreaterThan: return "greater";
-    case MetaQueryWidget::LessThan:    return "less";
-    case MetaQueryWidget::Between:     return "between";
-    case MetaQueryWidget::OlderThan:   return "older";
-    case MetaQueryWidget::Contains:    return "contains";
+    case MetaQueryWidget::Equals:      return QStringLiteral("equals");
+    case MetaQueryWidget::GreaterThan: return QStringLiteral("greater");
+    case MetaQueryWidget::LessThan:    return QStringLiteral("less");
+    case MetaQueryWidget::Between:     return QStringLiteral("between");
+    case MetaQueryWidget::OlderThan:   return QStringLiteral("older");
+    case MetaQueryWidget::Contains:    return QStringLiteral("contains");
     default:
         ;// the other conditions are only for the advanced playlist generator
     }
@@ -439,12 +439,12 @@ Dynamic::TagMatchBias::nameForCondition( MetaQueryWidget::FilterCondition cond )
 MetaQueryWidget::FilterCondition
 Dynamic::TagMatchBias::conditionForName( const QString &name )
 {
-    if( name == "equals" )        return MetaQueryWidget::Equals;
-    else if( name == "greater" )  return MetaQueryWidget::GreaterThan;
-    else if( name == "less" )     return MetaQueryWidget::LessThan;
-    else if( name == "between" )  return MetaQueryWidget::Between;
-    else if( name == "older" )    return MetaQueryWidget::OlderThan;
-    else if( name == "contains" ) return MetaQueryWidget::Contains;
+    if( name == QLatin1String("equals") )        return MetaQueryWidget::Equals;
+    else if( name == QLatin1String("greater") )  return MetaQueryWidget::GreaterThan;
+    else if( name == QLatin1String("less") )     return MetaQueryWidget::LessThan;
+    else if( name == QLatin1String("between") )  return MetaQueryWidget::Between;
+    else if( name == QLatin1String("older") )    return MetaQueryWidget::OlderThan;
+    else if( name == QLatin1String("contains") ) return MetaQueryWidget::Contains;
     else return MetaQueryWidget::Equals;
 }
 
@@ -472,7 +472,7 @@ Dynamic::TagMatchBias::matches( const Meta::TrackPtr &track ) const
                 value.toLongLong() < m_filter.numValue2;
             break;
         case MetaQueryWidget::OlderThan:
-            result = value.toLongLong() < m_filter.numValue + QDateTime::currentDateTime().toTime_t();
+            result = value.toLongLong() < m_filter.numValue + QDateTime::currentDateTimeUtc().toSecsSinceEpoch();
             break;
         default:
             ;
@@ -519,5 +519,4 @@ Dynamic::TagMatchBias::matches( const Meta::TrackPtr &track ) const
         return result;
 }
 
-#include "TagMatchBias.moc"
 
