@@ -37,7 +37,7 @@ namespace StatSyncing
 /**
  * A helper class encapsulating communication with the database. It guarantees that
  * a connection is only used in thread that created it, as per
- * @link http://qt-project.org/doc/qt-4.8/threads-modules.html#threads-and-the-sql-module
+ * http://doc.qt.io/qt-5/threads-modules.html#threads-and-the-sql-module
  * This class is very basic, e.g. returns a whole query result as a list of lists,
  * so it may not be suitable for more advanced usage.
  */
@@ -57,20 +57,23 @@ public:
     /**
      * Constructor. Overload for creating a connection to SQLite database.
      */
-    ImporterSqlConnection( const QString &dbPath );
+    explicit ImporterSqlConnection( const QString &dbPath );
 
     /**
      * Destructor. Removes connection created in the constructor. If a transaction was
      * in progress it is rolled back.
      */
-    virtual ~ImporterSqlConnection();
+    ~ImporterSqlConnection() override;
 
     /**
-     * Executes a query given in QString @param query , first using QSqlQuery::bindValue
-     * to bind parameters given in @param bindValues . If @param ok is not null the bool
+     * Executes a query given in QString @p query, first using QSqlQuery::bindValue
+     * to bind parameters given in @p bindValues. If @p ok is not null the bool
      * it points at is set to true if the query was successful and false if error occurred.
      * Note that if no transaction is started, the connection is opened for the query and
      * then closed again.
+     * @param query the query
+     * @param bindValues the bind parameters
+     * @param ok whether the query was successful
      *
      * @returns The result of the query.
      */
@@ -131,7 +134,7 @@ private:
     bool m_openTransaction;
     QList<QVariantList> m_result;
 
-private slots:
+private Q_SLOTS:
     void slotQuery( const QString &query, const QVariantMap &bindValues, bool* const ok );
     void slotTransaction();
     void slotRollback();
