@@ -60,7 +60,7 @@ MoodbarManager::MoodbarManager()
     : m_cache( new KImageCache( "Amarok-moodbars", 10 * 1024 ) )
     , m_lastPaintMode( 0 )
 {
-    connect( The::paletteHandler(), SIGNAL(newPalette(QPalette)), SLOT(paletteChanged(QPalette)) );
+    connect( The::paletteHandler(), &PaletteHandler::newPalette, this, &MoodbarManager::paletteChanged );
 }
 
 MoodbarManager::~MoodbarManager()
@@ -77,7 +77,7 @@ bool MoodbarManager::hasMoodbar( Meta::TrackPtr track )
     }
         
  
-    KUrl trackUrl = track->playableUrl();
+    QUrl trackUrl = track->playableUrl();
     //only supports local files for now.
     if ( !trackUrl.isLocalFile() )
     {
@@ -147,12 +147,12 @@ QPixmap MoodbarManager::getMoodbar( Meta::TrackPtr track, int width, int height,
         m_lastPaintMode = AmarokConfig::moodbarPaintStyle();
         m_cache->clear();
         m_moodDataMap.clear();
-        emit moodbarStyleChanged();
+        Q_EMIT moodbarStyleChanged();
     }
 
 
     //Do we already have this pixmap cached?
-    const QString pixmapKey = QString( "mood:%1-%2x%3%4" ).arg( track->uidUrl(), QString::number( width ),
+    const QString pixmapKey = QStringLiteral( "mood:%1-%2x%3%4" ).arg( track->uidUrl(), QString::number( width ),
                                                                 QString::number( height ), QString( rtl?"r":"" ) );
     QPixmap moodbar;
 
@@ -174,7 +174,7 @@ QPixmap MoodbarManager::getMoodbar( Meta::TrackPtr track, int width, int height,
         else
             moodFilePath = moodPath( track->playableUrl().path() );
 
-        data = readMoodFile( moodFilePath );
+        data = readMoodFile( QUrl::fromUserInput(moodFilePath) );
 
         if ( data.size() > 10 )
             m_moodDataMap.insert( track, data );
@@ -195,7 +195,7 @@ QPixmap MoodbarManager::getMoodbar( Meta::TrackPtr track, int width, int height,
     return moodbar;
 }
 
-MoodbarColorList MoodbarManager::readMoodFile( const KUrl &moodFileUrl )
+MoodbarColorList MoodbarManager::readMoodFile( const QUrl &moodFileUrl )
 {
     DEBUG_BLOCK
 
@@ -431,7 +431,7 @@ QPixmap MoodbarManager::drawMoodbar( const MoodbarColorList &data, int width, in
     // First average the moodbar samples that will go into each
     // vertical bar on the screen.
 
-    if( data.size() == 0 ) // Play it safe -- see below
+    if( data.isEmpty() ) // Play it safe -- see below
       return QPixmap();
 
     MoodbarColorList screenColors;
@@ -506,7 +506,7 @@ QPixmap MoodbarManager::drawMoodbar( const MoodbarColorList &data, int width, in
 
 QString MoodbarManager::moodPath( const QString &trackPath ) const
 {
-    QStringList parts = trackPath.split( '.' );
+    QStringList parts = trackPath.split( QLatin1Char('.') );
     parts.takeLast();
     parts.append( "mood" );
     QString moodPath = parts.join( "." );
