@@ -20,10 +20,10 @@
 #include "MusicBrainzTagsModel.h"
 
 #include "AmarokMimeData.h"
-#include "core/support/Debug.h"
 #include "MusicBrainzMeta.h"
 #include "MusicBrainzTagsItem.h"
-
+#include "core/support/Debug.h"
+#include "support/MetaConstants.h"
 #include <KLocalizedString>
 
 #include <QFont>
@@ -196,7 +196,7 @@ MusicBrainzTagsModel::setData( const QModelIndex &index, const QVariant &value,
     parentItem->clearChoices();
     item->setChosen( value.toBool() );
     QModelIndex parent = index.parent();
-    emit dataChanged( this->index( 0, 0, parent ),
+    Q_EMIT dataChanged( this->index( 0, 0, parent ),
                       this->index( rowCount( parent ) - 1, 0, parent ) );
     return true;
 }
@@ -249,7 +249,7 @@ MusicBrainzTagsModel::columnCount( const QModelIndex &parent ) const
 }
 
 void
-MusicBrainzTagsModel::addTrack( const Meta::TrackPtr track, const QVariantMap tags )
+MusicBrainzTagsModel::addTrack( const Meta::TrackPtr &track, const QVariantMap &tags )
 {
     DEBUG_BLOCK
 
@@ -298,7 +298,7 @@ MusicBrainzTagsModel::addTrack( const Meta::TrackPtr track, const QVariantMap ta
             similarItem = item;
 
             item->mergeData( tags );
-            emit dataChanged( index( i, 0, trackIndex ), index(i, columnCount() - 1, trackIndex ) );
+            Q_EMIT dataChanged( index( i, 0, trackIndex ), index(i, columnCount() - 1, trackIndex ) );
 
             break;
         }
@@ -348,7 +348,7 @@ MusicBrainzTagsModel::chooseBestMatches()
         if( item->chooseBestMatch() )
         {
             QModelIndex parent = index( i, 0 );
-            emit dataChanged( index( 0, 0, parent ),
+            Q_EMIT dataChanged( index( 0, 0, parent ),
                               index( rowCount( parent ) - 1, 0, parent ) );
         }
     }
@@ -363,7 +363,7 @@ MusicBrainzTagsModel::chooseBestMatchesFromRelease( const QStringList &releases
         if( item->chooseBestMatchFromRelease( releases ) )
         {
             QModelIndex parent = index( i, 0 );
-            emit dataChanged( index( 0, 0, parent ),
+            Q_EMIT dataChanged( index( 0, 0, parent ),
                               index( rowCount( parent ) - 1, 0, parent ) );
         }
     }
@@ -377,9 +377,8 @@ MusicBrainzTagsModel::clearChoices()
         MusicBrainzTagsItem *item = m_rootItem->child( i );
         item->clearChoices();
         QModelIndex parent = index( i, 0 );
-        emit dataChanged( index( 0, 0, parent ),
+        Q_EMIT dataChanged( index( 0, 0, parent ),
                           index( rowCount( parent ) - 1, 0, parent ) );
     }
 }
 
-#include "MusicBrainzTagsModel.moc"
