@@ -16,7 +16,7 @@
 
 #include "PlaylistBreadcrumbItemSortButton.h"
 
-#include <KIcon>
+#include <QIcon>
 
 #include <QPainter>
 #include <QStyle>
@@ -54,7 +54,7 @@ void
 BreadcrumbItemSortButton::init()
 {
     setMouseTracking( true );
-    emit arrowToggled( m_order );
+    Q_EMIT arrowToggled( m_order );
     repaint();
 }
 
@@ -103,10 +103,10 @@ BreadcrumbItemSortButton::drawHoverBackground( QPainter *painter )
     const bool isHovered = isDisplayHintEnabled( HoverHint );
     if( isHovered )
     {
-        QStyleOptionViewItemV4 option;
+        QStyleOptionViewItem option;
         option.initFrom(this);
         option.state = QStyle::State_Enabled | QStyle::State_MouseOver;
-        option.viewItemPosition = QStyleOptionViewItemV4::OnlyOne;
+        option.viewItemPosition = QStyleOptionViewItem::OnlyOne;
 
         if( m_arrowHovered )
         {
@@ -155,7 +155,7 @@ BreadcrumbItemSortButton::invertOrder()
         m_order = Qt::AscendingOrder;
     else    //ascending
         m_order = Qt::DescendingOrder;
-    emit arrowToggled( m_order );
+    Q_EMIT arrowToggled( m_order );
     repaint();
 }
 
