@@ -59,12 +59,12 @@ namespace The
 }
 
 
-Controller* Controller::s_instance = 0;
+Controller* Controller::s_instance = nullptr;
 
 Controller*
 Controller::instance()
 {
-    if( s_instance == 0 )
+    if( s_instance == nullptr )
         s_instance = new Controller();
     return s_instance;
 }
@@ -75,7 +75,7 @@ Controller::destroy()
     if( s_instance )
     {
         delete s_instance;
-        s_instance = 0;
+        s_instance = nullptr;
     }
 }
 
@@ -95,8 +95,8 @@ Controller::Controller()
     m_topModel = The::playlist();
 
     m_undoStack->setUndoLimit( 20 );
-    connect( m_undoStack, SIGNAL(canRedoChanged(bool)), this, SIGNAL(canRedoChanged(bool)) );
-    connect( m_undoStack, SIGNAL(canUndoChanged(bool)), this, SIGNAL(canUndoChanged(bool)) );
+    connect( m_undoStack, &QUndoStack::canRedoChanged, this, &Controller::canRedoChanged );
+    connect( m_undoStack, &QUndoStack::canUndoChanged, this, &Controller::canUndoChanged );
 }
 
 Controller::~Controller() {}
@@ -136,10 +136,10 @@ Controller::insertOptioned( Meta::TrackList list, AddOptions options )
 
     if( options.testFlag( Replace ) )
     {
-        emit replacingPlaylist();   //make sure that we clear filters
+        Q_EMIT replacingPlaylist();   //make sure that we clear filters
         clear();
         //make sure that we turn off dynamic mode.
-        Amarok::actionCollection()->action( "disable_dynamic" )->trigger();
+        Amarok::actionCollection()->action( QStringLiteral("disable_dynamic") )->trigger();
     }
 
     int bottomModelRowCount = m_bottomModel->qaim()->rowCount();
@@ -219,7 +219,7 @@ Controller::insertOptioned( Meta::TrackList list, AddOptions options )
     if( startPlaying )
         Actions::instance()->requestUserNextTrack(); // desired track will be first in queue
 
-    emit changed();
+    Q_EMIT changed();
 }
 
 void
@@ -242,19 +242,19 @@ Controller::insertOptioned( Playlists::PlaylistList list, AddOptions options )
         flags |= TrackLoader::RemotePlaylistsAreStreams;
     TrackLoader *loader = new TrackLoader( flags ); // auto-deletes itself
     loader->setProperty( "options", QVariant::fromValue<AddOptions>( options ) );
-    connect( loader, SIGNAL(finished(Meta::TrackList)),
-                 SLOT(slotLoaderWithOptionsFinished(Meta::TrackList)) );
+    connect( loader, &TrackLoader::finished,
+             this, &Controller::slotLoaderWithOptionsFinished );
     loader->init( list );
 }
 
 void
-Controller::insertOptioned( const KUrl &url, AddOptions options )
+Controller::insertOptioned( const QUrl &url, AddOptions options )
 {
-    insertOptioned( QList<KUrl>() << url, options );
+    insertOptioned( QList<QUrl>() << url, options );
 }
 
 void
-Controller::insertOptioned( QList<KUrl> &urls, AddOptions options )
+Controller::insertOptioned( QList<QUrl> &urls, AddOptions options )
 {
     TrackLoader::Flags flags;
     // if we are going to play, we need full metadata (playable tracks)
@@ -267,8 +267,8 @@ Controller::insertOptioned( QList<KUrl> &urls, AddOptions options )
         flags |= TrackLoader::RemotePlaylistsAreStreams;
     TrackLoader *loader = new TrackLoader( flags ); // auto-deletes itself
     loader->setProperty( "options", QVariant::fromValue<AddOptions>( options ) );
-    connect( loader, SIGNAL(finished(Meta::TrackList)),
-                 SLOT(slotLoaderWithOptionsFinished(Meta::TrackList)) );
+    connect( loader, &TrackLoader::finished,
+             this, &Controller::slotLoaderWithOptionsFinished );
     loader->init( urls );
 }
 
@@ -297,18 +297,18 @@ Controller::insertPlaylists( int topModelRow, Playlists::PlaylistList playlists
 {
     TrackLoader *loader = new TrackLoader(); // auto-deletes itself
     loader->setProperty( "topModelRow", QVariant( topModelRow ) );
-    connect( loader, SIGNAL(finished(Meta::TrackList)),
-             SLOT(slotLoaderWithRowFinished(Meta::TrackList)) );
+    connect( loader, &TrackLoader::finished,
+             this, &Controller::slotLoaderWithRowFinished );
     loader->init( playlists );
 }
 
 void
-Controller::insertUrls( int topModelRow, QList<KUrl> &urls )
+Controller::insertUrls( int topModelRow, QList<QUrl> &urls )
 {
     TrackLoader *loader = new TrackLoader(); // auto-deletes itself
     loader->setProperty( "topModelRow", QVariant( topModelRow ) );
-    connect( loader, SIGNAL(finished(Meta::TrackList)),
-             SLOT(slotLoaderWithRowFinished(Meta::TrackList)) );
+    connect( loader, &TrackLoader::finished,
+             this, &Controller::slotLoaderWithRowFinished );
     loader->init( urls );
 }
 
@@ -349,7 +349,7 @@ Controller::removeRows( QList<int>& topModelRows )
     if( bottomModelCmds.size() > 0 )
         m_undoStack->push( new RemoveTracksCmd( 0, bottomModelCmds ) );
 
-    emit changed();
+    Q_EMIT changed();
 }
 
 void
@@ -381,7 +381,7 @@ Controller::removeDeadAndDuplicates()
 
     if( !topModelRowsToRemove.empty() )
     {
-        m_undoStack->beginMacro( "Remove dead and duplicate entries" );     // TODO: Internationalize?
+        m_undoStack->beginMacro( QStringLiteral("Remove dead and duplicate entries") );     // TODO: Internationalize?
         removeRows( topModelRowsToRemove );
         m_undoStack->endMacro();
     }
@@ -508,7 +508,7 @@ Controller::reorderRows( const QList<int> &from, const QList<int> &to )
     if( bottomModelCmds.size() > 0 )
         m_undoStack->push( new MoveTracksCmd( 0, bottomModelCmds ) );
 
-    emit changed();
+    Q_EMIT changed();
 }
 
 void
@@ -516,7 +516,7 @@ Controller::undo()
 {
     DEBUG_BLOCK
     m_undoStack->undo();
-    emit changed();
+    Q_EMIT changed();
 }
 
 void
@@ -524,7 +524,7 @@ Controller::redo()
 {
     DEBUG_BLOCK
     m_undoStack->redo();
-    emit changed();
+    Q_EMIT changed();
 }
 
 void
@@ -532,7 +532,7 @@ Controller::clear()
 {
     DEBUG_BLOCK
     removeRows( 0, ModelStack::instance()->bottom()->qaim()->rowCount() );
-    emit changed();
+    Q_EMIT changed();
 }
 
 /**************************************************
@@ -612,9 +612,9 @@ Controller::insertionHelper( int bottomModelRow, Meta::TrackList& tl )
         {
             /*ignore*/
         }
-        else if( typeid( *track.data() ) == typeid( MetaFile::Track  ) )
+        else if( MetaFile::TrackPtr::dynamicCast( track ) )
         {
-            KUrl cuesheet = MetaCue::CueFileSupport::locateCueSheet( track->playableUrl() );
+            QUrl cuesheet = MetaCue::CueFileSupport::locateCueSheet( track->playableUrl() );
             if( !cuesheet.isEmpty() )
             {
                 MetaCue::CueFileItemMap cueMap = MetaCue::CueFileSupport::loadCueFile( cuesheet, track );
@@ -622,7 +622,7 @@ Controller::insertionHelper( int bottomModelRow, Meta::TrackList& tl )
                 {
                     Meta::TrackList cueTracks = MetaCue::CueFileSupport::generateTimeCodeTracks( track, cueMap );
                     if( !cueTracks.isEmpty() )
-                      modifiedList <<  cueTracks;
+                        modifiedList <<  cueTracks;
                     else
                         modifiedList << track;
                 }
@@ -646,5 +646,5 @@ Controller::insertionHelper( int bottomModelRow, Meta::TrackList& tl )
     if( bottomModelCmds.size() > 0 )
         m_undoStack->push( new InsertTracksCmd( 0, bottomModelCmds ) );
 
-    emit changed();
+    Q_EMIT changed();
 }
