@@ -45,18 +45,15 @@
 #include "core-impl/support/TrackLoader.h"
 #include "playlist/UndoCommands.h"
 
-#include <KGlobal>
+#include <KLocalizedString>
 #include <KIconLoader>
-#include <KLocale>
-#include <KUrl>
 
 #include <QAction>
 #include <QTimer>
 #include <QDate>
 #include <QStringList>
-#include <QTextDocument>
+#include <QUrl>
 
-#include <typeinfo>
 
 #define TOOLTIP_STATIC_LINEBREAK 50
 
@@ -78,9 +75,9 @@ breakLongLinesHTML( const QString &origText )
 {
     // filter-out HTML tags..
     QString text( origText );
-    text.replace( '&', "&amp;" ); // needs to be first, obviously
-    text.replace( '<', "&lt;" );
-    text.replace( '>', "&gt;" );
+    text.replace( '&', QLatin1String("&amp;") ); // needs to be first, obviously
+    text.replace( '<', QLatin1String("&lt;") );
+    text.replace( '>', QLatin1String("&gt;") );
 
     // Now let's break up long lines so that the tooltip doesn't become hideously large
     if( fitsInOneLineHTML( text ) )
@@ -101,7 +98,7 @@ breakLongLinesHTML( const QString &origText )
             {
                 if (lineLength > 0)
                 {
-                    textInLines += "<br/>";
+                    textInLines += QLatin1String("<br/>");
                 }
                 lineLength = 0;
                 // Let's check if the next word is not too long for the new line to contain
@@ -125,8 +122,9 @@ breakLongLinesHTML( const QString &origText )
 /**
 * Prepares a row for the playlist tooltips consisting of an icon representing
 * an mp3 tag and its value
-* @param column The colunm used to display the icon
+* @param column The column used to display the icon
 * @param value The QString value to be shown
+* @param force If @c true, allows to set empty values
 * @return The line to be shown or an empty QString if the value is null
 */
 static QString
@@ -135,11 +133,11 @@ HTMLLine( const Playlist::Column& column, const QString& value, bool force = fal
     if( !value.isEmpty() || force )
     {
         QString line;
-        line += "<tr><td align=\"right\">";
+        line += QLatin1String("<tr><td align=\"right\">");
         line += "<img src=\""+KIconLoader::global()->iconPath( Playlist::iconName( column ), -16)+"\" />";
-        line += "</td><td align=\"left\">";
+        line += QLatin1String("</td><td align=\"left\">");
         line += breakLongLinesHTML( value );
-        line += "</td></tr>";
+        line += QLatin1String("</td></tr>");
         return line;
     }
     else
@@ -149,15 +147,16 @@ HTMLLine( const Playlist::Column& column, const QString& value, bool force = fal
 /**
 * Prepares a row for the playlist tooltips consisting of an icon representing
 * an mp3 tag and its value
-* @param column The colunm used to display the icon
+* @param column The column used to display the icon
 * @param value The integer value to be shown
+* @param force If @c true, allows to set non-positive values
 * @return The line to be shown or an empty QString if the value is 0
 */
 static QString
 HTMLLine( const Playlist::Column& column, const int value, bool force = false )
 {
-    // there is currenly no numeric meta-data that would have sense if it were negative.
-    // also, zero denotes not available, unknow etc; don't show these unless forced.
+    // there is currently no numeric meta-data that would have sense if it were negative.
+    // also, zero denotes not available, unknown etc; don't show these unless forced.
     if( value > 0 || force )
     {
         return HTMLLine( column, QString::number( value ) );
@@ -179,18 +178,18 @@ Playlist::Model::Model( QObject *parent )
 
     m_saveStateTimer->setInterval( 5000 );
     m_saveStateTimer->setSingleShot( true );
-    connect( m_saveStateTimer, SIGNAL(timeout()),
-             this, SLOT(saveState()) );
-    connect( this, SIGNAL(modelReset()),
-             this, SLOT(queueSaveState()) );
-    connect( this, SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-             this, SLOT(queueSaveState()) );
-    connect( this, SIGNAL(rowsInserted(QModelIndex,int,int)),
-             this, SLOT(queueSaveState()) );
-    connect( this, SIGNAL(rowsMoved(QModelIndex,int,int,QModelIndex,int)),
-             this, SLOT(queueSaveState()) );
-    connect( this, SIGNAL(rowsRemoved(QModelIndex,int,int)),
-             this, SLOT(queueSaveState()) );
+    connect( m_saveStateTimer, &QTimer::timeout,
+             this, &Playlist::Model::saveState );
+    connect( this, &Playlist::Model::modelReset,
+             this, &Playlist::Model::queueSaveState );
+    connect( this, &Playlist::Model::dataChanged,
+             this, &Playlist::Model::queueSaveState );
+    connect( this, &Playlist::Model::rowsInserted,
+             this, &Playlist::Model::queueSaveState );
+    connect( this, &Playlist::Model::rowsMoved,
+             this, &Playlist::Model::queueSaveState );
+    connect( this, &Playlist::Model::rowsRemoved,
+             this, &Playlist::Model::queueSaveState );
 }
 
 Playlist::Model::~Model()
@@ -257,7 +256,6 @@ QString
 Playlist::Model::tooltipFor( Meta::TrackPtr track ) const
 {
     QString text;
-    KLocale *locale = KGlobal::locale();
     // get the shared pointers now to be thread safe
     Meta::ArtistPtr artist = track->artist();
     Meta::AlbumPtr album = track->album();
@@ -316,7 +314,7 @@ Playlist::Model::tooltipFor( Meta::TrackPtr track ) const
             if( label )
                 labels << label->name();
         }
-        text += HTMLLine( Playlist::Labels, labels.join( QString(", ") ) );
+        text += HTMLLine( Playlist::Labels, labels.join( QStringLiteral(", ") ) );
     }
 
     if( s_tooltipColumns[Playlist::Score] )
@@ -329,13 +327,13 @@ Playlist::Model::tooltipFor( Meta::TrackPtr track ) const
         text += HTMLLine( Playlist::PlayCount, statistics->playCount(), true );
 
     if( s_tooltipColumns[Playlist::LastPlayed] && statistics->lastPlayed().isValid() )
-        text += HTMLLine( Playlist::LastPlayed, locale->formatDateTime( statistics->lastPlayed() ) );
+        text += HTMLLine( Playlist::LastPlayed, QLocale().toString( statistics->lastPlayed() ) );
 
     if( s_tooltipColumns[Playlist::Bitrate] && track->bitrate() )
         text += HTMLLine( Playlist::Bitrate, i18nc( "%1: bitrate", "%1 kbps", track->bitrate() ) );
 
     if( text.isEmpty() )
-        text = QString( i18n( "No extra information available" ) );
+        text = i18n( "No extra information available" );
     else
         text = QString("<table>"+ text +"</table>");
 
@@ -445,7 +443,7 @@ Playlist::Model::data( const QModelIndex& index, int role ) const
             case Directory:
             {
                 if( track->playableUrl().isLocalFile() )
-                    return track->playableUrl().directory();
+                    return track->playableUrl().adjusted(QUrl::RemoveFilename).path();
                 break;
             }
             case DiscNumber:
@@ -489,7 +487,7 @@ Playlist::Model::data( const QModelIndex& index, int role ) const
                     {
                         labelNames << label->prettyName();
                     }
-                    return labelNames.join( ", " );
+                    return labelNames.join( QStringLiteral(", ") );
                 }
                 break;
             }
@@ -622,7 +620,7 @@ Playlist::Model::mimeTypes() const
 {
     QStringList ret = QAbstractListModel::mimeTypes();
     ret << AmarokMimeData::TRACK_MIME;
-    ret << "text/uri-list"; //we do accept urls
+    ret << QStringLiteral("text/uri-list"); //we do accept urls
     return ret;
 }
 
@@ -707,7 +705,7 @@ Playlist::Model::dropMimeData( const QMimeData* data, Qt::DropAction action, int
         debug() << "this is _something_ with a url....";
         TrackLoader *dl = new TrackLoader(); // auto-deletes itself
         dl->setProperty( "beginRow", beginRow );
-        connect( dl, SIGNAL(finished(Meta::TrackList)), SLOT(insertTracksFromTrackLoader(Meta::TrackList)) );
+        connect( dl, &TrackLoader::finished, this, &Model::insertTracksFromTrackLoader );
         dl->init( data->urls() );
         return true;
     }
@@ -723,19 +721,19 @@ Playlist::Model::setActiveRow( int row )
     {
         setStateOfRow( row, Item::Played );
         m_activeRow = row;
-        emit activeTrackChanged( m_items.at( row )->id() );
+        Q_EMIT activeTrackChanged( m_items.at( row )->id() );
     }
     else
     {
         m_activeRow = -1;
-        emit activeTrackChanged( 0 );
+        Q_EMIT activeTrackChanged( 0 );
     }
 }
 
 void
 Playlist::Model::emitQueueChanged()
 {
-    emit queueChanged();
+    Q_EMIT queueChanged();
 }
 
 int
@@ -855,7 +853,7 @@ Playlist::Model::stateOfId( quint64 id ) const
 }
 
 void
-Playlist::Model::metadataChanged( Meta::TrackPtr track )
+Playlist::Model::metadataChanged(const Meta::TrackPtr &track )
 {
     int row = 0;
     foreach( Item* i, m_items )
@@ -867,14 +865,14 @@ Playlist::Model::metadataChanged( Meta::TrackPtr track )
             if( album )
                 subscribeTo( album );
 
-            emit dataChanged( index( row, 0 ), index( row, columnCount() - 1 ) );
+            Q_EMIT dataChanged( index( row, 0 ), index( row, columnCount() - 1 ) );
         }
         row++;
     }
 }
 
 void
-Playlist::Model::metadataChanged( Meta::AlbumPtr album )
+Playlist::Model::metadataChanged(const Meta::AlbumPtr &album )
 {
     // Mainly to get update about changed covers
 
@@ -885,7 +883,7 @@ Playlist::Model::metadataChanged( Meta::AlbumPtr album )
     {
         if ( m_items.at( i )->track()->album() == album )
         {
-            emit dataChanged( index( i, 0 ), index( i, columnCount() - 1 ) );
+            Q_EMIT dataChanged( index( i, 0 ), index( i, columnCount() - 1 ) );
             found = true;
             debug()<<"Metadata updated for album"<<album->prettyName();
         }
@@ -898,7 +896,7 @@ Playlist::Model::metadataChanged( Meta::AlbumPtr album )
 }
 
 bool
-Playlist::Model::exportPlaylist( const QString &path, bool relative ) const
+Playlist::Model::exportPlaylist( const QString &path, bool relative )
 {
     // check queue state
     QQueue<quint64> queueIds = The::playlistActions()->queue();
@@ -906,11 +904,11 @@ Playlist::Model::exportPlaylist( const QString &path, bool relative ) const
     foreach( quint64 id, queueIds ) {
       queued << rowForId( id );
     }
-    return Playlists::exportPlaylistFile( tracks(), path, relative, queued );
+    return Playlists::exportPlaylistFile( tracks(), QUrl::fromLocalFile(path), relative, queued);
 }
 
 Meta::TrackList
-Playlist::Model::tracks() const
+Playlist::Model::tracks()
 {
     Meta::TrackList tl;
     foreach( Item* item, m_items )
@@ -946,7 +944,7 @@ Playlist::Model::prettyColumnName( Column index ) //static
     case LastPlayed: return i18nc( "Column name", "Last Played" );
     case Mood:       return i18n( "Mood" );
     case Filesize:   return i18n( "File Size" );
-    default:         return "This is a bug.";
+    default:         return QStringLiteral("This is a bug.");
     }
 
 }
@@ -1117,7 +1115,7 @@ Playlist::Model::removeTracksCommand( const RemoveCmdList &passedCmds )
     // BUG: 259675
     // FIXME: removing the track and normalizing the playlist should be grouped together
     //        so that an undo operation undos both.
-    QTimer::singleShot(0, Playlist::Actions::instance(), SLOT(normalizeDynamicPlaylist()));
+    QTimer::singleShot(0, Playlist::Actions::instance(), &Playlist::Actions::normalizeDynamicPlaylist);
 }
 
 
@@ -1192,14 +1190,14 @@ Playlist::Model::moveTracksCommand( const MoveCmdList& cmds, bool reverse )
     //   - Call 'beginMoveRows()' / 'endMoveRows()'. Drawback: we'd need to do N of them, all causing resorts etc.
     //   - Emit 'layoutAboutToChange' / 'layoutChanged'. Drawback: unspecific, 'changePersistentIndex()' complications.
     //   - Emit 'dataChanged'. Drawback: a bit inappropriate. But not wrong.
-    emit dataChanged( index( min, 0 ), index( max, columnCount() - 1 ) );
+    Q_EMIT dataChanged( index( min, 0 ), index( max, columnCount() - 1 ) );
 
     //update the active row
     m_activeRow = newActiveRow;
 }
 
 
-// When doing a 'setStateOfItem_batch', we emit 1 crude 'dataChanged' signal. If we're
+// When doing a 'setStateOfItem_batch', we Q_EMIT 1 crude 'dataChanged' signal. If we're
 // unlucky, that signal may span many innocent rows that haven't changed at all.
 // Although that "worst case" will cause unnecessary work in our listeners "upstream", it
 // still has much better performance than the worst case of emitting very many tiny
@@ -1217,7 +1215,7 @@ void
 Playlist::Model::setStateOfItem_batchEnd()
 {
     if ( ( m_setStateOfItem_batchMaxRow - m_setStateOfItem_batchMinRow ) >= 0 )
-        emit dataChanged( index( m_setStateOfItem_batchMinRow, 0 ), index( m_setStateOfItem_batchMaxRow, columnCount() - 1 ) );
+        Q_EMIT dataChanged( index( m_setStateOfItem_batchMinRow, 0 ), index( m_setStateOfItem_batchMaxRow, columnCount() - 1 ) );
 
     m_setStateOfItem_batchMinRow = -1;
 }
@@ -1228,7 +1226,7 @@ Playlist::Model::setStateOfItem( Item *item, int row, Item::State state )
     item->setState( state );
 
     if ( m_setStateOfItem_batchMinRow == -1 )    // If not in batch mode
-        emit dataChanged( index( row, 0 ), index( row, columnCount() - 1 ) );
+        Q_EMIT dataChanged( index( row, 0 ), index( row, columnCount() - 1 ) );
     else
     {
         m_setStateOfItem_batchMinRow = qMin( m_setStateOfItem_batchMinRow, row );
