@@ -24,12 +24,12 @@
 #include "playlist/PlaylistDock.h"
 #include "playlist/ProgressiveSearchWidget.h"
 
-#include <KStandardDirs>
-#include <KLocale>
+#include <KLocalizedString>
 
-#include <QList>
-#include <QStringList>
 #include <QActionGroup>
+#include <QList>
+#include <QStandardPaths>
+#include <QStringList>
 
 namespace Playlist
 {
@@ -44,32 +44,32 @@ ViewUrlRunner::~ViewUrlRunner()
 }
 
 bool
-ViewUrlRunner::run( AmarokUrl url )
+ViewUrlRunner::run( const AmarokUrl &url )
 {
     DEBUG_BLOCK
 
     const QMap< QString, QString > args = url.args();
-    QWeakPointer<Dock> playlistDock = The::mainWindow()->playlistDock();
+    auto playlistDock = The::mainWindow()->playlistDock();
 
-    if( args.keys().contains( "filter" ) )
+    if( args.keys().contains( QStringLiteral("filter") ) )
     {
-        const QString filterExpr = args.value( "filter" );
-        playlistDock.data()->searchWidget()->setCurrentFilter( filterExpr );
-        if( args.keys().contains( "matches" ) )
+        const QString filterExpr = args.value( QStringLiteral("filter") );
+        playlistDock->searchWidget()->setCurrentFilter( filterExpr );
+        if( args.keys().contains( QStringLiteral("matches") ) )
         {
-            const QString onlyMatches = args.value( "matches" );
-            playlistDock.data()->searchWidget()->slotShowOnlyMatches( ( onlyMatches == QString( "true" ) ) );
+            const QString onlyMatches = args.value( QStringLiteral("matches") );
+            playlistDock->searchWidget()->slotShowOnlyMatches( ( onlyMatches == QStringLiteral( "true" ) ) );
         }
     }
-    if( args.keys().contains( "sort" ) )
+    if( args.keys().contains( QStringLiteral("sort") ) )
     {
-        const QString sortPath = args.value( "sort" );
-        playlistDock.data()->sortWidget()->readSortPath( sortPath );
+        const QString sortPath = args.value( QStringLiteral("sort") );
+        playlistDock->sortWidget()->readSortPath( sortPath );
     }
 
-    if( args.keys().contains( "layout" ) )
+    if( args.keys().contains( QStringLiteral("layout") ) )
     {
-        const QString layout = args.value( "layout" );
+        const QString layout = args.value( QStringLiteral("layout") );
         LayoutManager::instance()->setActiveLayout( layout );
     }
 
@@ -81,7 +81,7 @@ ViewUrlRunner::run( AmarokUrl url )
 QString
 ViewUrlRunner::command() const
 {
-    return "playlist";
+    return QStringLiteral("playlist");
 }
 
 QString
@@ -90,10 +90,10 @@ ViewUrlRunner::prettyCommand() const
     return i18nc( "A type of command that affects the sorting, layout and filtering int he Playlist", "Playlist" );
 }
 
-KIcon
+QIcon
 ViewUrlRunner::icon() const
 {
-    return KIcon( QPixmap( KStandardDirs::locate( "data", "amarok/images/playlist-bookmark-16.png" ) ) );
+    return QIcon( QPixmap( QStandardPaths::locate( QStandardPaths::GenericDataLocation, "amarok/images/playlist-bookmark-16.png" ) ) );
 }
 
 } //namespace Playlist
