@@ -19,12 +19,13 @@
 #include "core/support/Debug.h"
 #include "playlist/PlaylistModel.h"
 
-#include <KAction>
 #include <KColorScheme>
 #include <KConfigGroup>
-#include <KHBox>
-#include <KLocale>
+#include <KLocalizedString>
 
+#include <QAction>
+#include <QHBoxLayout>
+#include <QVBoxLayout>
 #include <QKeyEvent>
 #include <QLabel>
 #include <QMenu>
@@ -35,94 +36,94 @@ namespace Playlist
 {
 
 ProgressiveSearchWidget::ProgressiveSearchWidget( QWidget * parent )
-    : KVBox( parent )
+: BoxWidget( true, parent )
 {
     DEBUG_BLOCK
 
     readConfig();
 
-    KHBox *searchBox = new KHBox( this );
+    BoxWidget *searchBox = new BoxWidget( false, this );
 
     m_searchEdit = new Amarok::LineEdit( searchBox );
-    m_searchEdit->setClickMessage( i18n( "Search playlist" ) );
+    m_searchEdit->setPlaceholderText( i18n( "Search playlist" ) );
     m_searchEdit->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed );
-    m_searchEdit->setClearButtonShown( true );
+    m_searchEdit->setClearButtonEnabled( true );
     m_searchEdit->setFrame( true );
     m_searchEdit->setToolTip( i18n( "Start typing to progressively search through the playlist" ) );
     m_searchEdit->setFocusPolicy( Qt::ClickFocus ); // Without this, the widget goes into text input mode directly on startup
 
-    connect( m_searchEdit, SIGNAL(textChanged(QString)), this, SLOT(slotFilterChanged(QString)) );
-    connect( m_searchEdit, SIGNAL(returnPressed(QString)), this, SIGNAL(activateFilterResult()) );
-    connect( m_searchEdit, SIGNAL(returnPressed(QString)), this, SLOT(slotFilterClear()) );
-    connect( m_searchEdit, SIGNAL(returnPressed()), this, SLOT(defocus()) );
-    connect( m_searchEdit, SIGNAL(downPressed()), this, SIGNAL(downPressed()) );
-    connect( m_searchEdit, SIGNAL(upPressed()), this, SIGNAL(upPressed()) );
+    connect( m_searchEdit, &Amarok::LineEdit::textChanged, this, &ProgressiveSearchWidget::slotFilterChanged );
+    connect( m_searchEdit, &Amarok::LineEdit::returnPressed, this, &ProgressiveSearchWidget::activateFilterResult );
+    connect( m_searchEdit, &Amarok::LineEdit::returnPressed, this, &ProgressiveSearchWidget::slotFilterClear );
+    connect( m_searchEdit, &Amarok::LineEdit::returnPressed, this, &ProgressiveSearchWidget::defocus );
+    connect( m_searchEdit, &Amarok::LineEdit::downPressed, this, &ProgressiveSearchWidget::downPressed );
+    connect( m_searchEdit, &Amarok::LineEdit::upPressed, this, &ProgressiveSearchWidget::upPressed );
 
-    m_nextAction = new KAction( KIcon( "go-down" ), i18n( "&Next" ), this );
-    connect( m_nextAction, SIGNAL(triggered()), this, SLOT(slotNext()) );
+    m_nextAction = new QAction( QIcon::fromTheme( QStringLiteral("go-down") ), i18n( "&Next" ), this );
+    connect( m_nextAction, &QAction::triggered, this, &ProgressiveSearchWidget::slotNext );
 
-    m_previousAction = new KAction( KIcon( "go-up" ), i18n( "&Previous" ), this );
-    connect( m_previousAction, SIGNAL(triggered()), this, SLOT(slotPrevious()) );
+    m_previousAction = new QAction( QIcon::fromTheme( QStringLiteral("go-up") ), i18n( "&Previous" ), this );
+    connect( m_previousAction, &QAction::triggered, this, &ProgressiveSearchWidget::slotPrevious );
 
     m_nextAction->setEnabled( false );
     m_previousAction->setEnabled( false );
 
     m_menu = new QMenu( this );
 
-    KAction * searchTracksAction = new KAction( i18n( "Tracks" ), this );
+    QAction * searchTracksAction = new QAction( i18n( "Tracks" ), this );
     searchTracksAction->setCheckable( true );
-    connect( searchTracksAction, SIGNAL(toggled(bool)), this, SLOT(slotSearchTracks(bool)) );
+    connect( searchTracksAction, &QAction::toggled, this, &ProgressiveSearchWidget::slotSearchTracks );
     if( m_searchFieldsMask & Playlist::MatchTrack )
         searchTracksAction->setChecked( true );
     m_menu->addAction( searchTracksAction );
 
-    KAction * searchAlbumsAction = new KAction( i18n( "Albums" ), this );
+    QAction * searchAlbumsAction = new QAction( i18n( "Albums" ), this );
     searchAlbumsAction->setCheckable( true );
-    connect( searchAlbumsAction, SIGNAL(toggled(bool)), this, SLOT(slotSearchAlbums(bool)) );
+    connect( searchAlbumsAction, &QAction::toggled, this, &ProgressiveSearchWidget::slotSearchAlbums );
     if( m_searchFieldsMask & Playlist::MatchAlbum )
         searchAlbumsAction->setChecked( true );
     m_menu->addAction( searchAlbumsAction );
 
-    KAction * searchArtistsAction = new KAction( i18n( "Artists" ), this );
+    QAction * searchArtistsAction = new QAction( i18n( "Artists" ), this );
     searchArtistsAction->setCheckable( true );
-    connect( searchArtistsAction, SIGNAL(toggled(bool)), this, SLOT(slotSearchArtists(bool)) );
+    connect( searchArtistsAction, &QAction::toggled, this, &ProgressiveSearchWidget::slotSearchArtists );
     if( m_searchFieldsMask & Playlist::MatchArtist )
         searchArtistsAction->setChecked( true );
     m_menu->addAction( searchArtistsAction );
 
-    KAction * searchGenreAction = new KAction( i18n( "Genre" ), this );
+    QAction * searchGenreAction = new QAction( i18n( "Genre" ), this );
     searchGenreAction->setCheckable( true );
-    connect( searchGenreAction, SIGNAL(toggled(bool)), this, SLOT(slotSearchGenre(bool)) );
+    connect( searchGenreAction, &QAction::toggled, this, &ProgressiveSearchWidget::slotSearchGenre );
     if( m_searchFieldsMask & Playlist::MatchGenre )
         searchGenreAction->setChecked( true );
     m_menu->addAction( searchGenreAction );
 
-    KAction * searchComposersAction = new KAction( i18n( "Composers" ), this );
+    QAction * searchComposersAction = new QAction( i18n( "Composers" ), this );
     searchComposersAction->setCheckable( true );
-    connect( searchComposersAction, SIGNAL(toggled(bool)), this, SLOT(slotSearchComposers(bool)) );
+    connect( searchComposersAction, &QAction::toggled, this, &ProgressiveSearchWidget::slotSearchComposers );
     if( m_searchFieldsMask & Playlist::MatchComposer )
         searchComposersAction->setChecked( true );
     m_menu->addAction( searchComposersAction );
 
-    KAction * searchRatingAction = new KAction( i18n( "Rating" ), this );
+    QAction * searchRatingAction = new QAction( i18n( "Rating" ), this );
     searchRatingAction->setCheckable( true );
-    connect( searchRatingAction, SIGNAL(toggled(bool)), this, SLOT(slotSearchRating(bool)) );
+    connect( searchRatingAction, &QAction::toggled, this, &ProgressiveSearchWidget::slotSearchRating );
     if( m_searchFieldsMask & Playlist::MatchRating )
         searchRatingAction->setChecked( true );
     m_menu->addAction( searchRatingAction );
 
-    KAction * searchYearsAction = new KAction( i18n( "Years" ), this );
+    QAction * searchYearsAction = new QAction( i18n( "Years" ), this );
     searchYearsAction->setCheckable( true );
-    connect( searchYearsAction, SIGNAL(toggled(bool)), this, SLOT(slotSearchYears(bool)) );
+    connect( searchYearsAction, &QAction::toggled, this, &ProgressiveSearchWidget::slotSearchYears );
     if( m_searchFieldsMask & Playlist::MatchYear)
         searchYearsAction->setChecked( true );
     m_menu->addAction( searchYearsAction );
 
     m_menu->addSeparator();
 
-    KAction * showOnlyMatchesAction = new KAction( i18n( "Show only matches" ), this );
+    QAction * showOnlyMatchesAction = new QAction( i18n( "Show only matches" ), this );
     showOnlyMatchesAction->setCheckable( true );
-    connect( showOnlyMatchesAction, SIGNAL(toggled(bool)), this, SLOT(slotShowOnlyMatches(bool)) );
+    connect( showOnlyMatchesAction, &QAction::toggled, this, &ProgressiveSearchWidget::slotShowOnlyMatches );
 
     m_toolBar = new QToolBar( searchBox );
     showOnlyMatchesAction->setChecked( m_showOnlyMatches );
@@ -132,7 +133,7 @@ ProgressiveSearchWidget::ProgressiveSearchWidget( QWidget * parent )
     m_nextAction->setVisible( !m_showOnlyMatches );
     m_previousAction->setVisible( !m_showOnlyMatches );
 
-    KAction *searchMenuAction = new KAction( KIcon( "preferences-other" ), i18n( "Search Preferences" ), this );
+    QAction *searchMenuAction = new QAction( QIcon::fromTheme( QStringLiteral("preferences-other") ), i18n( "Search Preferences" ), this );
     searchMenuAction->setMenu( m_menu );
 
     m_toolBar->addAction( searchMenuAction );
@@ -144,7 +145,7 @@ ProgressiveSearchWidget::ProgressiveSearchWidget( QWidget * parent )
     m_toolBar->setFixedHeight( m_searchEdit->sizeHint().height() );
 
     //make sure that this edit is cleared when the playlist is cleared:
-    connect( Amarok::actionCollection()->action( "playlist_clear" ), SIGNAL(triggered()), this, SLOT(slotFilterClear()) );
+    connect( Amarok::actionCollection()->action( QStringLiteral("playlist_clear") ), &QAction::triggered, this, &ProgressiveSearchWidget::slotFilterClear );
 }
 
 void ProgressiveSearchWidget::slotFilterChanged( const QString & filter )
@@ -169,24 +170,24 @@ void ProgressiveSearchWidget::slotFilterChanged( const QString & filter )
         p.setColor( QPalette::Base, palette().color( QPalette::Base ) );
         m_searchEdit->setPalette( p );
 
-        emit( filterCleared() );
+        Q_EMIT( filterCleared() );
 
         return;
     }
 
-    emit( filterChanged( filter, m_searchFieldsMask, m_showOnlyMatches ) );
+    Q_EMIT( filterChanged( filter, m_searchFieldsMask, m_showOnlyMatches ) );
 }
 
 void ProgressiveSearchWidget::slotNext()
 {
     DEBUG_BLOCK
-    emit( next( m_searchEdit->text(), m_searchFieldsMask ) );
+    Q_EMIT( next( m_searchEdit->text(), m_searchFieldsMask ) );
 }
 
 void ProgressiveSearchWidget::slotPrevious()
 {
     DEBUG_BLOCK
-    emit( previous( m_searchEdit->text(), m_searchFieldsMask ) );
+    Q_EMIT( previous( m_searchEdit->text(), m_searchFieldsMask ) );
 }
 
 void ProgressiveSearchWidget::match()
@@ -218,10 +219,10 @@ void ProgressiveSearchWidget::slotSearchTracks( bool search )
     else
         m_searchFieldsMask ^= Playlist::MatchTrack;
 
-    Amarok::config( "Playlist Search" ).writeEntry( "MatchTrack", search );
+    Amarok::config( QStringLiteral("Playlist Search") ).writeEntry( "MatchTrack", search );
 
     if( !m_searchEdit->text().isEmpty() )
-        emit( filterChanged( m_searchEdit->text(), m_searchFieldsMask, m_showOnlyMatches ) );
+        Q_EMIT( filterChanged( m_searchEdit->text(), m_searchFieldsMask, m_showOnlyMatches ) );
 }
 
 void ProgressiveSearchWidget::slotSearchArtists( bool search )
@@ -231,10 +232,10 @@ void ProgressiveSearchWidget::slotSearchArtists( bool search )
     else
         m_searchFieldsMask ^= Playlist::MatchArtist;
 
-    Amarok::config( "Playlist Search" ).writeEntry( "MatchArtist", search );
+    Amarok::config( QStringLiteral("Playlist Search") ).writeEntry( "MatchArtist", search );
 
     if( !m_searchEdit->text().isEmpty() )
-        emit( filterChanged( m_searchEdit->text(), m_searchFieldsMask, m_showOnlyMatches ) );
+        Q_EMIT( filterChanged( m_searchEdit->text(), m_searchFieldsMask, m_showOnlyMatches ) );
 }
 
 void ProgressiveSearchWidget::slotSearchAlbums( bool search )
@@ -244,10 +245,10 @@ void ProgressiveSearchWidget::slotSearchAlbums( bool search )
     else
         m_searchFieldsMask ^= Playlist::MatchAlbum;
 
-    Amarok::config( "Playlist Search" ).writeEntry( "MatchAlbum", search );
+    Amarok::config( QStringLiteral("Playlist Search") ).writeEntry( "MatchAlbum", search );
 
     if( !m_searchEdit->text().isEmpty() )
-        emit( filterChanged( m_searchEdit->text(), m_searchFieldsMask, m_showOnlyMatches ) );
+        Q_EMIT( filterChanged( m_searchEdit->text(), m_searchFieldsMask, m_showOnlyMatches ) );
 }
 
 void ProgressiveSearchWidget::slotSearchGenre( bool search )
@@ -257,10 +258,10 @@ void ProgressiveSearchWidget::slotSearchGenre( bool search )
     else
         m_searchFieldsMask ^= Playlist::MatchGenre;
 
-    Amarok::config( "Playlist Search" ).writeEntry( "MatchGenre", search );
+    Amarok::config( QStringLiteral("Playlist Search") ).writeEntry( "MatchGenre", search );
 
     if( !m_searchEdit->text().isEmpty() )
-        emit( filterChanged( m_searchEdit->text(), m_searchFieldsMask, m_showOnlyMatches ) );
+        Q_EMIT( filterChanged( m_searchEdit->text(), m_searchFieldsMask, m_showOnlyMatches ) );
 }
 
 void ProgressiveSearchWidget::slotSearchComposers( bool search )
@@ -270,10 +271,10 @@ void ProgressiveSearchWidget::slotSearchComposers( bool search )
     else
         m_searchFieldsMask ^= Playlist::MatchComposer;
 
-    Amarok::config( "Playlist Search" ).writeEntry( "MatchComposer", search );
+    Amarok::config( QStringLiteral("Playlist Search") ).writeEntry( "MatchComposer", search );
 
     if( !m_searchEdit->text().isEmpty() )
-        emit( filterChanged( m_searchEdit->text(), m_searchFieldsMask, m_showOnlyMatches ) );
+        Q_EMIT( filterChanged( m_searchEdit->text(), m_searchFieldsMask, m_showOnlyMatches ) );
 }
 
 void ProgressiveSearchWidget::slotSearchRating( bool search )
@@ -283,10 +284,10 @@ void ProgressiveSearchWidget::slotSearchRating( bool search )
     else
         m_searchFieldsMask ^= Playlist::MatchRating;
 
-    Amarok::config( "Playlist Search" ).writeEntry( "MatchRating", search );
+    Amarok::config( QStringLiteral("Playlist Search") ).writeEntry( "MatchRating", search );
 
     if( !m_searchEdit->text().isEmpty() )
-        emit( filterChanged( m_searchEdit->text(), m_searchFieldsMask, m_showOnlyMatches ) );
+        Q_EMIT( filterChanged( m_searchEdit->text(), m_searchFieldsMask, m_showOnlyMatches ) );
 }
 
 void ProgressiveSearchWidget::slotSearchYears( bool search )
@@ -296,17 +297,17 @@ void ProgressiveSearchWidget::slotSearchYears( bool search )
     else
         m_searchFieldsMask ^= Playlist::MatchYear;
 
-    Amarok::config( "Playlist Search" ).writeEntry( "MatchYear", search );
+    Amarok::config( QStringLiteral("Playlist Search") ).writeEntry( "MatchYear", search );
 
     if( !m_searchEdit->text().isEmpty() )
-        emit( filterChanged( m_searchEdit->text(), m_searchFieldsMask, m_showOnlyMatches ) );
+        Q_EMIT( filterChanged( m_searchEdit->text(), m_searchFieldsMask, m_showOnlyMatches ) );
 }
 
 void ProgressiveSearchWidget::readConfig()
 {
     m_searchFieldsMask = 0;
 
-    KConfigGroup config = Amarok::config("Playlist Search");
+    KConfigGroup config = Amarok::config(QStringLiteral("Playlist Search"));
 
     if( config.readEntry( "MatchTrack", true ) )
         m_searchFieldsMask |= Playlist::MatchTrack;
@@ -345,11 +346,11 @@ void ProgressiveSearchWidget::slotShowOnlyMatches( bool onlyMatches )
     m_nextAction->setVisible( !onlyMatches );
     m_previousAction->setVisible( !onlyMatches );
 
-    KConfigGroup cg = Amarok::config( "Playlist Search" );
+    KConfigGroup cg = Amarok::config( QStringLiteral("Playlist Search") );
     cg.writeEntry( "ShowOnlyMatches", m_showOnlyMatches );
     cg.sync();
 
-    emit( showOnlyMatches( onlyMatches ) );
+    Q_EMIT( showOnlyMatches( onlyMatches ) );
 }
 
 void
@@ -368,7 +369,7 @@ ProgressiveSearchWidget::keyPressEvent( QKeyEvent *event )
     else
     {
         event->ignore();
-        KHBox::keyPressEvent( event );
+        BoxWidget::keyPressEvent( event );
     }
 }
 
@@ -386,4 +387,3 @@ void ProgressiveSearchWidget::slotFilterClear()
 
 }   //namespace Playlist
 
-#include "ProgressiveSearchWidget.moc"
