@@ -20,15 +20,15 @@
 #include "core/support/Debug.h"
 #include "playlist/PlaylistActions.h"
 
-#include <KMenu>
-#include <KLocale>
-#include <KStandardDirs>
+#include <QMenu>
+#include <KLocalizedString>
+#include <QStandardPaths>
 
 NavigatorConfigAction::NavigatorConfigAction( QWidget * parent )
-    : KAction( parent )
+    : QAction( parent )
 {
 
-    KMenu * navigatorMenu = new KMenu( 0 );
+    QMenu * navigatorMenu = new QMenu( 0 );
     setMenu( navigatorMenu );
     setText( i18n( "Track Progression" ) );
 
@@ -36,12 +36,12 @@ NavigatorConfigAction::NavigatorConfigAction( QWidget * parent )
     navigatorActions->setExclusive( true );
 
     m_standardNavigatorAction = navigatorActions->addAction( i18n( "Standard" ) );
-    m_standardNavigatorAction->setIcon( KIcon( "media-standard-track-progression-amarok" ) );
+    m_standardNavigatorAction->setIcon( QIcon::fromTheme( QStringLiteral("media-standard-track-progression-amarok") ) );
     m_standardNavigatorAction->setCheckable( true );
     //action->setIcon( true );
 
     m_onlyQueueNavigatorAction = navigatorActions->addAction( i18n( "Only Queue" ) );
-    m_onlyQueueNavigatorAction->setIcon( KIcon( "media-standard-track-progression-amarok" ) );
+    m_onlyQueueNavigatorAction->setIcon( QIcon::fromTheme( QStringLiteral("media-standard-track-progression-amarok") ) );
     m_onlyQueueNavigatorAction->setCheckable( true );
 
     QAction * action = new QAction( parent );
@@ -49,15 +49,15 @@ NavigatorConfigAction::NavigatorConfigAction( QWidget * parent )
     navigatorActions->addAction( action );
 
     m_repeatTrackNavigatorAction = navigatorActions->addAction( i18n( "Repeat Track" ) );
-    m_repeatTrackNavigatorAction->setIcon( KIcon( "media-repeat-track-amarok" ) );
+    m_repeatTrackNavigatorAction->setIcon( QIcon::fromTheme( QStringLiteral("media-repeat-track-amarok") ) );
     m_repeatTrackNavigatorAction->setCheckable( true );
 
     m_repeatAlbumNavigatorAction = navigatorActions->addAction( i18n( "Repeat Album" ) );
-    m_repeatAlbumNavigatorAction->setIcon( KIcon( "media-repeat-album-amarok" ) );
+    m_repeatAlbumNavigatorAction->setIcon( QIcon::fromTheme( QStringLiteral("media-repeat-album-amarok") ) );
     m_repeatAlbumNavigatorAction->setCheckable( true );
 
     m_repeatPlaylistNavigatorAction = navigatorActions->addAction( i18n( "Repeat Playlist" ) );
-    m_repeatPlaylistNavigatorAction->setIcon( KIcon( "media-repeat-playlist-amarok" ) );
+    m_repeatPlaylistNavigatorAction->setIcon( QIcon::fromTheme( QStringLiteral("media-repeat-playlist-amarok") ) );
     m_repeatPlaylistNavigatorAction->setCheckable( true );
 
     action = new QAction( parent );
@@ -65,11 +65,11 @@ NavigatorConfigAction::NavigatorConfigAction( QWidget * parent )
     navigatorActions->addAction( action );
 
     m_randomTrackNavigatorAction = navigatorActions->addAction( i18n( "Random Tracks" ) );
-    m_randomTrackNavigatorAction->setIcon( KIcon( "media-random-tracks-amarok" ) );
+    m_randomTrackNavigatorAction->setIcon( QIcon::fromTheme( QStringLiteral("media-random-tracks-amarok") ) );
     m_randomTrackNavigatorAction->setCheckable( true );
 
     m_randomAlbumNavigatorAction = navigatorActions->addAction( i18n( "Random Albums" ) );
-    m_randomAlbumNavigatorAction->setIcon( KIcon( "media-random-albums-amarok" ) );
+    m_randomAlbumNavigatorAction->setIcon( QIcon::fromTheme( QStringLiteral("media-random-albums-amarok") ) );
     m_randomAlbumNavigatorAction->setCheckable( true );
 
     navigatorMenu->addActions( navigatorActions->actions() );
@@ -151,9 +151,9 @@ NavigatorConfigAction::NavigatorConfigAction( QWidget * parent )
             break;
     }
 
-     connect( navigatorMenu, SIGNAL(triggered(QAction*)), this, SLOT(setActiveNavigator(QAction*)) );
-     connect( favorMenu, SIGNAL(triggered(QAction*)), this, SLOT(setFavored(QAction*)) );
-     connect( The::playlistActions(), SIGNAL(navigatorChanged()), this, SLOT(navigatorChanged()) );
+     connect( navigatorMenu, &QMenu::triggered, this, &NavigatorConfigAction::setActiveNavigator );
+     connect( favorMenu, &QMenu::triggered, this, &NavigatorConfigAction::setFavored );
+     connect( The::playlistActions(), &Playlist::Actions::navigatorChanged, this, &NavigatorConfigAction::navigatorChanged );
 }
 
 NavigatorConfigAction::~NavigatorConfigAction()
@@ -266,4 +266,3 @@ void NavigatorConfigAction::navigatorChanged()
     }
 }
 
-#include "NavigatorConfigAction.moc"
