@@ -35,10 +35,9 @@ Playlist::TrackNavigator::TrackNavigator()
     // Connect to the QAbstractItemModel signals of the source model.
     //   Ignore SIGNAL dataChanged: we don't need to know when a playlist item changes.
     //   Ignore SIGNAL layoutChanged: we don't need to know when rows are moved around.
-    connect( m_model->qaim(), SIGNAL(modelReset()), this, SLOT(slotModelReset()) );
-    connect( Playlist::ModelStack::instance()->bottom(),
-             SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)),
-             SLOT(slotRowsAboutToBeRemoved(QModelIndex,int,int)) );
+    connect( m_model->qaim(), &QAbstractItemModel::modelReset, this, &TrackNavigator::slotModelReset );
+    connect( Playlist::ModelStack::instance()->bottom(), &Playlist::Model::rowsAboutToBeRemoved,
+             this, &TrackNavigator::slotRowsAboutToBeRemoved );
     //   Ignore SIGNAL rowsInserted.
 }
 
