@@ -20,6 +20,7 @@
 #include "core/meta/Meta.h"
 #include "core/meta/Statistics.h"
 #include "core-impl/playlists/types/file/PlaylistFileSupport.h"
+#include "playlist/PlaylistModel.h"
 
 namespace Playlist
 {
@@ -33,8 +34,10 @@ ProxyBase::ProxyBase( AbstractModel *belowModel, QObject *parent )
     // Proxy the Playlist::AbstractModel signals.
     //   If you need to do something special in a subclass, disconnect() this signal and
     //   do your own connect() call.
-    connect( sourceModel(), SIGNAL(activeTrackChanged(quint64)), this, SIGNAL(activeTrackChanged(quint64)) );
-    connect( sourceModel(), SIGNAL(queueChanged()), this, SIGNAL(queueChanged()) );
+    connect( qobject_cast<Playlist::Model*>( sourceModel() ), &Playlist::Model::activeTrackChanged,
+             this, &ProxyBase::activeTrackChanged );
+    connect( qobject_cast<Playlist::Model*>( sourceModel() ), &Playlist::Model::queueChanged,
+             this, &ProxyBase::queueChanged );
 }
 
 ProxyBase::~ProxyBase()
@@ -103,9 +106,9 @@ ProxyBase::currentSearchTerm()
 }
 
 bool
-ProxyBase::exportPlaylist( const QString &path, bool relative ) const
+ProxyBase::exportPlaylist( const QString &path, bool relative )
 {
-    return Playlists::exportPlaylistFile( tracks(), path, relative );
+    return Playlists::exportPlaylistFile( tracks(), QUrl::fromLocalFile(path), relative );
 }
 
 void
@@ -278,7 +281,7 @@ ProxyBase::trackForId( const quint64 id ) const
 }
 
 Meta::TrackList
-ProxyBase::tracks() const
+ProxyBase::tracks()
 {
     Meta::TrackList tl;
     for( int i = 0; i < rowCount(); ++i )
@@ -296,7 +299,7 @@ ProxyBase::rowMatch( int sourceModelRow, const QString &searchTerms, int searchF
 
     Meta::TrackPtr track = m_belowModel->trackAt( sourceModelRow );
 
-    QStringList searchList = searchTerms.split(' ', QString::SkipEmptyParts);
+    QStringList searchList = searchTerms.split(QLatin1Char(' '), QString::SkipEmptyParts);
 
     foreach( const QString& searchTerm, searchList )
     {
@@ -340,7 +343,7 @@ ProxyBase::rowMatch( int sourceModelRow, const QString &searchTerms, int searchF
         if( searchFields & MatchRating )
         {
             bool ok;
-            int rating = QString( searchTerm ).remove( "rating:" ).toInt( &ok );
+            int rating = QString( searchTerm ).remove( QStringLiteral("rating:") ).toInt( &ok );
             if( ok && ( track->statistics()->rating() == rating ) )
                 match = true;
         }
@@ -381,4 +384,3 @@ ProxyBase::rowToSource( int proxyModelRow ) const
 
 }   //namespace Playlist
 
-#include "ProxyBase.moc"
