@@ -26,23 +26,22 @@
 #include "playlist/proxymodels/GroupingProxy.h"
 #include "playlist/view/listview/PrettyItemDelegate.h"
 
-#include <KHBox>
 #include <KRatingWidget>
-#include <KVBox>
 
 #include <QEvent>
-#include <QBoxLayout>
+#include <QHBoxLayout>
 #include <QKeyEvent>
 #include <QLabel>
 #include <QLineEdit>
 #include <QPainter>
 #include <QPaintEvent>
+#include <QVBoxLayout>
 
 using namespace Playlist;
 
 InlineEditorWidget::InlineEditorWidget( QWidget * parent, const QModelIndex &index,
-                                        PlaylistLayout layout, int height, int width )
-    : KHBox( parent )
+                                        const PlaylistLayout &layout, int height, int width )
+    : BoxWidget( false, parent )
     , m_index( index )
     , m_layout( layout )
     , m_widgetHeight( height )
@@ -123,7 +122,7 @@ void InlineEditorWidget::createChildWidgets()
         }
     }
 
-    KVBox *rowsWidget = new KVBox( this );
+    BoxWidget *rowsWidget = new BoxWidget( true, this );
 
     // --- paint all the rows
     for( int i = 0; i < rowCount; i++ )
@@ -132,7 +131,7 @@ void InlineEditorWidget::createChildWidgets()
         const int elementCount = row.count();
 
         QSplitter *rowWidget = new QSplitter( rowsWidget );
-        connect( rowWidget, SIGNAL(splitterMoved(int,int)), this, SLOT(splitterMoved(int,int)) );
+        connect( rowWidget, &QSplitter::splitterMoved, this, &InlineEditorWidget::splitterMoved );
 
         m_splitterRowMap.insert( rowWidget, i );
 
@@ -193,20 +192,21 @@ void InlineEditorWidget::createChildWidgets()
                 ratingWidget->setRating( rating );
                 ratingWidget->setAttribute( Qt::WA_NoMousePropagation, true );
 
-                connect( ratingWidget, SIGNAL(ratingChanged(uint)), this, SLOT(ratingValueChanged()) );
+                connect( ratingWidget, QOverload<uint>::of(&KRatingWidget::ratingChanged),
+                         this, &InlineEditorWidget::ratingValueChanged );
 
                 m_editorRoleMap.insert( ratingWidget, value );
                 widget = ratingWidget;
             }
             else if( value == Divider )
             {
-                QPixmap left = The::svgHandler()->renderSvg( "divider_left",
+                QPixmap left = The::svgHandler()->renderSvg( QStringLiteral("divider_left"),
                                                              1, rowHeight,
-                                                             "divider_left" );
+                                                             QStringLiteral("divider_left") );
 
-                QPixmap right = The::svgHandler()->renderSvg( "divider_right",
+                QPixmap right = The::svgHandler()->renderSvg( QStringLiteral("divider_right"),
                                                               1, rowHeight,
-                                                              "divider_right" );
+                                                              QStringLiteral("divider_right") );
 
                 QPixmap dividerPixmap( 2, rowHeight );
                 dividerPixmap.fill( Qt::transparent );
@@ -256,7 +256,7 @@ void InlineEditorWidget::createChildWidgets()
                 font.setUnderline( underline );
                 edit->setFont( font );
 
-                connect( edit, SIGNAL(editingFinished()), this, SLOT(editValueChanged()) );
+                connect( edit, &QLineEdit::editingFinished, this, &InlineEditorWidget::editValueChanged );
 
                 //check if this is a column that is editable. If not, make the
                 //line edit read only.
@@ -407,7 +407,7 @@ InlineEditorWidget::eventFilter( QObject *obj, QEvent *event )
                     if( widget )
                     {
                         widget->clearFocus();
-                        emit editingDone( this );
+                        Q_EMIT editingDone( this );
                     }
                     return true;
             }
@@ -417,7 +417,6 @@ InlineEditorWidget::eventFilter( QObject *obj, QEvent *event )
             return false;
     }
     else
-        return KHBox::eventFilter( obj, event );
+        return BoxWidget::eventFilter( obj, event );
 }
 
-#include "InlineEditorWidget.moc"
