@@ -27,6 +27,7 @@
 
 #include "App.h"
 #include "EngineController.h"
+#include "MainWindow.h"
 #include "PaletteHandler.h"
 #include "SvgHandler.h"
 #include "QStringx.h"
@@ -42,7 +43,7 @@
 #include "playlist/view/listview/InlineEditorWidget.h"
 
 #include <KColorScheme>
-#include <kratingpainter.h>  // #include <KratingPainter> does not work on some distros
+#include <KRatingPainter>  // #include <KratingPainter> does not work on some distros
 #include <KWindowSystem>
 
 #include <QAction>
@@ -63,12 +64,12 @@ Playlist::PrettyItemDelegate::PrettyItemDelegate( QObject* parent )
 
     m_animationTimeLine = new QTimeLine( 900, this );
     m_animationTimeLine->setFrameRange( 1000, 600 );
-    connect( m_animationTimeLine, SIGNAL( frameChanged( int ) ), this, SIGNAL( redrawRequested() ) );
+    connect( m_animationTimeLine, &QTimeLine::frameChanged, this, &PrettyItemDelegate::redrawRequested );
 
 #ifdef Q_WS_X11
-    connect( KWindowSystem::self(), SIGNAL( currentDesktopChanged( int ) ), this, SLOT( currentDesktopChanged() ) );
+    connect( KWindowSystem::self(), &KWindowSystem::currentDesktopChanged, this, &PrettyItemDelegate::currentDesktopChanged );
 #endif
-    connect( EngineController::instance(), SIGNAL( playbackStateChanged() ), this, SIGNAL( redrawRequested() ) );
+    connect( EngineController::instance(), &EngineController::playbackStateChanged, this, &PrettyItemDelegate::redrawRequested );
 }
 
 PrettyItemDelegate::~PrettyItemDelegate() { }
@@ -126,7 +127,7 @@ PrettyItemDelegate::paint( QPainter* painter, const QStyleOptionViewItem& option
     QApplication::style()->drawPrimitive( QStyle::PE_PanelItemViewItem, &option, painter );
     painter->translate( option.rect.topLeft() );
 
-    painter->drawPixmap( 0, 0, The::svgHandler()->renderSvgWithDividers( "track", ( int )option.rect.width(), ( int )option.rect.height(), "track" ) );
+    painter->drawPixmap( 0, 0, The::svgHandler()->renderSvgWithDividers( QStringLiteral("track"), ( int )option.rect.width(), ( int )option.rect.height(), QStringLiteral("track") ) );
 
     painter->setPen( The::paletteHandler()->foregroundColor( painter, option.state & QStyle::State_Selected ) );
 
@@ -163,7 +164,6 @@ PrettyItemDelegate::paint( QPainter* painter, const QStyleOptionViewItem& option
 
         QFont boldfont( option.font );
         boldfont.setBold( true );
-        QFontMetricsF bfm( boldfont );
 
         QStyleOptionViewItem headOption( option );
         QStyleOptionViewItem trackOption( option );
@@ -298,7 +298,7 @@ void Playlist::PrettyItemDelegate::paintItem( const LayoutItemConfig &config,
     if( !headerRow && index.data( ActiveTrackRole ).toBool() )
     {
         //paint this in 3 parts to solve stretching issues with wide playlists
-        //TODO: propper 9 part painting, but I don't want to bother with this until we
+        //TODO: proper 9 part painting, but I don't want to bother with this until we
         //get some new graphics anyway...
 
         // -- try not to highlight the indicator row
@@ -326,26 +326,26 @@ void Playlist::PrettyItemDelegate::paintItem( const LayoutItemConfig &config,
         const bool skipCache = opacity == 1.0 ? false : true;
 
         painter->drawPixmap( overlayXOffset, overlayYOffset,
-                             The::svgHandler()->renderSvg( "active_overlay_left",
+                             The::svgHandler()->renderSvg( QStringLiteral("active_overlay_left"),
                                                            endWidth,
                                                            overlayHeight,
-                                                           "active_overlay_left",
+                                                           QStringLiteral("active_overlay_left"),
                                                            skipCache,
                                                            opacity ) );
 
         painter->drawPixmap( overlayXOffset + endWidth, overlayYOffset,
-                             The::svgHandler()->renderSvg( "active_overlay_mid",
+                             The::svgHandler()->renderSvg( QStringLiteral("active_overlay_mid"),
                                                            overlayLength - endWidth * 2,
                                                            overlayHeight,
-                                                           "active_overlay_mid",
+                                                           QStringLiteral("active_overlay_mid"),
                                                            skipCache,
                                                            opacity ) );
 
         painter->drawPixmap( overlayXOffset + ( overlayLength - endWidth ), overlayYOffset,
-                             The::svgHandler()->renderSvg( "active_overlay_right",
+                             The::svgHandler()->renderSvg( QStringLiteral("active_overlay_right"),
                                                            endWidth,
                                                            overlayHeight,
-                                                           "active_overlay_right",
+                                                           QStringLiteral("active_overlay_right"),
                                                            skipCache,
                                                            opacity ) );
     }
@@ -415,7 +415,7 @@ void Playlist::PrettyItemDelegate::paintItem( const LayoutItemConfig &config,
         {
             const int x = markerOffsetX;
             const int y = nominalImageRect.y() + ( coverHeight - smallIconSize );
-            painter->drawPixmap( x, y, The::svgHandler()->renderSvg( "multi_marker", smallIconSize, smallIconSize, "multi_marker" ) );
+            painter->drawPixmap( x, y, The::svgHandler()->renderSvg( QStringLiteral("multi_marker"), smallIconSize, smallIconSize, QStringLiteral("multi_marker") ) );
 
             markerOffsetX += ( smallIconSize + iconSpacing );
 
@@ -427,7 +427,7 @@ void Playlist::PrettyItemDelegate::paintItem( const LayoutItemConfig &config,
         {
             const int x = markerOffsetX;
             const int y = nominalImageRect.y() + ( coverHeight - smallIconSize );
-            painter->drawPixmap( x, y, The::svgHandler()->renderSvg( "stop_button", smallIconSize, smallIconSize, "stop_button" ) );
+            painter->drawPixmap( x, y, The::svgHandler()->renderSvg( QStringLiteral("stop_button"), smallIconSize, smallIconSize, QStringLiteral("stop_button") ) );
 
             markerOffsetX += ( smallIconSize + iconSpacing );
 
@@ -518,13 +518,13 @@ void Playlist::PrettyItemDelegate::paintItem( const LayoutItemConfig &config,
             }
             else if( value == Divider )
             {
-                QPixmap left = The::svgHandler()->renderSvg( "divider_left",
+                QPixmap left = The::svgHandler()->renderSvg( QStringLiteral("divider_left"),
                                                              1, rowHeight ,
-                                                             "divider_left" );
+                                                             QStringLiteral("divider_left") );
 
-                QPixmap right = The::svgHandler()->renderSvg( "divider_right",
+                QPixmap right = The::svgHandler()->renderSvg( QStringLiteral("divider_right"),
                                                               1, rowHeight,
-                                                              "divider_right" );
+                                                              QStringLiteral("divider_right") );
 
                 if( alignment & Qt::AlignLeft )
                 {
@@ -617,39 +617,39 @@ void Playlist::PrettyItemDelegate::paintActiveTrackExtras( const QRect &rect, QP
 
     int offset = x + frameHMargin;
     painter->drawPixmap( offset, y + 2,
-                         The::svgHandler()->renderSvg( "back_button",
+                         The::svgHandler()->renderSvg( QStringLiteral("back_button"),
                                                        buttonSize, buttonSize,
-                                                       "back_button" ) );
+                                                       QStringLiteral("back_button") ) );
 
     if( The::engineController()->isPlaying() )
     {
         offset += ( buttonSize + iconSpacing );
         painter->drawPixmap( offset, y + 2,
-                             The::svgHandler()->renderSvg( "pause_button",
+                             The::svgHandler()->renderSvg( QStringLiteral("pause_button"),
                                                            buttonSize, buttonSize,
-                                                           "pause_button" ) );
+                                                           QStringLiteral("pause_button") ) );
 
     }
     else
     {
         offset += ( buttonSize + iconSpacing );
         painter->drawPixmap( offset, y + 2,
-                             The::svgHandler()->renderSvg( "play_button",
+                             The::svgHandler()->renderSvg( QStringLiteral("play_button"),
                                                            buttonSize, buttonSize,
-                                                           "play_button" ) );
+                                                           QStringLiteral("play_button") ) );
     }
 
     offset += ( buttonSize + iconSpacing );
     painter->drawPixmap( offset, y + 2,
-                         The::svgHandler()->renderSvg( "stop_button",
+                         The::svgHandler()->renderSvg( QStringLiteral("stop_button"),
                                                        buttonSize, buttonSize,
-                                                       "stop_button" ) );
+                                                       QStringLiteral("stop_button") ) );
 
     offset += ( buttonSize + iconSpacing );
     painter->drawPixmap( offset, y + 2,
-                         The::svgHandler()->renderSvg( "next_button",
+                         The::svgHandler()->renderSvg( QStringLiteral("next_button"),
                                                        buttonSize, buttonSize,
-                                                       "next_button" ) );
+                                                       QStringLiteral("next_button") ) );
 
     offset += ( buttonSize + iconSpacing );
 
@@ -702,7 +702,7 @@ bool Playlist::PrettyItemDelegate::clicked( const QPoint &pos, const QRect &item
     QRect backRect( offset, extrasOffsetY + 2, buttonSize, buttonSize );
     if( backRect.contains( pos ) )
     {
-         Amarok::actionCollection()->action( "prev" )->trigger();
+         Amarok::actionCollection()->action( QStringLiteral("prev") )->trigger();
          return true;
     }
 
@@ -710,7 +710,7 @@ bool Playlist::PrettyItemDelegate::clicked( const QPoint &pos, const QRect &item
     QRect playRect( offset, extrasOffsetY + 2, buttonSize, buttonSize );
     if( playRect.contains( pos ) )
     {
-         Amarok::actionCollection()->action( "play_pause" )->trigger();
+         Amarok::actionCollection()->action( QStringLiteral("play_pause") )->trigger();
          return true;
     }
 
@@ -718,7 +718,7 @@ bool Playlist::PrettyItemDelegate::clicked( const QPoint &pos, const QRect &item
     QRect stopRect( offset, extrasOffsetY + 2, buttonSize, buttonSize );
     if( stopRect.contains( pos ) )
     {
-         Amarok::actionCollection()->action( "stop" )->trigger();
+         Amarok::actionCollection()->action( QStringLiteral("stop") )->trigger();
          return true;
     }
 
@@ -727,7 +727,7 @@ bool Playlist::PrettyItemDelegate::clicked( const QPoint &pos, const QRect &item
     QRect nextRect( offset, extrasOffsetY + 2, buttonSize, buttonSize );
     if( nextRect.contains( pos ) )
     {
-         Amarok::actionCollection()->action( "next" )->trigger();
+         Amarok::actionCollection()->action( QStringLiteral("next") )->trigger();
          return true;
     }
 
@@ -764,8 +764,8 @@ QWidget* Playlist::PrettyItemDelegate::createEditor( QWidget * parent, const QSt
     InlineEditorWidget *editor = new InlineEditorWidget( parent, index,
                      LayoutManager::instance()->activeLayout(), editorHeight, editorWidth );
 
-    connect( editor, SIGNAL(editingDone(InlineEditorWidget*)),
-             this, SLOT(editorDone(InlineEditorWidget*)) );
+    connect( editor, &InlineEditorWidget::editingDone,
+             this, &PrettyItemDelegate::editorDone );
     return editor;
 }
 
@@ -883,7 +883,7 @@ Playlist::PrettyItemDelegate::updateEditorGeometry( QWidget * editor, const QSty
 void
 Playlist::PrettyItemDelegate::editorDone( InlineEditorWidget * editor )
 {
-    emit commitData( editor );
+    Q_EMIT commitData( editor );
 }
 
 void
@@ -896,7 +896,7 @@ Playlist::PrettyItemDelegate::currentDesktopChanged()
 }
 
 QMap<QString, QString>
-Playlist::PrettyItemDelegate::buildTrackArgsMap( const Meta::TrackPtr track ) const
+Playlist::PrettyItemDelegate::buildTrackArgsMap( const Meta::TrackPtr &track ) const
 {
     QMap<QString, QString> args;
     QString artist = track->artist() ? track->artist()->name() : QString();
@@ -907,35 +907,34 @@ Playlist::PrettyItemDelegate::buildTrackArgsMap( const Meta::TrackPtr track ) co
         albumartist = artist;
 
 
-    args["title"] = track->name();
-    args["composer"] = track->composer() ? track->composer()->name() : QString();
+    args[QStringLiteral("title")] = track->name();
+    args[QStringLiteral("composer")] = track->composer() ? track->composer()->name() : QString();
 
     // if year == 0 then we don't want include it
     QString year = track->year() ? track->year()->name() : QString();
-    args["year"] = year.localeAwareCompare( "0" ) == 0 ? QString() : year;
-    args["album"] = track->album() ? track->album()->name() : QString();
+    args[QStringLiteral("year")] = year.localeAwareCompare( QStringLiteral("0") ) == 0 ? QString() : year;
+    args[QStringLiteral("album")] = track->album() ? track->album()->name() : QString();
 
     if( track->discNumber() )
-        args["discnumber"] = QString::number( track->discNumber() );
+        args[QStringLiteral("discnumber")] = QString::number( track->discNumber() );
 
-    args["genre"] = track->genre() ? track->genre()->name() : QString();
-    args["comment"] = track->comment();
-    args["artist"] = artist;
-    args["albumartist"] = albumartist;
-    args["initial"] = albumartist.mid( 0, 1 ).toUpper();    //artists starting with The are already handled above
-    args["filetype"] = track->type();
+    args[QStringLiteral("genre")] = track->genre() ? track->genre()->name() : QString();
+    args[QStringLiteral("comment")] = track->comment();
+    args[QStringLiteral("artist")] = artist;
+    args[QStringLiteral("albumartist")] = albumartist;
+    args[QStringLiteral("initial")] = albumartist.mid( 0, 1 ).toUpper();    //artists starting with The are already handled above
+    args[QStringLiteral("filetype")] = track->type();
 
-    args["rating"] = track->statistics()->rating();
-    args["filesize"] = track->filesize();
-    args["length"] = track->length() / 1000;
+    args[QStringLiteral("rating")] = track->statistics()->rating();
+    args[QStringLiteral("filesize")] = track->filesize();
+    args[QStringLiteral("length")] = track->length() / 1000;
 
     if ( track->trackNumber() )
     {
-        QString trackNum = QString( "%1" ).arg( track->trackNumber(), 2, 10, QChar('0') );
-        args["track"] = trackNum;
+        QString trackNum = QStringLiteral( "%1" ).arg( track->trackNumber(), 2, 10, QChar('0') );
+        args[QStringLiteral("track")] = trackNum;
     }
 
     return args;
 }
 
-#include "PrettyItemDelegate.moc"
