@@ -28,7 +28,6 @@
 #include "amarokconfig.h"
 #include "AmarokMimeData.h"
 #include "context/ContextView.h"
-#include "context/popupdropper/libpud/PopupDropperItem.h"
 #include "context/popupdropper/libpud/PopupDropper.h"
 #include "core/support/Debug.h"
 #include "EngineController.h"
@@ -50,24 +49,26 @@
 #include "SvgHandler.h"
 #include "SourceSelectionPopup.h"
 
-#include <KApplication>
-#include <KMenu>
-#include <KUrl>
-#include <KLocale>
-
+#include <QApplication>
 #include <QClipboard>
 #include <QContextMenuEvent>
 #include <QDropEvent>
 #include <QItemSelection>
 #include <QKeyEvent>
 #include <QListView>
+#include <QMenu>
 #include <QModelIndex>
 #include <QMouseEvent>
 #include <QPainter>
 #include <QPalette>
 #include <QPersistentModelIndex>
 #include <QScrollBar>
+#include <QSvgRenderer>
 #include <QTimer>
+#include <QUrl>
+
+#include <KLocalizedString>
+
 
 Playlist::PrettyListView::PrettyListView( QWidget* parent )
         : QListView( parent )
@@ -84,7 +85,7 @@ Playlist::PrettyListView::PrettyListView( QWidget* parent )
     setModel( The::playlist()->qaim() );
 
     m_prettyDelegate = new PrettyItemDelegate( this );
-    connect( m_prettyDelegate, SIGNAL( redrawRequested() ), this, SLOT( redrawActive() ) );
+    connect( m_prettyDelegate, &PrettyItemDelegate::redrawRequested, this, &Playlist::PrettyListView::redrawActive );
     setItemDelegate( m_prettyDelegate );
 
     setSelectionMode( ExtendedSelection );
@@ -101,33 +102,37 @@ Playlist::PrettyListView::PrettyListView( QWidget* parent )
     setFrameShape( QFrame::NoFrame );
     setAlternatingRowColors( true) ;
     The::paletteHandler()->updateItemView( this );
-    connect( The::paletteHandler(), SIGNAL(newPalette(QPalette)), SLOT(newPalette(QPalette)) );
+    connect( The::paletteHandler(), &PaletteHandler::newPalette, this, &PrettyListView::newPalette );
 
     setAutoFillBackground( false );
 
 
     // Signal connections
-    connect( this, SIGNAL(doubleClicked(QModelIndex)),
-             this, SLOT(trackActivated(QModelIndex)) );
-    connect( selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-             this, SLOT(slotSelectionChanged()) );
+    connect( this, &Playlist::PrettyListView::doubleClicked,
+             this, &Playlist::PrettyListView::trackActivated );
+    connect( selectionModel(), &QItemSelectionModel::selectionChanged,
+             this, &Playlist::PrettyListView::slotSelectionChanged );
 
-    connect( LayoutManager::instance(), SIGNAL(activeLayoutChanged()), this, SLOT(playlistLayoutChanged()) );
+    connect( LayoutManager::instance(), &LayoutManager::activeLayoutChanged, this, &PrettyListView::playlistLayoutChanged );
 
-    connect( model(), SIGNAL(activeTrackChanged(quint64)), this, SLOT(slotPlaylistActiveTrackChanged()) );
-
-    connect( model(), SIGNAL(queueChanged()), viewport(), SLOT(update()) );
+    if (auto m = static_cast<Playlist::Model*>(model()))
+    {
+        connect( m, &Playlist::Model::activeTrackChanged, this, &Playlist::PrettyListView::slotPlaylistActiveTrackChanged );
+        connect( m, &Playlist::Model::queueChanged, viewport(), QOverload<>::of(&QWidget::update) );
+    }
+    else
+        warning() << "Model is not a Playlist::Model";
 
     //   Warning, this one doesn't connect to the normal 'model()' (i.e. '->top()'), but to '->bottom()'.
-    connect( Playlist::ModelStack::instance()->bottom(), SIGNAL(rowsInserted(QModelIndex,int,int)), this, SLOT(bottomModelRowsInserted(QModelIndex,int,int)) );
+    connect( Playlist::ModelStack::instance()->bottom(), &Playlist::Model::rowsInserted, this, &Playlist::PrettyListView::bottomModelRowsInserted );
 
     // Timers
     m_proxyUpdateTimer = new QTimer( this );
     m_proxyUpdateTimer->setSingleShot( true );
-    connect( m_proxyUpdateTimer, SIGNAL(timeout()), this, SLOT(updateProxyTimeout()) );
+    connect( m_proxyUpdateTimer, &QTimer::timeout, this, &Playlist::PrettyListView::updateProxyTimeout );
 
     m_animationTimer = new QTimer(this);
-    connect( m_animationTimer, SIGNAL(timeout()), this, SLOT(redrawActive()) );
+    connect( m_animationTimer, &QTimer::timeout, this, &Playlist::PrettyListView::redrawActive );
     m_animationTimer->setInterval( 250 );
 
     playlistLayoutChanged();
@@ -371,7 +376,7 @@ Playlist::PrettyListView::selectionModel_setCurrentIndex( const QModelIndex &ind
 void
 Playlist::PrettyListView::showEvent( QShowEvent* event )
 {
-    QTimer::singleShot( 0, this, SLOT(fixInvisible()) );
+    QTimer::singleShot( 0, this, &Playlist::PrettyListView::fixInvisible );
 
     QListView::showEvent( event );
 }
@@ -584,10 +589,10 @@ Playlist::PrettyListView::mousePressEvent( QMouseEvent* event )
 
     if ( event->button() == Qt::MidButton )
     {
-        KUrl url( QApplication::clipboard()->text() );
+        QUrl url( QApplication::clipboard()->text() );
         if ( url.isValid() )
         {
-            QList<KUrl> urls = QList<KUrl>() << url;
+            QList<QUrl> urls = QList<QUrl>() << url;
             if( index.isValid() )
                 The::playlistController()->insertUrls( index.row() + 1, urls );
             else
@@ -670,7 +675,7 @@ Playlist::PrettyListView::paintEvent( QPaintEvent *event )
         if( m_dropIndicator.isValid() )
         {
             const QPoint offset( 6, 0 );
-            QColor c = KApplication::palette().color( QPalette::Highlight );
+            QColor c = QApplication::palette().color( QPalette::Highlight );
             painter.setPen( QPen( c, 6, Qt::SolidLine, Qt::RoundCap ) );
             painter.drawLine( m_dropIndicator.topLeft() + offset,
                               m_dropIndicator.topRight() - offset );
@@ -685,7 +690,7 @@ Playlist::PrettyListView::paintEvent( QPaintEvent *event )
             else
                 emptyText = i18n( "Add some songs here by dragging them from all around." );
 
-            QColor c = KApplication::palette().color( foregroundRole() );
+            QColor c = QApplication::palette().color( foregroundRole() );
             c.setAlpha( c.alpha() / 2 );
             painter.setPen( c );
             painter.drawText( rect(),
@@ -717,10 +722,10 @@ Playlist::PrettyListView::startDrag( Qt::DropActions supportedActions )
 
     if( m_pd && m_pd->isHidden() )
     {
-        m_pd->setSvgRenderer( The::svgHandler()->getRenderer( "amarok/images/pud_items.svg" ) );
-        qDebug() << "svgHandler SVG renderer is " << (QObject*)(The::svgHandler()->getRenderer( "amarok/images/pud_items.svg" ));
+        m_pd->setSvgRenderer( The::svgHandler()->getRenderer( QStringLiteral("amarok/images/pud_items.svg") ) );
+        qDebug() << "svgHandler SVG renderer is " << (QObject*)(The::svgHandler()->getRenderer( QStringLiteral("amarok/images/pud_items.svg") ));
         qDebug() << "m_pd SVG renderer is " << (QObject*)(m_pd->svgRenderer());
-        qDebug() << "does play exist in renderer? " << ( The::svgHandler()->getRenderer( "amarok/images/pud_items.svg" )->elementExists( "load" ) );
+        qDebug() << "does play exist in renderer? " << ( The::svgHandler()->getRenderer( QStringLiteral("amarok/images/pud_items.svg") )->elementExists( QStringLiteral("load") ) );
 
         QList<QAction*> actions =  actionsFor( this, &indices.first() );
         foreach( QAction * action, actions )
@@ -735,7 +740,7 @@ Playlist::PrettyListView::startDrag( Qt::DropActions supportedActions )
     if( m_pd )
     {
         debug() << "clearing PUD";
-        connect( m_pd, SIGNAL(fadeHideFinished()), m_pd, SLOT(clear()) );
+        connect( m_pd, &PopupDropper::fadeHideFinished, m_pd, &PopupDropper::clear );
         m_pd->hide();
     }
     ongoingDrags = false;
@@ -855,10 +860,10 @@ void Playlist::PrettyListView::findNext( const QString & searchTerm, int fields
         if ( foundIndex.isValid() )
             scrollTo( foundIndex, QAbstractItemView::PositionAtCenter );
 
-        emit( found() );
+        Q_EMIT( found() );
     }
     else
-        emit( notFound() );
+        Q_EMIT( notFound() );
 
     if ( updateProxy )
         The::playlist()->filterUpdated();
@@ -891,10 +896,10 @@ void Playlist::PrettyListView::findPrevious( const QString & searchTerm, int fie
         if ( foundIndex.isValid() )
             scrollTo( foundIndex, QAbstractItemView::PositionAtCenter );
 
-        emit( found() );
+        Q_EMIT( found() );
     }
     else
-        emit( notFound() );
+        Q_EMIT( notFound() );
 
     if ( updateProxy )
         The::playlist()->filterUpdated();
@@ -951,10 +956,10 @@ void Playlist::PrettyListView::updateProxyTimeout()
                 scrollTo( foundIndex, QAbstractItemView::PositionAtCenter );
         }
 
-        emit( found() );
+        Q_EMIT( found() );
     }
     else
-        emit( notFound() );
+        Q_EMIT( notFound() );
 }
 
 void Playlist::PrettyListView::showOnlyMatches( bool onlyMatches )
@@ -967,7 +972,7 @@ void Playlist::PrettyListView::showOnlyMatches( bool onlyMatches )
 // Handle scrolling to newly inserted playlist items.
 // Warning, this slot is connected to the 'rowsInserted' signal of the *bottom* model,
 // not the normal top model.
-// The reason: FilterProxy can emit *A LOT* (thousands) of 'rowsInserted' signals when its
+// The reason: FilterProxy can Q_EMIT *A LOT* (thousands) of 'rowsInserted' signals when its
 // search string changes. For that case we don't want to do any scrollTo() at all.
 void
 Playlist::PrettyListView::bottomModelRowsInserted( const QModelIndex& parent, int start, int end )
@@ -979,7 +984,7 @@ Playlist::PrettyListView::bottomModelRowsInserted( const QModelIndex& parent, in
     if( m_rowsInsertedScrollItem == 0 && !AmarokConfig::dynamicMode() )
     {
         m_rowsInsertedScrollItem = Playlist::ModelStack::instance()->bottom()->idAt( start );
-        QTimer::singleShot( 0, this, SLOT(bottomModelRowsInsertedScroll()) );
+        QTimer::singleShot( 0, this, &Playlist::PrettyListView::bottomModelRowsInsertedScroll );
     }
 }
 
@@ -1043,7 +1048,6 @@ void Playlist::PrettyListView::playlistLayoutChanged()
     update();
 
     // Schedule a re-scroll to the active playlist row. Assumption: Qt will run this *after* the repaint.
-    QTimer::singleShot( 0, this, SLOT(slotPlaylistActiveTrackChanged()) );
+    QTimer::singleShot( 0, this, &Playlist::PrettyListView::slotPlaylistActiveTrackChanged );
 }
 
-#include "PrettyListView.moc"
