@@ -1,5 +1,5 @@
 /****************************************************************************************
- * Copyright (c) 2008-2011 Soren Harward <stharward@gmail.com>                          *
+ * Copyright (c) 2008-2012 Soren Harward <stharward@gmail.com>                          *
  *                                                                                      *
  * This program is free software; you can redistribute it and/or modify it under        *
  * the terms of the GNU General Public License as published by the Free Software        *
@@ -31,13 +31,13 @@
 ConstraintGroup::ConstraintGroup( QDomElement& xmlelem, ConstraintNode* p ) : ConstraintNode( p )
 {
     DEBUG_BLOCK
-    if ( xmlelem.tagName() == "group" ) {
-        if ( xmlelem.attribute( "matchtype" ) == "any" ) {
+    if ( xmlelem.tagName() == QLatin1String("group") ) {
+        if ( xmlelem.attribute( QStringLiteral("matchtype") ) == QLatin1String("any") ) {
             m_matchtype = MatchAny;
         } else {
             m_matchtype = MatchAll;
         }
-    } else if ( xmlelem.tagName() == "constrainttree" ) {
+    } else if ( xmlelem.tagName() == QLatin1String("constrainttree") ) {
         // root node of a constraint tree
         m_matchtype = MatchAll;
     } else {
@@ -62,9 +62,9 @@ ConstraintGroup::createFromXml( QDomElement& xmlelem, ConstraintNode* p )
     for ( int i = 0; i < xmlelem.childNodes().count(); i++ ) {
         QDomElement childXmlElem = xmlelem.childNodes().item( i ).toElement();
         if ( !childXmlElem.isNull() ) {
-            if ( childXmlElem.tagName() == "group" ) {
+            if ( childXmlElem.tagName() == QLatin1String("group") ) {
                 cfact->createGroup( childXmlElem, cg );
-            } else if ( childXmlElem.tagName() == "constraint" ) {
+            } else if ( childXmlElem.tagName() == QLatin1String("constraint") ) {
                 cfact->createConstraint( childXmlElem, cg );
             } else {
                 debug() << "unknown child: " << childXmlElem.nodeName();
@@ -84,11 +84,11 @@ QString
 ConstraintGroup::getName() const
 {
     if ( m_matchtype == MatchAny ) {
-        return QString( i18nc("name of a type of constraint group", "\"Match Any\" group") );
+        return i18nc("name of a type of constraint group", "\"Match Any\" group");
     } else if ( m_matchtype == MatchAll ) {
-        return QString( i18nc("name of a type of constraint group", "\"Match All\" group") );
+        return i18nc("name of a type of constraint group", "\"Match All\" group");
     } else {
-        return QString( i18nc("name of a type of constraint group", "Unknown match group") );
+        return i18nc("name of a type of constraint group", "Unknown match group");
     }
 }
 
@@ -96,8 +96,8 @@ QWidget*
 ConstraintGroup::editWidget() const
 {
     ConstraintGroupEditWidget* e = new ConstraintGroupEditWidget( m_matchtype );
-    connect( e, SIGNAL( clickedMatchAny() ), this, SLOT( setMatchAny() ) );
-    connect( e, SIGNAL( clickedMatchAll() ), this, SLOT( setMatchAll() ) );
+    connect( e, &ConstraintGroupEditWidget::clickedMatchAny, this, &ConstraintGroup::setMatchAny );
+    connect( e, &ConstraintGroupEditWidget::clickedMatchAll, this, &ConstraintGroup::setMatchAll );
     return e;
 }
 
@@ -106,14 +106,14 @@ ConstraintGroup::toXml( QDomDocument& doc, QDomElement& elem ) const
 {
     QDomElement group;
 
-    if ( elem.tagName() == "generatorpreset" ) {
-        group = doc.createElement( "constrainttree" ); // unmodifiable root element of the constraint tree
+    if ( elem.tagName() == QLatin1String("generatorpreset") ) {
+        group = doc.createElement( QStringLiteral("constrainttree") ); // unmodifiable root element of the constraint tree
     } else {
-        group = doc.createElement( "group" );
+        group = doc.createElement( QStringLiteral("group") );
         if ( m_matchtype == MatchAny ) {
-            group.setAttribute( "matchtype", "any" );
+            group.setAttribute( QStringLiteral("matchtype"), QStringLiteral("any") );
         } else {
-            group.setAttribute( "matchtype", "all" );
+            group.setAttribute( QStringLiteral("matchtype"), QStringLiteral("all") );
         }
     }
 
@@ -198,12 +198,12 @@ ConstraintGroup::satisfaction( const Meta::TrackList& l ) const
 }
 
 quint32
-ConstraintGroup::suggestInitialPlaylistSize() const
+ConstraintGroup::suggestPlaylistSize() const
 {
     quint32 s = 0;
     quint32 c = 0;
     foreach( ConstraintNode* child, m_children ) {
-        quint32 x = child->suggestInitialPlaylistSize();
+        quint32 x = child->suggestPlaylistSize();
         if ( x > 0 ) {
             s += x;
             c++;
@@ -216,16 +216,6 @@ ConstraintGroup::suggestInitialPlaylistSize() const
     }
 }
 
-#ifndef KDE_NO_DEBUG_OUTPUT
-void
-ConstraintGroup::audit( const Meta::TrackList& tl ) const
-{
-    foreach( ConstraintNode* child, m_children ) {
-        child->audit( tl );
-    }
-}
-#endif
-
 double
 ConstraintGroup::combineInterdependentConstraints( const Meta::TrackList& l, const double s, const QHash<int,int>& cmt ) const
 {
@@ -277,14 +267,14 @@ void
 ConstraintGroup::setMatchAny()
 {
     m_matchtype = MatchAny;
-    emit dataChanged();
+    Q_EMIT dataChanged();
 }
 
 void
 ConstraintGroup::setMatchAll()
 {
     m_matchtype = MatchAll;
-    emit dataChanged();
+    Q_EMIT dataChanged();
 }
 
 /******************************
@@ -310,8 +300,8 @@ void
 ConstraintGroupEditWidget::on_radioButton_MatchAll_clicked( bool c )
 {
     if ( c ) {
-        emit clickedMatchAll();
-        emit updated();
+        Q_EMIT clickedMatchAll();
+        Q_EMIT updated();
     }
 }
 
@@ -319,7 +309,7 @@ void
 ConstraintGroupEditWidget::on_radioButton_MatchAny_clicked( bool c )
 {
     if ( c ) {
-        emit clickedMatchAny();
-        emit updated();
+        Q_EMIT clickedMatchAny();
+        Q_EMIT updated();
     }
 }
