@@ -43,22 +43,22 @@ class ConstraintGroup : public ConstraintNode {
         static ConstraintGroup* createFromXml( QDomElement&, ConstraintNode* );
         static ConstraintGroup* createNew( ConstraintNode* );
 
-        virtual QString getName() const;
-        virtual int getNodeType() const { return ConstraintNode::ConstraintGroupType; }
-        virtual QWidget* editWidget() const;
-        virtual void toXml( QDomDocument&, QDomElement& ) const;
+        QString getName() const override;
+        int getNodeType() const override { return ConstraintNode::ConstraintGroupType; }
+        QWidget* editWidget() const override;
+        void toXml( QDomDocument&, QDomElement& ) const override;
 
-        virtual Collections::QueryMaker* initQueryMaker( Collections::QueryMaker* ) const;
-        virtual double satisfaction( const Meta::TrackList& ) const;
-        virtual quint32 suggestPlaylistSize() const;
+        Collections::QueryMaker* initQueryMaker( Collections::QueryMaker* ) const override;
+        double satisfaction( const Meta::TrackList& ) const override;
+        quint32 suggestPlaylistSize() const override;
 
-    private slots:
+    private Q_SLOTS:
         void setMatchAny();
         void setMatchAll();
 
     private:
         ConstraintGroup(QDomElement&, ConstraintNode*);
-        ConstraintGroup(ConstraintNode*);
+        explicit ConstraintGroup(ConstraintNode*);
 
         // parameters
         MatchType m_matchtype;
@@ -71,14 +71,14 @@ class ConstraintGroupEditWidget : public QWidget {
     Q_OBJECT
 
     public:
-        ConstraintGroupEditWidget( const ConstraintGroup::MatchType );
+        explicit ConstraintGroupEditWidget( const ConstraintGroup::MatchType );
 
-    signals:
+    Q_SIGNALS:
         void updated();
         void clickedMatchAll();
         void clickedMatchAny();
 
-    private slots:
+    private Q_SLOTS:
         void on_radioButton_MatchAll_clicked( bool );
         void on_radioButton_MatchAny_clicked( bool );
 
