@@ -16,10 +16,6 @@
 
 #define DEBUG_PREFIX "APG::ConstraintSolver"
 
-// WORKAROUND for QTBUG-25960. Required for Qt versions < 4.8.5 in combination with libc++.
-#define QT_NO_STL 1
-    #include <qiterator.h>
-#undef QT_NO_STL
 
 #include "ConstraintSolver.h"
 
@@ -29,16 +25,18 @@
 #include "core/meta/Meta.h"
 #include "core/support/Debug.h"
 #include "core/support/Components.h"
-#include "core/interfaces/Logger.h"
+#include "core/logger/Logger.h"
 #include "core-impl/collections/support/CollectionManager.h"
 #include "playlist/PlaylistModel.h"
 
+#include <KLocalizedString>
 #include <KRandom>
+
 #include <QHash>
 #include <QMutexLocker>
 #include <QStringList>
 #include <QTimer>
-#include <threadweaver/ThreadWeaver.h>
+#include <ThreadWeaver/ThreadWeaver>
 
 #include <algorithm> // STL algorithms
 #include <cmath>
@@ -47,7 +45,9 @@
 const int APG::ConstraintSolver::QUALITY_RANGE = 10;
 
 APG::ConstraintSolver::ConstraintSolver( ConstraintNode* r, int qualityFactor )
-        : m_satisfactionThreshold( 0.95 )
+        : QObject()
+        , ThreadWeaver::Job()
+        , m_satisfactionThreshold( 0.95 )
         , m_finalSatisfaction( 0.0 )
         , m_constraintTreeRoot( r )
         , m_domainReductionFailed( false )
@@ -72,8 +72,10 @@ APG::ConstraintSolver::ConstraintSolver( ConstraintNode* r, int qualityFactor )
     if ( m_qm ) {
         debug() << "New ConstraintSolver with serial number" << m_serialNumber;
         m_qm->setQueryType( Collections::QueryMaker::Track );
-        connect( m_qm, SIGNAL(newResultReady(Meta::TrackList)), this, SLOT(receiveQueryMakerData(Meta::TrackList)), Qt::QueuedConnection );
-        connect( m_qm, SIGNAL(queryDone()), this, SLOT(receiveQueryMakerDone()), Qt::QueuedConnection );
+        connect( m_qm, &Collections::QueryMaker::newTracksReady,
+                 this, &APG::ConstraintSolver::receiveQueryMakerData, Qt::QueuedConnection );
+        connect( m_qm, &Collections::QueryMaker::queryDone,
+                 this, &APG::ConstraintSolver::receiveQueryMakerDone, Qt::QueuedConnection );
         m_constraintTreeRoot->initQueryMaker( m_qm );
         m_qm->run();
     } else {
@@ -135,8 +137,11 @@ APG::ConstraintSolver::success() const
 }
 
 void
-APG::ConstraintSolver::run()
+APG::ConstraintSolver::run(ThreadWeaver::JobPointer self, ThreadWeaver::Thread *thread)
 {
+    Q_UNUSED(self);
+    Q_UNUSED(thread);
+
     if ( !m_readyToRun ) {
         error() << "DANGER WILL ROBINSON!  A ConstraintSolver (serial no:" << m_serialNumber << ") tried to run before its QueryMaker finished!";
         m_abortRequested = true;
@@ -152,12 +157,12 @@ APG::ConstraintSolver::run()
 
     debug() << "Running ConstraintSolver" << m_serialNumber;
 
-    emit totalSteps( m_maxGenerations );
+    Q_EMIT totalSteps( m_maxGenerations );
 
     // GENETIC ALGORITHM LOOP
     Population population;
     quint32 generation = 0;
-    Meta::TrackList* best = NULL;
+    Meta::TrackList* best = nullptr;
     while ( !m_abortRequested && ( generation < m_maxGenerations ) ) {
         quint32 s = m_constraintTreeRoot->suggestPlaylistSize();
         m_suggestedPlaylistSize = (s > 0) ? s : m_suggestedPlaylistSize;
@@ -167,15 +172,19 @@ APG::ConstraintSolver::run()
             select_population( population, best );
             mutate_population( population );
             generation++;
-            emit incrementProgress();
+            Q_EMIT incrementProgress();
         } else {
             break;
         }
     }
-    debug() << "solution at" << (void*)(best);
-    
-    m_solvedPlaylist = best->mid( 0 );
-    m_finalSatisfaction = m_constraintTreeRoot->satisfaction( m_solvedPlaylist );
+
+    if( best )
+    {
+        debug() << "solution at" << (void*)(best);
+
+        m_solvedPlaylist = best->mid( 0 );
+        m_finalSatisfaction = m_constraintTreeRoot->satisfaction( m_solvedPlaylist );
+    }
 
     /* clean up */
     Population::iterator it = population.begin();
@@ -184,11 +193,26 @@ APG::ConstraintSolver::run()
         it = population.erase( it );
     }
 
-    emit endProgressOperation( this );
+    Q_EMIT endProgressOperation( this );
+}
+
+void APG::ConstraintSolver::defaultBegin(const ThreadWeaver::JobPointer& self, ThreadWeaver::Thread *thread)
+{
+    Q_EMIT started(self);
+    ThreadWeaver::Job::defaultBegin(self, thread);
+}
+
+void APG::ConstraintSolver::defaultEnd(const ThreadWeaver::JobPointer& self, ThreadWeaver::Thread *thread)
+{
+    ThreadWeaver::Job::defaultEnd(self, thread);
+    if (!self->success()) {
+        Q_EMIT failed(self);
+    }
+    Q_EMIT done(self);
 }
 
 void
-APG::ConstraintSolver::receiveQueryMakerData( Meta::TrackList results )
+APG::ConstraintSolver::receiveQueryMakerData( const Meta::TrackList &results )
 {
     m_domainMutex.lock();
     m_domain += results;
@@ -203,12 +227,12 @@ APG::ConstraintSolver::receiveQueryMakerDone()
 
     if (( m_domain.size() > 0 ) || m_domainReductionFailed ) {
         if ( m_domain.size() <= 0 ) {
-            Amarok::Components::logger()->shortMessage( i18n("The playlist generator failed to load any tracks from the collection.") );
+            Amarok::Logger::shortMessage( i18n("The playlist generator failed to load any tracks from the collection.") );
         }
         m_readyToRun = true;
-        emit readyToRun();
+        Q_EMIT readyToRun();
     } else {
-        Amarok::Components::logger()->longMessage(
+        Amarok::Logger::longMessage(
                     i18n("There are no tracks that match all constraints. " \
                          "The playlist generator will find the tracks that match best, " \
                 "but you may want to consider loosening the constraints to find more tracks.") );
@@ -217,8 +241,10 @@ APG::ConstraintSolver::receiveQueryMakerDone()
         // need a new query maker without constraints
         m_qm = CollectionManager::instance()->queryMaker();
         if ( m_qm ) {
-            connect( m_qm, SIGNAL(newResultReady(Meta::TrackList)), this, SLOT(receiveQueryMakerData(Meta::TrackList)), Qt::QueuedConnection );
-            connect( m_qm, SIGNAL(queryDone()), this, SLOT(receiveQueryMakerDone()), Qt::QueuedConnection );
+            connect( m_qm, &Collections::QueryMaker::newTracksReady,
+                     this, &APG::ConstraintSolver::receiveQueryMakerData, Qt::QueuedConnection );
+            connect( m_qm, &Collections::QueryMaker::queryDone,
+                     this, &APG::ConstraintSolver::receiveQueryMakerDone, Qt::QueuedConnection );
 
             m_qm->setQueryType( Collections::QueryMaker::Track );
             m_qm->run();
