@@ -32,7 +32,8 @@ namespace Collections {
 }
 
 namespace APG {
-    class ConstraintSolver : public ThreadWeaver::Job {
+    class ConstraintSolver : public QObject, public ThreadWeaver::Job
+    {
         Q_OBJECT
 
         public:
@@ -41,7 +42,7 @@ namespace APG {
             static const int QUALITY_RANGE; // allows used to adjust speed/quality tradeoff
 
             ConstraintSolver( ConstraintNode*, int );
-            ~ConstraintSolver();
+            ~ConstraintSolver() override;
 
             Meta::TrackList getSolution() const;
             bool satisfied() const;
@@ -50,22 +51,30 @@ namespace APG {
 
             // overloaded ThreadWeaver::Job functions
             bool canBeExecuted();
-            bool success() const;
+            bool success() const override;
+            void requestAbort() override;
 
-        public slots:
-            void requestAbort();
-
-        signals:
+        Q_SIGNALS:
             void readyToRun();
             void incrementProgress();
             void totalSteps( int );
             void endProgressOperation( QObject* );
 
-        protected:
-            void run(); // from ThreadWeaver::Job
+            /** This signal is emitted when this job is being processed by a thread. */
+            void started(ThreadWeaver::JobPointer);
+            /** This signal is emitted when the job has been finished (no matter if it succeeded or not). */
+            void done(ThreadWeaver::JobPointer);
+            /** This job has failed.
+             * This signal is emitted when success() returns false after the job is executed. */
+            void failed(ThreadWeaver::JobPointer);
 
-        private slots:
-            void receiveQueryMakerData( Meta::TrackList );
+        protected:
+            void defaultBegin(const ThreadWeaver::JobPointer& job, ThreadWeaver::Thread *thread) override;
+            void defaultEnd(const ThreadWeaver::JobPointer& job, ThreadWeaver::Thread *thread) override;
+            void run(ThreadWeaver::JobPointer self = QSharedPointer<ThreadWeaver::Job>(), ThreadWeaver::Thread *thread = 0) override; // from ThreadWeaver::Job
+
+        private Q_SLOTS:
+            void receiveQueryMakerData( const Meta::TrackList &);
             void receiveQueryMakerDone();
 
         private:
