@@ -30,7 +30,7 @@
 #include <QSignalMapper>
 #include <QWhatsThis>
 
-APG::PresetEditDialog::PresetEditDialog( PresetPtr p )
+APG::PresetEditDialog::PresetEditDialog( const PresetPtr &p )
             : QDialog( 0 )
             , m_preset( p )
 {
@@ -46,31 +46,32 @@ APG::PresetEditDialog::PresetEditDialog( PresetPtr p )
     ui.constraintTreeView->setModel( model );
     ui.constraintTreeView->setSelectionMode( QAbstractItemView::SingleSelection );
     ui.constraintTreeView->setHeaderHidden( true );
-    connect( ui.constraintTreeView->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
-             this, SLOT(currentNodeChanged(QModelIndex)) );
+    connect( ui.constraintTreeView->selectionModel(), &QItemSelectionModel::currentChanged,
+             this, &PresetEditDialog::currentNodeChanged );
     ui.constraintTreeView->setCurrentIndex( model->index( 0, 0 ) ); // select the visible root constraint
     ui.constraintTreeView->expandAll();
 
     QSignalMapper* adderMapper = new QSignalMapper( this );
-    connect( adderMapper, SIGNAL(mapped(QString)), this, SLOT(addNode(QString)) );
+    connect( adderMapper, QOverload<const QString&>::of(&QSignalMapper::mapped),
+             this, &PresetEditDialog::addNode );
 
     QMenuBar* menuBar_Actions = new QMenuBar( this );
     menuBar_Actions->setNativeMenuBar( false );  //required to make the menu work on OS X
 
     QAction* a;
     QMenu* m = new QMenu( i18n("Add new"), this );
-    a = m->addAction( QString( i18n("Constraint Group") ) );
-    connect( a, SIGNAL(triggered(bool)), adderMapper, SLOT(map()) );
+    a = m->addAction( i18n("Constraint Group") );
+    connect( a, &QAction::triggered, adderMapper, QOverload<>::of(&QSignalMapper::map) );
     adderMapper->setMapping( a, i18n("Constraint Group") );
     foreach( const QString& name, ConstraintFactory::instance()->i18nNames() ) {
         a = m->addAction( name );
-        connect( a, SIGNAL(triggered(bool)), adderMapper, SLOT(map()) );
+        connect( a, &QAction::triggered, adderMapper, QOverload<>::of(&QSignalMapper::map) );
         adderMapper->setMapping( a, name );
     }
     menuBar_Actions->addMenu( m );
 
     a = menuBar_Actions->addAction( i18n("Remove selected") );
-    connect( a, SIGNAL(triggered(bool)), m_controller, SLOT(removeNode()) );
+    connect( a, &QAction::triggered, m_controller, &APG::TreeController::removeNode );
 
     menuBar_Actions->addSeparator();
 
@@ -79,8 +80,8 @@ APG::PresetEditDialog::PresetEditDialog( PresetPtr p )
     menuBar_Actions->addAction( a );
     ui.treeLayout->insertWidget( 0, menuBar_Actions );
 
-    connect( ui.buttonBox, SIGNAL(accepted()), this, SLOT(accept()) );
-    connect( ui.buttonBox, SIGNAL(rejected()), this, SLOT(reject()) );
+    connect( ui.buttonBox, &QDialogButtonBox::accepted, this, &APG::PresetEditDialog::accept );
+    connect( ui.buttonBox, &QDialogButtonBox::rejected, this, &APG::PresetEditDialog::reject );
 
     QMetaObject::connectSlotsByName( this );
 }
