@@ -35,7 +35,7 @@ ConstraintTypes::TagMatch::createFromXml( QDomElement& xmlelem, ConstraintNode*
     if ( p )
         return new TagMatch( xmlelem, p );
     else
-        return 0;
+        return nullptr;
 }
 
 Constraint*
@@ -44,13 +44,13 @@ ConstraintTypes::TagMatch::createNew( ConstraintNode* p )
     if ( p )
         return new TagMatch( p );
     else
-        return 0;
+        return nullptr;
 }
 
 ConstraintFactoryEntry*
 ConstraintTypes::TagMatch::registerMe()
 {
-    return new ConstraintFactoryEntry( "TagMatch",
+    return new ConstraintFactoryEntry( QStringLiteral("TagMatch"),
                                        i18n("Match Tags"),
                                        i18n("Make all tracks in the playlist match the specified characteristic"),
                                        &TagMatch::createFromXml, &TagMatch::createNew );
@@ -63,18 +63,18 @@ ConstraintTypes::TagMatch::TagMatch( QDomElement& xmlelem, ConstraintNode* p )
 {
     QDomAttr a;
 
-    a = xmlelem.attributeNode( "field" );
+    a = xmlelem.attributeNode( QStringLiteral("field") );
     if ( !a.isNull() ) {
         if ( m_fieldsModel->contains( a.value() ) )
             m_field = a.value();
     }
 
-    a = xmlelem.attributeNode( "comparison" );
+    a = xmlelem.attributeNode( QStringLiteral("comparison") );
     if ( !a.isNull() ) {
         m_comparison = a.value().toInt();
     }
 
-    a = xmlelem.attributeNode( "value" );
+    a = xmlelem.attributeNode( QStringLiteral("value") );
     if ( !a.isNull() ) {
         if ( m_fieldsModel->type_of( m_field ) == FieldTypeInt ) {
             m_value = a.value().toInt();
@@ -84,9 +84,9 @@ ConstraintTypes::TagMatch::TagMatch( QDomElement& xmlelem, ConstraintNode* p )
                 if ( parts.size() == 2 ) {
                     int u = parts.at( 0 ).toInt();
                     int v = 0;
-                    if ( parts.at( 1 ) == "months" )
+                    if ( parts.at( 1 ) == QLatin1String("months") )
                         v = 1;
-                    else if ( parts.at( 1 ) == "years" )
+                    else if ( parts.at( 1 ) == QLatin1String("years") )
                         v = 2;
                     m_value = QVariant::fromValue( DateRange( u, v ) );
                 } else
@@ -98,13 +98,13 @@ ConstraintTypes::TagMatch::TagMatch( QDomElement& xmlelem, ConstraintNode* p )
         }
     }
 
-    a = xmlelem.attributeNode( "invert" );
-    if ( !a.isNull() && a.value() == "true" )
+    a = xmlelem.attributeNode( QStringLiteral("invert") );
+    if ( !a.isNull() && a.value() == QLatin1String("true") )
         m_invert = true;
     else
         m_invert = false;
 
-    a = xmlelem.attributeNode( "strictness" );
+    a = xmlelem.attributeNode( QStringLiteral("strictness") );
     if ( !a.isNull() )
         m_strictness = a.value().toDouble();
 }
@@ -112,7 +112,7 @@ ConstraintTypes::TagMatch::TagMatch( QDomElement& xmlelem, ConstraintNode* p )
 ConstraintTypes::TagMatch::TagMatch( ConstraintNode* p )
         : MatchingConstraint( p )
         , m_comparison( CompareStrEquals )
-        , m_field( "title" )
+        , m_field( QStringLiteral("title") )
         , m_invert( false )
         , m_strictness( 1.0 )
         , m_value()
@@ -136,30 +136,30 @@ ConstraintTypes::TagMatch::editWidget() const
                                             m_invert,
                                             static_cast<int>( m_strictness * 10 ),
                                             m_value );
-    connect( e, SIGNAL(comparisonChanged(int)), this, SLOT(setComparison(int)) );
-    connect( e, SIGNAL(fieldChanged(QString)), this, SLOT(setField(QString)) );
-    connect( e, SIGNAL(invertChanged(bool)), this, SLOT(setInvert(bool)) );
-    connect( e, SIGNAL(strictnessChanged(int)), this, SLOT(setStrictness(int)) );
-    connect( e, SIGNAL(valueChanged(QVariant)), this, SLOT(setValue(QVariant)) );
+    connect( e, &TagMatchEditWidget::comparisonChanged, this, &TagMatch::setComparison );
+    connect( e, &TagMatchEditWidget::fieldChanged, this, &TagMatch::setField );
+    connect( e, &TagMatchEditWidget::invertChanged, this, &TagMatch::setInvert );
+    connect( e, &TagMatchEditWidget::strictnessChanged, this, &TagMatch::setStrictness );
+    connect( e, &TagMatchEditWidget::valueChanged, this, &TagMatch::setValue );
     return e;
 }
 
 void
 ConstraintTypes::TagMatch::toXml( QDomDocument& doc, QDomElement& elem ) const
 {
-    QDomElement c = doc.createElement( "constraint" );
+    QDomElement c = doc.createElement( QStringLiteral("constraint") );
 
-    c.setAttribute( "type", "TagMatch" );
-    c.setAttribute( "field", m_field );
-    c.setAttribute( "comparison", m_comparison );
-    c.setAttribute( "value", valueToString() );
+    c.setAttribute( QStringLiteral("type"), QStringLiteral("TagMatch") );
+    c.setAttribute( QStringLiteral("field"), m_field );
+    c.setAttribute( QStringLiteral("comparison"), m_comparison );
+    c.setAttribute( QStringLiteral("value"), valueToString() );
 
     if ( m_invert )
-        c.setAttribute( "invert", "true" );
+        c.setAttribute( QStringLiteral("invert"), QStringLiteral("true") );
     else
-        c.setAttribute( "invert", "false" );
+        c.setAttribute( QStringLiteral("invert"), QStringLiteral("false") );
 
-    c.setAttribute( "strictness", QString::number( m_strictness ) );
+    c.setAttribute( QStringLiteral("strictness"), QString::number( m_strictness ) );
 
     elem.appendChild( c );
 }
@@ -172,16 +172,16 @@ ConstraintTypes::TagMatch::getName() const
                       "%3 = a predicate, can be equals, starts with, ends with or contains; "
                       "%4 = a string to match; "
                       "Example: Match tag: not title contains \"foo\"", "Match tag:%1 %2 %3 %4") );
-    v = v.arg( ( m_invert ? i18n(" not") : "" ), m_fieldsModel->pretty_name_of( m_field ), comparisonToString() );
-    if ( m_field == "rating" ) {
+    v = v.arg( ( m_invert ? i18n(" not") : QLatin1String("") ), m_fieldsModel->pretty_name_of( m_field ), comparisonToString() );
+    if ( m_field == QLatin1String("rating") ) {
         double r = m_value.toDouble() / 2.0;
         return v.arg( i18ncp("number of stars in the rating of a track", "%1 star", "%1 stars", r) );
-    } else if ( m_field == "length" ) {
-        return v.arg( QTime().addMSecs( m_value.toInt() ).toString( "H:mm:ss" ) );
+    } else if ( m_field == QLatin1String("length") ) {
+        return v.arg( QTime(0, 0, 0).addMSecs( m_value.toInt() ).toString( QStringLiteral("H:mm:ss") ) );
     } else {
         if ( m_fieldsModel->type_of( m_field ) == FieldTypeString ) {
             // put quotes around any strings (eg, track title or artist name) ...
-            QString s = QString( i18nc("an arbitrary string surrounded by quotes", "\"%1\"") ).arg( valueToString() );
+            QString s = i18nc("an arbitrary string surrounded by quotes", "\"%1\"", valueToString() );
             return v.arg( s );
         } else {
             // ... but don't quote put quotes around anything else
@@ -226,13 +226,13 @@ ConstraintTypes::TagMatch::initQueryMaker( Collections::QueryMaker* qm ) const
         uint referenceDate = 0;
         int range = m_comparer->rangeDate( m_strictness );
         if ( m_comparison == CompareDateBefore ) {
-            referenceDate = m_value.toDateTime().toTime_t();
+            referenceDate = m_value.toDateTime().toSecsSinceEpoch();
             if ( m_invert )
                 qm->excludeNumberFilter( m_fieldsModel->meta_value_of( m_field ), referenceDate - range, Collections::QueryMaker::LessThan );
             else
                 qm->addNumberFilter( m_fieldsModel->meta_value_of( m_field ), referenceDate + range, Collections::QueryMaker::LessThan );
         } else if ( m_comparison == CompareDateOn ) {
-            referenceDate = m_value.toDateTime().toTime_t();
+            referenceDate = m_value.toDateTime().toSecsSinceEpoch();
             if ( !m_invert ) {
                 qm->beginAnd();
                 qm->addNumberFilter( m_fieldsModel->meta_value_of( m_field ), referenceDate - range, Collections::QueryMaker::GreaterThan );
@@ -240,7 +240,7 @@ ConstraintTypes::TagMatch::initQueryMaker( Collections::QueryMaker* qm ) const
                 qm->endAndOr();
             }
         } else if ( m_comparison == CompareDateAfter ) {
-            referenceDate = m_value.toDateTime().toTime_t();
+            referenceDate = m_value.toDateTime().toSecsSinceEpoch();
             if ( m_invert )
                 qm->excludeNumberFilter( m_fieldsModel->meta_value_of( m_field ), referenceDate + range, Collections::QueryMaker::GreaterThan );
             else
@@ -250,13 +250,13 @@ ConstraintTypes::TagMatch::initQueryMaker( Collections::QueryMaker* qm ) const
             DateRange r = m_value.value<DateRange>();
             switch ( r.second ) {
                 case 0:
-                    referenceDate = now.addDays( -1 * r.first ).toTime_t();
+                    referenceDate = now.addDays( -1 * r.first ).toSecsSinceEpoch();
                     break;
                 case 1:
-                    referenceDate = now.addMonths( -1 * r.first ).toTime_t();
+                    referenceDate = now.addMonths( -1 * r.first ).toSecsSinceEpoch();
                     break;
                 case 2:
-                    referenceDate = now.addYears( -1 * r.first ).toTime_t();
+                    referenceDate = now.addYears( -1 * r.first ).toSecsSinceEpoch();
                     break;
                 default:
                     break;
@@ -332,36 +332,36 @@ ConstraintTypes::TagMatch::comparisonToString() const
 {
     if ( m_fieldsModel->type_of( m_field ) == FieldTypeInt ) {
         if ( m_comparison == CompareNumEquals ) {
-            return QString( i18nc("a numerical tag (like year or track number) equals a value","equals") );
+            return i18nc("a numerical tag (like year or track number) equals a value","equals");
         } else if ( m_comparison == CompareNumGreaterThan ) {
-            return QString( i18n("greater than") );
+            return i18n("greater than");
         } else if ( m_comparison == CompareNumLessThan ) {
-            return QString( i18n("less than") );
+            return i18n("less than");
         }
     } else if ( m_fieldsModel->type_of( m_field ) == FieldTypeDate ) {
         if ( m_comparison == CompareDateBefore ) {
-            return QString( i18n("before") );
+            return i18n("before");
         } else if ( m_comparison == CompareDateOn ) {
-            return QString( i18n("on") );
+            return i18n("on");
         } else if ( m_comparison == CompareDateAfter ) {
-            return QString( i18n("after") );
+            return i18n("after");
         } else if ( m_comparison == CompareDateWithin ) {
-            return QString( i18n("within") );
+            return i18n("within");
         }
     } else {
         if ( m_comparison == CompareStrEquals ) {
-            return QString( i18nc("an alphabetical tag (like title or artist name) equals some string","equals") );
+            return i18nc("an alphabetical tag (like title or artist name) equals some string","equals");
         } else if ( m_comparison == CompareStrStartsWith ) {
-            return QString( i18nc("an alphabetical tag (like title or artist name) starts with some string","starts with") );
+            return i18nc("an alphabetical tag (like title or artist name) starts with some string","starts with");
         } else if ( m_comparison == CompareStrEndsWith ) {
-            return QString( i18nc("an alphabetical tag (like title or artist name) ends with some string","ends with") );
+            return i18nc("an alphabetical tag (like title or artist name) ends with some string","ends with");
         } else if ( m_comparison == CompareStrContains ) {
-            return QString( i18nc("an alphabetical tag (like title or artist name) contains some string","contains") );
+            return i18nc("an alphabetical tag (like title or artist name) contains some string","contains");
         } else if ( m_comparison == CompareStrRegExp ) {
-            return QString( i18n("regexp") );
+            return i18n("regexp");
         }
     }
-    return QString( i18n("unknown comparison") );
+    return i18n("unknown comparison");
 }
 
 QString
@@ -439,7 +439,7 @@ ConstraintTypes::TagMatch::matches( Meta::TrackPtr track ) const
                 v = m_comparer->compareNum( track->filesize(), m_comparison, m_value.toInt(), m_strictness, fmv );
                 break;
             case Meta::valCreateDate:
-                v = m_comparer->compareDate( track->createDate().toTime_t(), m_comparison, m_value, m_strictness );
+                v = m_comparer->compareDate( track->createDate().toSecsSinceEpoch(), m_comparison, m_value, m_strictness );
                 break;
             case Meta::valScore:
                 v = m_comparer->compareNum( track->statistics()->score(), m_comparison, m_value.toDouble(), m_strictness, fmv );
@@ -448,10 +448,10 @@ ConstraintTypes::TagMatch::matches( Meta::TrackPtr track ) const
                 v = m_comparer->compareNum( track->statistics()->rating(), m_comparison, m_value.toInt(), m_strictness, fmv );
                 break;
             case Meta::valFirstPlayed:
-                v = m_comparer->compareDate( track->statistics()->firstPlayed().toTime_t(), m_comparison, m_value, m_strictness );
+                v = m_comparer->compareDate( track->statistics()->firstPlayed().toSecsSinceEpoch(), m_comparison, m_value, m_strictness );
                 break;
             case Meta::valLastPlayed:
-                v = m_comparer->compareDate( track->statistics()->lastPlayed().toTime_t(), m_comparison, m_value, m_strictness );
+                v = m_comparer->compareDate( track->statistics()->lastPlayed().toSecsSinceEpoch(), m_comparison, m_value, m_strictness );
                 break;
             case Meta::valPlaycount:
                 v = m_comparer->compareNum( track->statistics()->playCount(), m_comparison, m_value.toInt(), m_strictness, fmv );
@@ -476,7 +476,7 @@ ConstraintTypes::TagMatch::setComparison( int c )
 {
     m_comparison = c;
     m_matchCache.clear();
-    emit dataChanged();
+    Q_EMIT dataChanged();
 }
 
 void
@@ -484,7 +484,7 @@ ConstraintTypes::TagMatch::setField( const QString& s )
 {
     m_field = s;
     m_matchCache.clear();
-    emit dataChanged();
+    Q_EMIT dataChanged();
 }
 
 void
@@ -496,7 +496,7 @@ ConstraintTypes::TagMatch::setInvert( bool v )
         }
     }
     m_invert = v;
-    emit dataChanged();
+    Q_EMIT dataChanged();
 }
 
 void
@@ -511,7 +511,7 @@ ConstraintTypes::TagMatch::setValue( const QVariant& v )
 {
     m_value = v;
     m_matchCache.clear();
-    emit dataChanged();
+    Q_EMIT dataChanged();
 }
 
 /******************************
@@ -524,32 +524,33 @@ ConstraintTypes::TagMatchEditWidget::TagMatchEditWidget(
                         const bool invert,
                         const int strictness,
                         const QVariant& value )
-        : QWidget( 0 )
+        : QWidget( nullptr )
         , m_fieldsModel( new TagMatchFieldsModel() )
 {
     ui.setupUi( this );
 
     // plural support in combobox labels
-    connect( ui.spinBox_ValueDateValue, SIGNAL(valueChanged(int)), this, SLOT(slotUpdateComboBoxLabels(int)) );
+    connect( ui.spinBox_ValueDateValue, QOverload<int>::of(&QSpinBox::valueChanged),
+             this, &TagMatchEditWidget::slotUpdateComboBoxLabels );
     ui.comboBox_ValueDateUnit->insertItem(0, i18ncp("within the last %1 days", "day", "days", 0));
     ui.comboBox_ValueDateUnit->insertItem(1, i18ncp("within the last %1 months", "month", "months", 0));
     ui.comboBox_ValueDateUnit->insertItem(2, i18ncp("within the last %1 years", "year", "years", 0));
 
     // fill in appropriate defaults for some attributes
-    ui.kdatewidget_DateSpecific->setDate( QDate::currentDate() );
+    ui.qcalendarwidget_DateSpecific->setSelectedDate( QDate::currentDate() );
 
     // fill in user-specified values before the slots have been connected to we don't have to call back to the constraint a dozen times
     ui.comboBox_Field->setModel( m_fieldsModel );
     ui.checkBox_Invert->setChecked( invert );
 
-    if ( field == "rating" ) {
+    if ( field == QLatin1String("rating") ) {
         ui.comboBox_ComparisonRating->setCurrentIndex( comparison );
         ui.slider_StrictnessRating->setValue( strictness );
         ui.rating_RatingValue->setRating( value.toInt() );
-    } else if ( field == "length" ) {
+    } else if ( field == QLatin1String("length") ) {
         ui.comboBox_ComparisonTime->setCurrentIndex( comparison );
         ui.slider_StrictnessTime->setValue( strictness );
-        ui.timeEdit_TimeValue->setTime( QTime().addMSecs( value.toInt() ) );
+        ui.timeEdit_TimeValue->setTime( QTime(0, 0, 0).addMSecs( value.toInt() ) );
     } else if ( m_fieldsModel->type_of( field ) == TagMatch::FieldTypeInt ) {
         ui.comboBox_ComparisonInt->setCurrentIndex( comparison );
         ui.slider_StrictnessInt->setValue( strictness );
@@ -563,7 +564,7 @@ ConstraintTypes::TagMatchEditWidget::TagMatchEditWidget(
             ui.comboBox_ValueDateUnit->setCurrentIndex( value.value<DateRange>().second );
         } else {
             ui.stackedWidget_Date->setCurrentIndex( 0 );
-            ui.kdatewidget_DateSpecific->setDate( value.toDate() );
+            ui.qcalendarwidget_DateSpecific->setSelectedDate( value.toDate() );
         }
     } else if ( m_fieldsModel->type_of( field ) == TagMatch::FieldTypeString ) {
         ui.comboBox_ComparisonString->setCurrentIndex( comparison );
@@ -587,31 +588,31 @@ ConstraintTypes::TagMatchEditWidget::on_comboBox_ComparisonDate_currentIndexChan
         ui.stackedWidget_Date->setCurrentIndex( 1 );
     else
         ui.stackedWidget_Date->setCurrentIndex( 0 );
-    emit comparisonChanged( c );
+    Q_EMIT comparisonChanged( c );
 }
 
 void
 ConstraintTypes::TagMatchEditWidget::on_comboBox_ComparisonInt_currentIndexChanged( int c )
 {
-    emit comparisonChanged( c );
+    Q_EMIT comparisonChanged( c );
 }
 
 void
 ConstraintTypes::TagMatchEditWidget::on_comboBox_ComparisonRating_currentIndexChanged( int c )
 {
-    emit comparisonChanged( c );
+    Q_EMIT comparisonChanged( c );
 }
 
 void
 ConstraintTypes::TagMatchEditWidget::on_comboBox_ComparisonString_currentIndexChanged( int c )
 {
-    emit comparisonChanged( c );
+    Q_EMIT comparisonChanged( c );
 }
 
 void
 ConstraintTypes::TagMatchEditWidget::on_comboBox_ComparisonTime_currentIndexChanged( int c )
 {
-    emit comparisonChanged( c );
+    Q_EMIT comparisonChanged( c );
 }
 
 // ComboBox slots for field
@@ -622,12 +623,12 @@ ConstraintTypes::TagMatchEditWidget::on_comboBox_Field_currentIndexChanged( int
     int c = 0;
     int s = 0;
     QVariant v;
-    if ( field == "length" ) {
+    if ( field == QLatin1String("length") ) {
         ui.stackedWidget_Field->setCurrentIndex( 3 );
         c = ui.comboBox_ComparisonTime->currentIndex();
         s = ui.slider_StrictnessTime->value();
-        v = QTime().msecsTo( ui.timeEdit_TimeValue->time() );
-    } else if ( field == "rating" ) {
+        v = QTime(0, 0, 0).msecsTo( ui.timeEdit_TimeValue->time() );
+    } else if ( field == QLatin1String("rating") ) {
         ui.stackedWidget_Field->setCurrentIndex( 4 );
         c = ui.comboBox_ComparisonRating->currentIndex();
         s = ui.slider_StrictnessRating->value();
@@ -649,7 +650,7 @@ ConstraintTypes::TagMatchEditWidget::on_comboBox_Field_currentIndexChanged( int
                 v = QVariant::fromValue( DateRange( a, b ) );
             } else {
                 ui.stackedWidget_Date->setCurrentIndex( 0 );
-                v = ui.kdatewidget_DateSpecific->date();
+                v = ui.qcalendarwidget_DateSpecific->selectedDate();
             }
         } else if ( m_fieldsModel->type_of( field ) == TagMatch::FieldTypeString ) {
             ui.stackedWidget_Field->setCurrentIndex( 2 );
@@ -661,88 +662,88 @@ ConstraintTypes::TagMatchEditWidget::on_comboBox_Field_currentIndexChanged( int
 
     // TODO: set range limitations and default values depending on field
 
-    emit fieldChanged( field );
-    emit valueChanged( v );
-    emit comparisonChanged( c );
-    emit strictnessChanged( s );
+    Q_EMIT fieldChanged( field );
+    Q_EMIT valueChanged( v );
+    Q_EMIT comparisonChanged( c );
+    Q_EMIT strictnessChanged( s );
 }
 
 // Invert checkbox slot
 void
 ConstraintTypes::TagMatchEditWidget::on_checkBox_Invert_clicked( bool v )
 {
-    emit invertChanged( v );
+    Q_EMIT invertChanged( v );
 }
 
 // Strictness Slider slots
 void
 ConstraintTypes::TagMatchEditWidget::on_slider_StrictnessDate_valueChanged( int v )
 {
-    emit strictnessChanged( v );
+    Q_EMIT strictnessChanged( v );
 }
 
 void
 ConstraintTypes::TagMatchEditWidget::on_slider_StrictnessInt_valueChanged( int v )
 {
-    emit strictnessChanged( v );
+    Q_EMIT strictnessChanged( v );
 }
 
 void
 ConstraintTypes::TagMatchEditWidget::on_slider_StrictnessRating_valueChanged( int v )
 {
-    emit strictnessChanged( v );
+    Q_EMIT strictnessChanged( v );
 }
 
 void
 ConstraintTypes::TagMatchEditWidget::on_slider_StrictnessTime_valueChanged( int v )
 {
-    emit strictnessChanged( v );
+    Q_EMIT strictnessChanged( v );
 }
 
 // various value slots
 void
 ConstraintTypes::TagMatchEditWidget::on_kdatewidget_DateSpecific_changed( const QDate& v )
 {
-    emit valueChanged( QVariant( v ) );
+    Q_EMIT valueChanged( QVariant( v ) );
 }
 
 void
 ConstraintTypes::TagMatchEditWidget::on_comboBox_ValueDateUnit_currentIndexChanged( int u )
 {
     int v = ui.spinBox_ValueDateValue->value();
-    emit valueChanged( QVariant::fromValue( DateRange( v, u ) ) );
+    Q_EMIT valueChanged( QVariant::fromValue( DateRange( v, u ) ) );
 }
 
 void
 ConstraintTypes::TagMatchEditWidget::on_spinBox_ValueDateValue_valueChanged( int v )
 {
     int u = ui.comboBox_ValueDateUnit->currentIndex();
-    emit valueChanged( QVariant::fromValue( DateRange( v, u ) ) );
+    Q_EMIT valueChanged( QVariant::fromValue( DateRange( v, u ) ) );
 }
 
 void
 ConstraintTypes::TagMatchEditWidget::on_spinBox_ValueInt_valueChanged( int v )
 {
-    emit valueChanged( QVariant( v ) );
+    Q_EMIT valueChanged( QVariant( v ) );
 }
 
 void
 ConstraintTypes::TagMatchEditWidget::on_lineEdit_StringValue_textChanged( const QString& v )
 {
-    emit valueChanged( QVariant( v ) );
+    Q_EMIT valueChanged( QVariant( v ) );
 }
 
 void
 ConstraintTypes::TagMatchEditWidget::on_rating_RatingValue_ratingChanged( int v )
 {
-    emit valueChanged( QVariant( v ) );
+    Q_EMIT valueChanged( QVariant( v ) );
 }
 
 void
 ConstraintTypes::TagMatchEditWidget::on_timeEdit_TimeValue_timeChanged( const QTime& t )
 {
-    int v = QTime().msecsTo( t );
-    emit valueChanged( QVariant( v ) );
+    int v = QTime(0, 0, 0).msecsTo( t );
+    Q_EMIT valueChanged( QVariant( v ) );
 }
 
 void
