@@ -32,15 +32,15 @@
 #include "playlistmanager/SyncedPlaylist.h"
 #include "core/support/Debug.h"
 #include "core/support/Components.h"
-#include "core/interfaces/Logger.h"
+#include "core/logger/Logger.h"
 #include "browsers/playlistbrowser/UserPlaylistModel.h"
 
 #include <kdirlister.h>
 #include <kio/jobclasses.h>
 #include <kio/job.h>
-#include <KInputDialog>
-#include <KLocale>
-#include <KUrl>
+#include <QInputDialog>
+#include <KLocalizedString>
+#include <QUrl>
 
 #include <QFileInfo>
 
@@ -49,7 +49,7 @@
 using namespace Meta;
 using namespace Playlists;
 
-PlaylistManager *PlaylistManager::s_instance = 0;
+PlaylistManager *PlaylistManager::s_instance = nullptr;
 
 namespace The
 {
@@ -67,7 +67,7 @@ PlaylistManager::destroy()
 {
     if (s_instance) {
         delete s_instance;
-        s_instance = 0;
+        s_instance = nullptr;
     }
 }
 
@@ -121,17 +121,18 @@ PlaylistManager::addProvider( Playlists::PlaylistProvider *provider, int categor
     provider->disconnect( this, 0 );
 
     m_providerMap.insert( category, provider );
-    connect( provider, SIGNAL(updated()), SLOT(slotUpdated()));
-    connect( provider, SIGNAL(playlistAdded(Playlists::PlaylistPtr)),
-             SLOT(slotPlaylistAdded(Playlists::PlaylistPtr)));
-    connect( provider, SIGNAL(playlistRemoved(Playlists::PlaylistPtr)),
-             SLOT(slotPlaylistRemoved(Playlists::PlaylistPtr)));
+    connect( provider, &Playlists::PlaylistProvider::updated,
+             this, &PlaylistManager::slotUpdated );
+    connect( provider, &Playlists::PlaylistProvider::playlistAdded,
+             this, &PlaylistManager::slotPlaylistAdded );
+    connect( provider, &Playlists::PlaylistProvider::playlistRemoved,
+             this, &PlaylistManager::slotPlaylistRemoved );
 
     if( newCategory )
-        emit categoryAdded( category );
+        Q_EMIT categoryAdded( category );
 
-    emit providerAdded( provider, category );
-    emit updated( category );
+    Q_EMIT providerAdded( provider, category );
+    Q_EMIT updated( category );
 
     loadPlaylists( provider, category );
 }
@@ -175,25 +176,25 @@ PlaylistManager::addPlaylist( Playlists::PlaylistPtr playlist, int category )
         {
             m_syncedPlaylistMap.insert( syncedPlaylist, playlist );
 
-            //The synchronosation will be done in the next mainloop run
+            //The synchronization will be done in the next mainloop run
             m_syncNeeded.append( syncedPlaylist );
-            QTimer::singleShot( 0, this, SLOT(slotSyncNeeded()) );
+            QTimer::singleShot( 0, this, &PlaylistManager::slotSyncNeeded );
         }
 
-        //deliberatly reusing the passed argument
+        //deliberately reusing the passed argument
         playlist = PlaylistPtr::dynamicCast( syncedPlaylist );
 
         if( m_playlistMap.values( category ).contains( playlist ) )
         {
              //no need to add it again but do let the model know something changed.
-             emit playlistUpdated( playlist, category );
+             Q_EMIT playlistUpdated( playlist, category );
              return;
         }
     }
 
     m_playlistMap.insert( category, playlist );
     //reemit so models know about new playlist in their category
-    emit playlistAdded( playlist, category );
+    Q_EMIT playlistAdded( playlist, category );
 }
 
 void
@@ -213,8 +214,8 @@ PlaylistManager::removeProvider( Playlists::PlaylistProvider *provider )
 
     m_providerMap.remove( provider->category(), provider );
 
-    emit providerRemoved( provider, provider->category() );
-    emit updated( provider->category() );
+    Q_EMIT providerRemoved( provider, provider->category() );
+    Q_EMIT updated( provider->category() );
 }
 
 void
@@ -233,9 +234,8 @@ PlaylistManager::removePlaylists( Playlists::PlaylistProvider *provider )
 void
 PlaylistManager::removePlaylist( Playlists::PlaylistPtr playlist, int category )
 {
-    if( typeid( *playlist.data() ) == typeid( SyncedPlaylist ) )
+    if( auto syncedPlaylist = SyncedPlaylistPtr::dynamicCast( playlist ) )
     {
-        SyncedPlaylistPtr syncedPlaylist = SyncedPlaylistPtr::dynamicCast( playlist );
         //TODO: this might be wrong if there were multiple playlists from the same provider.
         //remove the specific child playlist, not all from same provider.
         syncedPlaylist->removePlaylistsFrom( playlist->provider() );
@@ -249,7 +249,7 @@ PlaylistManager::removePlaylist( Playlists::PlaylistPtr playlist, int category )
         m_playlistMap.remove( category, playlist );
     }
 
-    emit playlistRemoved( playlist, category );
+    Q_EMIT playlistRemoved( playlist, category );
 }
 
 void
@@ -260,11 +260,11 @@ PlaylistManager::slotUpdated()
     if( !provider )
         return;
 
-    //forcefull reload all the providers playlists.
+    //forceful reload all the providers playlists.
     //This is an expensive operation, the provider should use playlistAdded/Removed signals instead.
     removePlaylists( provider );
     loadPlaylists( provider, provider->category() );
-    emit updated( provider->category() );
+    Q_EMIT updated( provider->category() );
 }
 
 void
@@ -328,7 +328,7 @@ PlaylistManager::save( Meta::TrackList tracks, const QString &name,
 }
 
 bool
-PlaylistManager::import( const QString& fromLocation )
+PlaylistManager::import( const QUrl& fromLocation )
 {
     // used by: PlaylistBrowserNS::UserModel::dropMimeData()
     AMAROK_DEPRECATED
@@ -338,7 +338,7 @@ PlaylistManager::import( const QString& fromLocation )
         debug() << "ERROR: m_playlistFileProvider was null";
         return false;
     }
-    return m_playlistFileProvider->import( KUrl(fromLocation) );
+    return m_playlistFileProvider->import( fromLocation );
 }
 
 void
@@ -347,8 +347,8 @@ PlaylistManager::rename( Playlists::PlaylistPtr playlist )
     if( playlist.isNull() )
         return;
 
-    AmarokUrl("amarok://navigate/playlists/user playlists").run();
-    emit renamePlaylist( playlist ); // connected to PlaylistBrowserModel
+    AmarokUrl(QStringLiteral("amarok://navigate/playlists/user playlists")).run();
+    Q_EMIT renamePlaylist( playlist ); // connected to PlaylistBrowserModel
 }
 
 bool
@@ -515,7 +515,7 @@ PlaylistManager::setupSync( const Playlists::PlaylistPtr master, const Playlists
 
             m_playlistMap.insert( category, syncedPlaylistPtr );
             //reemit so models know about new playlist in their category
-            emit playlistAdded( syncedPlaylistPtr, category );
+            Q_EMIT playlistAdded( syncedPlaylistPtr, category );
         }
     }
 }
@@ -529,4 +529,3 @@ void PlaylistManager::slotSyncNeeded()
     m_syncNeeded.clear();
 }
 
-#include "PlaylistManager.moc"
