@@ -21,19 +21,19 @@
 #include "core/playlists/PlaylistProvider.h"
 #include "core/support/Debug.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 
 using namespace Meta;
 
-SyncedPlaylist::SyncedPlaylist( Playlists::PlaylistPtr playlist )
+SyncedPlaylist::SyncedPlaylist( const Playlists::PlaylistPtr &playlist )
 {
     addPlaylist( playlist );
 }
 
-KUrl
+QUrl
 SyncedPlaylist::uidUrl() const
 {
-    return KUrl( QString( "amarok-syncedplaylist://" ) +  m_playlists.first()->name() );
+    return QUrl( QStringLiteral( "amarok-syncedplaylist://" ) +  m_playlists.first()->name() );
 }
 
 QString
@@ -77,7 +77,7 @@ SyncedPlaylist::trackCount() const
 }
 
 void
-SyncedPlaylist::addTrack( Meta::TrackPtr track, int position )
+SyncedPlaylist::addTrack( const Meta::TrackPtr &track, int position )
 {
     //only apply it to the first, the rest will follow in trackAdded()
     m_playlists.first()->addTrack( track, position );
@@ -91,7 +91,7 @@ SyncedPlaylist::removeTrack( int position )
 }
 
 void
-SyncedPlaylist::metadataChanged( Playlists::PlaylistPtr playlist )
+SyncedPlaylist::metadataChanged( const Playlists::PlaylistPtr &playlist )
 {
     if( !m_playlists.contains( playlist ) )
         return;
@@ -106,12 +106,12 @@ SyncedPlaylist::tracksLoaded( Playlists::PlaylistPtr playlist )
     if( !m_playlists.contains( playlist ) )
         return;
 
-    // TODO: me may give more thought to this and emit tracksLoaded() only when all subplaylists load
+    // TODO: me may give more thought to this and Q_EMIT tracksLoaded() only when all subplaylists load
     notifyObserversTracksLoaded();
 }
 
 void
-SyncedPlaylist::trackAdded( Playlists::PlaylistPtr playlist, TrackPtr track, int position )
+SyncedPlaylist::trackAdded( const Playlists::PlaylistPtr &playlist, const TrackPtr &track, int position )
 {
     if( !m_playlists.contains( playlist ) )
         return;
@@ -132,7 +132,7 @@ SyncedPlaylist::trackAdded( Playlists::PlaylistPtr playlist, TrackPtr track, int
 }
 
 void
-SyncedPlaylist::trackRemoved( Playlists::PlaylistPtr playlist, int position )
+SyncedPlaylist::trackRemoved( const Playlists::PlaylistPtr &playlist, int position )
 {
     if( !m_playlists.contains( playlist ) )
         return;
@@ -245,7 +245,7 @@ SyncedPlaylist::doSync() const
     int position = 0;
     debug() << "Master Playlist: " << master->name() << " - " << master->uidUrl().url();
     while( m.hasNext() )
-        debug() << QString( "%1 : %2" ).arg( position++ ).arg( m.next()->name() );
+        debug() << QStringLiteral( "%1 : %2" ).arg( position++ ).arg( m.next()->name() );
     m.toFront();
 
     for( ;i != m_playlists.end(); ++i)
@@ -256,7 +256,7 @@ SyncedPlaylist::doSync() const
         position = 0;
         debug() << "Slave Playlist: " << slave->name() << " - " << slave->uidUrl().url();
         foreach( const TrackPtr track, slaveTracks )
-            debug() << QString( "%1 : %2" ).arg( position++ ).arg( track->name() );
+            debug() << QStringLiteral( "%1 : %2" ).arg( position++ ).arg( track->name() );
 
         //Add first. Tracks in slave that are not in master will eventually shift to the end.
         position = 0;
@@ -266,7 +266,7 @@ SyncedPlaylist::doSync() const
             if( position >= slaveTracks.size()
                     || track->uidUrl() != slaveTracks.at( position )->uidUrl() )
             {
-                debug() << QString( "insert %2 at %1" ).arg( position ).arg( track->name() );
+                debug() << QStringLiteral( "insert %2 at %1" ).arg( position ).arg( track->name() );
                 slave->addTrack( track, position );
 
                 slave->syncTrackStatus( position, track );
@@ -281,7 +281,7 @@ SyncedPlaylist::doSync() const
         position = 0;
         debug() << "slave playlist after insertions:";
         foreach( const TrackPtr track, slaveTracks )
-            debug() << QString( "%1 : %2" ).arg( position++ ).arg( track->name() );
+            debug() << QStringLiteral( "%1 : %2" ).arg( position++ ).arg( track->name() );
 
         //Then remove everything after the position of the last track in master.
         //This removes any tracks that are not in master.
@@ -294,7 +294,7 @@ SyncedPlaylist::doSync() const
         position = 0;
         debug() << "slave playlist after removal:";
         foreach( const TrackPtr track, slave->tracks() )
-            debug() << QString( "%1 : %2" ).arg( position++ ).arg( track->name() );
+            debug() << QStringLiteral( "%1 : %2" ).arg( position++ ).arg( track->name() );
 
     }
 }
