@@ -29,21 +29,20 @@
 #include "core-impl/playlists/types/file/xspf/XSPFPlaylist.h"
 #include "core-impl/playlists/types/file/PlaylistFileSupport.h"
 
-#include <KDialog>
-#include <KGlobal>
-#include <KIcon>
-#include <KInputDialog>
-#include <KLocale>
-#include <KMessageBox>
-#include <KUrl>
-
 #include <QAction>
+#include <QIcon>
+#include <QInputDialog>
 #include <QLabel>
 #include <QMap>
+#include <QUrl>
+
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KConfigGroup>
 
 static const int USERPLAYLIST_DB_VERSION = 3;
 // a database updater has been added in checkTables(). Use that when updating db version
-static const QString key("AMAROK_USERPLAYLIST");
+static const QString key(QStringLiteral("AMAROK_USERPLAYLIST"));
 
 namespace Playlists {
 
@@ -78,7 +77,7 @@ SqlUserPlaylistProvider::playlists()
 }
 
 void
-SqlUserPlaylistProvider::renamePlaylist( Playlists::PlaylistPtr playlist, const QString &newName )
+SqlUserPlaylistProvider::renamePlaylist(PlaylistPtr playlist, const QString &newName )
 {
     playlist->setName( newName.trimmed() );
 }
@@ -113,7 +112,7 @@ SqlUserPlaylistProvider::deleteSqlPlaylists( Playlists::SqlPlaylistList playlist
         {
             debug() << "deleting " << sqlPlaylist->name();
             m_root->m_childPlaylists.removeAll( sqlPlaylist );
-            emit playlistRemoved( Playlists::PlaylistPtr::dynamicCast( sqlPlaylist ) );
+            Q_EMIT playlistRemoved( Playlists::PlaylistPtr::dynamicCast( sqlPlaylist ) );
             sqlPlaylist->removeFromDb();
         }
     }
@@ -125,7 +124,7 @@ Playlists::PlaylistPtr
 SqlUserPlaylistProvider::save( const Meta::TrackList &tracks )
 {
     DEBUG_BLOCK
-    QString name = KGlobal::locale()->formatDateTime( QDateTime::currentDateTime(), KLocale::LongDate, true );
+    QString name = QLocale().toString( QDateTime::currentDateTime(), QLocale::LongFormat );
     return save( tracks, name );
 }
 
@@ -142,7 +141,7 @@ SqlUserPlaylistProvider::save( const Meta::TrackList &tracks, const QString& nam
     m_root->m_childPlaylists << sqlPlaylist;
     Playlists::PlaylistPtr playlist( sqlPlaylist.data() );
 
-    emit playlistAdded( playlist );
+    Q_EMIT playlistAdded( playlist );
     return playlist; // assumes insertion in db was successful!
 }
 
@@ -151,7 +150,7 @@ SqlUserPlaylistProvider::reloadFromDb()
 {
     DEBUG_BLOCK;
     m_root->clear();
-    emit updated();
+    Q_EMIT updated();
 }
 
 Playlists::SqlPlaylistGroupPtr
@@ -188,7 +187,7 @@ SqlUserPlaylistProvider::createTables()
 {
     DEBUG_BLOCK
 
-    SqlStorage *sqlStorage = StorageManager::instance()->sqlStorage();
+    auto sqlStorage = StorageManager::instance()->sqlStorage();
     if( !sqlStorage )
     {
         debug() << "No SQL Storage available!";
@@ -199,7 +198,7 @@ SqlUserPlaylistProvider::createTables()
             ", parent_id INTEGER"
             ", name " + sqlStorage->textColumnType() +
             ", description " + sqlStorage->textColumnType() + " ) ENGINE = MyISAM;" ) );
-    sqlStorage->query( "CREATE INDEX parent_podchannel ON playlist_groups( parent_id );" );
+    sqlStorage->query( QStringLiteral("CREATE INDEX parent_podchannel ON playlist_groups( parent_id );") );
 
 
     sqlStorage->query( QString( "CREATE TABLE playlists ("
@@ -207,7 +206,7 @@ SqlUserPlaylistProvider::createTables()
             ", parent_id INTEGER"
             ", name " + sqlStorage->textColumnType() +
             ", urlid " + sqlStorage->exactTextColumnType() + " ) ENGINE = MyISAM;" ) );
-    sqlStorage->query( "CREATE INDEX parent_playlist ON playlists( parent_id );" );
+    sqlStorage->query( QStringLiteral("CREATE INDEX parent_playlist ON playlists( parent_id );") );
 
     sqlStorage->query( QString( "CREATE TABLE playlist_tracks ("
             " id " + sqlStorage->idType() +
@@ -220,8 +219,8 @@ SqlUserPlaylistProvider::createTables()
             ", length INTEGER "
             ", uniqueid " + sqlStorage->textColumnType(128) + ") ENGINE = MyISAM;" ) );
 
-    sqlStorage->query( "CREATE INDEX parent_playlist_tracks ON playlist_tracks( playlist_id );" );
-    sqlStorage->query( "CREATE INDEX playlist_tracks_uniqueid ON playlist_tracks( uniqueid );" );
+    sqlStorage->query( QStringLiteral("CREATE INDEX parent_playlist_tracks ON playlist_tracks( playlist_id );") );
+    sqlStorage->query( QStringLiteral("CREATE INDEX playlist_tracks_uniqueid ON playlist_tracks( uniqueid );") );
 }
 
 void
@@ -229,7 +228,7 @@ SqlUserPlaylistProvider::deleteTables()
 {
     DEBUG_BLOCK
 
-    SqlStorage *sqlStorage = StorageManager::instance()->sqlStorage();
+    auto sqlStorage = StorageManager::instance()->sqlStorage();
 
     if( !sqlStorage )
     {
@@ -237,14 +236,14 @@ SqlUserPlaylistProvider::deleteTables()
         return;
     }
 
-    sqlStorage->query( "DROP INDEX parent_podchannel ON playlist_groups;" );
-    sqlStorage->query( "DROP INDEX parent_playlist ON playlists;" );
-    sqlStorage->query( "DROP INDEX parent_playlist_tracks ON playlist_tracks;" );
-    sqlStorage->query( "DROP INDEX playlist_tracks_uniqueid ON playlist_tracks;" );
+    sqlStorage->query( QStringLiteral("DROP INDEX parent_podchannel ON playlist_groups;") );
+    sqlStorage->query( QStringLiteral("DROP INDEX parent_playlist ON playlists;") );
+    sqlStorage->query( QStringLiteral("DROP INDEX parent_playlist_tracks ON playlist_tracks;") );
+    sqlStorage->query( QStringLiteral("DROP INDEX playlist_tracks_uniqueid ON playlist_tracks;") );
 
-    sqlStorage->query( "DROP TABLE IF EXISTS playlist_groups;" );
-    sqlStorage->query( "DROP TABLE IF EXISTS playlists;" );
-    sqlStorage->query( "DROP TABLE IF EXISTS playlist_tracks;" );
+    sqlStorage->query( QStringLiteral("DROP TABLE IF EXISTS playlist_groups;") );
+    sqlStorage->query( QStringLiteral("DROP TABLE IF EXISTS playlists;") );
+    sqlStorage->query( QStringLiteral("DROP TABLE IF EXISTS playlist_tracks;") );
 
 }
 
@@ -253,14 +252,14 @@ SqlUserPlaylistProvider::checkTables()
 {
     DEBUG_BLOCK
 
-    SqlStorage *sqlStorage = StorageManager::instance()->sqlStorage();
+    auto sqlStorage = StorageManager::instance()->sqlStorage();
     QStringList values;
 
     //Prevents amarok from crashing on bad DB
     if ( !sqlStorage )
 	    return;
 
-    values = sqlStorage->query( QString("SELECT version FROM admin WHERE component = '%1';").arg(sqlStorage->escape( key ) ) );
+    values = sqlStorage->query( QStringLiteral("SELECT version FROM admin WHERE component = '%1';").arg(sqlStorage->escape( key ) ) );
     
     if( values.isEmpty() )
     {
@@ -299,8 +298,8 @@ void
 SqlUserPlaylistProvider::upgradeVersion2to3()
 {
     DEBUG_BLOCK
-    SqlStorage *sqlStorage = StorageManager::instance()->sqlStorage();
-    sqlStorage->query( "ALTER TABLE playlists DROP COLUMN description" );
+    auto sqlStorage = StorageManager::instance()->sqlStorage();
+    sqlStorage->query( QStringLiteral("ALTER TABLE playlists DROP COLUMN description") );
 }
 
 Playlists::SqlPlaylistList
@@ -319,4 +318,3 @@ SqlUserPlaylistProvider::toSqlPlaylists( Playlists::PlaylistList playlists )
 
 } //namespace Playlists
 
-#include "SqlUserPlaylistProvider.moc"
