@@ -17,32 +17,35 @@
 #include "ScriptConsole.h"
 #define DEBUG_PREFIX "ScriptConsole"
 
+#include "core/support/Amarok.h"
 #include "core/support/Debug.h"
 #include "MainWindow.h"
 #include "ScriptEditorDocument.h"
 #include "ScriptConsoleItem.h"
 
+#include <QAction>
 #include <QApplication>
 #include <QFileDialog>
 #include <QListWidget>
+#include <QKeyEvent>
 #include <QMenuBar>
-#include <QScriptEngine>
+#include <QJSEngine>
 #include <QSettings>
+#include <QStandardPaths>
 #include <QTemporaryFile>
 #include <QToolBar>
 
-#include <KAction>
 #include <KMessageBox>
-#include <KStandardDirs>
-#include <KTextEditor/ContainerInterface>
 #include <KTextEditor/Editor>
-#include <KTextEditor/EditorChooser>
 #include <KTextEditor/View>
+#include <KLocalizedString>
+
+#include <iostream>
 
 using namespace AmarokScript;
 using namespace ScriptConsoleNS;
 
-QWeakPointer<ScriptConsole> ScriptConsole::s_instance;
+QPointer<ScriptConsole> ScriptConsole::s_instance;
 
 ScriptConsole*
 ScriptConsole::instance()
@@ -57,71 +60,67 @@ ScriptConsole::instance()
 ScriptConsole::ScriptConsole( QWidget *parent )
     : QMainWindow( parent, Qt::Window )
 {
-    m_editor = KTextEditor::EditorChooser::editor();
+    m_editor = KTextEditor::Editor::instance();
     if ( !m_editor )
     {
-        KMessageBox::error( 0, i18n("A KDE text-editor component could not be found.\n"
+        KMessageBox::error( nullptr, i18n("A KDE text-editor component could not be found.\n"
                                    "Please check your KDE installation.  Exiting the console!") );
         deleteLater();
         return;
     }
-    m_editor->readConfig( KGlobal::config().data() );
-    m_scriptListDock = new ScriptListDockWidget( this );
-    m_debugger = new QScriptEngineDebugger( this );
 
     setDockNestingEnabled( true );
     setWindowTitle( i18n( "Script Console" ) );
-    setObjectName( "scriptconsole" );
+    setObjectName( QStringLiteral("scriptconsole") );
 
-    m_debugger->setAutoShowStandardWindow( false );
-    m_codeWidget = getWidget( "Code", QScriptEngineDebugger::CodeWidget );
-    addDockWidget( Qt::BottomDockWidgetArea, m_codeWidget );
-    QList<QDockWidget*> debugWidgets = QList<QDockWidget*>() << getWidget( i18n( "Console" ), QScriptEngineDebugger::ConsoleWidget )
-                    << getWidget( i18n( "Error" ), QScriptEngineDebugger::ErrorLogWidget )
-                    << getWidget( i18n( "Debug Output" ), QScriptEngineDebugger::DebugOutputWidget )
-                    << getWidget( i18n( "Loaded Scripts" ), QScriptEngineDebugger::ScriptsWidget )
-                    << getWidget( i18n( "Breakpoints" ), QScriptEngineDebugger::BreakpointsWidget )
-                    << getWidget( i18n( "Stack" ), QScriptEngineDebugger::StackWidget )
-                    << getWidget( i18n( "Locals" ), QScriptEngineDebugger::LocalsWidget );
+    m_scriptListDock = new ScriptListDockWidget( this );
+    m_codeWidget = getWidget( i18n("Code"), nullptr );
+    m_consoleWidget = getWidget( i18n("Console"), nullptr );
+    m_outputWidget = getWidget( i18n( "Output" ), nullptr );
+    m_errorWidget = getWidget( i18n( "Error" ), nullptr );
+
+    QList<QDockWidget*> debugWidgets = QList<QDockWidget*>()
+                    << m_codeWidget
+                    << m_consoleWidget
+                    << m_outputWidget
+                    << m_errorWidget;
     foreach( QDockWidget *widget, debugWidgets )
     {
       addDockWidget( Qt::BottomDockWidgetArea, widget );
     }
-    addDockWidget( Qt::BottomDockWidgetArea, m_scriptListDock );
-    tabifyDockWidget( debugWidgets[0], debugWidgets[1] );
     tabifyDockWidget( debugWidgets[1], debugWidgets[2] );
-    tabifyDockWidget( debugWidgets[3], debugWidgets[4] );
-    tabifyDockWidget( debugWidgets[5], debugWidgets[6] );
+    tabifyDockWidget( debugWidgets[2], debugWidgets[3] );
+
+    addDockWidget( Qt::BottomDockWidgetArea, m_scriptListDock );
 
     QMenuBar *bar = new QMenuBar( this );
     setMenuBar( bar );
-    bar->addMenu( m_debugger->createStandardMenu( this ) );
-    QToolBar *toolBar = m_debugger->createStandardToolBar( this );
+    QToolBar *toolBar = new QToolBar( this );
     QAction *action = new QAction( i18n( "Stop" ), this );
     action->setIcon( QApplication::style()->standardIcon( QStyle::SP_MediaStop ) );
-    connect( action, SIGNAL(toggled(bool)), SLOT(slotAbortEvaluation()) );
+    connect( action, &QAction::toggled, this, &ScriptConsole::slotAbortEvaluation );
     toolBar->addAction( action );
-    action = new KAction( KIcon( "media-playback-start" ), i18n("Execute Script"), this );
+    action = new QAction( QIcon::fromTheme( QStringLiteral("media-playback-start") ), i18n("Execute Script"), this );
     action->setShortcut( Qt::CTRL + Qt::Key_Enter );
-    connect( action, SIGNAL(triggered(bool)), SLOT(slotExecuteNewScript()) );
+    connect( action, &QAction::triggered, this, &ScriptConsole::slotExecuteNewScript );
     toolBar->addAction( action );
-    action = new KAction( KIcon( "document-new" ), i18n( "&New Script" ), this );
+    action = new QAction( QIcon::fromTheme( QStringLiteral("document-new") ), i18n( "&New Script" ), this );
     action->setShortcut( Qt::CTRL + Qt::Key_N );
     toolBar->addAction( action );
-    connect( action, SIGNAL(triggered(bool)), SLOT(slotNewScript()) );
-    action = new KAction( KIcon( "edit-delete" ), i18n( "&Delete Script" ), this );
+    connect( action, &QAction::triggered, this, &ScriptConsole::slotNewScript );
+    action = new QAction( QIcon::fromTheme( QStringLiteral("edit-delete") ), i18n( "&Delete Script" ), this );
     toolBar->addAction( action );
-    connect( action, SIGNAL(triggered(bool)), m_scriptListDock, SLOT(removeCurrentScript()) );
-    action = new KAction( i18n( "&Clear All Scripts" ), this );
+    connect( action, &QAction::triggered, m_scriptListDock, &ScriptListDockWidget::removeCurrentScript );
+    action = new QAction( i18n( "&Clear All Scripts" ), this );
     toolBar->addAction( action );
-    connect( action, SIGNAL(triggered(bool)), m_scriptListDock, SLOT(clear()) );
-    action = new KAction( i18n("Previous Script"), this );
+    connect( action, &QAction::triggered, m_scriptListDock, &ScriptListDockWidget::clear );
+    action = new QAction( i18n("Previous Script"), this );
     action->setShortcut( QKeySequence::MoveToPreviousPage );
-    connect( action, SIGNAL(triggered(bool)), m_scriptListDock, SLOT(prev()) );
+    connect( action, &QAction::triggered, m_scriptListDock, &ScriptListDockWidget::prev );
     toolBar->addAction( action );
-    action = new KAction( i18n("Next Script"), this );
+    action = new QAction( i18n("Next Script"), this );
     action->setShortcut( QKeySequence::MoveToNextPage );
-    connect( action, SIGNAL(triggered(bool)), m_scriptListDock, SLOT(next()) );
+    connect( action, &QAction::triggered, m_scriptListDock, &ScriptListDockWidget::next );
     toolBar->addAction( action );
 
     addToolBar( toolBar );
@@ -135,13 +134,9 @@ ScriptConsole::ScriptConsole( QWidget *parent )
     }
     menuBar()->addMenu( viewMenu );
 
-    KTextEditor::ContainerInterface *iface = qobject_cast<KTextEditor::ContainerInterface*>( m_editor );
-    if (iface)
-        iface->setContainer( parent );
-
     addDockWidget( Qt::BottomDockWidgetArea, m_scriptListDock );
-    connect( m_scriptListDock, SIGNAL(edit(ScriptConsoleItem*)), SLOT(slotEditScript(ScriptConsoleItem*)) );
-    connect( m_scriptListDock, SIGNAL(currentItemChanged(ScriptConsoleItem*)), SLOT(setCurrentScriptItem(ScriptConsoleItem*)) );
+    connect( m_scriptListDock, &ScriptListDockWidget::edit, this, &ScriptConsole::slotEditScript );
+    connect( m_scriptListDock, &ScriptListDockWidget::currentItemChanged, this, &ScriptConsole::setCurrentScriptItem );
 
     QListWidgetItem *item = new QListWidgetItem( "The Amarok Script Console allows you to easily execute"
                                                 "JavaScript with access to all functions\nand methods you would"
@@ -149,59 +144,68 @@ ScriptConsole::ScriptConsole( QWidget *parent )
                                                 "available at:\nhttp://community.kde.org/Amarok/Development#Scripting"
                                                 "\nExecute code: CTRL-Enter\nBack in code history: Page Up"
                                                 "\nForward in code history: Page Down"
-                                                "See the debugger manual at: <link here>"
                                                , 0 );
     item->setFlags( Qt::NoItemFlags );
     m_scriptListDock->addItem( item );
 
-    QSettings settings( "KDE", "Amarok" );
-    settings.beginGroup( "ScriptConsole" );
-    restoreGeometry( settings.value("geometry").toByteArray() );
-    m_savePath = settings.value("savepath").toString();
+    QSettings settings( QStringLiteral("KDE"), QStringLiteral("Amarok") );
+    settings.beginGroup( QStringLiteral("ScriptConsole") );
+    restoreGeometry( settings.value(QStringLiteral("geometry")).toByteArray() );
+    m_savePath = settings.value(QStringLiteral("savepath")).toString();
     settings.endGroup();
 
     if( m_savePath.isEmpty() )
-        m_savePath = KUrl( KStandardDirs::locateLocal( "data", "amarok/scriptconsole/" ) ).path();
+        m_savePath = Amarok::saveLocation(QStringLiteral("scriptconsole"));
 
     slotNewScript();
-    connect( m_debugger, SIGNAL(evaluationSuspended()), SLOT(slotEvaluationSuspended()) );
-    connect( m_debugger, SIGNAL(evaluationResumed()), SLOT(slotEvaluationResumed()) );
     show();
     raise();
+
+    // Install interceptor for JS console logs and forward to appropriate widget
+    qInstallMessageHandler( [] ( QtMsgType type, const QMessageLogContext &context, const QString &msg )
+    {
+        Q_UNUSED( type );
+        QString category(context.category);
+        if ( category.compare( "js" ) == 0 ) {
+
+            QString scriptName( context.file );
+            // clean "file:" from file name
+            scriptName.remove( 0, 5);
+
+            // Search script by name
+            ScriptConsoleItem *searchResult = instance()->getScriptListDockWidget()->getScript( scriptName );
+            if (searchResult != nullptr ) {
+                // Found it - update its console widget
+                QString logEntry = QString("[%1: %2] %3")
+                .arg( scriptName )
+                .arg( context.line )
+                .arg( msg );
+                searchResult->appendToConsoleWidget( logEntry );
+            }
+        }
+
+        // Print all QT logging to STDERR as default
+        std::cerr << msg.toStdString() << std::endl;
+    });
 }
 
 void
 ScriptConsole::slotExecuteNewScript()
 {
-    if( m_scriptItem.data()->document()->text().isEmpty() )
+    if( m_scriptItem->document()->text().isEmpty() )
         return;
 
-    QScriptSyntaxCheckResult syntaxResult = m_scriptItem.data()->engine()->checkSyntax( m_scriptItem.data()->document()->text() );
-    if( QScriptSyntaxCheckResult::Valid != syntaxResult.state() )
-    {
-        debug() << "Syntax error: " << syntaxResult.errorLineNumber() << syntaxResult.errorMessage();
-        KTextEditor::View *view = dynamic_cast<KTextEditor::View*>( m_codeWidget->widget() );
-        ScriptEditorDocument::highlight( view, syntaxResult.errorLineNumber(), QColor( 255, 0, 0 ) );
-        int response = KMessageBox::warningContinueCancel( this, i18n( "Syntax error at line %1, continue anyway?\nError: %2",
-                                                  syntaxResult.errorLineNumber(), syntaxResult.errorMessage() ),
-                                            i18n( "Syntax Error" ) );
-        ScriptEditorDocument::clearHighlights( view );
-        if( response == KMessageBox::Cancel )
-            return;
-    }
-
-    m_scriptItem.data()->document()->save();
-    m_codeWidget->setWidget( m_debugger->widget( QScriptEngineDebugger::CodeWidget ) );
-    m_scriptItem.data()->start( false );
+    m_scriptItem->document()->save();
+    m_scriptItem->start( false );
 }
 
 void
 ScriptConsole::closeEvent( QCloseEvent *event )
 {
-    QSettings settings( "Amarok", "Script Console" );
-    settings.beginGroup( "ScriptConsole" );
-    settings.setValue( "geometry", saveGeometry() );
-    settings.setValue( "savepath", m_savePath );
+    QSettings settings( QStringLiteral("KDE"), QStringLiteral("Amarok") );
+    settings.beginGroup( QStringLiteral("ScriptConsole") );
+    settings.setValue( QStringLiteral("geometry"), saveGeometry() );
+    settings.setValue( QStringLiteral("savepath"), m_savePath );
     settings.endGroup();
     QMainWindow::closeEvent( event );
     deleteLater();
@@ -210,8 +214,8 @@ ScriptConsole::closeEvent( QCloseEvent *event )
 void
 ScriptConsole::slotEditScript( ScriptConsoleItem *item )
 {
-    if( m_scriptItem.data()->running() && KMessageBox::warningContinueCancel( this, i18n( "This will stop this script! Continue?" ), QString(), KStandardGuiItem::cont()
-                                        , KStandardGuiItem::cancel(), "stopRunningScriptWarning" ) == KMessageBox::Cancel )
+    if( m_scriptItem->running() && KMessageBox::warningContinueCancel( this, i18n( "This will stop this script! Continue?" ), QString(), KStandardGuiItem::cont()
+                                        , KStandardGuiItem::cancel(), QStringLiteral("stopRunningScriptWarning") ) == KMessageBox::Cancel )
         return;
 
     item->pause();
@@ -222,7 +226,7 @@ ScriptConsoleItem*
 ScriptConsole::createScriptItem( const QString &script )
 {
     if( ( m_savePath.isEmpty() || !QDir( m_savePath ).exists() )
-        && ( m_savePath = QFileDialog::getExistingDirectory(this, i18n( "Choose where to save your scripts" ), "~",
+        && ( m_savePath = QFileDialog::getExistingDirectory(this, i18n( "Choose where to save your scripts" ), QStringLiteral("~"),
             QFileDialog::ShowDirsOnly | QFileDialog::DontResolveSymlinks) ).isEmpty() )
         return 0;
 
@@ -230,20 +234,26 @@ ScriptConsole::createScriptItem( const QString &script )
     QString scriptName;
     do
     {
-        scriptName = QString( "Script-%1" ).arg( qrand() );
-        scriptPath =  QString( "%1/%2" ).arg( m_savePath, scriptName );
+        scriptName = QStringLiteral( "Script-%1" ).arg( qrand() );
+        scriptPath =  QStringLiteral( "%1/%2" ).arg( m_savePath, scriptName );
     } while ( QDir( scriptPath ).exists() );
     QDir().mkdir( scriptPath );
 
     ScriptEditorDocument *document = new ScriptEditorDocument( this, m_editor->createDocument( 0 ) );
     document->setText( script );
-    ScriptConsoleItem *scriptItem = new ScriptConsoleItem( this, scriptName, "Generic", scriptPath, document );
+    ScriptConsoleItem *scriptItem = new ScriptConsoleItem( this, scriptName, QStringLiteral("Generic"), scriptPath, document );
     return scriptItem;
 }
 
+ScriptListDockWidget*
+ScriptConsole::getScriptListDockWidget()
+{
+    return m_scriptListDock;
+}
+
 ScriptConsole::~ScriptConsole()
 {
-    m_debugger->detach();
+    //m_debugger->detach();
 }
 
 void
@@ -254,12 +264,14 @@ ScriptConsole::slotEvaluationSuspended()
         slotNewScript();
         return;
     }
-    debug() << "Is Evaluating() " << m_scriptItem.data()->engine()->isEvaluating();
-    debug() << "Exception isValid()" << m_scriptItem.data()->engine()->uncaughtException().isValid();
-    if( m_scriptItem.data()->engine() && m_scriptItem.data()->engine()->uncaughtException().isValid() )
+    debug() << "Is Running() " << m_scriptItem->running();
+    debug() << "Engine isError()" << m_scriptItem->engineResult().isError();
+    // TODO - Inspect if translations work with real debugger signals
+    //if( m_scriptItem->engine() && m_scriptItem->engine()->uncaughtException().isValid() )
+    if( m_scriptItem->engine() && m_scriptItem->engineResult().isError() )
         return;
 
-    KTextEditor::View *view = m_scriptItem.data()->createEditorView( m_codeWidget );
+    KTextEditor::View *view = m_scriptItem->getEditorView( m_codeWidget );
     view->installEventFilter( this );
     view->document()->installEventFilter( this );
     m_codeWidget->setWidget( view );
@@ -268,12 +280,12 @@ ScriptConsole::slotEvaluationSuspended()
 void
 ScriptConsole::slotEvaluationResumed()
 {
-    debug() << "Is Evaluating() " << m_scriptItem.data()->engine()->isEvaluating();
-    debug() << "Exception isValid()" << m_scriptItem.data()->engine()->uncaughtException().isValid();
-    if( !m_scriptItem.data()->engine() || !m_scriptItem.data()->engine()->isEvaluating() )
+    debug() << "Is running() " << m_scriptItem->running();
+    debug() << "Engine isError()" << m_scriptItem->engineResult().isError();
+    if( !m_scriptItem->engine() || !m_scriptItem->running() )
         return;
 
-    KTextEditor::View *view = m_scriptItem.data()->createEditorView( m_codeWidget );
+    KTextEditor::View *view = m_scriptItem->getEditorView( m_codeWidget );
     view->installEventFilter( this );
     m_codeWidget->setWidget( view );
 }
@@ -281,15 +293,16 @@ ScriptConsole::slotEvaluationResumed()
 void
 ScriptConsole::slotAbortEvaluation()
 {
-    m_scriptItem.data()->pause();
+    m_scriptItem->pause();
 }
 
+
 QDockWidget*
-ScriptConsole::getWidget( const QString &title, QScriptEngineDebugger::DebuggerWidget widget )
+ScriptConsole::getWidget( const QString &title, QWidget *widget )
 {
-    QDockWidget *debugWidget = new QDockWidget( title, this );
-    debugWidget->setWidget( m_debugger->widget( widget ) );
-    return debugWidget;
+    QDockWidget *dockWidget = new QDockWidget( title, this );
+    dockWidget->setWidget( widget );
+    return dockWidget;
 }
 
 void
@@ -297,25 +310,44 @@ ScriptConsole::setCurrentScriptItem( ScriptConsoleItem *item )
 {
     if( !item || m_scriptItem.data() == item )
         return;
-    m_debugger->detach();
-    m_debugger->attachTo( item->engine() );
+
+    // Set the active script widgets and update them
     m_scriptItem = item;
-    if( item->engine() && item->engine()->isEvaluating() )
+
+    KTextEditor::View *view = item->getEditorView( m_codeWidget );
+    m_codeWidget->setWidget( view  );
+    view->installEventFilter( this );
+    view->show();
+
+    QWidget *console = item->getConsoleWidget( m_consoleWidget );
+    m_consoleWidget->setWidget( console );
+    console->show();
+
+    QWidget *output = item->getOutputWdiget( m_outputWidget  );
+    m_outputWidget->setWidget( output );
+    output->show();
+
+    QWidget *error  = item->getErrorWidget( m_errorWidget );
+    m_errorWidget->setWidget( error );
+    error->show();
+
+    /* TODO - install filters
+    if( item->engine() && item->running() )
     {
-        m_codeWidget->setWidget( m_debugger->widget( QScriptEngineDebugger::CodeWidget ) );
+        view->document()->setReadWrite( false );
     }
     else
     {
-        KTextEditor::View *view = item->createEditorView( m_codeWidget );
+        view->document()->setReadWrite( true );
         view->installEventFilter( this );
-        m_codeWidget->setWidget( view );
     }
+    */
 }
 
 void
 ScriptConsole::slotNewScript()
 {
-    ScriptConsoleItem *item = createScriptItem( "" );
+    ScriptConsoleItem *item = createScriptItem( QLatin1String("") );
     m_scriptListDock->addScript( item );
     setCurrentScriptItem( item );
 }
@@ -344,24 +376,44 @@ ScriptConsole::eventFilter( QObject *watched, QEvent *event )
 ScriptListDockWidget::ScriptListDockWidget( QWidget *parent )
 : QDockWidget( i18n( "Scripts" ), parent )
 {
-    QWidget *widget = new KVBox( this );
+    QWidget *widget = new BoxWidget( true, this );
     setWidget( widget );
     m_scriptListWidget = new QListWidget( widget );
     m_scriptListWidget->setVerticalScrollMode( QAbstractItemView::ScrollPerPixel );
-    connect( m_scriptListWidget, SIGNAL(doubleClicked(QModelIndex)), SLOT(slotDoubleClicked(QModelIndex)) );
-    connect( m_scriptListWidget, SIGNAL(currentItemChanged(QListWidgetItem*,QListWidgetItem*)),
-             SLOT(slotCurrentItemChanged(QListWidgetItem*,QListWidgetItem*)) );
+    connect( m_scriptListWidget, &QListWidget::doubleClicked,
+             this, &ScriptListDockWidget::slotDoubleClicked );
+    connect( m_scriptListWidget, &QListWidget::currentItemChanged,
+             this, &ScriptListDockWidget::slotCurrentItemChanged );
+}
+
+QListWidget*
+ScriptListDockWidget::listWidget()
+{
+    return m_scriptListWidget;
 }
 
 void
 ScriptListDockWidget::addScript( ScriptConsoleItem *script )
 {
+    if( !script )
+        return;
+
     QListWidgetItem *item = new QListWidgetItem( script->name(), 0 );
     item->setData( ScriptRole, QVariant::fromValue<ScriptConsoleItem*>( script ) );
     m_scriptListWidget->addItem( item );
     m_scriptListWidget->setCurrentItem( item );
 }
 
+ScriptConsoleItem*
+ScriptListDockWidget::getScript( const QString &scriptName)
+{
+    QList<QListWidgetItem *> searchResult = listWidget()->findItems( scriptName, Qt::MatchFixedString);
+    if (! searchResult.isEmpty() ) {
+        return searchResult.first()->data( ScriptRole ).value<ScriptConsoleItem*>();
+    }
+    return nullptr;
+}
+
 void
 ScriptListDockWidget::removeCurrentScript()
 {
@@ -385,19 +437,19 @@ void
 ScriptListDockWidget::slotCurrentItemChanged( QListWidgetItem *newItem, QListWidgetItem *oldItem )
 {
     Q_UNUSED( oldItem )
-    emit currentItemChanged( newItem ? qvariant_cast<ScriptConsoleItem*>( newItem->data(ScriptRole) ) : 0 );
+    Q_EMIT currentItemChanged( newItem ? qvariant_cast<ScriptConsoleItem*>( newItem->data(ScriptRole) ) : nullptr );
 }
 
 void
 ScriptListDockWidget::slotDoubleClicked( const QModelIndex &index )
 {
-    emit edit( qvariant_cast<ScriptConsoleItem*>( index.data(ScriptRole) ) );
+    Q_EMIT edit( qvariant_cast<ScriptConsoleItem*>( index.data(ScriptRole) ) );
 }
 
 void
 ScriptListDockWidget::clear()
 {
-    if( sender() && KMessageBox::warningContinueCancel( 0, i18n("Are you absolutely certain?") ) == KMessageBox::Cancel )
+    if( sender() && KMessageBox::warningContinueCancel( nullptr, i18n("Are you absolutely certain?") ) == KMessageBox::Cancel )
         return;
     for( int i = 0; i<m_scriptListWidget->count(); ++i )
         qvariant_cast<ScriptConsoleItem*>( m_scriptListWidget->item( i )->data( ScriptRole ) )->deleteLater();
