@@ -25,50 +25,80 @@
 #include "core-impl/storage/StorageManager.h"
 #include "ServiceSqlCollection.h"
 
-#include <threadweaver/Job.h>
-#include <threadweaver/ThreadWeaver.h>
-
 #include <QStack>
+#include <QSharedPointer>
 
 using namespace Collections;
 
-class ServiceSqlWorkerThread : public ThreadWeaver::Job
+class ServiceSqlWorkerThread : public QObject, public ThreadWeaver::Job
 {
+    Q_OBJECT
     public:
         ServiceSqlWorkerThread( ServiceSqlQueryMaker *queryMaker )
-            : ThreadWeaver::Job()
+            : QObject()
+            , ThreadWeaver::Job()
             , m_queryMaker( queryMaker )
             , m_aborted( false )
         {
             //nothing to do
         }
 
-        virtual void requestAbort()
+        void requestAbort() override
         {
             m_aborted = true;
         }
 
+    Q_SIGNALS:
+        /** This signal is emitted when this job is being processed by a thread. */
+        void started(ThreadWeaver::JobPointer);
+        /** This signal is emitted when the job has been finished (no matter if it succeeded or not). */
+        void done(ThreadWeaver::JobPointer);
+        /** This job has failed.
+         * This signal is emitted when success() returns false after the job is executed. */
+        void failed(ThreadWeaver::JobPointer);
+
     protected:
-        virtual void run()
+
+        void run(ThreadWeaver::JobPointer self = QSharedPointer<ThreadWeaver::Job>(), ThreadWeaver::Thread *thread = nullptr) override
         {
+            Q_UNUSED(self);
+            Q_UNUSED(thread);
             QString query = m_queryMaker->query();
             QStringList result = m_queryMaker->runQuery( query );
             if( !m_aborted )
                 m_queryMaker->handleResult( result );
-            setFinished( !m_aborted );
+
+            if( m_aborted )
+                setStatus(Status_Aborted);
+            else
+                setStatus(Status_Running);
         }
+
+        void defaultBegin(const ThreadWeaver::JobPointer& self, ThreadWeaver::Thread *thread) override
+        {
+            Q_EMIT started(self);
+            ThreadWeaver::Job::defaultBegin(self, thread);
+        }
+
+        void defaultEnd(const ThreadWeaver::JobPointer& self, ThreadWeaver::Thread *thread) override
+        {
+            ThreadWeaver::Job::defaultEnd(self, thread);
+            if (!self->success()) {
+                Q_EMIT failed(self);
+            }
+            Q_EMIT done(self);
+        }
+
     private:
         ServiceSqlQueryMaker *m_queryMaker;
-
         bool m_aborted;
 };
 
 struct ServiceSqlQueryMaker::Private
 {
-    enum QueryType { NONE, TRACK, ARTIST, ALBUM, ALBUMARTIST, GENRE, COMPOSER, YEAR, CUSTOM };
-    enum {TRACKS_TABLE = 1, ALBUMS_TABLE = 2, ARTISTS_TABLE = 4, GENRE_TABLE = 8, ALBUMARTISTS_TABLE = 16 };
+    enum { TRACKS_TABLE = 1, ALBUMS_TABLE = 2, ARTISTS_TABLE = 4, GENRE_TABLE = 8, ALBUMARTISTS_TABLE = 16 };
     int linkedTables;
-    QueryType queryType;
+    QueryMaker::QueryType queryType;
     QString query;
     QString queryReturnValues;
     QString queryFrom;
@@ -80,7 +110,7 @@ struct ServiceSqlQueryMaker::Private
     AlbumQueryMode albumMode;
     bool withoutDuplicates;
     int maxResultSize;
-    ServiceSqlWorkerThread *worker;
+    QSharedPointer<ServiceSqlWorkerThread> worker;
     QStack<bool> andStack;
 };
 
@@ -93,9 +123,8 @@ ServiceSqlQueryMaker::ServiceSqlQueryMaker( ServiceSqlCollection* collection, Se
 {
     //d->includedBuilder = true;
     //d->collectionRestriction = false;
-    d->worker = 0;
 
-    d->queryType = Private::NONE;
+    d->queryType = QueryMaker::None;
     d->linkedTables = 0;
     d->withoutDuplicates = false;
     d->maxResultSize = -1;
@@ -103,10 +132,7 @@ ServiceSqlQueryMaker::ServiceSqlQueryMaker( ServiceSqlCollection* collection, Se
 }
 
 ServiceSqlQueryMaker::~ServiceSqlQueryMaker()
-{
-    // what about d->worker?
-    delete d;
-}
+{}
 
 void
 ServiceSqlQueryMaker::abortQuery()
@@ -118,29 +144,30 @@ ServiceSqlQueryMaker::abortQuery()
 void
 ServiceSqlQueryMaker::run()
 {
-    if( d->queryType == Private::NONE )
+    if( d->queryType == QueryMaker::None )
         return; //better error handling?
     if( d->worker && !d->worker->isFinished() )
     {
         //the worker thread seems to be running
-        //TODO: wait or job to complete
+        //TODO: wait for job to complete
 
     }
     else
     {
-        d->worker = new ServiceSqlWorkerThread( this );
-        connect( d->worker, SIGNAL(done(ThreadWeaver::Job*)), SLOT(done(ThreadWeaver::Job*)) );
-        ThreadWeaver::Weaver::instance()->enqueue( d->worker );
+        d->worker.reset( new ServiceSqlWorkerThread( this ) );
+        connect( d->worker.data(), &ServiceSqlWorkerThread::done, this, &ServiceSqlQueryMaker::done );
+
+        ThreadWeaver::Queue::instance()->enqueue( QSharedPointer<ThreadWeaver::Job>(d->worker) );
     }
 }
 
 void
-ServiceSqlQueryMaker::done( ThreadWeaver::Job *job )
+ServiceSqlQueryMaker::done( ThreadWeaver::JobPointer job )
 {
-    ThreadWeaver::Weaver::instance()->dequeue( job );
-    job->deleteLater();
-    d->worker = 0;
-    emit queryDone();
+    Q_UNUSED( job )
+
+    d->worker.clear();
+    Q_EMIT queryDone();
 }
 
 QueryMaker*
@@ -149,17 +176,17 @@ ServiceSqlQueryMaker::setQueryType( QueryType type)
     switch( type ) {
     case QueryMaker::Track:
         //make sure to keep this method in sync with handleTracks(QStringList) and the SqlTrack ctor
-        if( d->queryType == Private::NONE )
+        if( d->queryType == QueryMaker::None )
         {
             QString prefix = m_metaFactory->tablePrefix();
             //d->queryFrom = ' ' + prefix + "_tracks";
 
             d->withoutDuplicates = true;
             d->queryFrom = ' ' + prefix + "_tracks";
-            d->queryType = Private::TRACK;
-            d->queryReturnValues =  m_metaFactory->getTrackSqlRows() + ',' +
-            m_metaFactory->getAlbumSqlRows() + ',' +
-            m_metaFactory->getArtistSqlRows() + ',' +
+            d->queryType = QueryMaker::Track;
+            d->queryReturnValues =  m_metaFactory->getTrackSqlRows() + QLatin1Char(',') +
+            m_metaFactory->getAlbumSqlRows() + QLatin1Char(',') +
+            m_metaFactory->getArtistSqlRows() + QLatin1Char(',') +
             m_metaFactory->getGenreSqlRows();
 
             d->linkedTables |= Private::GENRE_TABLE;
@@ -176,13 +203,13 @@ ServiceSqlQueryMaker::setQueryType( QueryType type)
         return this;
 
     case QueryMaker::Artist:
-        if( d->queryType == Private::NONE )
+        if( d->queryType == QueryMaker::None )
         {
             QString prefix = m_metaFactory->tablePrefix();
             d->queryFrom = ' ' + prefix + "_tracks";
             d->linkedTables |= Private::ARTISTS_TABLE;
             d->linkedTables |= Private::ALBUMS_TABLE;
-            d->queryType = Private::ARTIST;
+            d->queryType = QueryMaker::Artist;
             d->withoutDuplicates = true;
             d->queryReturnValues = m_metaFactory->getArtistSqlRows();
 
@@ -191,14 +218,14 @@ ServiceSqlQueryMaker::setQueryType( QueryType type)
         return this;
 
     case QueryMaker::AlbumArtist:
-        if( d->queryType == Private::NONE )
+        if( d->queryType == QueryMaker::None )
         {
             QString prefix = m_metaFactory->tablePrefix();
             d->queryFrom = ' ' + prefix + "_tracks";
             d->linkedTables |= Private::ALBUMARTISTS_TABLE;
-            d->queryType = Private::ALBUMARTIST;
+            d->queryType = QueryMaker::AlbumArtist;
             d->withoutDuplicates = true;
-            d->queryReturnValues = QString( "albumartists.id, " ) +
+            d->queryReturnValues = QStringLiteral( "albumartists.id, " ) +
                                             "albumartists.name, " +
                                             "albumartists.description ";
             d->queryOrderBy += " GROUP BY " + prefix + "_tracks.id"; //fixes the same track being shown several times due to being in several genres
@@ -206,15 +233,15 @@ ServiceSqlQueryMaker::setQueryType( QueryType type)
         return this;
 
     case QueryMaker::Album:
-        if( d->queryType == Private::NONE )
+        if( d->queryType == QueryMaker::None )
         {
             QString prefix = m_metaFactory->tablePrefix();
             d->queryFrom = ' ' + prefix + "_tracks";
-            d->queryType = Private::ALBUM;
+            d->queryType = QueryMaker::Album;
             d->linkedTables |= Private::ALBUMS_TABLE;
             d->linkedTables |= Private::ARTISTS_TABLE;
             d->withoutDuplicates = true;
-            d->queryReturnValues = m_metaFactory->getAlbumSqlRows() + ',' +
+            d->queryReturnValues = m_metaFactory->getAlbumSqlRows() + QLatin1Char(',') +
             m_metaFactory->getArtistSqlRows();
 
             d->queryOrderBy += " GROUP BY " + prefix + "_tracks.id"; //fixes the same track being shown several times due to being in several genres
@@ -224,21 +251,21 @@ ServiceSqlQueryMaker::setQueryType( QueryType type)
     case QueryMaker::Composer:
         /* if( d->queryType == Private::NONE )
             {
-                d->queryType = Private::COMPOSER;
+                d->queryType = QueryMaker::Composer;
                 d->withoutDuplicates = true;
-                d->linkedTables |= Private::COMPOSER_TAB;
+                d->linkedTables |= QueryMaker::Composer_TAB;
                 d->queryReturnValues = "composer.name, composer.id";
             }*/
         return this;
 
     case QueryMaker::Genre:
-        if( d->queryType == Private::NONE )
+        if( d->queryType == QueryMaker::None )
         {
             QString prefix = m_metaFactory->tablePrefix();
             d->queryFrom = ' ' + prefix + "_genre";
-            d->queryType = Private::GENRE;
-            //d->linkedTables |= Private::ALBUMS_TABLE;
-            //d->linkedTables |= Private::GENRE_TABLE;
+            d->queryType = QueryMaker::Genre;
+            //d->linkedTables |= QueryMaker::Albums_TABLE;
+            //d->linkedTables |= QueryMaker::Genre_TABLE;
             d->withoutDuplicates = true;
             d->queryReturnValues = m_metaFactory->getGenreSqlRows();
             d->queryOrderBy = " GROUP BY " + prefix +"_genre.name"; // HAVING COUNT ( " + prefix +"_genre.name ) > 10 ";
@@ -273,7 +300,7 @@ ServiceSqlQueryMaker::addMatch( const Meta::TrackPtr &track )
 {
     //DEBUG_BLOCK
     Q_UNUSED( track );
-    //TODO still pondereing this one...
+    //TODO still pondering this one...
     return this;
 }
 
@@ -299,7 +326,7 @@ ServiceSqlQueryMaker::addMatch( const Meta::ArtistPtr &artist, QueryMaker::Artis
                  d->queryMatch += QString( " AND " + prefix + "_artists.id= '%1'" ).arg( serviceArtist->id() );
                  break;
             case AlbumArtists:
-                 d->queryMatch += QString( " AND albumartists.id= '%1'" ).arg( serviceArtist->id() );
+                 d->queryMatch += QStringLiteral( " AND albumartists.id= '%1'" ).arg( serviceArtist->id() );
                  break;
             case AlbumOrTrackArtists:
                  d->queryMatch += QString( " AND ( " + prefix + "_artists.id= '%1' OR albumartists.id= '%1' )" ).arg( serviceArtist->id() );
@@ -314,7 +341,7 @@ ServiceSqlQueryMaker::addMatch( const Meta::ArtistPtr &artist, QueryMaker::Artis
                  d->queryMatch += QString( " AND " + prefix + "_artists.name= '%1'" ).arg( escape( artist->name() ) );
                  break;
             case AlbumArtists:
-                 d->queryMatch += QString( " AND albumartists.name= '%1'" ).arg( escape( artist->name() ) );
+                 d->queryMatch += QStringLiteral( " AND albumartists.name= '%1'" ).arg( escape( artist->name() ) );
                  break;
             case AlbumOrTrackArtists:
                  d->queryMatch += QString( " AND ( " + prefix + "_artists.name= '%1' OR albumartists.name= '%1' )" ).arg( escape( artist->name() ) );
@@ -337,7 +364,7 @@ ServiceSqlQueryMaker::addMatch( const Meta::AlbumPtr &album )
 
     d->linkedTables |= Private::ALBUMS_TABLE;
     d->linkedTables |= Private::ARTISTS_TABLE;
-    if( d->queryType == Private::GENRE )
+    if( d->queryType == QueryMaker::Genre )
         d->linkedTables |= Private::GENRE_TABLE;
     if( serviceAlbum )
     {
@@ -364,12 +391,12 @@ ServiceSqlQueryMaker::addMatch( const Meta::GenrePtr &genre )
 
    // if (  d->queryType == Private::TRACK ) {
         //d->queryFrom = ' ' + prefix + "_tracks";
-        d->linkedTables |= Private::ALBUMS_TABLE;
+    d->linkedTables |= Private::ALBUMS_TABLE;
     //} else
         //d->queryFrom = ' ' + prefix + "_albums";
 
         //if ( d->queryType == Private::ARTIST )
-        //d->linkedTables |= Private::ARTISTS_TABLE;
+    //d->linkedTables |= Private::ARTISTS_TABLE;
     d->linkedTables |= Private::GENRE_TABLE;
     d->queryMatch += QString( " AND " + prefix + "_genre.name = '%1'" ).arg( serviceGenre->name() );
 
@@ -408,7 +435,7 @@ ServiceSqlQueryMaker::addFilter( qint64 value, const QString &filter, bool match
         return this;
     }
     //a few hacks needed by some of the speedup code:
-    if ( d->queryType == Private::GENRE )
+    if ( d->queryType == QueryMaker::Genre )
     {
         QString prefix = m_metaFactory->tablePrefix();
         d->queryFrom = ' ' + prefix + "_tracks";
@@ -417,7 +444,7 @@ ServiceSqlQueryMaker::addFilter( qint64 value, const QString &filter, bool match
         d->linkedTables |= Private::GENRE_TABLE;
     }
     QString like = likeCondition( filter, !matchBegin, !matchEnd );
-    d->queryFilter += QString( " %1 %2 %3 " ).arg( andOr(), nameForValue( value ), like );
+    d->queryFilter += QStringLiteral( " %1 %2 %3 " ).arg( andOr(), nameForValue( value ), like );
     return this;
 }
 
@@ -428,7 +455,7 @@ ServiceSqlQueryMaker::excludeFilter( qint64 value, const QString &filter, bool m
     if( isValidValue( value ) )
     {
         QString like = likeCondition( filter, !matchBegin, !matchEnd );
-        d->queryFilter += QString( " %1 NOT %2 %3 " ).arg( andOr(), nameForValue( value ), like );
+        d->queryFilter += QStringLiteral( " %1 NOT %2 %3 " ).arg( andOr(), nameForValue( value ), like );
     }
     return this;
 }
@@ -479,8 +506,8 @@ ServiceSqlQueryMaker::orderBy( qint64 value, bool descending )
 {
     Q_UNUSED( value );
     if ( d->queryOrderBy.isEmpty() )
-    d->queryOrderBy = " ORDER BY name "; //TODO FIX!!
-    d->queryOrderBy += QString( " %1 " ).arg( descending ? "DESC" : "ASC" );
+    d->queryOrderBy = QStringLiteral(" ORDER BY name "); //TODO FIX!!
+    d->queryOrderBy += QStringLiteral( " %1 " ).arg( descending ? "DESC" : "ASC" );
     return this;
 }
 
@@ -518,25 +545,25 @@ ServiceSqlQueryMaker::buildQuery()
         return;
 
     linkTables();
-    QString query = "SELECT ";
+    QString query = QStringLiteral("SELECT ");
     if ( d->withoutDuplicates )
-        query += "DISTINCT ";
+        query += QLatin1String("DISTINCT ");
     query += d->queryReturnValues;
-    query += " FROM ";
+    query += QLatin1String(" FROM ");
     query += d->queryFrom;
-    query += " WHERE 1 "; // oh... to not have to bother with the leadig "AND"
+    query += QLatin1String(" WHERE 1 "); // oh... to not have to bother with the leadig "AND"
                           // that may or may not be needed
     query += d->queryMatch;
     if ( !d->queryFilter.isEmpty() )
     {
-        query += " AND ( 1 ";
+        query += QLatin1String(" AND ( 1 ");
         query += d->queryFilter;
-        query += " ) ";
+        query += QLatin1String(" ) ");
     }
     //query += d->queryFilter;
     query += d->queryOrderBy;
     if ( d->maxResultSize > -1 )
-        query += QString( " LIMIT %1 OFFSET 0 " ).arg( d->maxResultSize );
+        query += QStringLiteral( " LIMIT %1 OFFSET 0 " ).arg( d->maxResultSize );
     query += ';';
     d->query = query;
 }
@@ -565,28 +592,28 @@ ServiceSqlQueryMaker::handleResult( const QStringList &result )
     {
         switch( d->queryType ) {
         /*case Private::CUSTOM:
-            emit newResultReady( result );
+            Q_EMIT newResultReady( result );
             break;*/
-        case Private::TRACK:
+        case QueryMaker::Track:
             handleTracks( result );
             break;
-        case Private::ARTIST:
-        case Private::ALBUMARTIST:
+        case QueryMaker::Artist:
+        case QueryMaker::AlbumArtist:
             handleArtists( result );
             break;
-        case Private::ALBUM:
+        case QueryMaker::Album:
             handleAlbums( result );
             break;
-        case Private::GENRE:
+        case QueryMaker::Genre:
             handleGenres( result );
             break;
-      /*  case Private::COMPOSER:
+      /*  case QueryMaker::Composer:
             handleComposers( result );
             break;
         case Private::YEAR:
             handleYears( result );
             break;*/
-        case Private::NONE:
+        case QueryMaker::None:
             debug() << "Warning: queryResult with queryType == NONE";
 
         default:
@@ -595,34 +622,36 @@ ServiceSqlQueryMaker::handleResult( const QStringList &result )
     }
     else
     {
-        switch( d->queryType ) {
+        switch( d->queryType )
+        {
             case QueryMaker::Custom:
-                emit newResultReady( QStringList() );
+                Q_EMIT newResultReady( QStringList() );
                 break;
             case QueryMaker::Track:
-                emit newResultReady( Meta::TrackList() );
+                Q_EMIT newTracksReady( Meta::TrackList() );
                 break;
             case QueryMaker::Artist:
-                emit newResultReady( Meta::ArtistList() );
+                Q_EMIT newArtistsReady( Meta::ArtistList() );
                 break;
             case QueryMaker::Album:
-                emit newResultReady( Meta::AlbumList() );
+                Q_EMIT newAlbumsReady( Meta::AlbumList() );
                 break;
             case QueryMaker::AlbumArtist:
-                emit newResultReady( Meta::ArtistList() );
+                Q_EMIT newArtistsReady( Meta::ArtistList() );
                 break;
             case QueryMaker::Genre:
-                emit newResultReady( Meta::GenreList() );
+                Q_EMIT newGenresReady( Meta::GenreList() );
                 break;
             case QueryMaker::Composer:
-                emit newResultReady( Meta::ComposerList() );
+                Q_EMIT newComposersReady( Meta::ComposerList() );
                 break;
             case QueryMaker::Year:
-                emit newResultReady( Meta::YearList() );
+                Q_EMIT newYearsReady( Meta::YearList() );
+                break;
+            case QueryMaker::None:
+                debug() << "Warning: queryResult with queryType == NONE";
+            default:
                 break;
-
-        case QueryMaker::None:
-            debug() << "Warning: queryResult with queryType == NONE";
         }
     }
 
@@ -685,7 +714,7 @@ ServiceSqlQueryMaker::handleTracks( const QStringList &result )
         tracks.append( trackptr );
     }
 
-    emit newResultReady( tracks );
+    Q_EMIT newTracksReady( tracks );
 }
 
 void
@@ -700,7 +729,7 @@ ServiceSqlQueryMaker::handleArtists( const QStringList &result )
         QStringList row = result.mid( i*rowCount, rowCount );
         artists.append( m_registry->getArtist( row ) );
     }
-    emit newResultReady( artists );
+    Q_EMIT newArtistsReady( artists );
 }
 
 void
@@ -715,7 +744,7 @@ ServiceSqlQueryMaker::handleAlbums( const QStringList &result )
         QStringList row = result.mid( i*rowCount, rowCount );
         albums.append( m_registry->getAlbum( row ) );
     }
-    emit newResultReady( albums );
+    Q_EMIT newAlbumsReady( albums );
 }
 
 void
@@ -730,7 +759,7 @@ ServiceSqlQueryMaker::handleGenres( const QStringList &result )
         QStringList row = result.mid( i*rowCount, rowCount );
         genres.append( m_registry->getGenre( row ) );
     }
-    emit newResultReady( genres );
+    Q_EMIT newGenresReady( genres );
 }
 
 /*void
@@ -744,7 +773,7 @@ ServiceSqlQueryMaker::handleComposers( const QStringList &result )
         QString id = iter.next();
         composers.append( reg->getComposer( name, id.toInt() ) );
     }
-    emit newResultReady( composers );
+    Q_EMIT newResultReady( composers );
 }
 
 void
@@ -758,13 +787,13 @@ ServiceSqlQueryMaker::handleYears( const QStringList &result )
         QString id = iter.next();
         years.append( reg->getYear( name, id.toInt() ) );
     }
-    emit newResultReady( years );
+    Q_EMIT newResultReady( years );
 }*/
 
 QString
-ServiceSqlQueryMaker::escape( QString text ) const //krazy2:exclude=constref
+ServiceSqlQueryMaker::escape( const QString &text ) const //krazy2:exclude=constref
 {
-    SqlStorage *storage = StorageManager::instance()->sqlStorage();
+    auto storage = StorageManager::instance()->sqlStorage();
     if( storage )
         return storage->escape( text );
     else
@@ -779,9 +808,9 @@ ServiceSqlQueryMaker::likeCondition( const QString &text, bool anyBegin, bool an
         QString escaped = text;
         escaped = escape( escaped );
         //see comments in SqlQueryMaker::likeCondition
-        escaped.replace( '%', "/%" ).replace( '_', "/_" );
+        escaped.replace( '%', QLatin1String("/%") ).replace( '_', QLatin1String("/_") );
 
-        QString ret = " LIKE ";
+        QString ret = QStringLiteral(" LIKE ");
 
         ret += '\'';
         if ( anyBegin )
@@ -792,16 +821,16 @@ ServiceSqlQueryMaker::likeCondition( const QString &text, bool anyBegin, bool an
         ret += '\'';
 
         //Case insensitive collation for queries
-        ret += " COLLATE utf8_unicode_ci ";
+        ret += QLatin1String(" COLLATE utf8_unicode_ci ");
 
         //Use / as the escape character
-        ret += " ESCAPE '/' ";
+        ret += QLatin1String(" ESCAPE '/' ");
 
         return ret;
     }
     else
     {
-        return QString( " = '%1' " ).arg( escape( text ) );
+        return QStringLiteral( " = '%1' " ).arg( escape( text ) );
     }
 }
 
@@ -809,7 +838,7 @@ QueryMaker*
 ServiceSqlQueryMaker::beginAnd()
 {
     d->queryFilter += andOr();
-    d->queryFilter += " ( 1 ";
+    d->queryFilter += QLatin1String(" ( 1 ");
     d->andStack.push( true );
     return this;
 }
@@ -818,7 +847,7 @@ QueryMaker*
 ServiceSqlQueryMaker::beginOr()
 {
     d->queryFilter += andOr();
-    d->queryFilter += " ( 0 ";
+    d->queryFilter += QLatin1String(" ( 0 ");
     d->andStack.push( false );
     return this;
 }
