@@ -25,14 +25,16 @@ class AmpacheTrackForUrlWorker : public Amarok::TrackForUrlWorker
 {
     Q_OBJECT
     public:
-        AmpacheTrackForUrlWorker( const KUrl &url, MetaProxy::TrackPtr track, const QString &server, const QString &sessionId, ServiceBase* service);
-        ~AmpacheTrackForUrlWorker();
-        virtual void run ();
+        AmpacheTrackForUrlWorker( const QUrl &url, const MetaProxy::TrackPtr &track,
+                                  const QUrl &server, const QString &sessionId,
+                                  ServiceBase *service);
+        ~AmpacheTrackForUrlWorker() override;
+        void run(ThreadWeaver::JobPointer self = QSharedPointer<ThreadWeaver::Job>(), ThreadWeaver::Thread *thread = 0) override;
         void parseTrack( const QString &xml );
-    signals:
+    Q_SIGNALS:
         void authenticationNeeded();
     private:
-        MetaProxy::TrackPtr mProxy;
+        MetaProxy::TrackPtr m_proxy;
         int m_urlTrackId;
         int m_urlAlbumId;
         int m_urlArtistId;
@@ -41,10 +43,10 @@ class AmpacheTrackForUrlWorker : public Amarok::TrackForUrlWorker
         Meta::AmpacheAlbum *m_urlAlbum;
         Meta::ServiceArtist *m_urlArtist;
 
-        QString m_server;
+        QUrl m_server;
         QString m_sessionId;
 
-        ServiceBase* m_service;
+        ServiceBase *m_service;
 };
 
 namespace Collections {
@@ -59,33 +61,31 @@ class AmpacheServiceCollection : public ServiceCollection
     Q_OBJECT
 
 public:
-    AmpacheServiceCollection( ServiceBase * service, const QString &server, const QString &sessionId );
+    AmpacheServiceCollection( ServiceBase *service, const QUrl &server,
+                              const QString &sessionId );
 
-    virtual ~AmpacheServiceCollection();
+    ~AmpacheServiceCollection() override;
 
-    virtual QueryMaker* queryMaker();
+    QueryMaker *queryMaker() override;
 
-    virtual QString collectionId() const;
-    virtual QString prettyName() const;
+    QString collectionId() const override;
+    QString prettyName() const override;
 
-    virtual Meta::TrackPtr trackForUrl( const KUrl &url );
-    virtual bool possiblyContainsTrack( const KUrl &url ) const;
+    Meta::TrackPtr trackForUrl( const QUrl &url ) override;
+    bool possiblyContainsTrack( const QUrl &url ) const override;
 
-signals:
+Q_SIGNALS:
     void authenticationNeeded();
 
-public slots:
+public Q_SLOTS:
     void slotAuthenticationNeeded();
-    void slotLookupComplete( const Meta::TrackPtr& );
+    void slotLookupComplete( const Meta::TrackPtr & );
 
 private:
-    /*void parseAlbum( const QString &xml );
-    void parseArtist( const QString &xml );*/
-
-    QString m_server;
+    QUrl m_server;
     QString m_sessionId;
 
-    AmpacheTrackForUrlWorker * m_trackForUrlWorker;
+    AmpacheTrackForUrlWorker *m_trackForUrlWorker;
 };
 
 } //namespace Collections
