@@ -24,10 +24,9 @@
 #include "GpodderServiceSettings.h"
 #include "GpodderTagTreeItem.h"
 
-#include <Solid/Networking>
-
 #include <QEventLoop>
 #include <QList>
+#include <QNetworkConfigurationManager>
 #include <QTimer>
 
 static const int s_numberItemsToLoad = 100;
@@ -36,11 +35,11 @@ using namespace mygpo;
 
 GpodderServiceModel::GpodderServiceModel( ApiRequest *request, QObject *parent )
     : QAbstractItemModel( parent )
-    , m_rootItem( 0 )
-    , m_topTagsItem( 0 )
-    , m_topPodcastsItem( 0 )
-    , m_suggestedPodcastsItem( 0 )
-    , m_topTags( 0 )
+    , m_rootItem( nullptr )
+    , m_topTagsItem( nullptr )
+    , m_topPodcastsItem( nullptr )
+    , m_suggestedPodcastsItem( nullptr )
+    , m_topTags( nullptr )
     , m_apiRequest( request )
 {
     GpodderServiceConfig config;
@@ -79,7 +78,7 @@ GpodderServiceModel::index( int row, int column, const QModelIndex &parent ) con
     else
         parentItem = static_cast<GpodderTreeItem *>( parent.internalPointer() );
 
-    if( parentItem == 0 )
+    if( parentItem == nullptr )
         return QModelIndex();
 
     GpodderTreeItem *childItem = parentItem->child( row );
@@ -97,12 +96,12 @@ GpodderServiceModel::parent( const QModelIndex &index ) const
 
     GpodderTreeItem *childItem = static_cast<GpodderTreeItem *>( index.internalPointer() );
 
-    if( childItem == 0 || childItem->isRoot() )
+    if( childItem == nullptr || childItem->isRoot() )
         return QModelIndex();
 
     GpodderTreeItem *parentItem = childItem->parent();
 
-    if( parentItem == 0 )
+    if( parentItem == nullptr )
         return QModelIndex();
 
     int childIndex;
@@ -126,7 +125,7 @@ GpodderServiceModel::rowCount( const QModelIndex &parent ) const
 
     parentItem = static_cast<GpodderTreeItem *>( parent.internalPointer() );
 
-    if( parentItem == 0 )
+    if( parentItem == nullptr )
         return 0;
 
     return parentItem->childCount();
@@ -149,7 +148,7 @@ GpodderServiceModel::data( const QModelIndex &index, int role ) const
         return QVariant();
 
     GpodderTreeItem *item = static_cast<GpodderTreeItem*>( index.internalPointer() );
-    if( item == 0 )
+    if( item == nullptr )
     {
         return QVariant();
     }
@@ -160,7 +159,7 @@ GpodderServiceModel::data( const QModelIndex &index, int role ) const
 void
 GpodderServiceModel::insertTagList()
 {
-    if( m_rootItem != 0 )
+    if( m_rootItem != nullptr )
     {
         beginInsertRows( createIndex( 0,0, m_topTagsItem), 0, m_topTags->list().count() - 1 );
         m_topTagsItem->appendTags( m_topTags );
@@ -175,7 +174,7 @@ GpodderServiceModel::topTagsRequestError( QNetworkReply::NetworkError error )
 
     debug() << "Error in TopTags request: " << error;
 
-    QTimer::singleShot( 20000, this, SLOT(requestTopTags()) );
+    QTimer::singleShot( 20000, this, &GpodderServiceModel::requestTopTags );
 }
 
 void
@@ -185,7 +184,7 @@ GpodderServiceModel::topTagsParseError()
 
     debug() << "Error while parsing TopTags";
 
-    QTimer::singleShot( 20000, this, SLOT(requestTopTags()) );
+    QTimer::singleShot( 20000, this, &GpodderServiceModel::requestTopTags );
 }
 
 void
@@ -195,7 +194,7 @@ GpodderServiceModel::topPodcastsRequestError( QNetworkReply::NetworkError error
 
     debug() << "Error in TopPodcasts request: " << error;
 
-    QTimer::singleShot( 20000, this, SLOT(requestTopPodcasts()) );
+    QTimer::singleShot( 20000, this, &GpodderServiceModel::requestTopPodcasts );
 }
 
 void
@@ -205,7 +204,7 @@ GpodderServiceModel::topPodcastsParseError()
 
     debug() << "Error while parsing TopPodcasts";
 
-    QTimer::singleShot( 20000, this, SLOT(requestTopPodcasts()) );
+    QTimer::singleShot( 20000, this, &GpodderServiceModel::requestTopPodcasts );
 }
 
 void
@@ -215,7 +214,7 @@ GpodderServiceModel::suggestedPodcastsRequestError( QNetworkReply::NetworkError
 
     debug() << "Error in suggestedPodcasts request: " << error;
 
-    QTimer::singleShot( 20000, this, SLOT(requestSuggestedPodcasts()) );
+    QTimer::singleShot( 20000, this, &GpodderServiceModel::requestSuggestedPodcasts );
 }
 
 void
@@ -225,7 +224,7 @@ GpodderServiceModel::suggestedPodcastsParseError()
 
     debug() << "Error while parsing suggestedPodcasts";
 
-    QTimer::singleShot( 20000, this, SLOT(requestSuggestedPodcasts()) );
+    QTimer::singleShot( 20000, this, &GpodderServiceModel::requestSuggestedPodcasts );
 }
 
 void
@@ -237,7 +236,7 @@ GpodderServiceModel::insertPodcastList( mygpo::PodcastListPtr podcasts,
     emit layoutAboutToBeChanged();
     beginInsertRows( parentItem, 0, podcasts->list().count() - 1 );
     GpodderTreeItem *item = static_cast<GpodderTreeItem*>( parentItem.internalPointer() );
-    if( item != 0 )
+    if( item != nullptr )
     {
         debug() << "Appending Podcasts...";
         item->appendPodcasts( podcasts );
@@ -255,7 +254,7 @@ GpodderServiceModel::hasChildren( const QModelIndex &parent ) const
 
     GpodderTreeItem *treeItem = static_cast<GpodderTreeItem *>( parent.internalPointer() );
 
-    if( treeItem == 0 )
+    if( treeItem == nullptr )
         return false;
 
     if( treeItem->childCount() > 0 )
@@ -291,7 +290,7 @@ GpodderServiceModel::canFetchMore( const QModelIndex &parent ) const
 
     if( qobject_cast<GpodderTagTreeItem*>( treeItem ) )
     {
-        if( Solid::Networking::status() == Solid::Networking::Unconnected )
+        if( !QNetworkConfigurationManager().isOnline() )
             return false;
 
         return true;
@@ -307,7 +306,7 @@ GpodderServiceModel::fetchMore( const QModelIndex &parent )
     {
         requestTopTags();
         requestTopPodcasts();
-        if ( m_suggestedPodcastsItem != 0 )
+        if ( m_suggestedPodcastsItem != nullptr )
             requestSuggestedPodcasts();
     }
 
@@ -334,7 +333,7 @@ GpodderServiceModel::fetchMore( const QModelIndex &parent )
 void
 GpodderServiceModel::requestTopTags()
 {
-    if( Solid::Networking::status() == Solid::Networking::Unconnected )
+    if( !QNetworkConfigurationManager().isOnline() )
     {
         QTimer::singleShot( 10000, this, SLOT(requestTopTags()) );
         return;
@@ -352,7 +351,7 @@ GpodderServiceModel::requestTopTags()
 void
 GpodderServiceModel::requestTopPodcasts()
 {
-    if( Solid::Networking::status() == Solid::Networking::Unconnected )
+    if( !QNetworkConfigurationManager().isOnline() )
     {
         QTimer::singleShot( 10000, this, SLOT(requestTopPodcasts()) );
         return;
@@ -374,7 +373,7 @@ GpodderServiceModel::requestTopPodcasts()
 void
 GpodderServiceModel::requestSuggestedPodcasts()
 {
-    if( Solid::Networking::status() == Solid::Networking::Unconnected )
+    if( !QNetworkConfigurationManager().isOnline() )
     {
         QTimer::singleShot( 10000, this, SLOT(requestSuggestedPodcasts()) );
         return;
