@@ -22,37 +22,31 @@
 #include "core-impl/collections/support/CollectionManager.h"
 #include "core/support/Debug.h"
 #include "core/support/Components.h"
-#include "core/interfaces/Logger.h"
+#include "core/logger/Logger.h"
 #include "EngineController.h"
 #include "JamendoInfoParser.h"
 #include "ServiceSqlRegistry.h"
 #include "widgets/SearchWidget.h"
 
-#include <KAction>
-#include <KFileDialog>
-#include <KMenuBar>
-#include <KRun>
-#include <KShell>
-#include <KStandardDirs>
-#include <KTemporaryFile>
-#include <threadweaver/ThreadWeaver.h>
-
+#include <QAction>
 #include <QDesktopServices>
+#include <QHBoxLayout>
+#include <QMenuBar>
+#include <QStandardPaths>
+#include <QTemporaryFile>
 #include <QToolBar>
 #include <QToolButton>
 
-#include <typeinfo>
+#include <KPluginFactory>
+#include <KShell>
+#include <ThreadWeaver/ThreadWeaver>
 
 using namespace Meta;
 
-AMAROK_EXPORT_SERVICE_PLUGIN( jamendo, JamendoServiceFactory )
 
-JamendoServiceFactory::JamendoServiceFactory( QObject *parent, const QVariantList &args )
-    : ServiceFactory( parent, args )
+JamendoServiceFactory::JamendoServiceFactory()
+    : ServiceFactory()
 {
-    KPluginInfo pluginInfo(  "amarok_service_jamendo.desktop", "services" );
-    pluginInfo.setConfig( config() );
-    m_info = pluginInfo;
 }
 
 void JamendoServiceFactory::init()
@@ -79,12 +73,12 @@ JamendoService::JamendoService( JamendoServiceFactory* parent, const QString & n
     , m_currentAlbum( 0 )
     , m_xmlParser( 0 )
 {
-    setShortDescription(  i18n( "A archive of free, Creative Commons licensed music" ) );
-    setIcon( KIcon( "view-services-jamendo-amarok" ) );
+    setShortDescription(  i18n( "An archive of free, Creative Commons licensed music" ) );
+    setIcon( QIcon::fromTheme( "view-services-jamendo-amarok" ) );
 
     setLongDescription( i18n( "Jamendo.com puts artists and music lovers in touch with each other. The site allows artists to upload their own albums to share them with the world and users to download all of them for free. Listen to and download all Jamendo.com contents from within Amarok." ) );
 
-setImagePath( KStandardDirs::locate( "data", "amarok/images/hover_info_jamendo.png" ) );
+    setImagePath( QStandardPaths::locate( QStandardPaths::GenericDataLocation, "amarok/images/hover_info_jamendo.png" ) );
 
     ServiceMetaFactory * metaFactory = new JamendoMetaFactory( "jamendo", this );
     ServiceSqlRegistry * registry = new ServiceSqlRegistry( metaFactory );
@@ -119,24 +113,23 @@ JamendoService::polish()
     if ( m_polished )
         return;
 
-    KHBox * bottomPanelLayout = new KHBox;
-    bottomPanelLayout->setParent( m_bottomPanel );
+    BoxWidget *bottomPanelLayout = new BoxWidget( false, m_bottomPanel );
 
     m_updateListButton = new QPushButton;
     m_updateListButton->setParent( bottomPanelLayout );
     m_updateListButton->setText( i18nc( "Fetch new information from the website", "Update" ) );
     m_updateListButton->setObjectName( "updateButton" );
-    m_updateListButton->setIcon( KIcon( "view-refresh-amarok" ) );
+    m_updateListButton->setIcon( QIcon::fromTheme( "view-refresh-amarok" ) );
 
     m_downloadButton = new QPushButton;
     m_downloadButton->setParent( bottomPanelLayout );
     m_downloadButton->setText( i18n( "Download" ) );
     m_downloadButton->setObjectName( "downloadButton" );
-    m_downloadButton->setIcon( KIcon( "download-amarok" ) );
+    m_downloadButton->setIcon( QIcon::fromTheme( "download-amarok" ) );
     m_downloadButton->setEnabled( false );
 
-    connect( m_updateListButton, SIGNAL(clicked()), this, SLOT(updateButtonClicked()) );
-    connect( m_downloadButton, SIGNAL(clicked()), this, SLOT(download()) );
+    connect( m_updateListButton, &QPushButton::clicked, this, &JamendoService::updateButtonClicked );
+    connect( m_downloadButton, &QPushButton::clicked, this, &JamendoService::download );
 
     setInfoParser( new JamendoInfoParser() );
 
@@ -145,7 +138,8 @@ JamendoService::polish()
 
     setModel( new SingleCollectionTreeItemModel( m_collection, levels ) );
 
-    connect( m_contentView, SIGNAL(itemSelected(CollectionTreeItem*)), this, SLOT(itemSelected(CollectionTreeItem*)) );
+    connect( static_cast<ServiceCollectionTreeView*>( m_contentView ), &ServiceCollectionTreeView::itemSelected,
+             this, &JamendoService::itemSelected );
 
     QMenu *filterMenu = new QMenu( 0 );
 
@@ -159,12 +153,12 @@ JamendoService::polish()
 //     connect( action, SIGNAL(triggered(bool)), SLOT(sortByAlbum()) );
 
     QAction *action = filterMenu->addAction( i18n( "Genre / Artist" ) );
-    connect( action, SIGNAL(triggered(bool)), SLOT(sortByGenreArtist()) );
+    connect( action, &QAction::triggered, this, &JamendoService::sortByGenreArtist );
 
     action = filterMenu->addAction( i18n( "Genre / Artist / Album" ) );
-    connect( action, SIGNAL(triggered(bool)), SLOT(sortByGenreArtistAlbum()) );
+    connect( action, &QAction::triggered, this, &JamendoService::sortByGenreArtistAlbum );
 
-    KAction *filterMenuAction = new KAction( KIcon( "preferences-other" ), i18n( "Sort Options" ), this );
+    QAction *filterMenuAction = new QAction( QIcon::fromTheme( "preferences-other" ), i18n( "Sort Options" ), this );
     filterMenuAction->setMenu( filterMenu );
 
     m_searchWidget->toolBar()->addSeparator();
@@ -186,20 +180,20 @@ JamendoService::updateButtonClicked()
 
     debug() << "JamendoService: start downloading xml file";
 
-    KTemporaryFile tempFile;
-    tempFile.setSuffix( ".gz" );
+    QTemporaryFile tempFile;
+//     tempFile.setSuffix( ".gz" );
     tempFile.setAutoRemove( false );  //file will be removed in JamendoXmlParser
     if( !tempFile.open() )
         return; //error
     m_tempFileName = tempFile.fileName();
     m_listDownloadJob = KIO::file_copy(
-                /* Deprecated */ KUrl( "http://imgjam.com/data/dbdump_artistalbumtrack.xml.gz" ),
-                KUrl( m_tempFileName ), 0700 , KIO::HideProgressInfo | KIO::Overwrite );
+                /* Deprecated */ QUrl("http://imgjam.com/data/dbdump_artistalbumtrack.xml.gz"),
+                QUrl::fromLocalFile( m_tempFileName ), 0700 , KIO::HideProgressInfo | KIO::Overwrite );
 
-    Amarok::Components::logger()->newProgressOperation( m_listDownloadJob, i18n( "Downloading Jamendo.com database..." ), this, SLOT(listDownloadCancelled()) );
+    Amarok::Logger::newProgressOperation( m_listDownloadJob, i18n( "Downloading Jamendo.com database..." ), this, SLOT(listDownloadCancelled()) );
 
-    connect( m_listDownloadJob, SIGNAL(result(KJob*)),
-            this, SLOT(listDownloadComplete(KJob*)) );
+    connect( m_listDownloadJob, &KJob::result,
+            this, &JamendoService::listDownloadComplete );
 }
 
 void
@@ -218,14 +212,14 @@ JamendoService::listDownloadComplete(KJob * downloadJob)
         return;
     }
 
-    Amarok::Components::logger()->shortMessage( i18n( "Updating the local Jamendo database."  ) );
+    Amarok::Logger::shortMessage( i18n( "Updating the local Jamendo database."  ) );
     debug() << "JamendoService: create xml parser";
 
     if( m_xmlParser == 0 )
         m_xmlParser = new JamendoXmlParser( m_tempFileName );
-    connect( m_xmlParser, SIGNAL(doneParsing()), SLOT(doneParsing()) );
+    connect( m_xmlParser, &JamendoXmlParser::doneParsing, this, &JamendoService::doneParsing );
 
-    ThreadWeaver::Weaver::instance()->enqueue( m_xmlParser );
+    ThreadWeaver::Queue::instance()->enqueue( QSharedPointer<ThreadWeaver::Job>(m_xmlParser) );
     downloadJob->deleteLater();
 }
 
@@ -292,7 +286,3 @@ JamendoService::download() // SLOT
     CollectionTreeView *treeView = static_cast<CollectionTreeView*>( view() );
     treeView->copySelectedToLocalCollection();
 }
-
-
-#include "JamendoService.moc"
-
