@@ -34,39 +34,29 @@
 #include "ScrobblerAdapter.h"
 #include "GlobalCurrentTrackActions.h"
 #include "core/support/Components.h"
-#include "core/interfaces/Logger.h"
+#include "core/logger/Logger.h"
 #include "meta/LastFmMeta.h"
 #include "SynchronizationAdapter.h"
 #include "statsyncing/Controller.h"
 #include "widgets/SearchWidget.h"
 
-#include <KLineEdit>
-#include <KStandardDirs>
+#include <QLineEdit>
+#include <KPluginFactory>
 
 #include <QCryptographicHash>
 #include <QGroupBox>
 #include <QHBoxLayout>
 #include <QLabel>
-#include <QTextDocument>        //Qt::escape
+#include <QPixmap>
+#include <QStandardPaths>
 #include <QTimer>
 
 #include <XmlQuery.h>
 
-AMAROK_EXPORT_SERVICE_PLUGIN( lastfm, LastFmServiceFactory )
 
-QString md5( const QByteArray& src )
-{
-    QByteArray const digest = QCryptographicHash::hash( src, QCryptographicHash::Md5 );
-    return QString::fromLatin1( digest.toHex() ).rightJustified( 32, '0' );
-}
-
-LastFmServiceFactory::LastFmServiceFactory( QObject *parent, const QVariantList &args )
-    : ServiceFactory( parent, args )
-{
-    KPluginInfo pluginInfo(  "amarok_service_lastfm.desktop", "services" );
-    pluginInfo.setConfig( config() );
-    m_info = pluginInfo;
-}
+LastFmServiceFactory::LastFmServiceFactory()
+    : ServiceFactory()
+{}
 
 void
 LastFmServiceFactory::init()
@@ -89,9 +79,9 @@ LastFmServiceFactory::config()
 }
 
 bool
-LastFmServiceFactory::possiblyContainsTrack( const KUrl &url ) const
+LastFmServiceFactory::possiblyContainsTrack( const QUrl &url ) const
 {
-    return url.protocol() == "lastfm";
+    return url.scheme() == "lastfm";
 }
 
 
@@ -108,9 +98,9 @@ LastFmService::LastFmService( LastFmServiceFactory *parent, const QString &name
 {
     DEBUG_BLOCK
     setShortDescription( i18n( "Last.fm: The social music revolution" ) );
-    setIcon( KIcon( "view-services-lastfm-amarok" ) );
-    setLongDescription( i18n( "Last.fm is a popular online service that provides personal radio stations and music recommendations. A personal listening station is tailored based on your listening habits and provides you with recommendations for new music. It is also possible to play stations with music that is similar to a particular artist as well as listen to streams from people you have added as friends or that Last.fm considers your musical \"neighbors\"" ) );
-    setImagePath( KStandardDirs::locate( "data", "amarok/images/hover_info_lastfm.png" ) );
+    setIcon( QIcon::fromTheme( "view-services-lastfm-amarok" ) );
+    setLongDescription( i18n( "Last.fm is a popular online service that provides personal radio stations and music recommendations. A personal listening station is tailored based on your listening habits and provides you with recommendations for new music. It is also possible to play stations with music that is similar to a particular artist as well as listen to streams from people you have added as friends" ) );
+    setImagePath( QStandardPaths::locate( QStandardPaths::GenericDataLocation, "amarok/images/hover_info_lastfm.png" ) );
 
     //We have no use for searching currently..
     m_searchWidget->setVisible( false );
@@ -119,6 +109,9 @@ LastFmService::LastFmService( LastFmServiceFactory *parent, const QString &name
     lastfm::ws::ApiKey = Amarok::lastfmApiKey();
     lastfm::ws::SharedSecret = Amarok::lastfmApiSharedSecret();
 
+    // HTTPS is the only scheme supported by Auth
+    lastfm::ws::setScheme(lastfm::ws::Https);
+
     // set the nam TWICE. Yes. It prevents liblastfm from deleting it, see their code
     lastfm::setNetworkAccessManager( The::networkAccessManager() );
     lastfm::setNetworkAccessManager( The::networkAccessManager() );
@@ -133,13 +126,13 @@ LastFmService::LastFmService( LastFmServiceFactory *parent, const QString &name
     The::globalCollectionActions()->addArtistAction( new SimilarArtistsAction( this ) );
     The::globalCollectionActions()->addTrackAction( new LoveTrackAction( this ) );
 
-    QAction *loveAction = new QAction( KIcon( "love-amarok" ), i18n( "Last.fm: Love" ), this );
-    connect( loveAction, SIGNAL(triggered()), this, SLOT(love()) );
+    QAction *loveAction = new QAction( QIcon::fromTheme( "love-amarok" ), i18n( "Last.fm: Love" ), this );
+    connect( loveAction, &QAction::triggered, this, &LastFmService::loveCurrentTrack );
     loveAction->setShortcut( i18n( "Ctrl+L" ) );
     The::globalCurrentTrackActions()->addAction( loveAction );
 
-    connect( m_config.data(), SIGNAL(updated()), this, SLOT(slotReconfigure()) );
-    QTimer::singleShot(0, this, SLOT(slotReconfigure())); // call reconfigure but only after constructor is finished (because it might call virtual methods)
+    connect( m_config.data(), &LastFmServiceConfig::updated, this, &LastFmService::slotReconfigure );
+    QTimer::singleShot(0, this, &LastFmService::slotReconfigure); // call reconfigure but only after constructor is finished (because it might call virtual methods)
 }
 
 LastFmService::~LastFmService()
@@ -165,7 +158,7 @@ LastFmService::~LastFmService()
 
     StatSyncing::Controller *controller = Amarok::Components::statSyncingController();
     if( m_scrobbler && controller )
-        controller->unregisterScrobblingService( StatSyncing::ScrobblingServicePtr( m_scrobbler.data() ) );
+        controller->unregisterScrobblingService( m_scrobbler.staticCast<StatSyncing::ScrobblingService>() );
     if( m_synchronizationAdapter && controller )
         controller->unregisterProvider( m_synchronizationAdapter );
 }
@@ -205,20 +198,18 @@ LastFmService::slotReconfigure()
         // discard any possible ongoing auth connections
         if( m_authenticateReply )
         {
-            disconnect( m_authenticateReply, SIGNAL(finished()), this, SLOT(onAuthenticated()) );
+            disconnect( m_authenticateReply, &QNetworkReply::finished, this, &LastFmService::onAuthenticated );
             m_authenticateReply->abort();
             m_authenticateReply->deleteLater();
             m_authenticateReply = 0;
         }
 
-        const QString authToken = md5( QString( "%1%2" ).arg( m_config->username(),
-                md5( m_config->password().toUtf8() ) ).toUtf8() );
         QMap<QString, QString> query;
         query[ "method" ] = "auth.getMobileSession";
+        query[ "password" ] = m_config->password();
         query[ "username" ] = m_config->username();
-        query[ "authToken" ] = authToken;
         m_authenticateReply = lastfm::ws::post( query );
-        connect( m_authenticateReply, SIGNAL(finished()), this, SLOT(onAuthenticated()) ); // calls continueReconfiguring()
+        connect( m_authenticateReply, &QNetworkReply::finished, this, &LastFmService::onAuthenticated ); // calls continueReconfiguring()
     }
     else
     {
@@ -239,33 +230,33 @@ LastFmService::continueReconfiguring()
 
     if( m_scrobbler && (!authenticated || !m_config->scrobble()) )
     {
-        debug() << __PRETTY_FUNCTION__ << "unregistering and destorying ScrobblerAdapter";
-        controller->unregisterScrobblingService( StatSyncing::ScrobblingServicePtr( m_scrobbler.data() ) );
-        m_scrobbler = 0;
+        debug() << __PRETTY_FUNCTION__ << "unregistering and destroying ScrobblerAdapter";
+        controller->unregisterScrobblingService( m_scrobbler.staticCast<StatSyncing::ScrobblingService>() );
+        m_scrobbler.clear();
     }
     else if( !m_scrobbler && authenticated && m_config->scrobble() )
     {
         debug() << __PRETTY_FUNCTION__ << "creating and registering ScrobblerAdapter";
-        m_scrobbler = new ScrobblerAdapter( "Amarok", m_config );
-        controller->registerScrobblingService( StatSyncing::ScrobblingServicePtr( m_scrobbler.data() ) );
+        m_scrobbler = QSharedPointer<ScrobblerAdapter>( new ScrobblerAdapter( "Amarok", m_config ) );
+        controller->registerScrobblingService( m_scrobbler.staticCast<StatSyncing::ScrobblingService>() );
     }
 
     if( m_synchronizationAdapter && !authenticated )
     {
-        debug() << __PRETTY_FUNCTION__ << "unregistering and destorying SynchronizationAdapter";
+        debug() << __PRETTY_FUNCTION__ << "unregistering and destroying SynchronizationAdapter";
         controller->unregisterProvider( m_synchronizationAdapter );
         m_synchronizationAdapter = 0;
     }
     else if( !m_synchronizationAdapter && authenticated )
     {
         debug() << __PRETTY_FUNCTION__ << "creating and registering SynchronizationAdapter";
-        m_synchronizationAdapter = new SynchronizationAdapter( m_config );
+        m_synchronizationAdapter = StatSyncing::ProviderPtr( new SynchronizationAdapter( m_config ) );
         controller->registerProvider( m_synchronizationAdapter );
     }
 
     // update possibly changed user info
     QNetworkReply *reply = lastfm::User::getInfo();
-    connect( reply, SIGNAL(finished()), SLOT(onGetUserInfo()) );
+    connect( reply, &QNetworkReply::finished, this, &LastFmService::onGetUserInfo );
 }
 
 void
@@ -278,7 +269,7 @@ LastFmService::onAuthenticated()
 
     /* temporarily disconnect form config updates to prevent calling
      * slotReconfigure() for the second time. */
-    disconnect( m_config.data(), SIGNAL(updated()), this, SLOT(slotReconfigure()) );
+    disconnect( m_config.data(), &LastFmServiceConfig::updated, this, &LastFmService::slotReconfigure );
 
     switch( m_authenticateReply ? m_authenticateReply->error() : QNetworkReply::UnknownNetworkError )
     {
@@ -298,19 +289,19 @@ LastFmService::onAuthenticated()
             break;
         }
         case QNetworkReply::AuthenticationRequiredError:
-            Amarok::Components::logger()->longMessage( i18nc("Last.fm: errorMessage",
+            Amarok::Logger::longMessage( i18nc("Last.fm: errorMessage",
                     "Either the username was not recognized, or the password was incorrect." ) );
             break;
 
         default:
-            Amarok::Components::logger()->longMessage( i18nc("Last.fm: errorMessage",
+            Amarok::Logger::longMessage( i18nc("Last.fm: errorMessage",
                     "There was a problem communicating with the Last.fm services. Please try again later." ) );
             break;
     }
     m_authenticateReply = 0;
 
     // connect back to config updates
-    connect( m_config.data(), SIGNAL(updated()), this, SLOT(slotReconfigure()) );
+    connect( m_config.data(), &LastFmServiceConfig::updated, this, &LastFmService::slotReconfigure );
     continueReconfiguring();
 }
 
@@ -340,10 +331,10 @@ LastFmService::onGetUserInfo()
                 {
                     debug() << "profile avatar: " <<lfm["user"][ "image" ].text();
                     AvatarDownloader* downloader = new AvatarDownloader();
-                    KUrl url( lfm["user"][ "image" ].text() );
+                    QUrl url( lfm["user"][ "image" ].text() );
                     downloader->downloadAvatar( m_config->username(),  url);
-                    connect( downloader, SIGNAL(avatarDownloaded(QString,QPixmap)),
-                                         SLOT(onAvatarDownloaded(QString,QPixmap)) );
+                    connect( downloader, &AvatarDownloader::avatarDownloaded,
+                             this, &LastFmService::onAvatarDownloaded );
                 }
                 updateProfileInfo();
             }
@@ -400,7 +391,7 @@ LastFmService::updateEditHint( int index )
         default:
             return;
     }
-    m_customStationEdit->setClickMessage( hint );
+    m_customStationEdit->setPlaceholderText( hint );
 }
 
 void
@@ -408,7 +399,7 @@ LastFmService::updateProfileInfo()
 {
     if( m_userinfo )
     {
-        m_userinfo->setText( i18n( "Username: %1", Qt::escape( m_config->username() ) ) );
+        m_userinfo->setText( i18n( "Username: %1", m_config->username().toHtmlEscaped() ) );
     }
 
     if( m_profile && !m_playcount.isEmpty() )
@@ -433,15 +424,14 @@ LastFmService::polish()
         m_bottomPanel->hide();
 
         m_topPanel->setMaximumHeight( 300 );
-        KHBox * outerProfilebox = new KHBox( m_topPanel );
-        outerProfilebox->setSpacing(1);
-        outerProfilebox->setMargin(0);
+        BoxWidget * outerProfilebox = new BoxWidget( false, m_topPanel );
+        outerProfilebox->layout()->setSpacing(1);
 
         m_avatarLabel = new QLabel(outerProfilebox);
         if( !m_avatar )
         {
             int m = LastFmTreeModel::avatarSize();
-            m_avatarLabel->setPixmap( KIcon( "filename-artist-amarok" ).pixmap(m, m) );
+            m_avatarLabel->setPixmap( QIcon::fromTheme( "filename-artist-amarok" ).pixmap(m, m) );
             m_avatarLabel->setFixedSize( m, m );
         }
         else
@@ -451,8 +441,7 @@ LastFmService::polish()
             m_avatarLabel->setMargin( 5 );
         }
 
-        KVBox * innerProfilebox = new KVBox( outerProfilebox );
-        innerProfilebox->setSpacing(0);
+        BoxWidget * innerProfilebox = new BoxWidget( true, outerProfilebox );
         innerProfilebox->setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum );
         m_userinfo = new QLabel(innerProfilebox);
         m_userinfo->setText( m_config->username() );
@@ -466,21 +455,22 @@ LastFmService::polish()
         QStringList choices;
         choices << i18n( "Artist" ) << i18n( "Tag" ) << i18n( "User" );
         m_customStationCombo->insertItems(0, choices);
-        m_customStationEdit = new KLineEdit;
-        m_customStationEdit->setClearButtonShown( true );
+        m_customStationEdit = new QLineEdit;
+        m_customStationEdit->setClearButtonEnabled( true );
         updateEditHint( m_customStationCombo->currentIndex() );
         m_customStationButton = new QPushButton;
         m_customStationButton->setObjectName( "customButton" );
-        m_customStationButton->setIcon( KIcon( "media-playback-start-amarok" ) );
+        m_customStationButton->setIcon( QIcon::fromTheme( "media-playback-start-amarok" ) );
         QHBoxLayout *hbox = new QHBoxLayout();
         hbox->addWidget(m_customStationCombo);
         hbox->addWidget(m_customStationEdit);
         hbox->addWidget(m_customStationButton);
         customStation->setLayout(hbox);
 
-        connect( m_customStationEdit, SIGNAL(returnPressed()), this, SLOT(playCustomStation()) );
-        connect( m_customStationButton, SIGNAL(clicked()), this, SLOT(playCustomStation()) );
-        connect( m_customStationCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(updateEditHint(int)));
+        connect( m_customStationEdit, &QLineEdit::returnPressed, this, &LastFmService::playCustomStation );
+        connect( m_customStationButton, &QPushButton::clicked, this, &LastFmService::playCustomStation );
+        connect( m_customStationCombo, QOverload<int>::of(&QComboBox::currentIndexChanged),
+                 this, &LastFmService::updateEditHint);
 
         QList<int> levels;
         levels << CategoryId::Genre << CategoryId::Album;
@@ -489,7 +479,7 @@ LastFmService::polish()
 }
 
 void
-LastFmService::love()
+LastFmService::loveCurrentTrack()
 {
     love( The::engineController()->currentTrack() );
 }
@@ -522,11 +512,11 @@ void LastFmService::playCustomStation()
     }
 
     if ( !station.isEmpty() ) {
-        playLastFmStation( station );
+        playLastFmStation( QUrl( station ) );
     }
 }
 
-void LastFmService::playLastFmStation( const KUrl &url )
+void LastFmService::playLastFmStation( const QUrl &url )
 {
     Meta::TrackPtr track = CollectionManager::instance()->trackForUrl( url );
     The::playlistController()->insertOptioned( track, Playlist::OnPlayMediaAction );
