@@ -25,7 +25,7 @@
 #include "core-impl/collections/support/CollectionManager.h"
 #include "AmarokMimeData.h"
 
-#include <KIcon>
+#include <QIcon>
 
 #include <QPainter>
 
@@ -41,17 +41,15 @@ LastFmTreeModel::LastFmTreeModel( QObject *parent )
     setupModelData( m_rootItem );
 
     QNetworkReply *reply;
-    reply = m_user.getNeighbours();
-    connect(reply, SIGNAL(finished()), this, SLOT(slotAddNeighbors()) );
 
     reply = m_user.getFriends();
-    connect( reply, SIGNAL(finished()), this, SLOT(slotAddFriends()) );
+    connect( reply, &QNetworkReply::finished, this, &LastFmTreeModel::slotAddFriends );
 
     reply = m_user.getTopTags();
-    connect( reply, SIGNAL(finished()), this, SLOT(slotAddTags()) );
+    connect( reply, &QNetworkReply::finished, this, &LastFmTreeModel::slotAddTags );
 
     reply = m_user.getTopArtists();
-    connect( reply, SIGNAL(finished()), this, SLOT(slotAddTopArtists()) );
+    connect( reply, &QNetworkReply::finished, this, &LastFmTreeModel::slotAddTopArtists );
 }
 
 LastFmTreeModel::~LastFmTreeModel()
@@ -59,49 +57,6 @@ LastFmTreeModel::~LastFmTreeModel()
     delete m_rootItem;
 }
 
-void
-LastFmTreeModel::slotAddNeighbors()
-{
-    QNetworkReply *reply = qobject_cast<QNetworkReply *>( sender() );
-    if( !reply )
-    {
-        debug() << __PRETTY_FUNCTION__ << "null reply!";
-        return;
-    }
-    reply->deleteLater();
-
-    lastfm::XmlQuery lfm;
-    if( lfm.parse( reply->readAll() ) )
-    {
-        QList<lastfm::XmlQuery> children = lfm[ "neighbours" ].children( "user" );
-        int start = m_myNeighbors->childCount();
-        QModelIndex parent = index( m_myNeighbors->row(), 0 );
-        beginInsertRows( parent, start, start + children.size() );
-
-        foreach( const lastfm::XmlQuery &e, children  )
-        {
-            const QString name = e[ "name" ].text();
-
-            LastFmTreeItem* neighbor = new LastFmTreeItem( mapTypeToUrl(LastFm::NeighborsChild, name),
-                                                           LastFm::NeighborsChild, name, m_myNeighbors );
-            KUrl avatarUrl( e[ QLatin1String("image size=small") ].text() );
-            if( !avatarUrl.isEmpty() )
-                neighbor->setAvatarUrl( avatarUrl );
-
-            m_myNeighbors->appendChild( neighbor );
-            appendUserStations( neighbor, name );
-        }
-
-        endInsertRows();
-        emit dataChanged( parent, parent );
-    }
-    else
-    {
-        debug() << "Got exception in parsing from last.fm:" << lfm.parseError().message();
-        return;
-    }
-}
-
 void
 LastFmTreeModel::slotAddFriends()
 {
@@ -128,7 +83,7 @@ LastFmTreeModel::slotAddFriends()
             LastFmTreeItem* afriend = new LastFmTreeItem( mapTypeToUrl(LastFm::FriendsChild, name),
                                                           LastFm::FriendsChild, name, m_myFriends );
 
-            KUrl avatarUrl( e[ QLatin1String("image size=small") ].text() );
+            QUrl avatarUrl( e[ QLatin1String("image size=small") ].text() );
             if( !avatarUrl.isEmpty() )
                 afriend->setAvatarUrl( avatarUrl );
 
@@ -239,10 +194,7 @@ LastFmTreeModel::appendUserStations( LastFmTreeItem* item, const QString &user )
     // beginInsertRows().
     LastFmTreeItem* personal = new LastFmTreeItem( mapTypeToUrl( LastFm::UserChildPersonal, user ),
                                                    LastFm::UserChildPersonal, i18n( "Personal Radio" ), item );
-    LastFmTreeItem* neigh = new LastFmTreeItem( mapTypeToUrl( LastFm::UserChildNeighborhood, user ),
-                                                LastFm::UserChildNeighborhood, i18n( "Neighborhood" ), item );
     item->appendChild( personal );
-    item->appendChild( neigh );
 }
 
 void
@@ -288,7 +240,7 @@ LastFmTreeModel::onAvatarDownloaded( const QString &username, QPixmap avatar )
 
     // these 2 categories have a chance to be updated:
     QList<LastFmTreeItem *> categories;
-    categories << m_myFriends << m_myNeighbors;
+    categories << m_myFriends;
 
     // now go through all children of the categories and notify view as appropriate
     foreach( LastFmTreeItem *category, categories )
@@ -311,9 +263,9 @@ LastFmTreeModel::onAvatarDownloaded( const QString &username, QPixmap avatar )
 }
 
 QIcon
-LastFmTreeModel::avatar( const QString &username, const KUrl &avatarUrl ) const
+LastFmTreeModel::avatar( const QString &username, const QUrl &avatarUrl ) const
 {
-    KIcon defaultIcon( "filename-artist-amarok" );
+    QIcon defaultIcon( "filename-artist-amarok" );
     if( username.isEmpty() )
         return defaultIcon;
     if( m_avatars.contains(username) )
@@ -325,8 +277,8 @@ LastFmTreeModel::avatar( const QString &username, const KUrl &avatarUrl ) const
     const_cast<LastFmTreeModel *>( this )->m_avatars.insert( username, defaultIcon );
     AvatarDownloader* downloader = new AvatarDownloader();
     downloader->downloadAvatar( username, avatarUrl );
-    connect( downloader, SIGNAL(avatarDownloaded(QString,QPixmap)),
-                         SLOT(onAvatarDownloaded(QString,QPixmap)) );
+    connect( downloader, &AvatarDownloader::avatarDownloaded,
+             this, &LastFmTreeModel::onAvatarDownloaded );
     return defaultIcon;
 }
 
@@ -359,30 +311,15 @@ LastFmTreeModel::data( const QModelIndex &index, int role ) const
             return i18n( "My Radio Station" );
         case MixRadio:
             return i18n( "My Mix Radio" );
-        case NeighborhoodRadio:
-            return i18n( "My Neighborhood" );
-            //             case RecentlyPlayed:      return tr("Recently Played");
-            //             case RecentlyLoved:       return tr("Recently Loved");
-            //             case RecentlyBanned:      return tr("Recently Banned");
         case TopArtists:
             return i18n( "My Top Artists" );
         case MyTags:
             return i18n( "My Tags" );
         case Friends:
             return i18n( "Friends" );
-        case Neighbors:
-            return i18n( "Neighbors" );
-            //             case History:             return tr("History");
-
-            //             case RecentlyPlayedTrack: return m_played.value( index.row() );
-            //             case RecentlyLovedTrack:  return m_loved.value( index.row() );
-            //             case RecentlyBannedTrack: return m_banned.value( index.row() );
-//             case MyTagsChild:         return m_tags.value( index.row() );
         case FriendsChild:
         case ArtistsChild:
-        case NeighborsChild:
         case UserChildPersonal:
-        case UserChildNeighborhood:
         case MyTagsChild:
             return i->data();
         default:
@@ -390,69 +327,59 @@ LastFmTreeModel::data( const QModelIndex &index, int role ) const
         }
 
     if( role == Qt::DecorationRole )
+    {
         switch( i->type() )
         {
         case MyRecommendations:
-            return KIcon( "lastfm-recommended-radio-amarok" );
+            return QIcon::fromTheme( "lastfm-recommended-radio-amarok" );
         case TopArtists:
         case PersonalRadio:
-            return KIcon( "lastfm-personal-radio-amarok" );
+            return QIcon::fromTheme( "lastfm-personal-radio-amarok" );
         case MixRadio:
-            return KIcon( "lastfm-mix-radio-amarok" );
-        case NeighborhoodRadio:
-            return KIcon( "lastfm-neighbour-radio-amarok" );
-            //             case RecentlyPlayed:      return KIcon( "lastfm-recent-tracks-amarok" );
-            //             case RecentlyLoved:       return KIcon( "lastfm-recently-loved-amarok" );
-            //             case RecentlyBanned:      return KIcon( "lastfm-recently-banned-amarok" );
+            return QIcon::fromTheme( "lastfm-mix-radio-amarok" );
         case MyTags:
-            return KIcon( "lastfm-my-tags-amarok" );
+            return QIcon::fromTheme( "lastfm-my-tags-amarok" );
         case Friends:
-            return KIcon( "lastfm-my-friends-amarok" );
-        case Neighbors:
-            return KIcon( "lastfm-my-neighbours-amarok" );
+            return QIcon::fromTheme( "lastfm-my-friends-amarok" );
 
-        case RecentlyPlayedTrack: //FALL THROUGH
-        case RecentlyLovedTrack:  //FALL THROUGH
+        case RecentlyPlayedTrack:
+            Q_FALLTHROUGH();
+        case RecentlyLovedTrack:
+            Q_FALLTHROUGH();
         case RecentlyBannedTrack:
-            return KIcon( "icon_track" );
+            return QIcon::fromTheme( "icon_track" );
         case MyTagsChild:
-            return KIcon( "lastfm-tag-amarok" );
+            return QIcon::fromTheme( "lastfm-tag-amarok" );
 
         case FriendsChild:
             return avatar( i->data().toString(), i->avatarUrl() );
         case UserChildPersonal:
-            return KIcon( "lastfm-personal-radio-amarok" );
-        case UserChildNeighborhood:
-            return KIcon( "lastfm-neighbour-radio-amarok" );
-
-        case NeighborsChild:
-            return avatar( i->data().toString(), i->avatarUrl() );
+            return QIcon::fromTheme( "lastfm-personal-radio-amarok" );
 
         case HistoryStation:
-            return KIcon( "icon_radio" );
+            return QIcon::fromTheme( "icon_radio" );
 
         default:
             break;
         }
+    }
 
     if( role == LastFm::TrackRole )
+    {
         switch( i->type() )
         {
-        case LastFm::MyRecommendations:
-        case LastFm::PersonalRadio:
-        case LastFm::MixRadio:
-        case LastFm::NeighborhoodRadio:
-        case LastFm::FriendsChild:
-        case LastFm::NeighborsChild:
-        case LastFm::MyTagsChild:
-        case LastFm::ArtistsChild:
-        case LastFm::UserChildPersonal:
-        case LastFm::UserChildNeighborhood:
-            return QVariant::fromValue( i->track() );
-        default:
-            break;
+            case LastFm::MyRecommendations:
+            case LastFm::PersonalRadio:
+            case LastFm::MixRadio:
+            case LastFm::FriendsChild:
+            case LastFm::MyTagsChild:
+            case LastFm::ArtistsChild:
+            case LastFm::UserChildPersonal:
+                return QVariant::fromValue( i->track() );
+            default:
+                break;
         }
-
+    }
     if( role == LastFm::TypeRole )
         return i->type();
 
@@ -472,17 +399,14 @@ LastFmTreeModel::flags( const QModelIndex &index ) const
     case MyRecommendations:
     case PersonalRadio:
     case MixRadio:
-    case NeighborhoodRadio:
     case RecentlyPlayedTrack:
     case RecentlyLovedTrack:
     case RecentlyBannedTrack:
     case MyTagsChild:
     case FriendsChild:
     case ArtistsChild:
-    case NeighborsChild:
     case HistoryStation:
     case UserChildPersonal:
-    case UserChildNeighborhood:
         flags |= Qt::ItemIsSelectable;
         break;
 
@@ -493,13 +417,11 @@ LastFmTreeModel::flags( const QModelIndex &index ) const
     switch( i->type() )
     {
     case UserChildPersonal:
-    case UserChildNeighborhood:
     case MyTagsChild:
     case ArtistsChild:
     case MyRecommendations:
     case PersonalRadio:
     case MixRadio:
-    case NeighborhoodRadio:
         flags |= Qt::ItemIsDragEnabled;
 
     default:
@@ -567,7 +489,6 @@ LastFmTreeModel::setupModelData( LastFmTreeItem *parent )
     parent->appendChild( new LastFmTreeItem( mapTypeToUrl( LastFm::MyRecommendations ), LastFm::MyRecommendations, parent ) );
     parent->appendChild( new LastFmTreeItem( mapTypeToUrl( LastFm::PersonalRadio ), LastFm::PersonalRadio, parent ) );
     parent->appendChild( new LastFmTreeItem( mapTypeToUrl( LastFm::MixRadio ), LastFm::MixRadio, parent ) );
-    parent->appendChild( new LastFmTreeItem( mapTypeToUrl( LastFm::NeighborhoodRadio ), LastFm::NeighborhoodRadio, parent ) );
 
     m_myTopArtists = new LastFmTreeItem( LastFm::TopArtists, parent );
     parent->appendChild( m_myTopArtists );
@@ -578,14 +499,12 @@ LastFmTreeModel::setupModelData( LastFmTreeItem *parent )
     m_myFriends = new LastFmTreeItem( LastFm::Friends, parent );
     parent->appendChild( m_myFriends );
 
-    m_myNeighbors = new LastFmTreeItem( LastFm::Neighbors, parent );
-    parent->appendChild( m_myNeighbors );
 }
 
 QString
 LastFmTreeModel::mapTypeToUrl( LastFm::Type type, const QString &key )
 {
-    QString const encoded_username = KUrl::toPercentEncoding( m_user.name() );
+    QString const encoded_username = QUrl::toPercentEncoding( m_user.name() );
     switch( type )
     {
     case MyRecommendations:
@@ -594,20 +513,14 @@ LastFmTreeModel::mapTypeToUrl( LastFm::Type type, const QString &key )
         return "lastfm://user/" + encoded_username + "/personal";
     case MixRadio:
         return "lastfm://user/" + encoded_username + "/mix";
-    case NeighborhoodRadio:
-        return "lastfm://user/" + encoded_username + "/neighbours";
     case MyTagsChild:
-        return "lastfm://usertags/" + encoded_username + "/" + KUrl::toPercentEncoding( key );
+        return "lastfm://usertags/" + encoded_username + "/" + QUrl::toPercentEncoding( key );
     case FriendsChild:
-        return "lastfm://user/" + KUrl::toPercentEncoding( key ) + "/personal";
+        return "lastfm://user/" + QUrl::toPercentEncoding( key ) + "/personal";
     case ArtistsChild:
-        return "lastfm://artist/" + KUrl::toPercentEncoding( key ) + "/similarartists";
-    case NeighborsChild:
-        return "lastfm://user/" + KUrl::toPercentEncoding( key ) + "/personal";
+        return "lastfm://artist/" + QUrl::toPercentEncoding( key ) + "/similarartists";
     case UserChildPersonal:
-        return "lastfm://user/" + KUrl::toPercentEncoding( key ) + "/personal";
-    case UserChildNeighborhood:
-        return "lastfm://user/" + KUrl::toPercentEncoding( key ) + "/neighbours";
+        return "lastfm://user/" + QUrl::toPercentEncoding( key ) + "/personal";
     default:
         return "";
     }
@@ -671,7 +584,7 @@ LastFmTreeItem::track() const
     if( mUrl.isEmpty() )
         return track;
 
-    KUrl url( mUrl );
+    QUrl url( mUrl );
     track = CollectionManager::instance()->trackForUrl( url );
 
     return track;
