@@ -18,31 +18,18 @@
 
 #include "LastFmTreeView.h"
 
-#include "Amarok.h"
-#include "Debug.h"
-#include "LastFmTreeModel.h" //FIXME just for enums
 #include "PopupDropperFactory.h"
-#include "SvgHandler.h"
 #include "context/ContextView.h"
-#include "context/popupdropper/libpud/PopupDropper.h"
-#include "context/popupdropper/libpud/PopupDropperItem.h"
+#include "core/meta/Meta.h"
+#include "core/support/Debug.h"
+#include "services/lastfm/LastFmTreeModel.h" // FIXME just for enums
 
-#include <KIcon>
-#include <KMenu>
-
-#include <QAction>
 #include <QContextMenuEvent>
-#include <QDesktopServices>
-#include <QDropEvent>
 #include <QHeaderView>
-#include <QMap>
-#include <QMouseEvent>
-#include <QPainter>
-#include <QSlider>
-#include <QStandardItemModel>
-#include <QTimer>
-#include <QTreeView>
-#include <QWidgetAction>
+#include <QMenu>
+
+#include <KLocalizedString>
+
 
 LastFmTreeView::LastFmTreeView ( QWidget* parent )
         : Amarok::PrettyTreeView ( parent )
@@ -53,7 +40,7 @@ LastFmTreeView::LastFmTreeView ( QWidget* parent )
         , m_dragMutex()
         , m_ongoingDrag( false )
 {
-//     connect ( this, SIGNAL ( activated ( QModelIndex ) ), SLOT ( onActivated ( QModelIndex ) ) );
+//     connect ( this, SIGNAL (activated(QModelIndex)), SLOT (onActivated(QModelIndex)) );
 
     header()->hide();
 //     setRootIsDecorated( false );
@@ -80,7 +67,7 @@ LastFmTreeView::contextMenuEvent ( QContextMenuEvent* event )
     QActionList actions = createBasicActions( m_currentItems );
 
     actions += &separator;
-    KMenu menu;
+    QMenu menu;
     foreach ( QAction * action, actions )
         menu.addAction ( action );
 
@@ -97,30 +84,26 @@ QActionList LastFmTreeView::createBasicActions( const QModelIndexList & indices
     {
         case LastFm::MyRecommendations:
         case LastFm::PersonalRadio:
-        case LastFm::LovedTracksRadio:
-        case LastFm::NeighborhoodRadio:
+        case LastFm::MixRadio:
         case LastFm::FriendsChild:
-        case LastFm::NeighborsChild:
         case LastFm::MyTagsChild:
         case LastFm::ArtistsChild:
-        case LastFm::UserChildLoved:
         case LastFm::UserChildPersonal:
-        case LastFm::UserChildNeighborhood:
         {
             if ( m_appendAction == 0 )
             {
-                m_appendAction = new QAction ( KIcon ( "media-track-add-amarok" ), i18n ( "&Add to Playlist" ), this );
+                m_appendAction = new QAction ( QIcon::fromTheme( "media-track-add-amarok" ), i18n ( "&Add to Playlist" ), this );
                 m_appendAction->setProperty( "popupdropper_svg_id", "append" );
-                connect ( m_appendAction, SIGNAL ( triggered() ), this, SLOT ( slotAppendChildTracks() ) );
+                connect ( m_appendAction, &QAction::triggered, this, &LastFmTreeView::slotAppendChildTracks );
             }
 
             actions.append ( m_appendAction );
 
             if ( m_loadAction == 0 )
             {
-                m_loadAction = new QAction ( KIcon ( "folder-open" ), i18nc ( "Replace the currently loaded tracks with these", "&Replace Playlist" ), this );
+                m_loadAction = new QAction ( QIcon::fromTheme( "folder-open" ), i18nc ( "Replace the currently loaded tracks with these", "&Replace Playlist" ), this );
                 m_appendAction->setProperty( "popupdropper_svg_id", "load" );
-                connect ( m_loadAction, SIGNAL ( triggered() ), this, SLOT ( slotPlayChildTracks() ) );
+                connect ( m_loadAction, &QAction::triggered, this, &LastFmTreeView::slotReplacePlaylistByChildTracks );
             }
             actions.append ( m_loadAction );
         }
@@ -137,7 +120,7 @@ void LastFmTreeView::mouseDoubleClickEvent( QMouseEvent *event )
 
     if( index.isValid() && index.internalPointer() )
     {
-        playChildTracks( index, Playlist::AppendAndPlay );
+        playChildTracks( index, Playlist::OnDoubleClickOnSelectedItems );
     }
 }
 
@@ -188,7 +171,7 @@ LastFmTreeView::startDrag(Qt::DropActions supportedActions)
         PopupDropper * morePud = 0;
         if ( actions.count() > 1 )
         {
-            morePud = The::popupDropperFactory()->createPopupDropper( 0 );
+            morePud = The::popupDropperFactory()->createPopupDropper( 0, true );
 
             foreach( QAction * action, actions )
                 morePud->addItem( The::popupDropperFactory()->createItem( action ) );
@@ -212,7 +195,7 @@ LastFmTreeView::startDrag(Qt::DropActions supportedActions)
     if( m_pd )
     {
         debug() << "clearing PUD";
-        connect( m_pd, SIGNAL( fadeHideFinished() ), m_pd, SLOT( clear() ) );
+        connect( m_pd, &PopupDropper::fadeHideFinished, m_pd, &PopupDropper::clear );
         m_pd->hide();
     }
 
@@ -222,15 +205,15 @@ LastFmTreeView::startDrag(Qt::DropActions supportedActions)
 }
 
 void
-LastFmTreeView::slotPlayChildTracks()
+LastFmTreeView::slotReplacePlaylistByChildTracks()
 {
-    playChildTracks ( m_currentItems, Playlist::LoadAndPlay );
+    playChildTracks( m_currentItems, Playlist::OnReplacePlaylistAction );
 }
 
 void
 LastFmTreeView::slotAppendChildTracks()
 {
-    playChildTracks ( m_currentItems, Playlist::AppendAndPlay );
+    playChildTracks( m_currentItems, Playlist::OnAppendToPlaylistAction );
 }
 
 void
@@ -253,5 +236,5 @@ LastFmTreeView::playChildTracks ( const QModelIndexList &items, Playlist::AddOpt
             list << track;
     }
     qStableSort ( list.begin(), list.end(), Meta::Track::lessThan );
-    The::playlistController()->insertOptioned ( list, insertMode );
+    The::playlistController()->insertOptioned( list, insertMode );
 }
