@@ -22,7 +22,7 @@
 #include "core/support/Debug.h"
 #include "core-impl/collections/support/CollectionManager.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 
 #include <QDomDocument>
 #include <QDomElement>
@@ -58,7 +58,7 @@ Dynamic::WeeklyTopBiasFactory::createBias()
 
 Dynamic::WeeklyTopBias::WeeklyTopBias()
     : SimpleMatchBias()
-    , m_weeklyTimesJob( 0 )
+    , m_weeklyTimesJob( )
 {
     m_range.from = QDateTime::currentDateTime();
     m_range.to = QDateTime::currentDateTime();
@@ -81,9 +81,9 @@ Dynamic::WeeklyTopBias::fromXml( QXmlStreamReader *reader )
         {
             QStringRef name = reader->name();
             if( name == "from" )
-                m_range.from = QDateTime::fromTime_t( reader->readElementText(QXmlStreamReader::SkipChildElements).toLong() );
+                m_range.from = QDateTime::fromSecsSinceEpoch( reader->readElementText(QXmlStreamReader::SkipChildElements).toLong() );
             else if( name == "to" )
-                m_range.to = QDateTime::fromTime_t( reader->readElementText(QXmlStreamReader::SkipChildElements).toLong() );
+                m_range.to = QDateTime::fromSecsSinceEpoch( reader->readElementText(QXmlStreamReader::SkipChildElements).toLong() );
             else
             {
                 debug()<<"Unexpected xml start element"<<name<<"in input";
@@ -100,8 +100,8 @@ Dynamic::WeeklyTopBias::fromXml( QXmlStreamReader *reader )
 void
 Dynamic::WeeklyTopBias::toXml( QXmlStreamWriter *writer ) const
 {
-    writer->writeTextElement( "from", QString::number( m_range.from.toTime_t() ) );
-    writer->writeTextElement( "to",   QString::number( m_range.to.toTime_t() ) );
+    writer->writeTextElement( "from", QString::number( m_range.from.toSecsSinceEpoch() ) );
+    writer->writeTextElement( "to",   QString::number( m_range.to.toSecsSinceEpoch() ) );
 }
 
 QString
@@ -131,28 +131,26 @@ Dynamic::WeeklyTopBias::widget( QWidget* parent )
 
     QLabel *label = new QLabel( i18nc( "in WeeklyTopBias. Label for the date widget", "from:" ) );
     QDateTimeEdit *fromEdit = new QDateTimeEdit( QDate::currentDate().addDays( -7 ) );
-    fromEdit->setMinimumDate( QDateTime::fromTime_t( 1111320001 ).date() ); // That's the first week in last fm
+    fromEdit->setMinimumDate( QDateTime::fromSecsSinceEpoch( 1111320001 ).date() ); // That's the first week in last fm
     fromEdit->setMaximumDate( QDate::currentDate() );
     fromEdit->setCalendarPopup( true );
     if( m_range.from.isValid() )
         fromEdit->setDateTime( m_range.from );
 
-    connect( fromEdit, SIGNAL(dateTimeChanged(QDateTime)),
-             this, SLOT(fromDateChanged(QDateTime)) );
+    connect( fromEdit, &QDateTimeEdit::dateTimeChanged, this, &WeeklyTopBias::fromDateChanged );
     label->setBuddy( fromEdit );
     layout->addWidget( label );
     layout->addWidget( fromEdit );
 
     label = new QLabel( i18nc( "in WeeklyTopBias. Label for the date widget", "to:" ) );
     QDateTimeEdit *toEdit = new QDateTimeEdit( QDate::currentDate().addDays( -7 ) );
-    toEdit->setMinimumDate( QDateTime::fromTime_t( 1111320001 ).date() ); // That's the first week in last fm
+    toEdit->setMinimumDate( QDateTime::fromSecsSinceEpoch( 1111320001 ).date() ); // That's the first week in last fm
     toEdit->setMaximumDate( QDate::currentDate() );
     toEdit->setCalendarPopup( true );
     if( m_range.to.isValid() )
         toEdit->setDateTime( m_range.to );
 
-    connect( toEdit, SIGNAL(dateTimeChanged(QDateTime)),
-             this, SLOT(toDateChanged(QDateTime)) );
+    connect( toEdit, &QDateTimeEdit::dateTimeChanged, this, &WeeklyTopBias::toDateChanged );
     label->setBuddy( toEdit );
     layout->addWidget( label );
     layout->addWidget( toEdit );
@@ -180,8 +178,8 @@ Dynamic::WeeklyTopBias::trackMatches( int position,
     QStringList artists;
     bool weeksMissing = false;
 
-    uint fromTime = m_range.from.toTime_t();
-    uint toTime   = m_range.to.toTime_t();
+    uint fromTime = m_range.from.toSecsSinceEpoch();
+    uint toTime   = m_range.to.toSecsSinceEpoch();
     uint lastWeekTime = 0;
     foreach( uint weekTime, m_weeklyFromTimes )
     {
@@ -223,8 +221,8 @@ Dynamic::WeeklyTopBias::newQuery()
     QStringList artists;
     bool weeksMissing = false;
 
-    uint fromTime = m_range.from.toTime_t();
-    uint toTime   = m_range.to.toTime_t();
+    uint fromTime = m_range.from.toSecsSinceEpoch();
+    uint toTime   = m_range.to.toSecsSinceEpoch();
     uint lastWeekTime = 0;
     foreach( uint weekTime, m_weeklyFromTimes )
     {
@@ -265,13 +263,13 @@ Dynamic::WeeklyTopBias::newQuery()
     m_qm->setQueryType( Collections::QueryMaker::Custom );
     m_qm->addReturnValue( Meta::valUniqueId );
 
-    connect( m_qm.data(), SIGNAL(newResultReady(QStringList)),
-             this, SLOT(updateReady(QStringList)) );
-    connect( m_qm.data(), SIGNAL(queryDone()),
-             this, SLOT(updateFinished()) );
+    connect( m_qm.data(), &Collections::QueryMaker::newResultReady,
+             this, &WeeklyTopBias::updateReady );
+    connect( m_qm.data(), &Collections::QueryMaker::queryDone,
+             this, &WeeklyTopBias::updateFinished );
 
     // - run the query
-    m_qm.data()->run();
+    m_qm->run();
 }
 
 void
@@ -285,8 +283,8 @@ Dynamic::WeeklyTopBias::newWeeklyTimesQuery()
 
     m_weeklyTimesJob = lastfm::ws::get( params );
 
-    connect( m_weeklyTimesJob, SIGNAL(finished()),
-             this, SLOT(weeklyTimesQueryFinished()) );
+    connect( m_weeklyTimesJob, &QNetworkReply::finished,
+             this, &WeeklyTopBias::weeklyTimesQueryFinished );
 }
 
 
@@ -307,8 +305,8 @@ void Dynamic::WeeklyTopBias::newWeeklyArtistQuery()
     if( jobCount >= 5 )
         return;
 
-    uint fromTime = m_range.from.toTime_t();
-    uint toTime   = m_range.to.toTime_t();
+    uint fromTime = m_range.from.toSecsSinceEpoch();
+    uint toTime   = m_range.to.toSecsSinceEpoch();
     uint lastWeekTime = 0;
     foreach( uint weekTime, m_weeklyFromTimes )
     {
@@ -331,8 +329,8 @@ void Dynamic::WeeklyTopBias::newWeeklyArtistQuery()
                 params[ "to" ] = QString::number( m_weeklyToTimes[m_weeklyFromTimes.indexOf(lastWeekTime)] );
 
                 QNetworkReply* reply = lastfm::ws::get( params );
-                connect( reply, SIGNAL(finished()),
-                         this, SLOT(weeklyArtistQueryFinished()) );
+                connect( reply, &QNetworkReply::finished,
+                         this, &WeeklyTopBias::weeklyArtistQueryFinished );
 
                 m_weeklyArtistJobs.insert( lastWeekTime, reply );
 
@@ -489,4 +487,3 @@ Dynamic::WeeklyTopBias::saveDataToFile() const
 }
 
 
-#include "WeeklyTopBias.moc"
