@@ -25,14 +25,13 @@
 #include "core/support/Amarok.h"
 #include "core-impl/support/TagStatisticsStore.h"
 
-#include <kio/job.h>
-#include <kio/jobclasses.h>
-#include <KStandardDirs>
+#include <KIO/Job>
 
 #include <QDir>
 #include <QImage>
 #include <QList>
 #include <QPixmap>
+#include <QStandardPaths>
 #include <QStringList>
 
 #include <Track.h>
@@ -85,7 +84,7 @@ class Track::Private : public QObject
             artist = QString ( "Last.fm" );
         }
 
-        ~Private()
+        ~Private() override
         {
         }
 
@@ -114,7 +113,7 @@ class Track::Private : public QObject
             if( newTrackInfo )
             {
                 statsStore = new TagStatisticsStore( t );
-                currentTrackStartTime = QDateTime::currentDateTime().toTime_t();
+                currentTrackStartTime = QDateTime::currentDateTimeUtc().toSecsSinceEpoch();
             }
 
             notifyObservers();
@@ -132,7 +131,7 @@ class Track::Private : public QObject
             }
         }
 
-    public slots:
+    public Q_SLOTS:
         void requestResult( )
         {
             if( !m_userFetch )
@@ -152,7 +151,7 @@ class Track::Private : public QObject
 
                     if( !imageUrl.isEmpty() )
                     {
-                        KIO::Job* job = KIO::storedGet( KUrl( imageUrl ), KIO::Reload, KIO::HideProgressInfo );
+                        KIO::Job* job = KIO::storedGet( QUrl( imageUrl ), KIO::Reload, KIO::HideProgressInfo );
                         connect( job, SIGNAL( result( KJob* ) ), this, SLOT( fetchImageFinished( KJob* ) ) );
                     }
                 }
@@ -199,21 +198,21 @@ class Track::Private : public QObject
 class LastFmArtist : public Meta::Artist
 {
 public:
-    LastFmArtist( Track::Private *dptr )
+    explicit LastFmArtist( Track::Private *dptr )
         : Meta::Artist()
         , d( dptr )
     {}
 
-    Meta::TrackList tracks()
+    Meta::TrackList tracks() override
     {
         return Meta::TrackList();
     }
 
-    QString name() const
+    QString name() const override
     {
         if( d )
             return d->artist;
-        return QString( "Last.fm" );
+        return QStringLiteral( "Last.fm" );
     }
 
     Track::Private * const d;
@@ -224,28 +223,28 @@ public:
 class LastFmAlbum : public Meta::Album
 {
 public:
-    LastFmAlbum( Track::Private *dptr )
+    explicit LastFmAlbum( Track::Private *dptr )
         : Meta::Album()
         , d( dptr )
     {}
 
-    bool isCompilation() const { return false; }
-    bool hasAlbumArtist() const { return false; }
-    Meta::ArtistPtr albumArtist() const { return Meta::ArtistPtr(); }
+    bool isCompilation() const override { return false; }
+    bool hasAlbumArtist() const override { return false; }
+    Meta::ArtistPtr albumArtist() const override { return Meta::ArtistPtr(); }
 
-    Meta::TrackList tracks()
+    Meta::TrackList tracks() override
     {
         return Meta::TrackList();
     }
 
-    QString name() const
+    QString name() const override
     {
         if( d )
             return d->album;
         return QString();
     }
 
-    QImage image( int size ) const
+    QImage image( int size ) const override
     {
         if( !d || d->albumArt.isNull() )
         {
@@ -263,7 +262,7 @@ public:
                 image = QImage( cacheCoverDir.filePath( sizeKey + "lastfm-default-cover.png" ) );
             else
             {
-                QImage orgImage = QImage( KStandardDirs::locate( "data", "amarok/images/lastfm-default-cover.png" ) ); //optimize this!
+                QImage orgImage = QImage( QStandardPaths::locate( QStandardPaths::GenericDataLocation, "amarok/images/lastfm-default-cover.png" ) ); //optimize this!
                 //scaled() does not change the original image but returns a scaled copy
                 image = orgImage.scaled( size, size, Qt::KeepAspectRatio, Qt::SmoothTransformation );
                 image.save( cacheCoverDir.filePath( sizeKey + "lastfm-default-cover.png" ), "PNG" );
@@ -278,16 +277,16 @@ public:
         return d->albumArt;
     }
 
-    KUrl imageLocation( int size )
+    QUrl imageLocation( int size ) override
     {
         Q_UNUSED( size );
         if( d && !d->imageUrl.isEmpty() )
-            return KUrl( d->imageUrl );
-        return KUrl();
+            return QUrl( d->imageUrl );
+        return QUrl();
     }
 
     // return true since we handle our own fetching
-    bool hasImage( int size = 1 ) const { Q_UNUSED( size ); return true; }
+    bool hasImage( int size = 1 ) const override { Q_UNUSED( size ); return true; }
 
     Track::Private * const d;
 
@@ -297,17 +296,17 @@ public:
 class LastFmGenre : public Meta::Genre
 {
 public:
-    LastFmGenre( Track::Private *dptr )
+    explicit LastFmGenre( Track::Private *dptr )
         : Meta::Genre()
         , d( dptr )
     {}
 
-    QString name() const
+    QString name() const override
     {
         return QString();
     }
 
-    Meta::TrackList tracks()
+    Meta::TrackList tracks() override
     {
         return Meta::TrackList();
     }
@@ -320,17 +319,17 @@ public:
 class LastFmComposer : public Meta::Composer
 {
 public:
-    LastFmComposer( Track::Private *dptr )
+    explicit LastFmComposer( Track::Private *dptr )
         : Meta::Composer()
         , d( dptr )
     {}
 
-    QString name() const
+    QString name() const override
     {
         return QString();
     }
 
-    Meta::TrackList tracks()
+    Meta::TrackList tracks() override
     {
         return Meta::TrackList();
     }
@@ -343,17 +342,17 @@ public:
 class LastFmYear : public Meta::Year
 {
 public:
-    LastFmYear( Track::Private *dptr )
+    explicit LastFmYear( Track::Private *dptr )
         : Meta::Year()
         , d( dptr )
     {}
 
-    QString name() const
+    QString name() const override
     {
         return QString();
     }
 
-    Meta::TrackList tracks()
+    Meta::TrackList tracks() override
     {
         return Meta::TrackList();
     }
