@@ -33,23 +33,23 @@ void
 MagnatuneDatabaseHandler::createDatabase( )
 {
     //Get database instance
-    SqlStorage *sqlDb = StorageManager::instance()->sqlStorage();
+    auto sqlDb = StorageManager::instance()->sqlStorage();
 
     QString autoIncrement = "AUTO_INCREMENT";
 
     // create table containing tracks
     QString queryString = "CREATE TABLE magnatune_tracks ("
-                          "id INTEGER PRIMARY KEY " + autoIncrement + ',' +
-                          "name " + sqlDb->textColumnType() + ',' +
+                          "id INTEGER PRIMARY KEY " + autoIncrement + QLatin1Char(',') +
+                          "name " + sqlDb->textColumnType() + QLatin1Char(',') +
                           "track_number INTEGER,"
                           "length INTEGER,"
                           "album_id INTEGER,"
                           "artist_id INTEGER,"
-                          "preview_lofi " + sqlDb->exactTextColumnType() + ',' +
-                          "preview_ogg " + sqlDb->exactTextColumnType() + ',' +
+                          "preview_lofi " + sqlDb->exactTextColumnType() + QLatin1Char(',') +
+                          "preview_ogg " + sqlDb->exactTextColumnType() + QLatin1Char(',') +
                           "preview_url " + sqlDb->exactTextColumnType() + ") ENGINE = MyISAM;";
 
-    debug() << "Creating mangnatune_tracks: " << queryString;
+    debug() << "Creating magnatune_tracks: " << queryString;
 
 
     QStringList result = sqlDb->query( queryString );
@@ -59,15 +59,15 @@ MagnatuneDatabaseHandler::createDatabase( )
 
     //Create album table
     queryString = "CREATE TABLE magnatune_albums ("
-                  "id INTEGER PRIMARY KEY " + autoIncrement + ',' +
-                  "name " + sqlDb->textColumnType() + ',' +
+                  "id INTEGER PRIMARY KEY " + autoIncrement + QLatin1Char(',') +
+                  "name " + sqlDb->textColumnType() + QLatin1Char(',') +
                   "year INTEGER,"
                   "artist_id INTEGER,"
-                  "album_code " + sqlDb->textColumnType() + ',' +
-                  "cover_url " + sqlDb->exactTextColumnType() + ',' +
+                  "album_code " + sqlDb->textColumnType() + QLatin1Char(',') +
+                  "cover_url " + sqlDb->exactTextColumnType() + QLatin1Char(',') +
                   "description " + sqlDb->exactTextColumnType() + ") ENGINE = MyISAM;";
 
-    debug() << "Creating Mangnatune_albums: " << queryString;
+    debug() << "Creating Magnatune_albums: " << queryString;
 
     result = sqlDb->query( queryString );
 
@@ -77,13 +77,13 @@ MagnatuneDatabaseHandler::createDatabase( )
 
     //Create artist table
     queryString = "CREATE TABLE magnatune_artists ("
-                  "id INTEGER PRIMARY KEY " + autoIncrement + ',' +
-                  "name " + sqlDb->textColumnType() + ',' +
-                  "artist_page " + sqlDb->exactTextColumnType() + ',' +
-                  "description " + sqlDb->textColumnType() + ',' +
+                  "id INTEGER PRIMARY KEY " + autoIncrement + QLatin1Char(',') +
+                  "name " + sqlDb->textColumnType() + QLatin1Char(',') +
+                  "artist_page " + sqlDb->exactTextColumnType() + QLatin1Char(',') +
+                  "description " + sqlDb->textColumnType() + QLatin1Char(',') +
                   "photo_url " + sqlDb->exactTextColumnType() + ") ENGINE = MyISAM;";
 
-    debug() << "Creating mangnatune_artist: " << queryString;
+    debug() << "Creating magnatune_artist: " << queryString;
 
     result = sqlDb->query( queryString );
 
@@ -91,8 +91,8 @@ MagnatuneDatabaseHandler::createDatabase( )
 
     //create genre table
     queryString = "CREATE TABLE magnatune_genre ("
-                  "id INTEGER PRIMARY KEY " + autoIncrement + ',' +
-                  "name " + sqlDb->textColumnType() + ',' +
+                  "id INTEGER PRIMARY KEY " + autoIncrement + QLatin1Char(',') +
+                  "name " + sqlDb->textColumnType() + QLatin1Char(',') +
                   "album_id INTEGER" + ") ENGINE = MyISAM;";
 
     result = sqlDb->query( queryString );
@@ -103,11 +103,11 @@ MagnatuneDatabaseHandler::createDatabase( )
 
     //create moods table
      queryString = "CREATE TABLE magnatune_moods ("
-                  "id INTEGER PRIMARY KEY " + autoIncrement + ',' +
+                  "id INTEGER PRIMARY KEY " + autoIncrement + QLatin1Char(',') +
                   "track_id INTEGER," +
                   "mood " + sqlDb->textColumnType() + ") ENGINE = MyISAM;";
 
-    debug() << "Creating mangnatune_moods: " << queryString;
+    debug() << "Creating magnatune_moods: " << queryString;
 
     result = sqlDb->query( queryString );
 
@@ -118,7 +118,7 @@ MagnatuneDatabaseHandler::createDatabase( )
 void
 MagnatuneDatabaseHandler::destroyDatabase( )
 {
-    SqlStorage *sqlDb = StorageManager::instance()->sqlStorage();
+    auto sqlDb = StorageManager::instance()->sqlStorage();
     QStringList result = sqlDb->query( "DROP TABLE IF EXISTS magnatune_tracks;" );
     result = sqlDb->query( "DROP TABLE IF EXISTS magnatune_albums;" );
     result = sqlDb->query( "DROP TABLE IF EXISTS magnatune_artists;" );
@@ -150,7 +150,7 @@ MagnatuneDatabaseHandler::insertTrack( ServiceTrack *track )
 {
     MagnatuneTrack * mTrack = static_cast<MagnatuneTrack *> ( track );
 
-    SqlStorage *sqlDb = StorageManager::instance()->sqlStorage();
+    auto sqlDb = StorageManager::instance()->sqlStorage();
     QString queryString = "INSERT INTO magnatune_tracks ( name, track_number, length, "
             "album_id, artist_id, preview_lofi, preview_ogg, preview_url ) VALUES ( '"
                           + sqlDb->escape( mTrack->name()) + "', "
@@ -164,7 +164,7 @@ MagnatuneDatabaseHandler::insertTrack( ServiceTrack *track )
 
 
     // debug() << "Adding Magnatune track " << queryString;
-    int trackId = sqlDb->insert( queryString, NULL );
+    int trackId = sqlDb->insert( queryString, nullptr );
 
     return trackId;
 
@@ -178,7 +178,7 @@ MagnatuneDatabaseHandler::insertAlbum( ServiceAlbum *album )
     MagnatuneAlbum * mAlbum = static_cast<MagnatuneAlbum *> ( album );
 
     QString queryString;
-    SqlStorage *sqlDb = StorageManager::instance()->sqlStorage();
+    auto sqlDb = StorageManager::instance()->sqlStorage();
     queryString = "INSERT INTO magnatune_albums ( name, year, artist_id, "
                   "album_code, cover_url, description ) VALUES ( '"
                   + sqlDb->escape( sqlDb->escape( mAlbum->name() ) ) + "', "
@@ -201,13 +201,13 @@ MagnatuneDatabaseHandler::insertArtist( ServiceArtist *artist )
     MagnatuneArtist * mArtist = static_cast<MagnatuneArtist *> ( artist );
 
     QString queryString;
-    SqlStorage *sqlDb = StorageManager::instance()->sqlStorage();
+    auto sqlDb = StorageManager::instance()->sqlStorage();
     queryString = "INSERT INTO magnatune_artists ( name, artist_page, description, "
                   "photo_url ) VALUES ( '"
                   + sqlDb->escape( mArtist->name() ) + "', '"
-                  + sqlDb->escape( mArtist->magnatuneUrl()) + "', '"
+                  + sqlDb->escape( mArtist->magnatuneUrl().url() ) + "', '"
                   + sqlDb->escape( mArtist->description() ) + "', '"
-                  + sqlDb->escape( mArtist->photoUrl() ) + "' );";
+                  + sqlDb->escape( mArtist->photoUrl().url() ) + "' );";
 
     //debug() << "Adding Magnatune artist " << queryString;
 
@@ -219,7 +219,7 @@ void
 MagnatuneDatabaseHandler::begin( )
 {
 
-    SqlStorage *sqlDb = StorageManager::instance()->sqlStorage();
+    auto sqlDb = StorageManager::instance()->sqlStorage();
 
     QString queryString = "BEGIN;";
 
@@ -229,7 +229,7 @@ MagnatuneDatabaseHandler::begin( )
 void
 MagnatuneDatabaseHandler::commit( )
 {
-    SqlStorage *sqlDb = StorageManager::instance()->sqlStorage();
+    auto sqlDb = StorageManager::instance()->sqlStorage();
     QString queryString = "COMMIT;";
 
     sqlDb->query( queryString );
@@ -240,7 +240,7 @@ void MagnatuneDatabaseHandler::insertMoods(int trackId, const QStringList &moods
 {
 
     QString queryString;
-    SqlStorage *sqlDb = StorageManager::instance()->sqlStorage();
+    auto sqlDb = StorageManager::instance()->sqlStorage();
 
     foreach( const QString &mood, moods ) {
         queryString = "INSERT INTO magnatune_moods ( track_id, mood ) VALUES ( "
@@ -249,14 +249,14 @@ void MagnatuneDatabaseHandler::insertMoods(int trackId, const QStringList &moods
 
 
         //debug() << "Adding Magnatune mood: " << queryString;
-        sqlDb->insert( queryString, NULL );
+        sqlDb->insert( queryString, nullptr );
     }
 }
 
 int MagnatuneDatabaseHandler::getArtistIdByExactName(const QString & name)
 {
 
-    SqlStorage *sqlDb = StorageManager::instance()->sqlStorage();
+    auto sqlDb = StorageManager::instance()->sqlStorage();
 
     QString queryString = "SELECT id from magnatune_artists WHERE name='" + sqlDb->escape( name ) + "';";
     QStringList result = sqlDb->query( queryString );
@@ -274,7 +274,7 @@ int MagnatuneDatabaseHandler::getArtistIdByExactName(const QString & name)
 
 int MagnatuneDatabaseHandler::getAlbumIdByAlbumCode(const QString & albumcode)
 {
-    SqlStorage *sqlDb = StorageManager::instance()->sqlStorage();
+    auto sqlDb = StorageManager::instance()->sqlStorage();
 
     QString queryString = "SELECT id from magnatune_albums WHERE album_code='" + sqlDb->escape( albumcode ) + "';";
     QStringList result = sqlDb->query( queryString );
@@ -292,7 +292,7 @@ int MagnatuneDatabaseHandler::getAlbumIdByAlbumCode(const QString & albumcode)
 int MagnatuneDatabaseHandler::insertGenre(ServiceGenre * genre)
 {
     QString queryString;
-    SqlStorage *sqlDb = StorageManager::instance()->sqlStorage();
+    auto sqlDb = StorageManager::instance()->sqlStorage();
     queryString = "INSERT INTO magnatune_genre ( album_id, name "
                   ") VALUES ( "
                   + QString::number ( genre->albumId() ) + ", '"
