@@ -31,11 +31,11 @@ class ScriptableServiceCollection : public ServiceCollection
 {
     Q_OBJECT
 public:
-    ScriptableServiceCollection( const QString &name );
+    explicit ScriptableServiceCollection( const QString &name );
 
-    ~ScriptableServiceCollection();
+    ~ScriptableServiceCollection() override;
 
-    virtual Collections::QueryMaker* queryMaker();
+    Collections::QueryMaker* queryMaker() override;
 
     void donePopulating( int parentId );
 
@@ -52,7 +52,7 @@ public:
 
     void clear();
 
-    signals:
+    Q_SIGNALS:
         void updateComplete();
 
 private:
