@@ -32,12 +32,12 @@ ScriptableServiceInfoParser::~ScriptableServiceInfoParser()
 {
 }
 
-void ScriptableServiceInfoParser::getInfo( ArtistPtr artist )
+void ScriptableServiceInfoParser::getInfo( const ArtistPtr &artist )
 {
     ScriptableServiceArtist * serviceArtist = dynamic_cast< ScriptableServiceArtist * >( artist.data() );
-    if (serviceArtist == 0) return;
+    if (!serviceArtist) return;
 
-    emit( info( serviceArtist->description() ) );
+    Q_EMIT( info( serviceArtist->description() ) );
 
     if ( serviceArtist->description().isEmpty() )
     {
@@ -46,13 +46,13 @@ void ScriptableServiceInfoParser::getInfo( ArtistPtr artist )
     }
 }
 
-void ScriptableServiceInfoParser::getInfo(AlbumPtr album)
+void ScriptableServiceInfoParser::getInfo(const AlbumPtr &album)
 {
     DEBUG_BLOCK
     ScriptableServiceAlbum * serviceAlbum = dynamic_cast< ScriptableServiceAlbum * >( album.data() );
     if (serviceAlbum == 0) return;
 
-    emit( info( serviceAlbum->description() ) );
+    Q_EMIT( info( serviceAlbum->description() ) );
 
     if ( serviceAlbum->description().isEmpty() )
     {
@@ -61,13 +61,13 @@ void ScriptableServiceInfoParser::getInfo(AlbumPtr album)
     }
 }
 
-void ScriptableServiceInfoParser::getInfo(TrackPtr track)
+void ScriptableServiceInfoParser::getInfo(const TrackPtr &track)
 {
     DEBUG_BLOCK
     ScriptableServiceTrack * serviceTrack = dynamic_cast< ScriptableServiceTrack * >( track.data() );
-    if (serviceTrack == 0) return;
+    if (!serviceTrack) return;
 
-    emit( info( serviceTrack->description() ) );
+    Q_EMIT  info( serviceTrack->description() );
 
     if ( serviceTrack->description().isEmpty() )
     {
@@ -76,12 +76,12 @@ void ScriptableServiceInfoParser::getInfo(TrackPtr track)
     }
 }
 
-void ScriptableServiceInfoParser::getInfo( Meta::GenrePtr genre )
+void ScriptableServiceInfoParser::getInfo( const Meta::GenrePtr &genre )
 {
     ScriptableServiceGenre * serviceGenre = dynamic_cast< ScriptableServiceGenre * >( genre.data() );
-    if (serviceGenre == 0) return;
+    if (!serviceGenre) return;
 
-    emit( info( serviceGenre->description() ) );
+    Q_EMIT info( serviceGenre->description() );
 
     if ( serviceGenre->description().isEmpty() )
     {
