@@ -25,11 +25,10 @@
 #include "../ServiceMetaBase.h"
 #include "browsers/servicebrowser/ServiceBrowser.h"
 
-#include <kiconloader.h>
 
 using namespace Meta;
 
-ScriptableServiceManager * ScriptableServiceManager::s_instance = 0;
+ScriptableServiceManager * ScriptableServiceManager::s_instance = nullptr;
 
 
 ScriptableServiceManager::ScriptableServiceManager()
@@ -51,13 +50,13 @@ bool ScriptableServiceManager::initService( const QString &name, int levels, con
     ScriptableService * service = new ScriptableService ( name );
     m_serviceMap[name] = service;
 
-    service->setIcon( KIcon( "view-services-scripted-amarok" ) );
+    service->setIcon( QIcon::fromTheme( QStringLiteral("view-services-scripted-amarok") ) );
     service->setShortDescription( shortDescription );
     service->init( levels, rootHtml, showSearchBar );
     m_rootHtml = rootHtml;
 
     debug() << "emitting scripted service " << name;
-    emit addService( service );
+    Q_EMIT addService( service );
 
     return true;
 }
@@ -122,9 +121,9 @@ void ScriptableServiceManager::setIcon( const QString & serviceName, const QPixm
         return;
     }
 
-  
-    m_serviceMap[serviceName]->setIcon( KIcon( QIcon( icon ) ) );
-    emit( serviceUpdated( m_serviceMap[serviceName] ) );
+
+    m_serviceMap[serviceName]->setIcon( QIcon( icon ) );
+    Q_EMIT( serviceUpdated( m_serviceMap[serviceName] ) );
 }
 
 void ScriptableServiceManager::setEmblem( const QString & serviceName, const QPixmap & emblem )
@@ -135,7 +134,7 @@ void ScriptableServiceManager::setEmblem( const QString & serviceName, const QPi
     }
     
     m_serviceMap[serviceName]->setCustomEmblem( emblem );
-    emit( serviceUpdated( m_serviceMap[serviceName] ) );
+    Q_EMIT( serviceUpdated( m_serviceMap[serviceName] ) );
 }
 
 
@@ -147,7 +146,7 @@ void ScriptableServiceManager::setScalableEmblem ( const QString& serviceName, c
     }
     
     m_serviceMap[serviceName]->setCustomScalableEmblem( emblemPath );
-    emit( serviceUpdated( m_serviceMap[serviceName] ) );
+    Q_EMIT( serviceUpdated( m_serviceMap[serviceName] ) );
 }
 
 
@@ -166,7 +165,7 @@ namespace The {
     ScriptableServiceManager*
     scriptableServiceManager()
     {
-        if ( ScriptableServiceManager::s_instance == 0 )
+        if ( ScriptableServiceManager::s_instance == nullptr )
             ScriptableServiceManager::s_instance = new ScriptableServiceManager();
 
         return ScriptableServiceManager::s_instance;
@@ -178,7 +177,6 @@ namespace The {
 
 
 
-#include "ScriptableServiceManager.moc"
 
 
 
