@@ -20,16 +20,16 @@
 #define AMAROK_SCRIPTABLE_SERVICE_META_P_H
 
 
-#include "Debug.h"
-#include "Meta.h"
-#include "SourceInfoCapability.h"
+#include "core/support/Debug.h"
+#include "core/meta/Meta.h"
+#include "core/capabilities/SourceInfoCapability.h"
 
 #include <QObject>
 #include <QPixmap>
 #include <QPointer>
 #include <QString>
 
-#include <KLocale>
+#include <KLocalizedString>
 
 
 
@@ -37,7 +37,7 @@
 
 
 /**
- * Base class for the private meta types. This is used to give these private items source info capability which is neede in some cases,for instance when bookmarking.
+ * Base class for the private meta types. This is used to give these private items source info capability which is needed in some cases,for instance when bookmarking.
  */
 class ScriptableServiceInternalMetaItem
 {
@@ -61,19 +61,19 @@ class ScriptableServiceInternalMetaItem
 };
 
 
-class AMAROK_EXPORT ScriptableServiceInternalSourceInfoCapability : public Meta::SourceInfoCapability
+class AMAROK_EXPORT ScriptableServiceInternalSourceInfoCapability : public Capabilities::SourceInfoCapability
 {
     public:
-        ScriptableServiceInternalSourceInfoCapability( ScriptableServiceInternalMetaItem * sourceInfoProvider )
+        explicit ScriptableServiceInternalSourceInfoCapability( ScriptableServiceInternalMetaItem * sourceInfoProvider )
         {
             m_sourceInfoProvider = sourceInfoProvider;
         }
-        ~ScriptableServiceInternalSourceInfoCapability() {};
+        ~ScriptableServiceInternalSourceInfoCapability() override {}
 
-        QString sourceName() { return m_sourceInfoProvider->serviceName(); }
-        QString sourceDescription() { return m_sourceInfoProvider->serviceDescription(); }
-        QPixmap emblem() { return m_sourceInfoProvider->serviceEmblem(); }
-        QString scalableEmblem() { return m_sourceInfoProvider->serviceScalableEmblem(); }
+        QString sourceName() override { return m_sourceInfoProvider->serviceName(); }
+        QString sourceDescription() override { return m_sourceInfoProvider->serviceDescription(); }
+        QPixmap emblem() override { return m_sourceInfoProvider->serviceEmblem(); }
+        QString scalableEmblem() override { return m_sourceInfoProvider->serviceScalableEmblem(); }
         
 
     private:
@@ -85,22 +85,17 @@ class AMAROK_EXPORT ScriptableServiceInternalSourceInfoCapability : public Meta:
 class ScriptableServiceInternalArtist : public Meta::Artist, public ScriptableServiceInternalMetaItem
 {
     public:
-        ScriptableServiceInternalArtist( const QString &name = QString() )
+        explicit ScriptableServiceInternalArtist( const QString &name = QString() )
         : Meta::Artist()
         , m_name( name )
         {}
 
-        Meta::TrackList tracks()
+        Meta::TrackList tracks() override
         {
             return Meta::TrackList();
         }
 
-        Meta::AlbumList albums()
-        {
-            return Meta::AlbumList();
-        }
-
-        QString name() const
+        QString name() const override
         {
             if( !m_name.isEmpty() )
                 return m_name;
@@ -108,19 +103,19 @@ class ScriptableServiceInternalArtist : public Meta::Artist, public ScriptableSe
                 return i18nc( "The value is not known", "Unknown" );
         }
 
-        QString prettyName() const
+        QString prettyName() const override
         {
             return name();
         }
 
-        virtual bool hasCapabilityInterface( Meta::Capability::Type type ) const
+        bool hasCapabilityInterface( Capabilities::Capability::Type type ) const override
         {
-            return ( type == Meta::Capability::SourceInfo );
+            return ( type == Capabilities::Capability::SourceInfo );
         }
 
-        virtual Meta::Capability* createCapabilityInterface( Meta::Capability::Type type )
+        Capabilities::Capability* createCapabilityInterface( Capabilities::Capability::Type type ) override
         {
-            if ( type == Meta::Capability::SourceInfo )
+            if ( type == Capabilities::Capability::SourceInfo )
                 return new ScriptableServiceInternalSourceInfoCapability( this );
             return 0;
         }
@@ -133,32 +128,32 @@ private:
 class ScriptableServiceInternalAlbum : public Meta::ServiceAlbumWithCover, public ScriptableServiceInternalMetaItem
 {
     public:
-        ScriptableServiceInternalAlbum( const QString &name = QString() )
+        explicit ScriptableServiceInternalAlbum( const QString &name = QString() )
         : Meta::ServiceAlbumWithCover( QString() )
         , m_name( name )
         {}
 
-        bool isCompilation() const
+        bool isCompilation() const override
         {
             return false;
         }
 
-        bool hasAlbumArtist() const
+        bool hasAlbumArtist() const override
         {
             return false;
         }
 
-        Meta::ArtistPtr albumArtist() const
+        Meta::ArtistPtr albumArtist() const override
         {
             return Meta::ArtistPtr();
         }
 
-        Meta::TrackList tracks()
+        Meta::TrackList tracks() override
         {
             return Meta::TrackList();
         }
 
-        QString name() const
+        QString name() const override
         {
             if( !m_name.isEmpty() )
                 return m_name;
@@ -166,25 +161,25 @@ class ScriptableServiceInternalAlbum : public Meta::ServiceAlbumWithCover, publi
                 return i18nc( "The value is not known", "Unknown" );
         }
 
-        QString prettyName() const
+        QString prettyName() const override
         {
             return name();
         }
 
-        virtual QString downloadPrefix() const { return "script"; }
-        virtual void setCoverUrl( const QString &coverUrl ) { m_coverUrl = coverUrl; }
-        virtual QString coverUrl() const { return m_coverUrl; }
+        QString downloadPrefix() const override { return QStringLiteral("script"); }
+        void setCoverUrl( const QString &coverUrl ) override { m_coverUrl = coverUrl; }
+        QString coverUrl() const override { return m_coverUrl; }
 
-        virtual KUrl imageLocation( int size = 1 ) { Q_UNUSED( size ); return KUrl( coverUrl() ); }
+        QUrl imageLocation( int size = 1 ) override { Q_UNUSED( size ); return QUrl( coverUrl() ); }
 
-        virtual bool hasCapabilityInterface( Meta::Capability::Type type ) const
+        bool hasCapabilityInterface( Capabilities::Capability::Type type ) const override
         {
-            return ( type == Meta::Capability::SourceInfo );
+            return ( type == Capabilities::Capability::SourceInfo );
         }
 
-        virtual Meta::Capability* createCapabilityInterface( Meta::Capability::Type type )
+        Capabilities::Capability* createCapabilityInterface( Capabilities::Capability::Type type ) override
         {
-            if ( type == Meta::Capability::SourceInfo )
+            if ( type == Capabilities::Capability::SourceInfo )
                 return new ScriptableServiceInternalSourceInfoCapability( this );
             return 0;
         }
@@ -197,17 +192,17 @@ class ScriptableServiceInternalAlbum : public Meta::ServiceAlbumWithCover, publi
 class ScriptableServiceInternalGenre : public Meta::Genre, public ScriptableServiceInternalMetaItem
 {
     public:
-        ScriptableServiceInternalGenre( const QString &name = QString() )
+        explicit ScriptableServiceInternalGenre( const QString &name = QString() )
         : Meta::Genre()
         , m_name( name )
         {}
 
-        Meta::TrackList tracks()
+        Meta::TrackList tracks() override
         {
             return Meta::TrackList();
         }
 
-        QString name() const
+        QString name() const override
         {
             if( !m_name.isEmpty() )
                 return m_name;
@@ -215,19 +210,19 @@ class ScriptableServiceInternalGenre : public Meta::Genre, public ScriptableServ
                 return i18nc( "The value is not known", "Unknown" );
         }
 
-        QString prettyName() const
+        QString prettyName() const override
         {
             return name();
         }
 
-        virtual bool hasCapabilityInterface( Meta::Capability::Type type ) const
+        bool hasCapabilityInterface( Capabilities::Capability::Type type ) const override
         {
-            return ( type == Meta::Capability::SourceInfo );
+            return ( type == Capabilities::Capability::SourceInfo );
         }
 
-        virtual Meta::Capability* createCapabilityInterface( Meta::Capability::Type type )
+        Capabilities::Capability* createCapabilityInterface( Capabilities::Capability::Type type ) override
         {
-            if ( type == Meta::Capability::SourceInfo )
+            if ( type == Capabilities::Capability::SourceInfo )
                 return new ScriptableServiceInternalSourceInfoCapability( this );
             return 0;
         }
@@ -239,17 +234,17 @@ class ScriptableServiceInternalGenre : public Meta::Genre, public ScriptableServ
 class ScriptableServiceInternalComposer : public Meta::Composer, public ScriptableServiceInternalMetaItem
 {
     public:
-        ScriptableServiceInternalComposer( const QString &name = QString() )
+        explicit ScriptableServiceInternalComposer( const QString &name = QString() )
         : Meta::Composer()
         , m_name( name )
         {}
 
-        Meta::TrackList tracks()
+        Meta::TrackList tracks() override
         {
             return Meta::TrackList();
         }
 
-        QString name() const
+        QString name() const override
         {
 
             if( !m_name.isEmpty() )
@@ -258,19 +253,19 @@ class ScriptableServiceInternalComposer : public Meta::Composer, public Scriptab
                 return i18nc( "The value is not known", "Unknown" );
         }
 
-        QString prettyName() const
+        QString prettyName() const override
         {
             return name();
         }
 
-        virtual bool hasCapabilityInterface( Meta::Capability::Type type ) const
+        bool hasCapabilityInterface( Capabilities::Capability::Type type ) const override
         {
-            return ( type == Meta::Capability::SourceInfo );
+            return ( type == Capabilities::Capability::SourceInfo );
         }
 
-        virtual Meta::Capability* createCapabilityInterface( Meta::Capability::Type type )
+        Capabilities::Capability* createCapabilityInterface( Capabilities::Capability::Type type ) override
         {
-            if ( type == Meta::Capability::SourceInfo )
+            if ( type == Capabilities::Capability::SourceInfo )
                 return new ScriptableServiceInternalSourceInfoCapability( this );
             return 0;
         }
@@ -282,17 +277,17 @@ class ScriptableServiceInternalComposer : public Meta::Composer, public Scriptab
 class ScriptableServiceInternalYear : public Meta::Year, public ScriptableServiceInternalMetaItem
 {
     public:
-        ScriptableServiceInternalYear( const QString &name = QString() )
+        explicit ScriptableServiceInternalYear( const QString &name = QString() )
         : Meta::Year()
         , m_name( name )
         {}
 
-        Meta::TrackList tracks()
+        Meta::TrackList tracks() override
         {
             return Meta::TrackList();
         }
 
-        QString name() const
+        QString name() const override
         {
             if( !m_name.isEmpty() )
                 return m_name;
@@ -300,19 +295,19 @@ class ScriptableServiceInternalYear : public Meta::Year, public ScriptableServic
                 return i18nc( "The value is not known", "Unknown" );
         }
 
-        QString prettyName() const
+        QString prettyName() const override
         {
             return name();
         }
 
-        virtual bool hasCapabilityInterface( Meta::Capability::Type type ) const
+        bool hasCapabilityInterface( Capabilities::Capability::Type type ) const override
         {
-            return ( type == Meta::Capability::SourceInfo );
+            return ( type == Capabilities::Capability::SourceInfo );
         }
 
-        virtual Meta::Capability* createCapabilityInterface( Meta::Capability::Type type )
+        Capabilities::Capability* createCapabilityInterface( Capabilities::Capability::Type type ) override
         {
-            if ( type == Meta::Capability::SourceInfo )
+            if ( type == Capabilities::Capability::SourceInfo )
                 return new ScriptableServiceInternalSourceInfoCapability( this );
             return 0;
         }
