@@ -21,17 +21,16 @@
 #include "core/support/Amarok.h"
 
 #include <KConfigGroup>
-#include <KIcon>
+#include <QIcon>
 #include <KLocalizedString>
 
 #include <QBrush>
-#include <QIcon>
 #include <QPalette>
 
 namespace StatSyncing
 {
     struct ProviderData {
-        ProviderData( QString id_, QString name_, QIcon icon_, bool online_, bool enabled_ )
+        ProviderData( const QString &id_, const QString &name_, const QIcon &icon_, bool online_, bool enabled_ )
             : id( id_ ), name( name_ ), icon( icon_ ), online( online_ ), enabled( enabled_ )
         {}
 
@@ -82,7 +81,7 @@ Config::data( const QModelIndex &index, int role ) const
         {
             if( !provider.icon.isNull() )
                 return provider.icon;
-            return KIcon( provider.online ? "image-missing" : "network-disconnect" );
+            return QIcon::fromTheme( provider.online ? "image-missing" : "network-disconnect" );
         }
         case Qt::CheckStateRole:
             return provider.enabled ? Qt::Checked : Qt::Unchecked;
@@ -118,7 +117,7 @@ Config::setData( const QModelIndex &index, const QVariant &value, int role )
     Qt::CheckState state = Qt::CheckState( value.toInt() );
     m_providerData[ index.row() ].enabled = ( state == Qt::Checked ) ? true : false;
     m_hasChanged = true;
-    emit dataChanged( index, index );
+    Q_EMIT dataChanged( index, index );
     return true;
 }
 
@@ -149,7 +148,7 @@ Config::updateProvider( const QString &id, const QString &name, const QIcon &ico
         {
             m_providerData[ i ] = providerData;
             m_hasChanged = true;
-            emit dataChanged( index( i ), index( i ) );
+            Q_EMIT dataChanged( index( i ), index( i ) );
             return;
         }
     }
@@ -181,7 +180,7 @@ Config::forgetProvider( const QString &id )
             it.remove();
             m_hasChanged = true;
             endRemoveRows();
-            emit providerForgotten( id );
+            Q_EMIT providerForgotten( id );
             return true;
         }
         i++;
@@ -268,7 +267,7 @@ Config::hasChanged() const
 void
 Config::read()
 {
-    KConfigGroup group = Amarok::config( "StatSyncing" );
+    KConfigGroup group = Amarok::config( QStringLiteral("StatSyncing") );
 
     QStringList providerIds = group.readEntry( "providerIds", QStringList() );
     QStringList providerNames = group.readEntry( "providerNames", QStringList() );
@@ -288,8 +287,8 @@ Config::read()
     endResetModel();
 
     m_checkedFields = 0;
-    QStringList fieldNames = group.readEntry( "checkedFields", QStringList( "FIRST" ) );
-    if( fieldNames == QStringList( "FIRST" ) )
+    QStringList fieldNames = group.readEntry( "checkedFields", QStringList( QStringLiteral("FIRST") ) );
+    if( fieldNames == QStringList( QStringLiteral("FIRST") ) )
         m_checkedFields = Meta::valRating | Meta::valFirstPlayed | Meta::valLastPlayed |
                           Meta::valPlaycount | Meta::valLabel;
     else
@@ -316,7 +315,7 @@ Config::save()
         providerEnabledStatuses << data.enabled;
     }
 
-    KConfigGroup group = Amarok::config( "StatSyncing" );
+    KConfigGroup group = Amarok::config( QStringLiteral("StatSyncing") );
     group.writeEntry( "providerIds", providerIds );
     group.writeEntry( "providerNames", providerNames );
     group.writeEntry( "providerEnabledStatuses", providerEnabledStatuses );
