@@ -18,18 +18,20 @@
 
 #include "core/support/Debug.h"
 
-#include <KIcon>
-#include <KLocale>
+#include <QIcon>
+#include <QMutexLocker>
+
+#include <KLocalizedString>
 
-#include <QLayout>
 
 CompoundProgressBar::CompoundProgressBar( QWidget *parent )
         : ProgressBar( parent )
+        , m_mutex( QMutex::Recursive )
 {
-    m_progressDetailsWidget = new PopupWidget( parent );
+    m_progressDetailsWidget = new PopupWidget();
     m_progressDetailsWidget->hide();
 
-    connect( cancelButton(), SIGNAL( clicked() ), this, SLOT( cancelAll() ) );
+    connect( cancelButton(), &QAbstractButton::clicked, this, &CompoundProgressBar::cancelAll );
 }
 
 CompoundProgressBar::~CompoundProgressBar()
@@ -40,6 +42,8 @@ CompoundProgressBar::~CompoundProgressBar()
 
 void CompoundProgressBar::addProgressBar( ProgressBar *childBar, QObject *owner )
 {
+    QMutexLocker locker( &m_mutex );
+
     m_progressMap.insert( owner, childBar );
     m_progressDetailsWidget->layout()->addWidget( childBar );
     if( m_progressDetailsWidget->width() < childBar->width() )
@@ -49,13 +53,13 @@ void CompoundProgressBar::addProgressBar( ProgressBar *childBar, QObject *owner
 
     m_progressDetailsWidget->reposition();
 
-    connect( childBar, SIGNAL( percentageChanged( int ) ),
-            SLOT( childPercentageChanged() ) );
-    connect( childBar, SIGNAL( cancelled( ProgressBar * ) ),
-            SLOT( childBarCancelled( ProgressBar * ) ) );
-    connect( childBar, SIGNAL( complete( ProgressBar * ) ),
-            SLOT( childBarComplete( ProgressBar * ) ) );
-    connect( owner, SIGNAL( destroyed( QObject * ) ), SLOT( slotObjectDestroyed( QObject * ) ) );
+    connect( childBar, &ProgressBar::percentageChanged,
+             this, &CompoundProgressBar::childPercentageChanged );
+    connect( childBar, &ProgressBar::cancelled,
+             this, &CompoundProgressBar::childBarCancelled );
+    connect( childBar, &ProgressBar::complete,
+             this, &CompoundProgressBar::childBarComplete );
+    connect( owner, &QObject::destroyed, this, &CompoundProgressBar::slotObjectDestroyed );
 
     if( m_progressMap.count() == 1 )
     {
@@ -73,6 +77,8 @@ void CompoundProgressBar::addProgressBar( ProgressBar *childBar, QObject *owner
 
 void CompoundProgressBar::endProgressOperation( QObject *owner )
 {
+    QMutexLocker locker( &m_mutex );
+
     if( !m_progressMap.contains( owner ) )
         return ;
 
@@ -87,6 +93,8 @@ CompoundProgressBar::slotIncrementProgress()
 
 void CompoundProgressBar::incrementProgress( const QObject *owner )
 {
+    QMutexLocker locker( &m_mutex );
+
     if( !m_progressMap.contains( owner ) )
         return ;
 
@@ -95,6 +103,8 @@ void CompoundProgressBar::incrementProgress( const QObject *owner )
 
 void CompoundProgressBar::setProgress( const QObject *owner, int steps )
 {
+    QMutexLocker locker( &m_mutex );
+
     if( !m_progressMap.contains( owner ) )
         return ;
 
@@ -104,6 +114,8 @@ void CompoundProgressBar::setProgress( const QObject *owner, int steps )
 void
 CompoundProgressBar::mousePressEvent( QMouseEvent *event )
 {
+    QMutexLocker locker( &m_mutex );
+
     if( m_progressDetailsWidget->isHidden() )
     {
         if( m_progressMap.count() )
@@ -119,24 +131,18 @@ CompoundProgressBar::mousePressEvent( QMouseEvent *event )
 
 void CompoundProgressBar::setProgressTotalSteps( const QObject *owner, int value )
 {
+    QMutexLocker locker( &m_mutex );
+
     if( !m_progressMap.contains( owner ) )
         return ;
 
     m_progressMap.value( owner )->setMaximum( value );
 }
 
-void CompoundProgressBar::setParent( QWidget *parent )
-{
-    delete m_progressDetailsWidget;
-    m_progressDetailsWidget = new PopupWidget( parent );
-    m_progressDetailsWidget->hide();
-
-    ProgressBar::setParent( parent );
-}
-
-
 void CompoundProgressBar::setProgressStatus( const QObject *owner, const QString &text )
 {
+    QMutexLocker locker( &m_mutex );
+
     if( !m_progressMap.contains( owner ) )
         return ;
 
@@ -160,6 +166,8 @@ void CompoundProgressBar::childBarComplete( ProgressBar *childBar )
 
 void CompoundProgressBar::slotObjectDestroyed( QObject *object )
 {
+    QMutexLocker locker( &m_mutex );
+
     if( m_progressMap.contains( object ) )
     {
         childBarFinished( m_progressMap.value( object ) );
@@ -168,6 +176,8 @@ void CompoundProgressBar::slotObjectDestroyed( QObject *object )
 
 void CompoundProgressBar::childBarFinished( ProgressBar *bar )
 {
+    QMutexLocker locker( &m_mutex );
+
     QObject *owner = const_cast<QObject *>( m_progressMap.key( bar ) );
     owner->disconnect( this );
     owner->disconnect( bar );
@@ -190,7 +200,7 @@ void CompoundProgressBar::childBarFinished( ProgressBar *bar )
     {
         progressBar()->setValue( 0 );
         hideDetails();
-        emit( allDone() );
+        Q_EMIT( allDone() );
         return;
     }
     else
@@ -204,6 +214,8 @@ void CompoundProgressBar::childBarFinished( ProgressBar *bar )
 
 int CompoundProgressBar::calcCompoundPercentage()
 {
+    QMutexLocker locker( &m_mutex );
+
     int count = m_progressMap.count();
     int total = 0;
 
@@ -215,12 +227,16 @@ int CompoundProgressBar::calcCompoundPercentage()
 
 void CompoundProgressBar::cancelAll()
 {
+    QMutexLocker locker( &m_mutex );
+
     foreach( ProgressBar *currentBar, m_progressMap )
         currentBar->cancel();
 }
 
 void CompoundProgressBar::showDetails()
 {
+    QMutexLocker locker( &m_mutex );
+
     m_progressDetailsWidget->raise();
 
     //Hack to make sure it has the right height first time it is shown...
