@@ -25,7 +25,7 @@ class AnimatedLabelStack : public QWidget
     Q_OBJECT
 
 public:
-    explicit AnimatedLabelStack( const QStringList &data, QWidget *parent = 0, Qt::WindowFlags f = 0 );
+    explicit AnimatedLabelStack( const QStringList &data, QWidget *parent = nullptr, Qt::WindowFlags f = {} );
     inline const QStringList &data() const { return m_data; }
     inline int opacity() { return m_targetOpacity; }
     void pulse( int cycles = -1, int minimum = 3 );
@@ -39,24 +39,24 @@ public:
     */
     inline QRect textRect() const { return rect().adjusted( m_padding[0], 0, -m_padding[1], 0 ); }
 
-public slots:
+public Q_SLOTS:
     void setAnimated( bool on = true );
     inline void setStill( bool off = true ) { setAnimated( !off ); }
 
-signals:
+Q_SIGNALS:
     void pulsing( bool );
     void clicked( const QString &current );
 
 protected:
-    void enterEvent( QEvent * );
-    void hideEvent( QHideEvent * );
-    void leaveEvent( QEvent * );
-    void paintEvent( QPaintEvent * );
-    void mouseReleaseEvent( QMouseEvent * );
-    void mousePressEvent( QMouseEvent * );
-    void showEvent( QShowEvent * );
-    void timerEvent( QTimerEvent * );
-    void wheelEvent( QWheelEvent * );
+    void enterEvent( QEvent * ) override;
+    void hideEvent( QHideEvent * ) override;
+    void leaveEvent( QEvent * ) override;
+    void paintEvent( QPaintEvent * ) override;
+    void mouseReleaseEvent( QMouseEvent * ) override;
+    void mousePressEvent( QMouseEvent * ) override;
+    void showEvent( QShowEvent * ) override;
+    void timerEvent( QTimerEvent * ) override;
+    void wheelEvent( QWheelEvent * ) override;
 
 private:
     void ensureAnimationStatus();
@@ -64,7 +64,7 @@ private:
     void sleep( int ms );
     void wakeUp();
 
-private slots:
+private Q_SLOTS:
     void activateOnEnter();
 
 private:
