@@ -27,14 +27,14 @@
 #include "core/meta/support/MetaUtility.h"
 #include "core/support/Debug.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 
 #include <QMenu>
 #include <QPainter>
 #include <QSize>
 #include <QSizePolicy>
 
-BookmarkTriangle::BookmarkTriangle ( QWidget *parent, int milliseconds, QString name,
+BookmarkTriangle::BookmarkTriangle (QWidget *parent, int milliseconds, const QString &name,
                                      int sliderwidth, bool showPopup )
     : QWidget ( parent ),
     m_mseconds ( milliseconds ),
@@ -109,7 +109,7 @@ void BookmarkTriangle::mouseReleaseEvent ( QMouseEvent * event )
     event->accept();
 
     if( this->x() == m_pos ){
-        emit clicked ( m_mseconds );
+        Q_EMIT clicked ( m_mseconds );
     }
     else
     {
@@ -127,7 +127,7 @@ void BookmarkTriangle::mouseReleaseEvent ( QMouseEvent * event )
     }
 }
 
-void BookmarkTriangle::moveBookmark ( qint64 newMilliseconds, QString name )
+void BookmarkTriangle::moveBookmark ( qint64 newMilliseconds, const QString &name )
 {
     hidePopup();
     Meta::TrackPtr track = The::engineController()->currentTrack();
@@ -149,7 +149,7 @@ void BookmarkTriangle::enterEvent ( QEvent * event )
     DEBUG_BLOCK
     Q_UNUSED ( event )
 
-    emit focused ( m_mseconds );
+    Q_EMIT focused ( m_mseconds );
     initPopup();
 }
 
@@ -184,5 +184,4 @@ void BookmarkTriangle::hidePopup()
 {
     if ( m_tooltip )  m_tooltip->hide();
 }
-#include "BookmarkTriangle.moc"
 
