@@ -122,10 +122,9 @@ void ElidingButton::elideText( const QSize &widgetSize )
     if( m_isElided != elided )
     {
         m_isElided = elided;
-        emit( sizePolicyChanged() );
+        Q_EMIT( sizePolicyChanged() );
     }
 }
 
 }
 
-#include "ElidingButton.moc"
