@@ -36,11 +36,8 @@
 #include <QListView>
 #include <QTimeEdit>
 
-#include <KComboBox>
-#include <KIcon>
-#include <KLocale>
-#include <klocalizeddate.h>
-#include <KNumInput>
+#include <QIcon>
+#include <KLocalizedString>
 #include <KRatingWidget>
 
 using namespace Amarok;
@@ -50,12 +47,13 @@ static const int maxHours = 24;
 TimeDistanceWidget::TimeDistanceWidget( QWidget *parent )
     : QWidget( parent )
 {
-    m_timeEdit = new KIntSpinBox(this);
+    m_timeEdit = new QSpinBox(this);
     m_timeEdit->setMinimum( 0 );
     m_timeEdit->setMaximum( 600 );
 
-    m_unitSelection = new KComboBox(this);
-    connect( m_timeEdit, SIGNAL(valueChanged(int)), this, SLOT(slotUpdateComboBoxLabels(int)) );
+    m_unitSelection = new QComboBox(this);
+    connect( m_timeEdit, QOverload<int>::of(&QSpinBox::valueChanged),
+             this, &TimeDistanceWidget::slotUpdateComboBoxLabels );
     for (int i = 0; i < 7; ++i) {
         m_unitSelection->addItem( QString() );
     }
@@ -97,7 +95,7 @@ qint64 TimeDistanceWidget::timeDistance() const
 
 void TimeDistanceWidget::setTimeDistance( qint64 value )
 {
-    // as we don't store the time unit we try to reconstuct it
+    // as we don't store the time unit we try to reconstruct it
     int unit = 0;
     if( value > 600 || !(value % 60) ) {
         unit = 1;
@@ -129,13 +127,6 @@ void TimeDistanceWidget::setTimeDistance( qint64 value )
     m_timeEdit->setValue( value );
 }
 
-void TimeDistanceWidget::connectChanged( QObject *receiver, const char *slot )
-{
-    connect( m_timeEdit, SIGNAL(valueChanged(QString)), receiver, slot );
-    connect( m_unitSelection, SIGNAL(currentIndexChanged(int)), receiver, slot );
-}
-
-
 void TimeDistanceWidget::slotUpdateComboBoxLabels( int value )
 {
     m_unitSelection->setItemText(0, i18np("second", "seconds", value));
@@ -164,8 +155,8 @@ MetaQueryWidget::Filter::setField( qint64 newField )
     }
     if( !MetaQueryWidget::isDate( m_field ) && MetaQueryWidget::isDate( newField ) )
     {
-        numValue = QDateTime::currentDateTime().toTime_t();
-        numValue2 = QDateTime::currentDateTime().toTime_t();
+        numValue = QDateTime::currentDateTimeUtc().toSecsSinceEpoch();
+        numValue2 = QDateTime::currentDateTimeUtc().toSecsSinceEpoch();
     }
     else
     {
@@ -307,23 +298,23 @@ MetaQueryWidget::setFilter( const MetaQueryWidget::Filter &value )
     setValueSelection();
 
     m_settingFilter = false;
-    emit changed(m_filter);
+    Q_EMIT changed(m_filter);
 }
 
-static void addIconItem( KComboBox *box, qint64 field )
+static void addIconItem( QComboBox *box, qint64 field )
 {
     QString icon = Meta::iconForField( field );
     QString text = Meta::i18nForField( field );
     if( icon.isEmpty() )
         box->addItem( text, field );
     else
-        box->addItem( KIcon( icon ), text, field );
+        box->addItem( QIcon::fromTheme( icon ), text, field );
 }
 
 void
 MetaQueryWidget::makeFieldSelection()
 {
-    m_fieldSelection = new KComboBox( this );
+    m_fieldSelection = new QComboBox( this );
     if (!m_onlyNumeric)
     {
         m_fieldSelection->addItem( i18n( "Simple Search" ), 0 );
@@ -357,7 +348,8 @@ MetaQueryWidget::makeFieldSelection()
     if (!m_onlyNumeric)
         addIconItem( m_fieldSelection, Meta::valLabel );
     addIconItem( m_fieldSelection, Meta::valModified );
-    connect( m_fieldSelection, SIGNAL(currentIndexChanged(int)), this, SLOT(fieldChanged(int)) );
+    connect( m_fieldSelection, QOverload<int>::of(&QComboBox::currentIndexChanged),
+             this, &MetaQueryWidget::fieldChanged );
 }
 
 void
@@ -383,7 +375,7 @@ MetaQueryWidget::fieldChanged( int i )
 
     setValueSelection();
 
-    emit changed(m_filter);
+    Q_EMIT changed(m_filter);
 }
 
 void
@@ -400,10 +392,10 @@ MetaQueryWidget::compareChanged( int index )
             && m_filter.condition != OlderThan && m_filter.condition != NewerThan
           )
         {
-            // fix some inaccuracies caused by the conversion absoulte/relative time specifications
+            // fix some inaccuracies caused by the conversion absolute/relative time specifications
             // this is actually just for visual consistency
             int unit = 0;
-            qint64 value = QDateTime::currentDateTime().toTime_t() - m_filter.numValue;
+            qint64 value = QDateTime::currentDateTimeUtc().toSecsSinceEpoch() - m_filter.numValue;
             if( value > 600 || !(value % 60) ) {
                 unit = 1;
                 value /= 60;
@@ -456,7 +448,7 @@ MetaQueryWidget::compareChanged( int index )
             && ( m_filter.condition == OlderThan || m_filter.condition == NewerThan )
           )
         {
-            m_filter.numValue = QDateTime::currentDateTime().toTime_t() - m_filter.numValue;
+            m_filter.numValue = QDateTime::currentDateTimeUtc().toSecsSinceEpoch() - m_filter.numValue;
         }
     }
 
@@ -467,7 +459,7 @@ MetaQueryWidget::compareChanged( int index )
 
     setValueSelection();
 
-    emit changed(m_filter);
+    Q_EMIT changed(m_filter);
 }
 
 void
@@ -475,7 +467,7 @@ MetaQueryWidget::valueChanged( const QString& value )
 {
     m_filter.value = value;
 
-    emit changed(m_filter);
+    Q_EMIT changed(m_filter);
 }
 
 void
@@ -483,7 +475,7 @@ MetaQueryWidget::numValueChanged( int value )
 {
     m_filter.numValue = value;
 
-    emit changed(m_filter);
+    Q_EMIT changed(m_filter);
 }
 
 void
@@ -491,7 +483,7 @@ MetaQueryWidget::numValue2Changed( int value )
 {
     m_filter.numValue2 = value;
 
-    emit changed(m_filter);
+    Q_EMIT changed(m_filter);
 }
 
 void
@@ -499,7 +491,7 @@ MetaQueryWidget::numValueChanged( qint64 value )
 {
     m_filter.numValue = value;
 
-    emit changed(m_filter);
+    Q_EMIT changed(m_filter);
 }
 
 void
@@ -507,7 +499,7 @@ MetaQueryWidget::numValue2Changed( qint64 value )
 {
     m_filter.numValue2 = value;
 
-    emit changed(m_filter);
+    Q_EMIT changed(m_filter);
 }
 
 void
@@ -515,7 +507,7 @@ MetaQueryWidget::numValueChanged( const QTime& value )
 {
     m_filter.numValue = qAbs( value.secsTo( QTime(0,0,0) ) );
 
-    emit changed(m_filter);
+    Q_EMIT changed(m_filter);
 }
 
 void
@@ -523,7 +515,7 @@ MetaQueryWidget::numValue2Changed( const QTime& value )
 {
     m_filter.numValue2 = qAbs( value.secsTo( QTime(0,0,0) ) );
 
-    emit changed(m_filter);
+    Q_EMIT changed(m_filter);
 }
 
 void
@@ -534,9 +526,9 @@ MetaQueryWidget::numValueDateChanged()
     {
         QDate date;
         dateSelection->getDate( &date );
-        m_filter.numValue = QDateTime( date ).toTime_t();
+        m_filter.numValue = QDateTime( date ).toSecsSinceEpoch();
 
-        emit changed(m_filter);
+        Q_EMIT changed(m_filter);
     }
 }
 
@@ -548,9 +540,9 @@ MetaQueryWidget::numValue2DateChanged()
     {
         QDate date;
         dateSelection->getDate( &date );
-        m_filter.numValue2 = QDateTime( date ).toTime_t();
+        m_filter.numValue2 = QDateTime( date ).toSecsSinceEpoch();
 
-        emit changed(m_filter);
+        Q_EMIT changed(m_filter);
     }
 }
 
@@ -566,18 +558,18 @@ MetaQueryWidget::numValueTimeDistanceChanged()
     {
         m_filter.numValue = distanceSelection->timeDistance();
 
-        emit changed(m_filter);
+        Q_EMIT changed(m_filter);
     }
 }
 
 void
 MetaQueryWidget::numValueFormatChanged(int index)
 {
-    KComboBox* combo = static_cast<KComboBox*>(sender());
+    QComboBox* combo = static_cast<QComboBox*>(sender());
     if( combo ) {
         m_filter.numValue = combo->itemData( index ).toInt();
 
-        emit changed(m_filter);
+        Q_EMIT changed(m_filter);
     }
 }
 
@@ -620,7 +612,7 @@ MetaQueryWidget::makeCompareSelection()
 
     else if( isDate(field) )
     {
-        m_compareSelection = new KComboBox();
+        m_compareSelection = new QComboBox();
         m_compareSelection->addItem( conditionToString( Equals, field ), (int)Equals );
         m_compareSelection->addItem( conditionToString( LessThan, field ), (int)LessThan );
         m_compareSelection->addItem( conditionToString( GreaterThan, field ), (int)GreaterThan );
@@ -630,7 +622,7 @@ MetaQueryWidget::makeCompareSelection()
     }
     else if( isNumeric(field) )
     {
-        m_compareSelection = new KComboBox();
+        m_compareSelection = new QComboBox();
         m_compareSelection->addItem( conditionToString( Equals, field ), (int)Equals );
         m_compareSelection->addItem( conditionToString( LessThan, field ), (int)LessThan );
         m_compareSelection->addItem( conditionToString( GreaterThan, field ), (int)GreaterThan );
@@ -638,7 +630,7 @@ MetaQueryWidget::makeCompareSelection()
     }
     else
     {
-        m_compareSelection = new KComboBox();
+        m_compareSelection = new QComboBox();
         m_compareSelection->addItem( conditionToString( Contains, field ), (int)Contains );
         m_compareSelection->addItem( conditionToString( Equals, field ), (int)Equals );
     }
@@ -653,8 +645,8 @@ MetaQueryWidget::makeCompareSelection()
     }
     m_compareSelection->setCurrentIndex( index == -1 ? 0 : index );
 
-    connect( m_compareSelection, SIGNAL(currentIndexChanged(int)),
-            SLOT(compareChanged(int)) );
+    connect( m_compareSelection, QOverload<int>::of(&QComboBox::currentIndexChanged),
+             this, &MetaQueryWidget::compareChanged );
 }
 
 void
@@ -725,22 +717,22 @@ MetaQueryWidget::makeGenericComboSelection( bool editable, Collections::QueryMak
 
     if( populateQuery != 0 )
     {
-        m_runningQueries.insert(populateQuery, QWeakPointer<KComboBox>(combo));
-        connect( populateQuery, SIGNAL(newResultReady(QStringList)),
-                SLOT(populateComboBox(QStringList)) );
-        connect( populateQuery, SIGNAL(queryDone()),
-                SLOT(comboBoxPopulated()) );
+        m_runningQueries.insert(populateQuery, QPointer<KComboBox>(combo));
+        connect( populateQuery, &Collections::QueryMaker::newResultReady,
+                 this, &MetaQueryWidget::populateComboBox );
+        connect( populateQuery, &Collections::QueryMaker::queryDone,
+                 this, &MetaQueryWidget::comboBoxPopulated );
 
         populateQuery->run();
     }
     combo->setEditText( m_filter.value );
 
-    connect( combo, SIGNAL(editTextChanged(QString)),
-            SLOT(valueChanged(QString)) );
+    connect( combo, &KComboBox::editTextChanged,
+             this, &MetaQueryWidget::valueChanged );
 
     combo->completionObject()->setIgnoreCase( true );
-    combo->setCompletionMode( KGlobalSettings::CompletionPopup );
-    combo->setInsertPolicy( QComboBox::InsertAtTop );
+    combo->setCompletionMode( KCompletion::CompletionPopup );
+    combo->setInsertPolicy( KComboBox::InsertAtTop );
     m_valueSelection1 = combo;
 }
 
@@ -755,13 +747,13 @@ MetaQueryWidget::makeMetaComboSelection( qint64 field )
 }
 
 void
-MetaQueryWidget::populateComboBox( QStringList results )
+MetaQueryWidget::populateComboBox( const QStringList &results )
 {
     QObject* query = sender();
     if( !query )
         return;
 
-    QWeakPointer<KComboBox> combo = m_runningQueries.value(query);
+    QPointer<KComboBox> combo = m_runningQueries.value(query);
     if( combo.isNull() )
         return;
 
@@ -773,21 +765,21 @@ MetaQueryWidget::populateComboBox( QStringList results )
     const QSet<QString> dataSet = results.toSet();
     QStringList dataList = dataSet.toList();
     dataList.sort();
-    combo.data()->addItems( dataList );
+    combo->addItems( dataList );
 
-    KCompletion* comp = combo.data()->completionObject();
+    KCompletion* comp = combo->completionObject();
     comp->setItems( dataList );
 
     // reset the text and re-enable the signal
     combo.data()->setEditText( m_filter.value );
-    connect( combo.data(), SIGNAL(editTextChanged(QString)),
-            SLOT(valueChanged(QString)) );
+    connect( combo.data(), &QComboBox::editTextChanged,
+             this, &MetaQueryWidget::valueChanged );
 }
 
 void
 MetaQueryWidget::makeFormatComboSelection()
 {
-    KComboBox* combo = new KComboBox( this );
+    QComboBox* combo = new QComboBox( this );
     combo->setSizePolicy( QSizePolicy::Ignored, QSizePolicy::Preferred );
     QStringList filetypes = Amarok::FileTypeSupport::possibleFileTypes();
     for (int listpos=0;listpos<filetypes.size();listpos++)
@@ -798,9 +790,8 @@ MetaQueryWidget::makeFormatComboSelection()
     int index = m_fieldSelection->findData( (int)m_filter.numValue );
     combo->setCurrentIndex( index == -1 ? 0 : index );
 
-    connect( combo,
-             SIGNAL(currentIndexChanged(int)),
-             SLOT(numValueFormatChanged(int)) );
+    connect( combo, QOverload<int>::of(&QComboBox::currentIndexChanged),
+             this, &MetaQueryWidget::numValueFormatChanged );
 
     m_valueSelection1 = combo;
 }
@@ -828,8 +819,8 @@ MetaQueryWidget::makeRatingSelection()
 {
     KRatingWidget* ratingWidget = new KRatingWidget();
     ratingWidget->setRating( (int)m_filter.numValue );
-    connect( ratingWidget, SIGNAL(ratingChanged(int)),
-             this, SLOT(numValueChanged(int)) );
+    connect( ratingWidget, QOverload<int>::of(&KRatingWidget::ratingChanged),
+             this, QOverload<int>::of(&MetaQueryWidget::numValueChanged) );
 
     m_valueSelection1 = ratingWidget;
 
@@ -839,8 +830,8 @@ MetaQueryWidget::makeRatingSelection()
     // second KRatingWidget for the between selection
     KRatingWidget* ratingWidget2 = new KRatingWidget();
     ratingWidget2->setRating( (int)m_filter.numValue2 );
-    connect( ratingWidget2, SIGNAL(ratingChanged(int)),
-             this, SLOT(numValue2Changed(int)) );
+    connect( ratingWidget2, QOverload<int>::of(&KRatingWidget::ratingChanged),
+             this, QOverload<int>::of(&MetaQueryWidget::numValue2Changed) );
 
     m_valueSelection2 = ratingWidget2;
 }
@@ -854,10 +845,10 @@ MetaQueryWidget::makeLengthSelection()
     timeSpin->setDisplayFormat( displayFormat );
     timeSpin->setMinimumTime( QTime( 0, 0, 0 ) );
     timeSpin->setMaximumTime( QTime( maxHours - 1, 59, 59 ) );
-    timeSpin->setTime( QTime().addSecs( m_filter.numValue ) );
+    timeSpin->setTime( QTime(0, 0, 0).addSecs( m_filter.numValue ) );
 
-    connect( timeSpin, SIGNAL(timeChanged(QTime)),
-            SLOT(numValueChanged(QTime)) );
+    connect( timeSpin, &QTimeEdit::timeChanged,
+             this, QOverload<const QTime&>::of(&MetaQueryWidget::numValueChanged) );
 
     m_valueSelection1 = timeSpin;
 
@@ -868,10 +859,10 @@ MetaQueryWidget::makeLengthSelection()
     timeSpin2->setDisplayFormat( displayFormat );
     timeSpin2->setMinimumTime( QTime( 0, 0, 0 ) );
     timeSpin2->setMaximumTime( QTime( maxHours - 1, 59, 59 ) );
-    timeSpin2->setTime( QTime().addSecs( m_filter.numValue2 ) );
+    timeSpin2->setTime( QTime(0, 0, 0).addSecs( m_filter.numValue2 ) );
 
-    connect( timeSpin2, SIGNAL(timeChanged(QTime)),
-            SLOT(numValue2Changed(QTime)) );
+    connect( timeSpin2, &QTimeEdit::timeChanged,
+             this, QOverload<const QTime&>::of(&MetaQueryWidget::numValue2Changed) );
 
     m_valueSelection2 = timeSpin2;
 }
@@ -879,15 +870,15 @@ MetaQueryWidget::makeLengthSelection()
 void
 MetaQueryWidget::makeGenericNumberSelection( qint64 field, const QString& unit )
 {
-    KIntSpinBox* spin = new KIntSpinBox();
+    QSpinBox* spin = new QSpinBox();
     spin->setMinimum( Filter::minimumValue( field ) );
     spin->setMaximum( Filter::maximumValue( field ) );
     if( !unit.isEmpty() )
         spin->setSuffix( ' ' + unit );
     spin->setValue( m_filter.numValue );
 
-    connect( spin, SIGNAL(valueChanged(int)),
-            this, SLOT(numValueChanged(int)) );
+    connect( spin, QOverload<int>::of(&QSpinBox::valueChanged),
+             this, QOverload<int>::of(&MetaQueryWidget::numValueChanged) );
 
     m_valueSelection1 = spin;
 
@@ -895,15 +886,15 @@ MetaQueryWidget::makeGenericNumberSelection( qint64 field, const QString& unit )
         return;
 
     // second spin box for the between selection
-    KIntSpinBox* spin2 = new KIntSpinBox();
+    QSpinBox* spin2 = new QSpinBox();
     spin2->setMinimum( Filter::minimumValue( field ) );
     spin2->setMaximum( Filter::maximumValue( field ) );
     if( !unit.isEmpty() )
         spin2->setSuffix( ' ' + unit );
     spin2->setValue( m_filter.numValue2 );
 
-    connect( spin2, SIGNAL(valueChanged(int)),
-            this, SLOT(numValue2Changed(int)) );
+    connect( spin2, QOverload<int>::of(&QSpinBox::valueChanged),
+             this, QOverload<int>::of(&MetaQueryWidget::numValue2Changed) );
 
     m_valueSelection2 = spin2;
 }
@@ -917,7 +908,7 @@ MetaQueryWidget::makeDateTimeSelection()
         TimeDistanceWidget* distanceSelection = new TimeDistanceWidget();
         distanceSelection->setTimeDistance( m_filter.numValue );
 
-        distanceSelection->connectChanged( this, SLOT(numValueTimeDistanceChanged()));
+        distanceSelection->connectChanged( this, &MetaQueryWidget::numValueTimeDistanceChanged);
 
         m_valueSelection1 = distanceSelection;
     }
@@ -928,12 +919,12 @@ MetaQueryWidget::makeDateTimeSelection()
 //         if( m_filter.condition == Contains || m_filter.condition == Equals )
 //             dt = QDateTime::currentDateTime();
 //         else
-//             dt.setTime_t( m_filter.numValue );
-        dt.setTime_t( m_filter.numValue );
+//             dt.setSecsSinceEpoch( m_filter.numValue );
+        dt.setSecsSinceEpoch( m_filter.numValue );
         dateSelection->setDate( dt.date() );
 
-        connect( dateSelection, SIGNAL(currentIndexChanged(int)),
-                SLOT(numValueDateChanged()) );
+        connect( dateSelection, QOverload<int>::of(&KDateCombo::currentIndexChanged),
+                 this, &MetaQueryWidget::numValueDateChanged );
 
         m_valueSelection1 = dateSelection;
 
@@ -942,11 +933,11 @@ MetaQueryWidget::makeDateTimeSelection()
 
         // second KDateCombo for the between selection
         KDateCombo* dateSelection2 = new KDateCombo();
-        dt.setTime_t( m_filter.numValue2 );
+        dt.setSecsSinceEpoch( m_filter.numValue2 );
         dateSelection2->setDate( dt.date() );
 
-        connect( dateSelection2, SIGNAL(currentIndexChanged(int)),
-                SLOT(numValue2DateChanged()) );
+        connect( dateSelection2, QOverload<int>::of(&KDateCombo::currentIndexChanged),
+                 this, &MetaQueryWidget::numValue2DateChanged );
 
         m_valueSelection2 = dateSelection2;
     }
@@ -1046,7 +1037,7 @@ MetaQueryWidget::conditionToString( FilterCondition condition, qint64 field )
             ; // fall through
         }
     }
-    return QString( i18n("unknown comparison") );
+    return i18n("unknown comparison");
 }
 
 QString
@@ -1079,10 +1070,8 @@ QString MetaQueryWidget::Filter::toString( bool invert ) const
         }
         else
         {
-            KLocalizedDate localizedDate1( QDateTime::fromTime_t(numValue).date() );
-            strValue1 = localizedDate1.formatDate( KLocale::ShortDate );
-            KLocalizedDate localizedDate2( QDateTime::fromTime_t(numValue2).date() );
-            strValue2 = localizedDate2.formatDate( KLocale::ShortDate );
+            strValue1 = QLocale().toString( QDateTime::fromSecsSinceEpoch(numValue).date(), QLocale::ShortFormat );
+            strValue2 = QLocale().toString( QDateTime::fromSecsSinceEpoch(numValue2).date(), QLocale::ShortFormat );
         }
     }
     else if( isNumeric() )
@@ -1216,6 +1205,3 @@ MetaQueryWidget::setField( const qint64 field )
     int index = m_fieldSelection->findData( field );
     m_fieldSelection->setCurrentIndex( index == -1 ? 0 : index );
 }
-
-#include "MetaQueryWidget.moc"
-
