@@ -34,10 +34,11 @@
 #include "core/support/Debug.h"
 #include "widgets/StarManager.h"
 
-#include <KApplication>
-#include <KIcon>
-#include <KLocale>
+#include <QApplication>
+#include <QIcon>
+#include <KLocalizedString>
 #include <KWindowSystem>
+#include <KIconLoader>
 
 #include <QDesktopWidget>
 #include <QMouseEvent>
@@ -90,13 +91,13 @@ OSDWidget::OSDWidget( QWidget *parent, const char *name )
     #endif
 
     m_timer->setSingleShot( true );
-    connect( m_timer, SIGNAL(timeout()), SLOT(hide()) );
+    connect( m_timer, &QTimer::timeout, this, &OSDWidget::hide );
 
     m_fadeTimeLine->setUpdateInterval( 30 ); //~33 frames per second 
-    connect( m_fadeTimeLine, SIGNAL(valueChanged(qreal)), SLOT(setFadeOpacity(qreal)) );
+    connect( m_fadeTimeLine, &QTimeLine::valueChanged, this, &OSDWidget::setFadeOpacity );
 
     //or crashes, KWindowSystem bug I think, crashes in QWidget::icon()
-    kapp->setTopWidget( this );
+    //kapp->setTopWidget( this );
 }
 
 OSDWidget::~OSDWidget()
@@ -184,7 +185,7 @@ OSDWidget::ratingChanged( const QString& path, int rating )
 void
 OSDWidget::ratingChanged( const short rating )
 {
-    m_text = '\n' + i18n( "Rating changed" );
+    m_text = QLatin1Char('\n') + i18n( "Rating changed" );
     setRating( rating ); //Checks isEnabled() before doing anything
 
     show();
@@ -198,8 +199,7 @@ OSDWidget::volumeChanged( int volume )
     if ( isEnabled() )
     {
         m_showVolume = true;
-        const KLocalizedString text = The::engineController()->isMuted() ? ki18n( "Volume: %1% (muted)" ) : ki18n( "Volume: %1%" );
-        m_text = text.subs( m_volume ).toString();
+        m_text = The::engineController()->isMuted() ? i18n( "Volume: %1% (muted)", m_volume) : i18n( "Volume: %1%", m_volume);
 
         show();
     }
@@ -326,7 +326,7 @@ OSDWidget::determineMetrics( const int M )
         case Center:
             newPos.ry() = ( screen.height() - newSize.height() ) / 2;
 
-            //FALL THROUGH
+            Q_FALLTHROUGH();
 
         case Middle:
             newPos.rx() = ( screen.width() - newSize.width() ) / 2;
@@ -540,7 +540,7 @@ OSDPreviewWidget::mouseReleaseEvent( QMouseEvent * /*event*/ )
         m_dragging = false;
         releaseMouse();
 
-        emit positionChanged();
+        Q_EMIT positionChanged();
     }
 }
 
@@ -606,7 +606,7 @@ OSDPreviewWidget::mouseMoveEvent( QMouseEvent *e )
 // Class OSD
 /////////////////////////////////////////////////////////////////////////////////////////
 
-Amarok::OSD* Amarok::OSD::s_instance = 0;
+Amarok::OSD* Amarok::OSD::s_instance = nullptr;
 
 Amarok::OSD*
 Amarok::OSD::instance()
@@ -620,7 +620,7 @@ Amarok::OSD::destroy()
     if ( s_instance )
     {
         delete s_instance;
-        s_instance = 0;
+        s_instance = nullptr;
     }
 }
 
@@ -634,23 +634,23 @@ Amarok::OSD::OSD()
     if( engine->isPlaying() )
         trackPlaying( engine->currentTrack() );
 
-    connect( engine, SIGNAL(trackPlaying(Meta::TrackPtr)),
-             this, SLOT(trackPlaying(Meta::TrackPtr)) );
-    connect( engine, SIGNAL(stopped(qint64,qint64)),
-             this, SLOT(stopped()) );
-    connect( engine, SIGNAL(paused()),
-             this, SLOT(paused()) );
+    connect( engine, &EngineController::trackPlaying,
+             this, &Amarok::OSD::trackPlaying );
+    connect( engine, &EngineController::stopped,
+             this, &Amarok::OSD::stopped );
+    connect( engine, &EngineController::paused,
+             this, &Amarok::OSD::paused );
 
-    connect( engine, SIGNAL(trackMetadataChanged(Meta::TrackPtr)),
-             this, SLOT(metadataChanged()) );
-    connect( engine, SIGNAL(albumMetadataChanged(Meta::AlbumPtr)),
-             this, SLOT(metadataChanged()) );
+    connect( engine, &EngineController::trackMetadataChanged,
+             this, &Amarok::OSD::metadataChanged );
+    connect( engine, &EngineController::albumMetadataChanged,
+             this, &Amarok::OSD::metadataChanged );
 
-    connect( engine, SIGNAL(volumeChanged(int)),
-             this, SLOT(volumeChanged(int)) );
+    connect( engine, &EngineController::volumeChanged,
+             this, &Amarok::OSD::volumeChanged );
 
-    connect( engine, SIGNAL(muteStateChanged(bool)),
-             this, SLOT(muteStateChanged(bool)) );
+    connect( engine, &EngineController::muteStateChanged,
+             this, &Amarok::OSD::muteStateChanged );
 
 }
 
@@ -743,7 +743,7 @@ Amarok::OSD::muteStateChanged( bool mute )
 }
 
 void
-Amarok::OSD::trackPlaying( Meta::TrackPtr track )
+Amarok::OSD::trackPlaying( const Meta::TrackPtr &track )
 {
     m_currentTrack = track;
 
@@ -863,4 +863,3 @@ namespace ShadowEngine
     }
 }
 
-#include "Osd.moc"
