@@ -31,10 +31,9 @@
 #include "SvgHandler.h"
 #include "ProgressWidget.h"
 
-#include <KIcon>
-#include <KLocale>
-#include <KStandardDirs>
-#include <KGlobalSettings>
+#include <QIcon>
+#include <KLocalizedString>
+#include <QStandardPaths>
 
 #include <QAction>
 #include <QContextMenuEvent>
@@ -105,7 +104,7 @@ Amarok::Slider::wheelEvent( QWheelEvent *e )
 
     QSlider::setValue( nval );
 
-    emit sliderReleased( value() );
+    Q_EMIT sliderReleased( value() );
 }
 
 void
@@ -121,8 +120,8 @@ Amarok::Slider::mouseMoveEvent( QMouseEvent *e )
             if ( !m_outside )
             {
                 QSlider::setValue( m_prevValue );
-                //if mouse released outside of slider, emit sliderMoved to previous value
-                emit sliderMoved( m_prevValue );
+                //if mouse released outside of slider, Q_EMIT sliderMoved to previous value
+                Q_EMIT sliderMoved( m_prevValue );
             }
             m_outside = true;
         }
@@ -130,7 +129,7 @@ Amarok::Slider::mouseMoveEvent( QMouseEvent *e )
         {
             m_outside = false;
             slideEvent( e );
-            emit sliderMoved( value() );
+            Q_EMIT sliderMoved( value() );
         }
     }
     else
@@ -182,7 +181,7 @@ void
 Amarok::Slider::mouseReleaseEvent( QMouseEvent* )
 {
     if( !m_outside && value() != m_prevValue )
-       emit sliderReleased( value() );
+       Q_EMIT sliderReleased( value() );
 
     m_sliding = false;
     m_outside = false;
@@ -252,7 +251,7 @@ Amarok::VolumeSlider::contextMenuEvent( QContextMenuEvent *e )
     /*
     // TODO: Phonon
     menu.addSeparator();
-    menu.addAction( KIcon( "view-media-equalizer-amarok" ), i18n( "&Equalizer" ), kapp, SLOT(slotConfigEqualizer()) )->setData( -1 );
+    menu.addAction( QIcon::fromTheme( "view-media-equalizer-amarok" ), i18n( "&Equalizer" ), qApp, &QCoreApplication::slotConfigEqualizer()) )->setData( -1 );
     */
 
     QAction* a = menu.exec( mapToGlobal( e->pos() ) );
@@ -262,7 +261,7 @@ Amarok::VolumeSlider::contextMenuEvent( QContextMenuEvent *e )
         if( n >= 0 )
         {
             QSlider::setValue( n );
-            emit sliderReleased( n );
+            Q_EMIT sliderReleased( n );
         }
     }
 }
@@ -273,7 +272,7 @@ Amarok::VolumeSlider::wheelEvent( QWheelEvent *e )
     const uint step = e->delta() / Amarok::VOLUME_SENSITIVITY;
     QSlider::setValue( QSlider::value() + step );
 
-    emit sliderReleased( value() );
+    Q_EMIT sliderReleased( value() );
 }
 
 void
@@ -356,8 +355,8 @@ void Amarok::TimeSlider::drawTriangle( const QString& name, int milliSeconds, bo
     int x_pos = ( ( ( double ) milliSeconds - ( double ) minimum() ) / ( maximum() - minimum() ) ) * ( width() - ( sliderLeftWidth + sliderLeftWidth + s_sliderInsertX * 2 ) );
     debug() << "drawing triangle at " << x_pos;
     BookmarkTriangle * tri = new BookmarkTriangle( this, milliSeconds, name, width(), showPopup );
-    connect( tri, SIGNAL(clicked(int)), SLOT(slotTriangleClicked(int)) );
-    connect( tri, SIGNAL(focused(int)), SLOT(slotTriangleFocused(int)) );
+    connect( tri, &BookmarkTriangle::clicked, this, &TimeSlider::slotTriangleClicked );
+    connect( tri, &BookmarkTriangle::focused, this, &TimeSlider::slotTriangleFocused );
     m_triangles << tri;
     tri->setGeometry( x_pos + 6 /* to center the point */, 1 /*y*/, 11, 11 ); // 6 = hard coded border width
     tri->show();
@@ -365,7 +364,7 @@ void Amarok::TimeSlider::drawTriangle( const QString& name, int milliSeconds, bo
 
 void Amarok::TimeSlider::slotTriangleClicked( int seconds )
 {
-    emit sliderReleased( seconds );
+    Q_EMIT sliderReleased( seconds );
 }
 
 void Amarok::TimeSlider::slotTriangleFocused( int seconds )
@@ -416,4 +415,3 @@ bool Amarok::TimeSlider::event( QEvent * event )
 }
 
 
-#include "SliderWidget.moc"
