@@ -1,5 +1,5 @@
 /****************************************************************************************
- * Copyright (c) 2009 Thomas Lbking <thomas.luebking@web.de>                            *
+ * Copyright (c) 2009 Thomas Luebking <thomas.luebking@web.de>                          *
  * Copyright (c) 2012 Ralf Engels <ralf-engels@gmx.de>                                  *
  *                                                                                      *
  * This program is free software; you can redistribute it and/or modify it under        *
@@ -21,12 +21,12 @@
 #include "TokenPool.h"
 #include "core/support/Debug.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 
 #include <QDropEvent>
 #include <QPainter>
 #include <QVBoxLayout>
-
+#include <QMimeData>
 
 TokenDropTarget::TokenDropTarget( QWidget *parent )
     : QWidget( parent )
@@ -92,7 +92,9 @@ TokenDropTarget::clear()
 {
     QList< Token *> allTokens = tokensAtRow();
     foreach( Token* token, allTokens )
-        delete token;
+        token->deleteLater();;
+
+    Q_EMIT changed();
 }
 
 int
@@ -202,12 +204,11 @@ TokenDropTarget::insertToken( Token *token, int row, int col )
     box->insertWidget( col, token );
     token->show();
 
-    connect( token, SIGNAL(changed()), this, SIGNAL(changed()) );
-    connect( token, SIGNAL(gotFocus(Token*)), this, SIGNAL(tokenSelected(Token*)) );
-    connect( token, SIGNAL(destroyed(QObject*)), this, SIGNAL(changed()) );
-    connect( token, SIGNAL(destroyed(QObject*)), this, SLOT(deleteEmptyRows()) );
+    connect( token, &Token::changed, this, &TokenDropTarget::changed );
+    connect( token, &Token::gotFocus, this, &TokenDropTarget::tokenSelected );
+    connect( token, &Token::removed, this, &TokenDropTarget::deleteEmptyRows );
 
-    emit changed();
+    Q_EMIT changed();
 }
 
 
@@ -261,7 +262,7 @@ TokenDropTarget::drop( Token *token, const QPoint &pos )
     }
     else
     {
-        insertToken( token );
+        appendToken( token );
     }
 
     token->setFocus( Qt::OtherFocusReason ); // select the new token right away
