@@ -27,7 +27,7 @@ TrackActionButton::TrackActionButton( QWidget *parent, const QAction *act ) : Ic
     if ( parent )
         parent->installEventFilter( this );
     // this is during the labelslide - so we wait a short time with image processing ;-)
-    QTimer::singleShot( 1200, this, SLOT(init()) );
+    QTimer::singleShot( 1200, this, &TrackActionButton::init );
 }
 
 bool TrackActionButton::eventFilter( QObject *o, QEvent *e )
@@ -65,8 +65,8 @@ void TrackActionButton::reloadContent( const QSize &sz )
         return;
     int r,g,b;
     palette().color(foregroundRole()).getRgb(&r,&g,&b);
-    
-    m_icon.image[2] = m_icon.icon.pixmap( sz ).toImage();
+    //double size render to have better looking high-dpi toolbar
+    m_icon.image[2] = m_icon.icon.pixmap( QSize( sz.width()*2, sz.height()*2 ) ).toImage();
     QImage img = m_icon.image[2].convertToFormat(QImage::Format_ARGB32);
     int n = img.width() * img.height();
     
@@ -108,14 +108,14 @@ void TrackActionButton::reloadContent( const QSize &sz )
 
 void TrackActionButton::setAction( const QAction *act )
 {
-    disconnect( SIGNAL(clicked()) );
+    disconnect( this, &TrackActionButton::clicked, 0, 0 );
     m_action = act;
     if ( act )
     {
         m_icon.icon = act->icon();
         setToolTip( act->toolTip() );
-        connect ( this, SIGNAL(clicked()), act, SLOT(trigger()) );
-        connect ( act, SIGNAL(changed()), SLOT(updateAction()) );
+        connect ( this, &TrackActionButton::clicked, act, &QAction::trigger );
+        connect ( act, &QAction::changed, this, &TrackActionButton::updateAction );
     }
     else
     {
@@ -126,7 +126,7 @@ void TrackActionButton::setAction( const QAction *act )
 
 QSize TrackActionButton::sizeHint() const
 {
-    return QSize( 16, 16 );
+    return QSize( 24, 24 );
 }
 
 void TrackActionButton::updateAction()
@@ -139,8 +139,7 @@ void TrackActionButton::updateAction()
             setToolTip( act->toolTip() );
         }
         else // old action, stop listening
-            disconnect ( act, SIGNAL(changed()), this, SLOT(updateAction()) );
+            disconnect ( act, &QAction::changed, this, &TrackActionButton::updateAction );
     }
 }
 
-#include "TrackActionButton.moc"
