@@ -21,13 +21,11 @@
 
 #include "core/support/Debug.h"
 
-#include <QtTest/QTest>
-#include <QtCore/QString>
-#include <QtCore/QMap>
+#include <QTest>
+#include <QString>
+#include <QMap>
 
-#include <qtest_kde.h>
-
-QTEST_KDEMAIN_CORE( TestQStringx )
+QTEST_GUILESS_MAIN( TestQStringx )
 
 //required for Debug.h
 QMutex Debug::mutex;
@@ -40,32 +38,32 @@ void TestQStringx::testArgs()
 {
     QStringList testArgs;
 
-    m_testString = "";
+    m_testString = Amarok::QStringx("");
     QCOMPARE( m_testString.args( testArgs ) , QString( "" ) );
 
-    m_testString = "test";
+    m_testString = Amarok::QStringx("test");
     QCOMPARE( m_testString.args( testArgs ), QString( "test" ) );
 
-    m_testString = "";
+    m_testString = Amarok::QStringx("");
     testArgs.append( "test" );
     QCOMPARE( m_testString.args( testArgs ), QString( "" ) );
 
-    m_testString = "test%12abc";
+    m_testString = Amarok::QStringx("test%12abc");
     QCOMPARE( m_testString.args( testArgs ) , QString( "testtestabc" ) );
 
-    m_testString = "%12test abc";
+    m_testString = Amarok::QStringx("%12test abc");
     QCOMPARE( m_testString.args( testArgs ) , QString( "testtest abc" ) );
 
-    m_testString = "te%st%12abc";
+    m_testString = Amarok::QStringx("te%st%12abc");
     QCOMPARE( m_testString.args( testArgs ) , QString( "te%sttestabc" ) );
 
     testArgs.clear();
     testArgs.append( "test" );
     testArgs.append( "abc" );
-    m_testString = "test%12abc%2xyz";
+    m_testString = Amarok::QStringx("test%12abc%2xyz");
     QCOMPARE( m_testString.args( testArgs ) , QString( "testtestabcabcxyz" ) );
 
-    m_testString = "%12test%23abc";
+    m_testString = Amarok::QStringx("%12test%23abc");
     QCOMPARE( m_testString.args( testArgs ) , QString( "testtestabcabc" ) );
 }
 
@@ -73,26 +71,26 @@ void TestQStringx::testNamedArgs()
 {
     QMap<QString, QString> testArgs;
 
-    m_testString = "";
+    m_testString = Amarok::QStringx("");
     QCOMPARE( m_testString.namedArgs( testArgs ) , QString( "" ) );
 
-    m_testString = "test";
+    m_testString = Amarok::QStringx("test");
     QCOMPARE( m_testString.namedArgs( testArgs ) , QString( "test" ) );
 
     testArgs[ "artist" ] = "Pornophonique";
-    m_testString = "test";
+    m_testString = Amarok::QStringx("test");
     QCOMPARE( m_testString.namedArgs( testArgs ) , QString( "test" ) );
 
-    m_testString = "artist: %artist%";
+    m_testString = Amarok::QStringx("artist: %artist%");
     QCOMPARE( m_testString.namedArgs( testArgs ) , QString( "artist: Pornophonique" ) );
 
-    m_testString = "artist: %artist% - %album%";
+    m_testString = Amarok::QStringx("artist: %artist% - %album%");
     QCOMPARE( m_testString.namedArgs( testArgs ) , QString( "artist: Pornophonique - " ) );
 
     testArgs[ "album" ] = "8-Bit Lagerfeuer";
     QCOMPARE( m_testString.namedArgs( testArgs ) , QString( "artist: Pornophonique - 8-Bit Lagerfeuer" ) );
 
-    m_testString = "%artist%: %artist% - %album%";
+    m_testString = Amarok::QStringx("%artist%: %artist% - %album%");
     QCOMPARE( m_testString.namedArgs( testArgs ) , QString( "Pornophonique: Pornophonique - 8-Bit Lagerfeuer" ) );
 
     testArgs[ "year" ] = "2007";
@@ -103,72 +101,72 @@ void TestQStringx::testNamedOptArgs()
 {
     QMap<QString, QString> testArgs;
 
-    m_testString = "";
+    m_testString = Amarok::QStringx("");
     QCOMPARE( m_testString.namedOptArgs( testArgs ) , QString( "" ) );
 
-    m_testString = "test";
+    m_testString = Amarok::QStringx("test");
     QCOMPARE( m_testString.namedOptArgs( testArgs ) , QString( "test" ) );
 
-    m_testString = "%test%";
+    m_testString = Amarok::QStringx("%test%");
     QCOMPARE( m_testString.namedOptArgs( testArgs ) , QString( "" ) );
 
-    m_testString = "{ %test% }";
+    m_testString = Amarok::QStringx("{ %test% }");
     QCOMPARE( m_testString.namedOptArgs( testArgs ) , QString( "" ) );
 
-    m_testString = "test{%test%}";
+    m_testString = Amarok::QStringx("test{%test%}");
     QCOMPARE( m_testString.namedOptArgs( testArgs ) , QString( "test" ) );
 
-    m_testString = "{test{%test%}}";
+    m_testString = Amarok::QStringx("{test{%test%}}");
     QCOMPARE( m_testString.namedOptArgs( testArgs ) , QString( "test" ) );
 
-    m_testString = "%test%{%test%}";
+    m_testString = Amarok::QStringx("%test%{%test%}");
     QCOMPARE( m_testString.namedOptArgs( testArgs ) , QString( "" ) );
 
-    m_testString = "test%test% ";
+    m_testString = Amarok::QStringx("test%test% ");
     QCOMPARE( m_testString.namedOptArgs( testArgs ) , QString( "test " ) );
 
     testArgs[ "artist" ] = "All:My:Faults";
-    m_testString = "%artist%";
+    m_testString = Amarok::QStringx("%artist%");
     QCOMPARE( m_testString.namedOptArgs( testArgs ) , QString( "All:My:Faults" ) );
 
-    m_testString = "{%test% }{%artist%}";
+    m_testString = Amarok::QStringx("{%test% }{%artist%}");
     QCOMPARE( m_testString.namedOptArgs( testArgs ) , QString( "All:My:Faults" ) );
 
-    m_testString = "{%test% {%artist%}}";
+    m_testString = Amarok::QStringx("{%test% {%artist%}}");
     QCOMPARE( m_testString.namedOptArgs( testArgs ) , QString( "" ) );
 
-    m_testString = "{%artist% {%test%}}";
+    m_testString = Amarok::QStringx("{%artist% {%test%}}");
     QCOMPARE( m_testString.namedOptArgs( testArgs ) , QString( "All:My:Faults " ) );
 
     testArgs[ "track" ] = "Some track";
-    m_testString = "{%test% {%artist%}}%track%";
+    m_testString = Amarok::QStringx("{%test% {%artist%}}%track%");
     QCOMPARE( m_testString.namedOptArgs( testArgs ) , QString( "Some track" ) );
 
-    m_testString = "{%artist% {%track%}} %test%";
+    m_testString = Amarok::QStringx("{%artist% {%track%}} %test%");
     QCOMPARE( m_testString.namedOptArgs( testArgs ) , QString( "All:My:Faults Some track " ) );
 
     testArgs[ "test" ] = "";
-    m_testString = "{%test%}";
+    m_testString = Amarok::QStringx("{%test%}");
     QCOMPARE( m_testString.namedOptArgs( testArgs ) , QString( "" ) );
 
-    m_testString = "before{%test%}";
+    m_testString = Amarok::QStringx("before{%test%}");
     QCOMPARE( m_testString.namedOptArgs( testArgs ) , QString( "before" ) );
 
-    m_testString = "{%test%}after";
+    m_testString = Amarok::QStringx("{%test%}after");
     QCOMPARE( m_testString.namedOptArgs( testArgs ) , QString( "after" ) );
 
-    m_testString = "before{%test%}after";
+    m_testString = Amarok::QStringx("before{%test%}after");
     QCOMPARE( m_testString.namedOptArgs( testArgs ) , QString( "beforeafter" ) );
 
-    m_testString = "{%test% }{%artist%}";
+    m_testString = Amarok::QStringx("{%test% }{%artist%}");
     QCOMPARE( m_testString.namedOptArgs( testArgs ) , QString( "All:My:Faults" ) );
 
-    m_testString = "{%test% {%artist%}}";
+    m_testString = Amarok::QStringx("{%test% {%artist%}}");
     QCOMPARE( m_testString.namedOptArgs( testArgs ) , QString( "" ) );
 
-    m_testString = "{%artist% {%test%}}";
+    m_testString = Amarok::QStringx("{%artist% {%test%}}");
     QCOMPARE( m_testString.namedOptArgs( testArgs ) , QString( "All:My:Faults " ) );
-    
-    m_testString = "[%test2%:test {%artist%}%test%{ [%test%]}]";
+
+    m_testString = Amarok::QStringx("[%test2%:test {%artist%}%test%{ [%test%]}]");
     QCOMPARE( m_testString.namedOptArgs( testArgs ), QString( "test All:My:Faults Unknown test" ) );
 }
