@@ -19,7 +19,6 @@
 #include "DatabaseUpdater.h"
 #include "core/support/Debug.h"
 #include "core/support/Components.h"
-#include "core-impl/logger/ProxyLogger.h"
 #include "DefaultSqlQueryMakerFactory.h"
 #include "core/meta/Meta.h"
 #include "core-impl/storage/sql/mysqlestorage/MySqlEmbeddedStorage.h"
@@ -35,12 +34,8 @@
 #include <QProcess>
 #include <QTimer>
 
-#include <KCmdLineArgs>
-#include <KGlobal>
-
-#include <qtest_kde.h>
-
 #include <gmock/gmock.h>
+#include <KConfigGroup>
 
 using ::testing::AnyNumber;
 using ::testing::Return;
@@ -53,28 +48,28 @@ class MySqlCollectionLocation : public Collections::SqlCollectionLocation
 {
 public:
     MySqlCollectionLocation( Collections::SqlCollection *coll ) : Collections::SqlCollectionLocation( coll ) {}
-    virtual ~MySqlCollectionLocation() {}
+    ~MySqlCollectionLocation() override {}
 
-    bool isWritable() const { return true; }
+    bool isWritable() const override { return true; }
 };
 
 class MyOrganizeCollectionDelegate : public OrganizeCollectionDelegate
 {
 public:
     MyOrganizeCollectionDelegate() : OrganizeCollectionDelegate(), overwrite( false ), migrate( false ) {}
-    virtual ~ MyOrganizeCollectionDelegate() {}
+    ~MyOrganizeCollectionDelegate() override {}
 
-    void setTracks( const Meta::TrackList &tracks ) { Q_UNUSED( tracks ) }
-    void setFolders( const QStringList &folders ) { Q_UNUSED( folders ) }
-    void setIsOrganizing( bool organizing ) { Q_UNUSED( organizing ) }
-    void setTranscodingConfiguration(const Transcoding::Configuration &configuration)
+    void setTracks( const Meta::TrackList &tracks ) override { Q_UNUSED( tracks ) }
+    void setFolders( const QStringList &folders ) override { Q_UNUSED( folders ) }
+    void setIsOrganizing( bool organizing ) override { Q_UNUSED( organizing ) }
+    void setTranscodingConfiguration(const Transcoding::Configuration &configuration) override
     { Q_UNUSED( configuration ) }
-    void setCaption( const QString& ) {}
+    void setCaption( const QString& ) override {}
 
-    void show() { emit accepted(); }
+    void show() override { emit accepted(); }
 
-    bool overwriteDestinations() const { return overwrite; }
-    QMap<Meta::TrackPtr, QString> destinations() const { return dests; }
+    bool overwriteDestinations() const override { return overwrite; }
+    QMap<Meta::TrackPtr, QString> destinations() const override { return dests; }
     bool migrateLabels() const { return migrate; }
 
     bool overwrite;
@@ -88,17 +83,17 @@ public:
     MyOrganizeCollectionDelegateFactory( OrganizeCollectionDelegate *d )
         : OrganizeCollectionDelegateFactory()
         , delegate( d ) {}
-    virtual ~ MyOrganizeCollectionDelegateFactory() {}
+    ~MyOrganizeCollectionDelegateFactory() override {}
 
     //warning: SqlCollectionLocation will delete the delegate
-    OrganizeCollectionDelegate* createDelegate() { return delegate; }
+    OrganizeCollectionDelegate* createDelegate() override { return delegate; }
 
     OrganizeCollectionDelegate *delegate;
 };
 
 
 
-QTEST_KDEMAIN_CORE( TestSqlCollectionLocation )
+QTEST_GUILESS_MAIN( TestSqlCollectionLocation )
 
 TestSqlCollectionLocation::TestSqlCollectionLocation()
     : QObject()
@@ -106,20 +101,21 @@ TestSqlCollectionLocation::TestSqlCollectionLocation()
     , m_storage( 0 )
     , m_tmpDir( 0 )
 {
-    KCmdLineArgs::init( KGlobal::activeComponent().aboutData() );
-    ::testing::InitGoogleMock( &KCmdLineArgs::qtArgc(), KCmdLineArgs::qtArgv() );
+    int argc = 1;
+    char **argv = (char **) malloc(sizeof(char *));
+    argv[0] = strdup( QCoreApplication::applicationName().toLocal8Bit().data() );
+    ::testing::InitGoogleMock( &argc, argv );
 }
 
 void
 TestSqlCollectionLocation::initTestCase()
 {
-    Amarok::Components::setLogger( new ProxyLogger() );
-    m_tmpDir = new KTempDir();
-    m_storage = new MySqlEmbeddedStorage();
-    QVERIFY( m_storage->init( m_tmpDir->name() ) );
+    m_tmpDir = new QTemporaryDir();
+    m_storage = QSharedPointer<MySqlEmbeddedStorage>( new MySqlEmbeddedStorage() );
+    QVERIFY( m_storage->init( m_tmpDir->path() ) );
     m_collection = new Collections::SqlCollection( m_storage );
     SqlMountPointManagerMock *mock = new SqlMountPointManagerMock( this, m_storage );
-    mock->setCollectionFolders( QStringList() << m_tmpDir->name() ); // the target folder needs to have enough space and be writable
+    mock->setCollectionFolders( QStringList() << m_tmpDir->path() ); // the target folder needs to have enough space and be writable
     m_collection->setMountPointManager( mock );
 
     // I just need the table and not the whole playlist manager
@@ -139,7 +135,6 @@ void
 TestSqlCollectionLocation::cleanupTestCase()
 {
     delete m_collection;
-    delete Amarok::Components::setLogger( 0 );
     //m_storage is deleted by SqlCollection
     delete m_tmpDir;
 }
@@ -160,9 +155,9 @@ TestSqlCollectionLocation::init()
     m_storage->query( "INSERT INTO genres(id, name) VALUES (1, 'genre1');" );
     m_storage->query( "INSERT INTO years(id, name) VALUES (1, '1');" );
 
-    m_storage->query( "INSERT INTO directories(id,deviceid,dir) VALUES (1, -1, '." + m_tmpDir->name() + "ab/')");
-    m_storage->query( "INSERT INTO directories(id,deviceid,dir) VALUES (2, -1, '." + m_tmpDir->name() + "b/')");
-    m_storage->query( "INSERT INTO directories(id,deviceid,dir) VALUES (3, -1, '." + m_tmpDir->name() + "c/')");
+    m_storage->query( "INSERT INTO directories(id,deviceid,dir) VALUES (1, -1, '." + m_tmpDir->path() + "/ab/')");
+    m_storage->query( "INSERT INTO directories(id,deviceid,dir) VALUES (2, -1, '." + m_tmpDir->path() + "/b/')");
+    m_storage->query( "INSERT INTO directories(id,deviceid,dir) VALUES (3, -1, '." + m_tmpDir->path() + "/c/')");
 
     m_storage->query( QString( "INSERT INTO urls(id, deviceid, rpath, uniqueid, directory ) VALUES (1, -1, '%1', 'uid://1', 1);" ).arg( setupFileInTempDir( "ab/IDoNotExist.mp3" ) ) );
     m_storage->query( QString( "INSERT INTO urls(id, deviceid, rpath, uniqueid, directory ) VALUES (2, -1, '%1', 'uid://2', 2);" ).arg( setupFileInTempDir( "b/IDoNotExistAsWell.mp3") ) );
@@ -216,18 +211,19 @@ TestSqlCollectionLocation::testOrganizingCopiesLabels()
 
         Collections::SqlCollectionLocation *source = new MySqlCollectionLocation( m_collection );
         Collections::SqlCollectionLocation *dest = new MySqlCollectionLocation( m_collection );
+        QSignalSpy spy( source, &Collections::SqlCollectionLocation::destroyed );
 
         {
             MyOrganizeCollectionDelegate *delegate = new MyOrganizeCollectionDelegate();
             delegate->overwrite = true;
             delegate->migrate = true;
-            delegate->dests.insert( track, m_tmpDir->name() + "b/IDoNotExist.mp3" );
+            delegate->dests.insert( track, m_tmpDir->path() + "b/IDoNotExist.mp3" );
             dest->setOrganizeCollectionDelegateFactory( new MyOrganizeCollectionDelegateFactory( delegate ) );
         }
 
         source->prepareMove( track, dest );
 
-        QTest::kWaitForSignal( source, SIGNAL(destroyed(QObject*)), 1000 );
+        spy.wait( 1000 );
 
         QCOMPARE( track->labels().count(), 1 );
         QVERIFY( track->playableUrl().path().endsWith( "b/IDoNotExist.mp3" ) );
@@ -237,7 +233,7 @@ TestSqlCollectionLocation::testOrganizingCopiesLabels()
     m_collection->registry()->emptyCache();
 
     {
-        // Meta::TrackPtr track = m_collection->registry()->getTrack( m_tmpDir->name() + "b/IDoNotExist.mp3" );
+        // Meta::TrackPtr track = m_collection->registry()->getTrack( m_tmpDir->path() + "/b/IDoNotExist.mp3" );
         Meta::TrackPtr track = m_collection->registry()->getTrack(1);
         QVERIFY( track );
         QVERIFY( track->playableUrl().path().endsWith( "b/IDoNotExist.mp3" ) );
@@ -261,11 +257,11 @@ TestSqlCollectionLocation::testCopyTrackToDirectoryWithExistingTracks()
 QString
 TestSqlCollectionLocation::setupFileInTempDir( const QString &relativeName )
 {
-    QString absoluteName = m_tmpDir->name() + relativeName;
+    QString absoluteName = m_tmpDir->path() + '/' + relativeName;
 
     //TODO: unix specific
     //create directory where necessary
-    int index = absoluteName.lastIndexOf( QDir::separator() );
+    int index = absoluteName.lastIndexOf( '/' );
     if(index > 0 )
     {
         QString dir = absoluteName.left( index );
@@ -273,7 +269,7 @@ TestSqlCollectionLocation::setupFileInTempDir( const QString &relativeName )
     }
     else
     {
-        qDebug() << "huh? index was " << index << " relative name was " << relativeName << " tmpDir " << m_tmpDir->name();
+        qDebug() << "huh? index was " << index << " relative name was " << relativeName << " tmpDir " << m_tmpDir->path();
     }
 
     QProcess::execute( "touch", QStringList() << absoluteName );
