@@ -15,20 +15,19 @@
 
 #include "TestTrackForUrlWorker.h"
 
+#include "amarokconfig.h"
 #include "config-amarok-test.h"
-#include "core/meta/Meta.h"
 #include "core-impl/collections/support/CollectionManager.h"
 #include "mocks/MockTrackForUrlWorker.h"
 
-#include <KUrl>
-#include <ThreadWeaver/Job>
-#include <ThreadWeaver/Weaver>
-#include <qtest_kde.h>
-
 #include <QMetaType>
 #include <QSignalSpy>
+#include <QUrl>
 
-QTEST_KDEMAIN_CORE( TestTrackForUrlWorker )
+#include <ThreadWeaver/Job>
+#include <ThreadWeaver/Queue>
+
+QTEST_GUILESS_MAIN( TestTrackForUrlWorker )
 
 void
 TestTrackForUrlWorker::initTestCase()
@@ -36,6 +35,7 @@ TestTrackForUrlWorker::initTestCase()
     // To make queued signals/slots work with custom payload
     qRegisterMetaType<Meta::TrackPtr>( "Meta::TrackPtr" );
     qRegisterMetaType<ThreadWeaver::Job*>( "ThreadWeaver::Job*" );
+    AmarokConfig::instance("amarokrc");
 }
 
 QString
@@ -45,15 +45,15 @@ TestTrackForUrlWorker::dataPath( const QString &relPath )
 }
 
 void
-TestTrackForUrlWorker::testCompleteJobKUrl_data()
+TestTrackForUrlWorker::testCompleteJobQUrl_data()
 {
     testCompleteJobInternal_data();
 }
 
 void
-TestTrackForUrlWorker::testCompleteJobKUrl()
+TestTrackForUrlWorker::testCompleteJobQUrl()
 {
-    KUrl url;
+    QUrl url;
 
     MockTrackForUrlWorker *trackForUrlWorker = new MockTrackForUrlWorker( url );
     QVERIFY( trackForUrlWorker );
@@ -82,23 +82,24 @@ TestTrackForUrlWorker::testCompleteJobInternal_data()
 {
     QTest::addColumn<Meta::TrackPtr>( "track" );
 
-    QTest::newRow( "track 1" ) << CollectionManager::instance()->trackForUrl( dataPath( "data/audio/album/Track01.ogg" ) );
-    QTest::newRow( "track 2" ) << CollectionManager::instance()->trackForUrl( dataPath( "data/audio/album/Track02.ogg" ) );
-    QTest::newRow( "track 3" ) << CollectionManager::instance()->trackForUrl( dataPath( "data/audio/album/Track03.ogg" ) );
+    QTest::newRow( "track 1" ) << CollectionManager::instance()->trackForUrl( QUrl::fromLocalFile(dataPath( "data/audio/album/Track01.ogg" )) );
+    QTest::newRow( "track 2" ) << CollectionManager::instance()->trackForUrl( QUrl::fromLocalFile(dataPath( "data/audio/album/Track02.ogg" )) );
+    QTest::newRow( "track 3" ) << CollectionManager::instance()->trackForUrl( QUrl::fromLocalFile(dataPath( "data/audio/album/Track03.ogg" )) );
 }
 
 void
 TestTrackForUrlWorker::testCompleteJobInternal( MockTrackForUrlWorker *trackForUrlWorker )
 {
     // Connect finishedLookup with setEmittedTrack() that will store the emitted track
-    connect( trackForUrlWorker, SIGNAL(finishedLookup(Meta::TrackPtr)),
-             this, SLOT(setEmittedTrack(Meta::TrackPtr)) );
+    connect( trackForUrlWorker, &MockTrackForUrlWorker::finishedLookup,
+             this, &TestTrackForUrlWorker::setEmittedTrack );
 
-    QSignalSpy spyFinishedLookup( trackForUrlWorker, SIGNAL(finishedLookup(Meta::TrackPtr)) );
+    QSignalSpy spyFinishedLookup( trackForUrlWorker, &MockTrackForUrlWorker::finishedLookup );
+    QSignalSpy spyDone( trackForUrlWorker, &MockTrackForUrlWorker::done );
 
     // Enqueue the job for execution and verify that it emits done when finished, which triggers completeJob
-    ThreadWeaver::Weaver::instance()->enqueue( trackForUrlWorker );
-    bool receivedDone = QTest::kWaitForSignal( trackForUrlWorker, SIGNAL(done(ThreadWeaver::Job*)), 1000 );
+    ThreadWeaver::Queue::instance()->enqueue( QSharedPointer<ThreadWeaver::Job>( trackForUrlWorker ) );
+    bool receivedDone = spyDone.wait( 1000 );
     QVERIFY( receivedDone );
 
     // Verify that finishedLookup was emitted
@@ -107,10 +108,6 @@ TestTrackForUrlWorker::testCompleteJobInternal( MockTrackForUrlWorker *trackForU
     // Verify that the track emitted with finishedLookup is indeed the track set by run()
     QFETCH( Meta::TrackPtr, track );
     QCOMPARE( m_emittedTrack, track );
-
-    // Check for emission of the destroyed signal after deferred delete ( deleteLater )
-    bool receivedDestroyed = QTest::kWaitForSignal( trackForUrlWorker, SIGNAL(destroyed()), 1000 );
-    QVERIFY( receivedDestroyed );
 }
 
 void
@@ -119,4 +116,3 @@ TestTrackForUrlWorker::setEmittedTrack( Meta::TrackPtr track )
     m_emittedTrack = track;
 }
 
-#include "TestTrackForUrlWorker.moc"
