@@ -21,11 +21,13 @@
 #include "FileType.h"
 
 #include <QDateTime>
-#include <qtest_kde.h>
+
+#include <KLocalizedString>
+
 
 using namespace Meta;
 
-QTEST_KDEMAIN_CORE( TestMetaConstants )
+QTEST_MAIN( TestMetaConstants )
 
 /* Just for clarification. This is not how you would normally write an auto test.
    You don't write a switch just to test if the switch returns the correct values.
@@ -403,7 +405,7 @@ TestMetaConstants::testValueForField()
 
     // Set up mock track details and create mock track
     QVariantMap trackData;
-    trackData[ Meta::Field::URL ] = KUrl( "file:///test/url" );
+    trackData[ Meta::Field::URL ] = QUrl("file:///test/url");
     trackData[ Meta::Field::TITLE ] = "test track";
     trackData[ Meta::Field::COMMENT ] = "test comment" ;
     trackData[ Meta::Field::TRACKNUMBER ] = 1;
@@ -449,7 +451,7 @@ TestMetaConstants::testValueForField()
 
     // Case 0
     QVariant trackValue = valueForField( qint64( 0 ), trackPtr );
-    QVERIFY( trackValue.toStringList().contains( trackData.value( Meta::Field::URL ).value<KUrl>().path()
+    QVERIFY( trackValue.toStringList().contains( trackData.value( Meta::Field::URL ).value<QUrl>().path()
         + trackData.value( Meta::Field::TITLE ).toString()
         + trackData.value( Meta::Field::COMMENT ).toString() ) );
     QVERIFY( trackValue.toStringList().contains( testAlbum->name() ) );
@@ -458,7 +460,7 @@ TestMetaConstants::testValueForField()
 
     // Case Meta::valUrl
     trackValue = valueForField( Meta::valUrl, trackPtr );
-    QVERIFY( trackValue.toString() == trackData.value( Meta::Field::URL ).value<KUrl>().path() );
+    QVERIFY( trackValue.toString() == trackData.value( Meta::Field::URL ).value<QUrl>().path() );
 
     // Case Meta::valTitle
     trackValue = valueForField( Meta::valTitle, trackPtr );
