@@ -28,14 +28,12 @@
 #include "mocks/MockAlbum.h"
 #include "mocks/MockArtist.h"
 
-#include <KCmdLineArgs>
-#include <KGlobal>
-
-#include <qtest_kde.h>
-
 #include <gmock/gmock.h>
 
-QTEST_KDEMAIN_CORE( TestMasterSlaveSynchronizationJob )
+#include <QSignalSpy>
+
+
+QTEST_GUILESS_MAIN( TestMasterSlaveSynchronizationJob )
 
 using ::testing::Return;
 using ::testing::AnyNumber;
@@ -51,10 +49,10 @@ class MyCollectionLocation : public CollectionLocation
 public:
     Collections::CollectionTestImpl *coll;
 
-    QString prettyLocation() const { return "foo"; }
-    bool isWritable() const { return true; }
+    QString prettyLocation() const override { return "foo"; }
+    bool isWritable() const override { return true; }
 
-    void removeUrlsFromCollection( const Meta::TrackList &sources )
+    void removeUrlsFromCollection( const Meta::TrackList &sources ) override
     {
         trackRemoveCount += sources.count();
         coll->mc->acquireWriteLock();
@@ -66,7 +64,7 @@ public:
         slotRemoveOperationFinished();
     }
 
-    void copyUrlsToCollection(const QMap<Meta::TrackPtr, KUrl> &sources, const Transcoding::Configuration& conf)
+    void copyUrlsToCollection(const QMap<Meta::TrackPtr, QUrl> &sources, const Transcoding::Configuration& conf) override
     {
         Q_UNUSED( conf )
         trackCopyCount = sources.count();
@@ -82,7 +80,7 @@ class MyCollectionTestImpl : public CollectionTestImpl
 public:
     MyCollectionTestImpl( const QString &id ) : CollectionTestImpl( id ) {}
 
-    CollectionLocation* location()
+    CollectionLocation* location() override
     {
         MyCollectionLocation *r = new MyCollectionLocation();
         r->coll = this;
@@ -99,7 +97,7 @@ void addMockTrack( Collections::CollectionTestImpl *coll, const QString &trackNa
     Meta::TrackPtr trackPtr( track );
     EXPECT_CALL( *track, name() ).Times( AnyNumber() ).WillRepeatedly( Return( trackName ) );
     EXPECT_CALL( *track, uidUrl() ).Times( AnyNumber() ).WillRepeatedly( Return( trackName + '_' + artistName + '_' + albumName ) );
-    EXPECT_CALL( *track, playableUrl() ).Times( AnyNumber() ).WillRepeatedly( Return( KUrl( '/' + track->uidUrl() ) ) );
+    EXPECT_CALL( *track, playableUrl() ).Times( AnyNumber() ).WillRepeatedly( Return( QUrl( '/' + track->uidUrl() ) ) );
     coll->mc->addTrack( trackPtr );
 
     Meta::AlbumPtr albumPtr = coll->mc->albumMap().value( albumName, QString() /* no album artist */ );
@@ -158,8 +156,10 @@ void addMockTrack( Collections::CollectionTestImpl *coll, const QString &trackNa
 
 TestMasterSlaveSynchronizationJob::TestMasterSlaveSynchronizationJob()
 {
-    KCmdLineArgs::init( KGlobal::activeComponent().aboutData() );
-    ::testing::InitGoogleMock( &KCmdLineArgs::qtArgc(), KCmdLineArgs::qtArgv() );
+    int argc = 1;
+    char **argv = (char **) malloc(sizeof(char *));
+    argv[0] = strdup( QCoreApplication::applicationName().toLocal8Bit().data() );
+    ::testing::InitGoogleMock( &argc, argv );
     qRegisterMetaType<Meta::TrackList>();
     qRegisterMetaType<Meta::AlbumList>();
     qRegisterMetaType<Meta::ArtistList>();
@@ -186,10 +186,11 @@ TestMasterSlaveSynchronizationJob::testAddTracksToEmptySlave()
     QCOMPARE( trackRemoveCount, 0 );
 
     MasterSlaveSynchronizationJob *job = new MasterSlaveSynchronizationJob();
+    QSignalSpy spy( job, &MasterSlaveSynchronizationJob::destroyed );
     job->setMaster( master );
     job->setSlave( slave );
     job->synchronize();
-    QTest::kWaitForSignal( job, SIGNAL(destroyed()), 1000 );
+    spy.wait( 1000 );
 
     QCOMPARE( trackCopyCount, 1 );
     QCOMPARE( trackRemoveCount, 0 );
@@ -217,10 +218,11 @@ TestMasterSlaveSynchronizationJob::testAddSingleTrack()
 
     //test
     MasterSlaveSynchronizationJob *job = new MasterSlaveSynchronizationJob();
+    QSignalSpy spy( job, &MasterSlaveSynchronizationJob::destroyed );
     job->setMaster( master );
     job->setSlave( slave );
     job->synchronize();
-    QTest::kWaitForSignal( job, SIGNAL(destroyed()), 1000 );
+    spy.wait( 1000 );
 
     //verify
     QCOMPARE( trackCopyCount, 1 );
@@ -250,10 +252,11 @@ TestMasterSlaveSynchronizationJob::testAddAlbum()
 
     //test
     MasterSlaveSynchronizationJob *job = new MasterSlaveSynchronizationJob();
+    QSignalSpy spy( job, &MasterSlaveSynchronizationJob::destroyed );
     job->setMaster( master );
     job->setSlave( slave );
     job->synchronize();
-    QTest::kWaitForSignal( job, SIGNAL(destroyed()), 1000 );
+    spy.wait( 1000 );
 
     //verify
     QCOMPARE( trackCopyCount, 1 );
@@ -283,10 +286,11 @@ TestMasterSlaveSynchronizationJob::testAddArtist()
 
     //test
     MasterSlaveSynchronizationJob *job = new MasterSlaveSynchronizationJob();
+    QSignalSpy spy( job, &MasterSlaveSynchronizationJob::destroyed );
     job->setMaster( master );
     job->setSlave( slave );
     job->synchronize();
-    QTest::kWaitForSignal( job, SIGNAL(destroyed()), 1000 );
+    spy.wait( 1000 );
 
     //verify
     QCOMPARE( trackCopyCount, 1 );
@@ -320,10 +324,11 @@ TestMasterSlaveSynchronizationJob::testRemoveSingleTrack()
 
     //test
     MasterSlaveSynchronizationJob *job = new MasterSlaveSynchronizationJob();
+    QSignalSpy spy( job, &MasterSlaveSynchronizationJob::destroyed );
     job->setMaster( master );
     job->setSlave( slave );
     job->synchronize();
-    QTest::kWaitForSignal( job, SIGNAL(destroyed()), 1000 );
+    spy.wait( 1000 );
 
     //verify
     QCOMPARE( trackCopyCount, 0 );
@@ -358,10 +363,11 @@ TestMasterSlaveSynchronizationJob::testRemoveAlbum()
 
     //test
     MasterSlaveSynchronizationJob *job = new MasterSlaveSynchronizationJob();
+    QSignalSpy spy( job, &MasterSlaveSynchronizationJob::destroyed );
     job->setMaster( master );
     job->setSlave( slave );
     job->synchronize();
-    QTest::kWaitForSignal( job, SIGNAL(destroyed()), 1000 );
+    spy.wait( 1000 );
 
     //verify
     QCOMPARE( trackCopyCount, 0 );
@@ -396,10 +402,11 @@ TestMasterSlaveSynchronizationJob::testRemoveArtist()
 
     //test
     MasterSlaveSynchronizationJob *job = new MasterSlaveSynchronizationJob();
+    QSignalSpy spy( job, &MasterSlaveSynchronizationJob::destroyed );
     job->setMaster( master );
     job->setSlave( slave );
     job->synchronize();
-    QTest::kWaitForSignal( job, SIGNAL(destroyed()), 1000 );
+    spy.wait( 1000 );
 
     //verify
     QCOMPARE( trackCopyCount, 0 );
@@ -430,10 +437,11 @@ TestMasterSlaveSynchronizationJob::testEmptyMaster()
     QCOMPARE( trackRemoveCount, 0 );
 
     MasterSlaveSynchronizationJob *job = new MasterSlaveSynchronizationJob();
+    QSignalSpy spy( job, &MasterSlaveSynchronizationJob::destroyed );
     job->setMaster( master );
     job->setSlave( slave );
     job->synchronize();
-    QTest::kWaitForSignal( job, SIGNAL(destroyed()), 1000 );
+    spy.wait( 1000 );
 
     QCOMPARE( trackCopyCount, 0 );
     QCOMPARE( trackRemoveCount, 1 );
