@@ -1,6 +1,6 @@
 /*
  *  Copyright (c) 2008-2009 Jeff Mitchell <mitchell@kde.org>
- *  Qt4QStringToTString and TStringToQString macros Copyright 2002-2008 by Scott Wheeler, wheeler@kde.org, licensed under LGPL 2.1
+ *  QStringToTString and TStringToQString macros Copyright 2002-2008 by Scott Wheeler, wheeler@kde.org, licensed under LGPL 2.1
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -48,8 +48,8 @@
 
 #include <iostream>
 
-//QT4-happy versions
-#define Qt4QStringToTString(s) TagLib::String(s.toUtf8().data(), TagLib::String::UTF8)
+//QT5-happy versions
+#define Qt5QStringToTString(s) TagLib::String(s.toUtf8().data(), TagLib::String::UTF8)
 
 static int s_currentVersion = 1;
 
@@ -71,14 +71,14 @@ AFTTagger::AFTTagger( int &argc, char **argv )
     , m_textStream( stderr )
 {
 
-    setObjectName( "amarok_afttagger" );
+    setObjectName( QStringLiteral("amarok_afttagger") );
 
     readArgs();
 
     QString terms;
     if( !m_quiet )
     {
-        m_textStream << qPrintable( tr( "TERMS OF USE:\n\n" 
+        m_textStream << qPrintable( tr( "TERMS OF USE:\n\n"
                 "This program has been extensively tested and errs on the side of safety wherever possible.\n\n"
                 "With that being said, since this program can modify thousands or hundreds of thousands of files\n"
                 "at a time, here is the obligatory warning text:\n\n"
@@ -100,7 +100,7 @@ AFTTagger::AFTTagger( int &argc, char **argv )
         }
     }
 
-    qsrand(QDateTime::currentDateTime().toTime_t());
+    qsrand(QDateTime::currentDateTimeUtc().toSecsSinceEpoch());
     m_time.start();
 
     foreach( const QString &path, m_fileFolderList )
@@ -134,8 +134,8 @@ AFTTagger::processPath( const QString &path )
                 m_textStream << tr( "INFO: Processing directory %1" ).arg( path ) << endl;
             foreach( const QString &pathEntry, QDir( path ).entryList() )
             {
-                if( pathEntry != "." && pathEntry != ".." )
-                    processPath( QDir( path ).canonicalPath() + '/' +  pathEntry );
+                if( pathEntry != QLatin1String(".") && pathEntry != QLatin1String("..") )
+                    processPath( QDir( path ).canonicalPath() + QLatin1Char('/') +  pathEntry );
             }
         }
     }
@@ -164,7 +164,7 @@ AFTTagger::processPath( const QString &path )
 
         SafeFileSaver sfs( filePath );
         sfs.setVerbose( false );
-        sfs.setPrefix( "amarok-afttagger" );
+        sfs.setPrefix( QStringLiteral("amarok-afttagger") );
         QString tempFilePath = sfs.prepareToSave();
         if( tempFilePath.isEmpty() )
         {
@@ -258,7 +258,7 @@ AFTTagger::handleMPEG( TagLib::MPEG::File *file )
                 if( currFrame )
                 {
                     QString owner = TStringToQString( currFrame->owner() ).toUpper();
-                    if( owner.startsWith( "AMAROK - REDISCOVER YOUR MUSIC" ) )
+                    if( owner.startsWith( QLatin1String("AMAROK - REDISCOVER YOUR MUSIC") ) )
                     {
                         nothingfound = false;
                         if( m_verbose )
@@ -272,7 +272,7 @@ AFTTagger::handleMPEG( TagLib::MPEG::File *file )
                         else
                             return true;
                     }
-                    if( owner.startsWith( "AMAROK 2 AFT" ) )
+                    if( owner.startsWith( QLatin1String("AMAROK 2 AFT") ) )
                     {
                         nothingfound = false;
                         if( m_verbose )
@@ -325,7 +325,7 @@ AFTTagger::handleMPEG( TagLib::MPEG::File *file )
             if( m_verbose )
                 m_textStream << tr( "INFO: Adding new frame and saving file with UID: %1" ).arg( uid ) << endl;
             file->ID3v2Tag()->addFrame( new TagLib::ID3v2::UniqueFileIdentifierFrame(
-                Qt4QStringToTString( ourId ), Qt4QStringToTString( uid ).data( TagLib::String::Latin1 ) ) );
+                Qt5QStringToTString( ourId ), Qt5QStringToTString( uid ).data( TagLib::String::Latin1 ) ) );
             file->save();
             return true;
         }
@@ -410,7 +410,7 @@ AFTTagger::handleXiphComment( TagLib::Ogg::XiphComment *comment, TagLib::File *f
         {
             TagLib::String key = iter->first;
             QString qkey = TStringToQString( key ).toUpper();
-            if( qkey.startsWith( "AMAROK - REDISCOVER YOUR MUSIC" ) )
+            if( qkey.startsWith( QLatin1String("AMAROK - REDISCOVER YOUR MUSIC") ) )
             {
                 nothingfound = false;
 
@@ -421,7 +421,7 @@ AFTTagger::handleXiphComment( TagLib::Ogg::XiphComment *comment, TagLib::File *f
                 if( !m_delete )
                     newUid = true;
             }
-            else if( qkey.startsWith( "AMAROK 2 AFT" ) )
+            else if( qkey.startsWith( QLatin1String("AMAROK 2 AFT") ) )
             {
                 nothingfound = false;
 
@@ -475,7 +475,7 @@ AFTTagger::handleXiphComment( TagLib::Ogg::XiphComment *comment, TagLib::File *f
             uid = createCurrentUID( file );
         if( m_verbose )
             m_textStream << tr( "INFO: Adding new field and saving file with UID: %1" ).arg( uid ) << endl;
-        comment->addField( Qt4QStringToTString( ourId ), Qt4QStringToTString( uid ) );
+        comment->addField( Qt5QStringToTString( ourId ), Qt5QStringToTString( uid ) );
         return true;
     }
     else if( toRemove.size() )
@@ -515,7 +515,7 @@ AFTTagger::handleMPC( TagLib::MPC::File *file )
         {
             TagLib::String key = it->first;
             QString qkey = TStringToQString( key ).toUpper();
-            if( qkey.startsWith( "AMAROK - REDISCOVER YOUR MUSIC" ) )
+            if( qkey.startsWith( QLatin1String("AMAROK - REDISCOVER YOUR MUSIC") ) )
             {
                 nothingfound = false;
 
@@ -526,7 +526,7 @@ AFTTagger::handleMPC( TagLib::MPC::File *file )
                 if( !m_delete )
                     newUid = true;
             }
-            else if( qkey.startsWith( "AMAROK 2 AFT" ) )
+            else if( qkey.startsWith( QLatin1String("AMAROK 2 AFT") ) )
             {
                 nothingfound = false;
 
@@ -581,7 +581,7 @@ AFTTagger::handleMPC( TagLib::MPC::File *file )
             uid = createCurrentUID( file );
         if( m_verbose )
             m_textStream << tr( "INFO: Adding new field and saving file with UID: %1" ).arg( uid ) << endl;
-        file->APETag()->addValue( Qt4QStringToTString( ourId.toUpper() ), Qt4QStringToTString( uid ) );
+        file->APETag()->addValue( Qt5QStringToTString( ourId.toUpper() ), Qt5QStringToTString( uid ) );
         file->save();
         return true;
     }
@@ -617,7 +617,7 @@ AFTTagger::handleMP4( TagLib::MP4::File *file )
         {
             TagLib::String key = it->first;
             const QString qkey = TStringToQString( key ).toUpper();
-            if( qkey.contains( "AMAROK - REDISCOVER YOUR MUSIC" ) )
+            if( qkey.contains( QLatin1String("AMAROK - REDISCOVER YOUR MUSIC") ) )
             {
                 nothingfound = false;
 
@@ -628,7 +628,7 @@ AFTTagger::handleMP4( TagLib::MP4::File *file )
                 if( !m_delete )
                     newUid = true;
             }
-            else if( qkey.contains( "AMAROK 2 AFT" ) )
+            else if( qkey.contains( QLatin1String("AMAROK 2 AFT") ) )
             {
                 nothingfound = false;
 
@@ -643,14 +643,14 @@ AFTTagger::handleMP4( TagLib::MP4::File *file )
                 }
                 else
                 {
-                    int version = qkey.at( qkey.indexOf( "AMAROK 2 AFT" ) + 13 ).digitValue();
+                    int version = qkey.at( qkey.indexOf( QLatin1String("AMAROK 2 AFT") ) + 13 ).digitValue();
                     if( m_verbose )
                         m_textStream << tr( "INFO: AFT identifier is version %1" ).arg( version ) << endl;
                     if( version < s_currentVersion )
                     {
                         if( m_verbose )
                             m_textStream << tr( "INFO: Upgrading AFT identifier from version %1 to version %2" )
-                            .arg( QString::number( version ), QString::number( s_currentVersion ) ) 
+                            .arg( QString::number( version ), QString::number( s_currentVersion ) )
                             << endl;
                         uid = upgradeUID( version, TStringToQString( itemsMap[ key ].toStringList().toString() ) );
                         if( m_verbose )
@@ -685,8 +685,8 @@ AFTTagger::handleMP4( TagLib::MP4::File *file )
             uid = createCurrentUID( file );
         if( m_verbose )
             m_textStream << tr( "INFO: Adding new field and saving file with UID: %1" ).arg( uid ) << endl;
-        itemsMap.insert( Qt4QStringToTString( QString( "----:com.apple.iTunes:" + ourId ) ),
-                         TagLib::StringList( Qt4QStringToTString( uid ) ) );
+        itemsMap.insert( Qt5QStringToTString( QString( "----:com.apple.iTunes:" + ourId ) ),
+                         TagLib::StringList( Qt5QStringToTString( uid ) ) );
         file->save();
         return true;
     }
@@ -713,18 +713,18 @@ AFTTagger::createV1UID( TagLib::File *file )
     QCryptographicHash md5( QCryptographicHash::Md5 );
     QByteArray size;
     md5.addData( size.setNum( (qulonglong)(file->length()) ) );
-    md5.addData( QString::number( m_time.elapsed() ).toAscii() );
-    md5.addData( QString::number( qrand() ).toAscii() );
-    md5.addData( QString::number( qrand() ).toAscii() );
-    md5.addData( QString::number( qrand() ).toAscii() );
-    md5.addData( QString::number( qrand() ).toAscii() );
-    md5.addData( QString::number( qrand() ).toAscii() );
-    md5.addData( QString::number( m_time.elapsed() ).toAscii() );
+    md5.addData( QString::number( m_time.elapsed() ).toUtf8() );
+    md5.addData( QString::number( qrand() ).toUtf8() );
+    md5.addData( QString::number( qrand() ).toUtf8() );
+    md5.addData( QString::number( qrand() ).toUtf8() );
+    md5.addData( QString::number( qrand() ).toUtf8() );
+    md5.addData( QString::number( qrand() ).toUtf8() );
+    md5.addData( QString::number( m_time.elapsed() ).toUtf8() );
     return QString( md5.result().toHex() );
 }
 
 QString
-AFTTagger::upgradeUID( int version, QString currValue )
+AFTTagger::upgradeUID( int version, const QString &currValue )
 {
     Q_UNUSED(version)
     return currValue + "abcd";
@@ -747,18 +747,18 @@ AFTTagger::readArgs()
         {
             m_fileFolderList.append( arg );
         }
-        else if( arg.startsWith( "--" ) )
+        else if( arg.startsWith( QLatin1String("--") ) )
         {
             QString myarg = QString( arg ).remove( 0, 2 );
-            if ( myarg == "recurse" || myarg == "recursively" )
+            if ( myarg == QLatin1String("recurse") || myarg == QLatin1String("recursively") )
                 m_recurse = true;
-            else if( myarg == "verbose" )
+            else if( myarg == QLatin1String("verbose") )
                 m_verbose = true;
-            else if( myarg == "quiet" )
+            else if( myarg == QLatin1String("quiet") )
                 m_quiet = true;
-            else if( myarg == "newid" )
+            else if( myarg == QLatin1String("newid") )
                 m_newid = true;
-            else if( myarg == "delete" )
+            else if( myarg == QLatin1String("delete") )
                 m_delete = true;
             else
                 displayHelp();
